@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2016 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,9 +20,7 @@
 
 #include <QApplication>
 #include <QLocale>
-#include <QLibraryInfo>
 #include <QIcon>
-#include <QTranslator>
 #include <stdio.h>
 #include <stdlib.h>
 #ifdef Q_OS_WIN
@@ -33,7 +31,7 @@
 #include <qmmp/qmmp.h>
 #include "qmmpstarter.h"
 
-#if defined(Q_OS_UNIX) && (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+#ifdef Q_OS_UNIX
 #include <QSettings>
 #endif
 
@@ -43,8 +41,9 @@ int main(int argc, char *argv[])
     //allows to activate main window from other instances
     AllowSetForegroundWindow(ASFW_ANY);
 #endif
+    QCoreApplication::setQuitLockEnabled(false);
 
-#if defined(Q_OS_UNIX) && (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+#ifdef Q_OS_UNIX
     //using XWayland for skinned user interface
     if(qEnvironmentVariable("XDG_SESSION_TYPE") == QLatin1String("wayland") && !qEnvironmentVariableIsSet("QT_QPA_PLATFORM"))
     {
@@ -55,27 +54,20 @@ int main(int argc, char *argv[])
 #endif
 
     QApplication a(argc, argv);
-    a.setApplicationName("qmmp");
+    a.setApplicationName(u"qmmp"_s);
+    a.setOrganizationName(u"qmmp"_s);
+
     QIcon icon;
-    icon.addFile(":/16x16/qmmp-1.png");
-    icon.addFile(":/32x32/qmmp-1.png");
-    icon.addFile(":/48x48/qmmp-1.png");
-    icon.addFile(":/56x56/qmmp-1.png");
-    icon.addFile(":/64x64/qmmp-1.png");
-    icon.addFile(":/128x128/qmmp-1.png");
-    icon.addFile(":/256x256/qmmp-1.png");
-    icon.addFile(":/scalable/qmmp-1.svgz");
+    icon.addFile(u":/16x16/qmmp-1.png"_s);
+    icon.addFile(u":/32x32/qmmp-1.png"_s);
+    icon.addFile(u":/48x48/qmmp-1.png"_s);
+    icon.addFile(u":/56x56/qmmp-1.png"_s);
+    icon.addFile(u":/64x64/qmmp-1.png"_s);
+    icon.addFile(u":/128x128/qmmp-1.png"_s);
+    icon.addFile(u":/256x256/qmmp-1.png"_s);
+    icon.addFile(u":/scalable/qmmp-1.svgz"_s);
     a.setWindowIcon(icon);
 
-    QTranslator translator;
-    QString locale = Qmmp::systemLanguageID();
-    if(translator.load(QString(":/qmmp_") + locale))
-        a.installTranslator(&translator);
-
-    QTranslator qt_translator;
-    if(qt_translator.load(QLibraryInfo::location(QLibraryInfo::TranslationsPath) + "/qtbase_" + locale))
-        a.installTranslator(&qt_translator);
-
     QMMPStarter starter;
 
     if(starter.isFinished())
