@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,6 +24,9 @@
 #include <QLocalSocket>
 #include <QSettings>
 #include <QIcon>
+#include <QProcess>
+#include <QTranslator>
+#include <QLibraryInfo>
 #include <cstdlib>
 #include <iostream>
 #include <unistd.h>
@@ -48,98 +51,125 @@
 #endif
 
 #ifdef Q_OS_WIN
-#define UDS_PATH QString("qmmp")
+#define UDS_PATH QStringLiteral("qmmp")
 #else
-#define UDS_PATH QString("/tmp/qmmp.sock.%1").arg(getuid()).toLatin1().constData()
+#define UDS_PATH QStringLiteral("/tmp/qmmp.sock.%1").arg(getuid())
 #endif
 
 using namespace std;
 
 QMMPStarter::QMMPStarter() : QObject()
 {
+    if(qApp->arguments().contains(u"--debug"_s))
+    {
+        qSetMessagePattern(u"[%{type}]: %{function}: %{message}"_s);
+        QLoggingCategory::setFilterRules(u"qmmp.core.debug=true\nqmmp.plugin.debug=true"_s);
+    }
+    else
+    {
+        qSetMessagePattern(u"%{function}: %{message}"_s);
+    }
+
 #ifndef QT_NO_SESSIONMANAGER
-    connect(qApp, SIGNAL(commitDataRequest(QSessionManager&)), SLOT(commitData(QSessionManager&)), Qt::DirectConnection);
+    connect(qApp, &QApplication::commitDataRequest, this, &QMMPStarter::commitData, Qt::DirectConnection);
 #endif
+    createPaths();
 #ifdef Q_OS_WIN
-    m_named_mutex = nullptr;
+    QString defaultConfig = Qmmp::dataPath() + QStringLiteral("/qmmp-default.ini");
+    QString userConfig = Qmmp::configDir() + QStringLiteral("/qmmp.ini");
+    if(!QFile::exists(userConfig) && QFile::exists(defaultConfig))
+    {
+        qCDebug(core) << "creating initial config";
+        QFile::copy(defaultConfig, userConfig);
+    }
+
+    QFileInfo configDirInfo(Qmmp::configDir());
+    QCoreApplication::setOrganizationName(configDirInfo.fileName());
+    QSettings::setDefaultFormat(QSettings::IniFormat);
+    QSettings::setPath(QSettings::IniFormat, QSettings::UserScope, configDirInfo.canonicalPath());
 #endif
-    createInitialConfig();
+
+    QTranslator *translator = new QTranslator(qApp);
+    QString locale = Qmmp::systemLanguageID();
+    if(translator->load((u":/qmmp_"_s) + locale))
+        qApp->installTranslator(translator);
+
+    QTranslator *qt_translator = new QTranslator(qApp);
+    if(qt_translator->load(QLibraryInfo::location(QLibraryInfo::TranslationsPath) + u"/qtbase_"_s + locale))
+        qApp->installTranslator(qt_translator);
+
     m_option_manager = new BuiltinCommandLineOption(this);
+    m_option_manager->registerOprions();
     QStringList tmp = qApp->arguments().mid(1);
 
-    argString = tmp.join("|||");
-    QHash <QString, QStringList> commands = m_option_manager->splitArgs(tmp);
+    argString = tmp.join(u"|||"_s);
+    QHash<QString, QStringList> commands = m_option_manager->splitArgs(tmp);
 
-    if(commands.keys().contains("--help") || commands.keys().contains("-h"))
+    if(commands.contains(u"--help"_s) || commands.contains(u"-h"_s))
     {
         printUsage();
         m_finished = true;
         return;
     }
-    if(commands.keys().contains("--version") || commands.keys().contains("-v"))
+    if(commands.contains(u"--version"_s) || commands.contains(u"-v"_s))
     {
         printVersion();
         m_finished = true;
         return;
     }
-    if(commands.keys().contains("--ui-list"))
+    if(commands.contains(u"--ui-list"_s))
     {
         printUserInterfaces();
         m_finished = true;
         return;
     }
-    if(commands.keys().contains("--ui"))
+    if(commands.contains(u"--ui"_s))
     {
-        QStringList args = commands.value("--ui");
+        QStringList args = commands.value(u"--ui"_s);
         if(args.size() == 1)
-            UiLoader::select(args.first());
+            UiLoader::select(args.constFirst());
     }
 
-    if(!commands.isEmpty())
-    {
-        for(const QString &key : commands.keys())
-        {
-            CommandLineHandler::OptionFlags flags;
-            if(!m_option_manager->identify(key) &&
-                    !CommandLineManager::hasOption(key, &flags) &&
-                    key != "--no-start" &&
-                    key != "--ui")
-            {
-                cout << qPrintable(tr("Unknown command")) << endl;
-                m_exit_code = EXIT_FAILURE;
-                m_finished = true;
-                return;
-            }
 
-            if(flags & CommandLineHandler::NoStart)
+    for(auto it = commands.cbegin(); it != commands.cend(); ++it)
+    {
+        CommandLineHandler::OptionFlags flags;
+        if(!m_option_manager->identify(it.key()) && !CommandLineManager::hasOption(it.key(), &flags) &&
+                it.key() != u"--no-start"_s && it.key() != u"--ui"_s)
+        {
+            cout << qPrintable(tr("Unknown command")) << endl;
+            m_exit_code = EXIT_FAILURE;
+            m_finished = true;
+            return;
+        }
+
+        if(flags & CommandLineHandler::NoStart)
+        {
+            m_exit_code = EXIT_SUCCESS;
+            m_finished = true;
+            QString out = CommandLineManager::executeCommand(it.key(), it.value(), QDir::currentPath()).trimmed();
+            if(!out.isEmpty())
             {
-                m_exit_code = EXIT_SUCCESS;
-                m_finished = true;
-                QString out = CommandLineManager::executeCommand(key, commands.value(key)).trimmed();
-                if(!out.isEmpty())
-                {
-                    //show dialog with command line documentation under ms windows
+                //show dialog with command line documentation under ms windows
 #ifdef Q_OS_WIN
-                    stringstream tmp_stream;
-                    tmp_stream.copyfmt(cout);
-                    streambuf *old_stream = cout.rdbuf(tmp_stream.rdbuf());
+                stringstream tmp_stream;
+                tmp_stream.copyfmt(cout);
+                streambuf *old_stream = cout.rdbuf(tmp_stream.rdbuf());
 #endif
-                    cout << qPrintable(out.trimmed()) << endl;
+                cout << qPrintable(out.trimmed()) << endl;
 #ifdef Q_OS_WIN
-                    string text = tmp_stream.str();
-                    QMessageBox::information(nullptr, tr("Command Line Help"), QString::fromLocal8Bit(text.c_str()));
-                    cout.rdbuf(old_stream); //restore old stream buffer
+                string text = tmp_stream.str();
+                QMessageBox::information(nullptr, tr("Command Line Help"), QString::fromLocal8Bit(text.c_str()));
+                cout.rdbuf(old_stream); //restore old stream buffer
 #endif
-                }
-                return;
             }
+            return;
         }
     }
 
-
     m_server = new QLocalServer(this);
     m_socket = new QLocalSocket(this);
-    bool noStart = commands.keys().contains("--no-start") || commands.keys().contains("--quit");
+    bool noStart = commands.contains(u"--no-start"_s) || commands.contains(u"--quit"_s);
 
 #ifdef Q_OS_WIN
     //Windows IPC implementation (named mutex and named pipe)
@@ -155,7 +185,7 @@ QMMPStarter::QMMPStarter() : QObject()
         m_socket->waitForConnected();
         if(!m_socket->isValid()) //invalid connection
         {
-            qWarning("QMMPStarter: unable to connect to server");
+            qCWarning(core, "unable to connect to server");
             m_exit_code = EXIT_FAILURE;
             m_finished = true;
             return;
@@ -163,10 +193,10 @@ QMMPStarter::QMMPStarter() : QObject()
         writeCommand();
     }
 #else
-    if(!noStart && m_server->listen (UDS_PATH)) //trying to create server
+    if(!noStart && m_server->listen(UDS_PATH)) //trying to create server
     {
 #ifndef Q_OS_WIN
-        chmod(UDS_PATH, S_IRUSR | S_IWUSR);
+        chmod(UDS_PATH.toLocal8Bit().constData(), S_IRUSR | S_IWUSR);
 #endif
         startPlayer();
     }
@@ -178,28 +208,29 @@ QMMPStarter::QMMPStarter() : QObject()
         {
             if(!QLocalServer::removeServer(UDS_PATH))
             {
-                qWarning("QMMPStarter: unable to remove invalid socket file");
+                qCWarning(core, "unable to remove invalid socket file");
                 m_exit_code = EXIT_FAILURE;
                 m_finished = true;
                 return;
             }
-            qWarning("QMMPStarter: removed invalid socket file");
+            qCWarning(core, "removed invalid socket file");
             if(noStart)
             {
                 m_exit_code = EXIT_FAILURE;
                 m_finished = true;
                 return;
             }
-            else if(m_server->listen (UDS_PATH))
+
+            if(m_server->listen(UDS_PATH))
             {
 #ifndef Q_OS_WIN
-                chmod(UDS_PATH, S_IRUSR | S_IWUSR);
+                chmod(UDS_PATH.toLocal8Bit().constData(), S_IRUSR | S_IWUSR);
 #endif
                 startPlayer();
             }
             else
             {
-                qWarning("QMMPStarter: server error: %s", qPrintable(m_server->errorString()));
+                qCWarning(core, "server error: %s", qPrintable(m_server->errorString()));
                 m_exit_code = EXIT_FAILURE;
                 m_finished = true;
                 return;
@@ -215,8 +246,7 @@ QMMPStarter::QMMPStarter() : QObject()
 
 QMMPStarter::~QMMPStarter()
 {
-    if (m_ui)
-        delete m_ui;
+    delete m_ui;
 #ifdef Q_OS_WIN
     if(m_named_mutex)
         ReleaseMutex(m_named_mutex);
@@ -235,19 +265,19 @@ int QMMPStarter::exitCode() const
 
 void QMMPStarter::startPlayer()
 {
-    connect(m_server, SIGNAL(newConnection()), SLOT(readCommand()));
-    QStringList args = argString.split("|||", QString::SkipEmptyParts);
+    connect(m_server, &QLocalServer::newConnection, this, &QMMPStarter::readCommand);
+    QStringList args = argString.split(u"|||"_s, Qt::SkipEmptyParts);
 
 #ifdef Q_OS_WIN
-    QIcon::setThemeSearchPaths(QStringList() << qApp->applicationDirPath() + "/themes/");
-    QIcon::setThemeName("oxygen");
+    QIcon::setThemeSearchPaths(QStringList{ qApp->applicationDirPath() + u"/themes/"_s });
+    QIcon::setThemeName(u"oxygen"_s);
 #else
     //add extra theme path;
     QStringList theme_paths = QIcon::themeSearchPaths();
-    QString share_path = qgetenv("XDG_DATA_HOME");
+    QString share_path = QString::fromLatin1(qgetenv("XDG_DATA_HOME"));
     if(share_path.isEmpty())
-        share_path = QDir::homePath() + "/.local/share";
-    theme_paths << share_path + "/icons";
+        share_path = QDir::homePath() + u"/.local/share"_s;
+    theme_paths << share_path + u"/icons"_s;
     theme_paths.removeDuplicates();
     QIcon::setThemeSearchPaths(theme_paths);
 #endif
@@ -265,44 +295,38 @@ void QMMPStarter::startPlayer()
         m_ui = factory->create();
     else
     {
-        qWarning("QMMPStarter: no user interface found");
+        qCWarning(core, "no user interface found");
         m_finished = true;
         m_exit_code = EXIT_FAILURE;
         return;
     }
-    connect(qApp, SIGNAL(aboutToQuit()), SLOT(savePosition()));
+    connect(qApp, &QApplication::aboutToQuit, this, &QMMPStarter::savePosition);
     processCommandArgs(args, QDir::currentPath());
     if(args.isEmpty())
     {
         QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-        settings.beginGroup("General");
-        if(settings.value("resume_playback", false).toBool())
+        settings.beginGroup(u"General"_s);
+        if(settings.value(u"resume_playback"_s, false).toBool())
         {
-            qint64 pos =  settings.value("resume_playback_time").toLongLong();
-            m_player->play(pos);
+            qint64 pos =  settings.value(u"resume_playback_time"_s).toLongLong();
+            m_player->playFromPosition(pos);
         }
     }
 }
 
-void QMMPStarter::createInitialConfig()
+void QMMPStarter::createPaths()
 {
-    QString defaultConfig = Qmmp::dataPath() + "/qmmprc.default";
-
-    if(!QFile::exists(Qmmp::configFile()) && QFile::exists(defaultConfig))
-    {
-        qDebug("QMMPStarter: creating initial config");
-        QDir("/").mkpath(Qmmp::configDir());
-        QFile::copy(defaultConfig, Qmmp::configFile());
-    }
+    QDir(u"/"_s).mkpath(Qmmp::configDir());
+    QDir(u"/"_s).mkpath(Qmmp::cacheDir());
 }
 
 void QMMPStarter::savePosition()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("General");
-    settings.setValue("resume_playback",m_core->state() == Qmmp::Playing &&
+    settings.beginGroup(u"General"_s);
+    settings.setValue(u"resume_playback"_s, m_core->state() == Qmmp::Playing &&
                       QmmpUiSettings::instance()->resumeOnStartup());
-    settings.setValue("resume_playback_time", m_core->duration() > 0 ? m_core->elapsed() : 0);
+    settings.setValue(u"resume_playback_time"_s, m_core->duration() > 0 ? m_core->elapsed() : 0);
     settings.endGroup();
     m_core->stop();
 }
@@ -318,10 +342,10 @@ void QMMPStarter::commitData(QSessionManager &manager)
 
 void QMMPStarter::writeCommand()
 {
-    QString workingDir = QDir::currentPath() + "|||";
+    QString workingDir = QDir::currentPath() + u"|||"_s;
     QByteArray barray;
     barray.append(workingDir.toUtf8 ());
-    barray.append(argString.isEmpty() ? "--show-mw" : argString.toUtf8 ());
+    barray.append(argString.isEmpty() ? "--show-mw" : argString.toUtf8());
     while(!barray.isEmpty())
     {
         qint64 size = m_socket->write(barray);
@@ -330,7 +354,7 @@ void QMMPStarter::writeCommand()
     m_socket->flush();
     //reading answer
     while(m_socket->waitForReadyRead(1500))
-        cout << m_socket->readAll().data();
+        cout << m_socket->readAll().constData();
 
 #ifndef Q_OS_WIN
     if (argString.isEmpty())
@@ -350,7 +374,7 @@ void QMMPStarter::readCommand()
         socket->deleteLater();
         return;
     }
-    QStringList slist = QString::fromUtf8(inputArray.data()).split("|||",QString::SkipEmptyParts);
+    QStringList slist = QString::fromUtf8(inputArray.data()).split(u"|||"_s, Qt::SkipEmptyParts);
     QString cwd = slist.takeAt(0);
     QString out = processCommandArgs(slist, cwd);
     if(!out.isEmpty())
@@ -368,29 +392,32 @@ QString QMMPStarter::processCommandArgs(const QStringList &slist, const QString&
     if(slist.isEmpty())
         return QString();
     QStringList paths;
-    for(const QString &arg : qAsConst(slist)) //detect file/directory paths
+    for(const QString &arg : std::as_const(slist)) //detect file/directory paths
     {
-        if(arg.startsWith("-"))
+        if(arg.startsWith(QLatin1Char('-')))
             break;
         paths.append(arg);
     }
     if(!paths.isEmpty())
     {
-        return m_option_manager->executeCommand(QString(), paths, cwd); //add paths only
+        return m_option_manager->executeCommand(BuiltinCommandLineOption::OPEN, paths, cwd); //add paths only
     }
     QHash<QString, QStringList> commands = m_option_manager->splitArgs(slist);
     if(commands.isEmpty())
         return QString();
 
     QString out;
-    for(const QString &key : commands.keys())
+    for(auto it = commands.cbegin(); it != commands.cend(); ++it)
     {
-        if(key == "--no-start" || key == "--ui")
+        if(it.key() == "--no-start"_L1 || it.key() == "--ui"_L1)
             continue;
-        if (CommandLineManager::hasOption(key))
-            return CommandLineManager::executeCommand(key, commands.value(key));
-        else if (m_option_manager->identify(key))
-            out += m_option_manager->executeCommand(key, commands.value(key), cwd);
+
+        if (CommandLineManager::hasOption(it.key()))
+            return CommandLineManager::executeCommand(it.key(), it.value(), cwd);
+
+        int id = m_option_manager->identify(it.key());
+        if(id >= 0)
+            out += m_option_manager->executeCommand(id, it.value(), cwd);
         else
             return QString();
     }
@@ -412,16 +439,17 @@ void QMMPStarter::printUsage()
         cout << qPrintable(CommandLineManager::formatHelpString(line) ) << endl;
     CommandLineManager::printUsage();
     QStringList extraHelp;
-    extraHelp << QString("--ui <name>") + "||" + tr("Start qmmp with the specified user interface");
-    extraHelp << QString("--ui-list") + "||" + tr("List all available user interfaces");
-    extraHelp << QString("--no-start") + "||" + tr("Don't start the application");
-    extraHelp << QString("-h, --help") + "||" + tr("Display this text and exit");
-    extraHelp << QString("-v, --version") + "||" + tr("Print version number and exit");
-    extraHelp << "";
-    extraHelp << tr("Home page: %1").arg("https://qmmp.ylsoftware.com");
-    extraHelp << tr("Development page: %1").arg("https://sourceforge.net/p/qmmp-dev");
-    extraHelp << tr("Bug tracker: %1").arg("https://sourceforge.net/p/qmmp-dev/tickets");
-    for(const QString &line : qAsConst(extraHelp))
+    extraHelp << QStringLiteral("--ui <name>||") + tr("Start qmmp with the specified user interface");
+    extraHelp << QStringLiteral("--ui-list||") + tr("List all available user interfaces");
+    extraHelp << QStringLiteral("--no-start||") + tr("Don't start the application");
+    extraHelp << QStringLiteral("--debug||") + tr("Print debugging messages");
+    extraHelp << QStringLiteral("-h, --help||") + tr("Display this text and exit");
+    extraHelp << QStringLiteral("-v, --version||") + tr("Print version number and exit");
+    extraHelp << QString();
+    extraHelp << tr("Home page: %1").arg(u"https://qmmp.ylsoftware.com"_s);
+    extraHelp << tr("Development page: %1").arg(u"https://sourceforge.net/p/qmmp-dev"_s);
+    extraHelp << tr("Bug tracker: %1").arg(u"https://sourceforge.net/p/qmmp-dev/tickets"_s);
+    for(const QString &line : std::as_const(extraHelp))
         cout << qPrintable(CommandLineManager::formatHelpString(line)) << endl;
 #ifdef Q_OS_WIN
     string text = tmp_stream.str();
@@ -439,8 +467,8 @@ void QMMPStarter::printVersion()
     streambuf* old_stream = cout.rdbuf(tmp_stream.rdbuf());
 #endif
     cout << qPrintable(tr("QMMP version: %1").arg(Qmmp::strVersion())) << endl;
-    cout << qPrintable(tr("Compiled with Qt version: %1").arg(QT_VERSION_STR)) << endl;
-    cout << qPrintable(tr("Using Qt version: %1").arg(qVersion())) << endl;
+    cout << qPrintable(tr("Compiled with Qt version: %1").arg(QLatin1StringView(QT_VERSION_STR))) << endl;
+    cout << qPrintable(tr("Using Qt version: %1").arg(QString::fromLatin1(qVersion()))) << endl;
 #ifdef Q_OS_WIN
     string text = tmp_stream.str();
     QMessageBox::information(nullptr, tr("Qmmp Version"), QString::fromLocal8Bit(text.c_str()));
