@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -73,7 +73,7 @@ private:
     void printVersion();
     void printUserInterfaces();
     void startPlayer();
-    void createInitialConfig();
+    void createPaths();
 
 private:
     MediaPlayer *m_player = nullptr;
@@ -86,7 +86,7 @@ private:
     bool m_finished = false;
     int m_exit_code = EXIT_SUCCESS;
 #ifdef Q_OS_WIN
-    HANDLE m_named_mutex;
+    HANDLE m_named_mutex = nullptr;
 #endif
 };
 
