@@ -4,87 +4,87 @@
 <context>
     <name>BuiltinCommandLineOption</name>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="71"/>
+        <location filename="../builtincommandlineoption.cpp" line="46"/>
         <source>Don&apos;t clear the playlist</source>
-        <translation type="unfinished"></translation>
+        <translation>Çalma listesi temizleme</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="72"/>
+        <location filename="../builtincommandlineoption.cpp" line="47"/>
         <source>Start playing current song</source>
         <translation>Mevcut şarkıyı çalmaya başla</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="73"/>
+        <location filename="../builtincommandlineoption.cpp" line="48"/>
         <source>Pause current song</source>
         <translation>Mevcut şarkıyı duraklat</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="74"/>
+        <location filename="../builtincommandlineoption.cpp" line="49"/>
         <source>Pause if playing, play otherwise</source>
         <translation>Çalıyorsa duraklat, değilse oynat</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="75"/>
+        <location filename="../builtincommandlineoption.cpp" line="50"/>
         <source>Stop current song</source>
         <translation>Mevcut şarkıyı durdur</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="76"/>
-        <source>Display Jump to File dialog</source>
-        <translation>Dosyaya atlama diyaloğunu göster</translation>
+        <location filename="../builtincommandlineoption.cpp" line="51"/>
+        <source>Display Jump to Track dialog</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="77"/>
+        <location filename="../builtincommandlineoption.cpp" line="52"/>
         <source>Quit application</source>
-        <translation type="unfinished"></translation>
+        <translation>Uygulamadan çıkış yap</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="78"/>
+        <location filename="../builtincommandlineoption.cpp" line="53"/>
         <source>Set playback volume (example: qmmp --volume 20)</source>
-        <translation type="unfinished"></translation>
+        <translation>Kayıttan çalma ses seviyesini ayarlayın (örneğin: qmmp --volume 20)</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="79"/>
+        <location filename="../builtincommandlineoption.cpp" line="54"/>
         <source>Print volume level</source>
-        <translation type="unfinished"></translation>
+        <translation>Ses seviyesini bastır</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="80"/>
+        <location filename="../builtincommandlineoption.cpp" line="55"/>
         <source>Mute/Restore volume</source>
-        <translation type="unfinished"></translation>
+        <translation>Sesi kıs/Eski haline getir</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="81"/>
+        <location filename="../builtincommandlineoption.cpp" line="56"/>
         <source>Print mute status</source>
-        <translation type="unfinished"></translation>
+        <translation>Ses kısılı durumunu bastır</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="82"/>
+        <location filename="../builtincommandlineoption.cpp" line="57"/>
         <source>Skip forward in playlist</source>
         <translation>İleri atla</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="83"/>
+        <location filename="../builtincommandlineoption.cpp" line="58"/>
         <source>Skip backwards in playlist</source>
         <translation>Geri atla</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="84"/>
+        <location filename="../builtincommandlineoption.cpp" line="59"/>
         <source>Show/hide application</source>
         <translation>Uygulamayı göster/gizle</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="85"/>
+        <location filename="../builtincommandlineoption.cpp" line="60"/>
         <source>Show main window</source>
-        <translation type="unfinished"></translation>
+        <translation>Ana pencereyi göster</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="86"/>
+        <location filename="../builtincommandlineoption.cpp" line="61"/>
         <source>Display Add File dialog</source>
         <translation>Dosya ekleme diyaloğunu göster</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="87"/>
+        <location filename="../builtincommandlineoption.cpp" line="62"/>
         <source>Display Add Directory dialog</source>
         <translation>Dizin ekleme diyaloğunu göster</translation>
     </message>
@@ -92,90 +92,95 @@
 <context>
     <name>QMMPStarter</name>
     <message>
-        <location filename="../qmmpstarter.cpp" line="108"/>
+        <location filename="../qmmpstarter.cpp" line="140"/>
         <source>Unknown command</source>
-        <translation type="unfinished"></translation>
+        <translation>Bilinmeyen komut</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="408"/>
+        <location filename="../qmmpstarter.cpp" line="435"/>
         <source>Usage: qmmp [options] [files]</source>
         <translation>Kullanım:qmmp [seçenek] [dosyalar]</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="409"/>
+        <location filename="../qmmpstarter.cpp" line="436"/>
         <source>Options:</source>
         <translation>Seçenekler:</translation>
     </message>
-    <message>
-        <location filename="../qmmpstarter.cpp" line="415"/>
-        <source>Start qmmp with the specified user interface</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../qmmpstarter.cpp" line="416"/>
-        <source>List all available user interfaces</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../qmmpstarter.cpp" line="417"/>
-        <source>Don&apos;t start the application</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../qmmpstarter.cpp" line="418"/>
-        <source>Display this text and exit</source>
-        <translation>Bu metni göster ve çık</translation>
-    </message>
-    <message>
-        <location filename="../qmmpstarter.cpp" line="419"/>
-        <source>Print version number and exit</source>
-        <translation>Sürüm numarasını yazdır ve çık</translation>
-    </message>
-    <message>
-        <location filename="../qmmpstarter.cpp" line="421"/>
-        <source>Home page: %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../qmmpstarter.cpp" line="422"/>
-        <source>Development page: %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../qmmpstarter.cpp" line="423"/>
-        <source>Bug tracker: %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../qmmpstarter.cpp" line="130"/>
-        <location filename="../qmmpstarter.cpp" line="428"/>
-        <source>Command Line Help</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../qmmpstarter.cpp" line="441"/>
-        <source>QMMP version: %1</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../qmmpstarter.cpp" line="442"/>
-        <source>Compiled with Qt version: %1</source>
-        <translation type="unfinished"></translation>
+        <source>Start qmmp with the specified user interface</source>
+        <translation>Belirtilen kullanıcı arabirimiyle qmmp&apos;yi başlatın</translation>
     </message>
     <message>
         <location filename="../qmmpstarter.cpp" line="443"/>
-        <source>Using Qt version: %1</source>
+        <source>List all available user interfaces</source>
+        <translation>Mevcut tüm kullanıcı arayüzlerini listele</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="444"/>
+        <source>Don&apos;t start the application</source>
+        <translation>Uygulamayı başlatmayın</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="445"/>
+        <source>Print debugging messages</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../qmmpstarter.cpp" line="446"/>
-        <source>Qmmp Version</source>
-        <translation type="unfinished"></translation>
+        <source>Display this text and exit</source>
+        <translation>Bu metni göster ve çık</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="463"/>
+        <location filename="../qmmpstarter.cpp" line="447"/>
+        <source>Print version number and exit</source>
+        <translation>Sürüm numarasını yazdır ve çık</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="449"/>
+        <source>Home page: %1</source>
+        <translation>Ana sayfa: %1</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="450"/>
+        <source>Development page: %1</source>
+        <translation>Geliştirme sayfası: %1</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="451"/>
+        <source>Bug tracker: %1</source>
+        <translation>Hata izleyici: %1</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="162"/>
+        <location filename="../qmmpstarter.cpp" line="456"/>
+        <source>Command Line Help</source>
+        <translation>Komut Satırı Yardımı</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="469"/>
+        <source>QMMP version: %1</source>
+        <translation>QMMP sürümü: %1</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="470"/>
+        <source>Compiled with Qt version: %1</source>
+        <translation>Qt sürümüyle derlendi: %1</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="471"/>
+        <source>Using Qt version: %1</source>
+        <translation>Qt sürümü kullanılıyor: %1</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="474"/>
+        <source>Qmmp Version</source>
+        <translation>Qmmp Sürümü</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="491"/>
         <source>User Interfaces</source>
-        <translation type="unfinished"></translation>
+        <translation>Kullanıcı Arayüzleri</translation>
     </message>
 </context>
 </TS>
