@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov <forkotov02@ya.ru>              *
+ *   Copyright (C) 2009-2024 by Ilya Kotov <forkotov02@ya.ru>              *
  *   Copyright (C) 2009 by Sebastian Pipping <sebastian@pipping.org>       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,14 +26,10 @@
 
 CrossfadePlugin::CrossfadePlugin() : Effect()
 {
-    m_buffer = nullptr;
-    m_buffer_at = 0;
-    m_buffer_size = 0;
     m_core = SoundCore::instance() ;
     m_handler = StateHandler::instance();
-    m_state = WAITING;
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    m_overlap = settings.value("Crossfade/overlap", 6000).toLongLong();
+    m_overlap = settings.value(u"Crossfade/overlap"_s, 6000).toLongLong();
 }
 
 CrossfadePlugin::~CrossfadePlugin()
@@ -69,7 +65,7 @@ void CrossfadePlugin::applyEffect(Buffer *b)
                 m_buffer = (float *)realloc(m_buffer, m_buffer_size * sizeof(float));
                 if(!m_buffer)
                 {
-                    qWarning("CrossfadePlugin: unable to allocate  %zu bytes", m_buffer_size);
+                    qCWarning(plugin, "unable to allocate  %zu bytes", m_buffer_size);
                     m_buffer_size = 0;
                     if(tmp)
                         free(tmp);
@@ -113,7 +109,7 @@ void CrossfadePlugin::mix(float *cur_buf, float *prev_buf, uint samples, double
 {
     for (uint i = 0; i < samples; i++)
     {
-        cur_buf[i] = cur_buf[i]*(1.0 - volume) + prev_buf[i]*volume;
+        cur_buf[i] = cur_buf[i] * (1.0 - volume) + prev_buf[i]*volume;
         cur_buf[i] = qBound(-1.0f, cur_buf[i], 1.0f);
     }
 }
