@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2002-2003 Nick Lamb <njl195@zepler.org.uk>              *
  *   Copyright (C) 2005 Giacomo Lozito <city_hunter@users.sf.net>          *
- *   Copyright (C) 2009-2022 by Ilya Kotov <forkotov02@ya.ru>              *
+ *   Copyright (C) 2009-2024 by Ilya Kotov <forkotov02@ya.ru>              *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -23,7 +23,6 @@
 #include <QByteArray>
 #include <QDir>
 #include <QFileInfo>
-#include <QSettings>
 #include <math.h>
 #include <stdlib.h>
 #include <dlfcn.h>
@@ -46,21 +45,21 @@ LADSPAHost::LADSPAHost(QObject *parent) : QObject(parent)
     loadModules();
 
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    int pluginNumber = settings.value("LADSPA/plugin_number", 0).toInt();
+    int pluginNumber = settings.value(u"LADSPA/plugin_number"_s, 0).toInt();
     for(int i = 0; i < pluginNumber; ++i)
     {
-        QString section = QString("LADSPA_%1/").arg(i);
+        QString section = QStringLiteral("LADSPA_%1/").arg(i);
         settings.beginGroup(section);
 
-        int id = settings.value("id").toInt();
+        int id = settings.value("id"_L1).toInt();
         auto it = std::find_if(m_plugins.cbegin(), m_plugins.cend(), [id](LADSPAPlugin *p){ return p->unique_id == id; });
         if(it == m_plugins.cend())
             continue;
 
         LADSPAPlugin *plugin = *it;
         LADSPAEffect *effect = createEffect(plugin);
-        for(LADSPAControl *c : qAsConst(effect->controls))
-            c->value = settings.value(QString("port%1").arg(c->port), c->value).toFloat();
+        for(LADSPAControl *c : std::as_const(effect->controls))
+            c->value = settings.value(QStringLiteral("port%1").arg(c->port), c->value).toFloat();
 
         m_effects.append(effect);
         settings.endGroup();
@@ -71,20 +70,20 @@ LADSPAHost::~LADSPAHost()
 {
     m_instance = nullptr;
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    for(int i = 0; i < settings.value("LADSPA/plugin_number", 0).toInt(); ++i)
+    for(int i = 0; i < settings.value(u"LADSPA/plugin_number"_s, 0).toInt(); ++i)
     {
-        settings.remove(QString("LADSPA_%1/").arg(i));
+        settings.remove(QStringLiteral("LADSPA_%1/").arg(i));
     }
-    settings.setValue("LADSPA/plugin_number", m_effects.count());
+    settings.setValue("LADSPA/plugin_number"_L1, m_effects.count());
     for(int i = 0; i < m_effects.count(); ++i)
     {
-        QString section = QString("LADSPA_%1/").arg(i);
+        QString section = QStringLiteral("LADSPA_%1/").arg(i);
         settings.beginGroup(section);
 
-        settings.setValue("id", (quint64)m_effects[i]->plugin->desc->UniqueID);
+        settings.setValue(u"id"_s, (quint64)m_effects[i]->plugin->desc->UniqueID);
 
-        for(const LADSPAControl *c : qAsConst(m_effects[i]->controls))
-            settings.setValue(QString("port%1").arg(c->port), c->value);
+        for(const LADSPAControl *c : std::as_const(m_effects[i]->controls))
+            settings.setValue(QStringLiteral("port%1").arg(c->port), c->value);
 
         settings.endGroup();
     }
@@ -96,7 +95,7 @@ void LADSPAHost::configure(quint32 freq, int chan)
     m_chan = chan;
     m_freq = freq;
 
-    for(LADSPAEffect *e : qAsConst(m_effects))
+    for(LADSPAEffect *e : std::as_const(m_effects))
     {
         //deactivate effect
         deactivateEffect(e);
@@ -127,20 +126,20 @@ void LADSPAHost::loadModules()
     if(!m_modules.isEmpty())
         return;
 
-    QString ladspa_path = qgetenv("LADSPA_PATH");
+    QString ladspa_path = QString::fromLocal8Bit(qgetenv("LADSPA_PATH"));
     QStringList directories;
 
     if (ladspa_path.isEmpty())
     {
         /* Fallback, look in obvious places */
-        directories << "/usr/lib/ladspa";
-        directories << "/usr/local/lib/ladspa";
-        directories << "/usr/lib64/ladspa";
-        directories << "/usr/local/lib64/ladspa";
+        directories << u"/usr/lib/ladspa"_s;
+        directories << u"/usr/local/lib/ladspa"_s;
+        directories << u"/usr/lib64/ladspa"_s;
+        directories << u"/usr/local/lib64/ladspa"_s;
     }
     else
-        directories = ladspa_path.split(':');
-    for(const QString &dir : qAsConst(directories))
+        directories = ladspa_path.split(QLatin1Char(':'));
+    for(const QString &dir : std::as_const(directories))
         findModules(dir);
 }
 
@@ -149,9 +148,9 @@ void LADSPAHost::findModules(const QString &path)
     QDir dir (path);
     dir.setFilter(QDir::Files | QDir::Hidden);
     dir.setSorting(QDir::Name);
-    const QFileInfoList files = dir.entryInfoList((QStringList() << "*.so"));
+    const QFileInfoList files = dir.entryInfoList({ u"*.so"_s });
 
-    for(const QFileInfo &file : qAsConst(files))
+    for(const QFileInfo &file : std::as_const(files))
     {
         void *library = dlopen(qPrintable(file.absoluteFilePath ()), RTLD_LAZY);
         if (!library)
@@ -173,11 +172,11 @@ void LADSPAHost::findModules(const QString &path)
         {
             if(LADSPA_IS_INPLACE_BROKEN(descriptor->Properties))
             {
-                qWarning("LADSPAHost: plugin %s is ignored due to LADSPA_PROPERTY_INPLACE_BROKEN property", descriptor->Name);
+                qCWarning(plugin, "plugin %s is ignored due to LADSPA_PROPERTY_INPLACE_BROKEN property", descriptor->Name);
                 continue;
             }
             LADSPAPlugin *plugin = new LADSPAPlugin;
-            plugin->name = descriptor->Name;
+            plugin->name = QString::fromLocal8Bit(descriptor->Name);
             plugin->id = k;
             plugin->unique_id = descriptor->UniqueID;
             plugin->desc = descriptor;
@@ -230,7 +229,7 @@ LADSPAControl *LADSPAHost::createControl(const LADSPA_Descriptor *desc, unsigned
     LADSPA_Data fact, min, max, step, start;
 
     LADSPAControl *c = new LADSPAControl;
-    c->name = QString(desc->PortNames[port]);
+    c->name = QString::fromLocal8Bit(desc->PortNames[port]);
     c->port = port;
 
     if (LADSPA_IS_HINT_TOGGLED(hint.HintDescriptor))
@@ -318,14 +317,15 @@ void LADSPAHost::activateEffect(LADSPAEffect *e)
 
     if(e->out_ports.isEmpty())
     {
-        qWarning("LADSPAHost: unsupported plugin: %s", desc->Name);
+        qCWarning(plugin, "unsupported plugin: %s", desc->Name);
         return;
     }
-    else if(e->in_ports.isEmpty())
+
+    if(e->in_ports.isEmpty())
     {
         if(m_chan % e->out_ports.count())
         {
-            qWarning("LADSPAHost: plugin %s does not support %d channels", desc->Name, m_chan);
+            qCWarning(plugin, "plugin %s does not support %d channels", desc->Name, m_chan);
             return;
         }
         instance_count = m_chan / e->out_ports.count();
@@ -334,14 +334,14 @@ void LADSPAHost::activateEffect(LADSPAEffect *e)
     {
         if(m_chan % e->in_ports.count())
         {
-            qWarning("LADSPAHost: plugin %s does not support %d channels", desc->Name, m_chan);
+            qCWarning(plugin, "plugin %s does not support %d channels", desc->Name, m_chan);
             return;
         }
         instance_count = m_chan / e->in_ports.count();
     }
     else
     {
-        qWarning("LADSPAHost: unsupported plugin: %s", desc->Name);
+        qCWarning(plugin, "unsupported plugin: %s", desc->Name);
         return;
     }
 
@@ -349,16 +349,21 @@ void LADSPAHost::activateEffect(LADSPAEffect *e)
     for(int i = 0; i < instance_count; ++i)
     {
         LADSPA_Handle handle = desc->instantiate(desc, m_freq);
+        if(!handle)
+        {
+            qCWarning(plugin, "failed to instantiate plugin: %s", desc->Name);
+            continue;
+        }
 
-        for(LADSPAControl *c : qAsConst(e->controls))
+        for(LADSPAControl *c : std::as_const(e->controls))
         {
             desc->connect_port(handle, c->port, &c->value);
         }
-        for(int port : qAsConst(e->in_ports))
+        for(int port : std::as_const(e->in_ports))
         {
             desc->connect_port(handle, port, m_buf[in_at++]);
         }
-        for(int port : qAsConst(e->out_ports))
+        for(int port : std::as_const(e->out_ports))
         {
             desc->connect_port(handle, port, m_buf[out_at++]);
         }
@@ -372,7 +377,7 @@ void LADSPAHost::activateEffect(LADSPAEffect *e)
 void LADSPAHost::deactivateEffect(LADSPAEffect *e)
 {
     const LADSPA_Descriptor *desc = e->plugin->desc;
-    for(const LADSPA_Handle &handle : qAsConst(e->handles))
+    for(const LADSPA_Handle &handle : std::as_const(e->handles))
     {
         if(desc->deactivate)
             desc->deactivate(handle);
@@ -386,7 +391,7 @@ const QList<LADSPAPlugin *> &LADSPAHost::plugins() const
     return m_plugins;
 }
 
-const QList <LADSPAEffect *> &LADSPAHost::effects() const
+const QList<LADSPAEffect *> &LADSPAHost::effects() const
 {
     return m_effects;
 }
