@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2016-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2016-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -27,8 +27,8 @@
 SoXResampler::SoXResampler() : Effect()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    m_overSamplingFs = settings.value("SOXR/sample_rate", 48000).toInt();
-    m_quality = soxr_quality_spec(settings.value("SOXR/quality", SOXR_HQ).toInt(), 0);
+    m_overSamplingFs = settings.value(u"SOXR/sample_rate"_s, 48000).toInt();
+    m_quality = soxr_quality_spec(settings.value(u"SOXR/quality"_s, SOXR_HQ).toInt(), 0);
 }
 
 SoXResampler::~SoXResampler()
