@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -27,7 +27,6 @@
 #include <QRegularExpression>
 #include <QSettings>
 #include <QFileInfo>
-#include <QDebug>
 #include <QDir>
 #include <qmmp/trackinfo.h>
 #include <qmmp/inputsource.h>
@@ -38,20 +37,20 @@
 
 TrackInfo *MplayerInfo::createTrackInfo(const QString &path)
 {
-    QRegularExpression rx_id_length("^ID_LENGTH=([0-9,.]+)*");
-    QRegularExpression rx_id_audio_bitrate("^ID_AUDIO_BITRATE=([0-9,.]+)*");
-    QRegularExpression rx_id_audio_rate("^ID_AUDIO_RATE=([0-9,.]+)*");
-    QRegularExpression rx_id_audio_nch("^ID_AUDIO_NCH=([0-9,.]+)*");
-    QRegularExpression rx_id_audio_codec("^ID_AUDIO_CODEC=(.*)");
-    QStringList args = { "-slave", "-identify", "-frames", "0", "-vo", "null", "-ao", "null", path };
+    static const QRegularExpression rx_id_length(u"^ID_LENGTH=([0-9,.]+)*"_s);
+    static const QRegularExpression rx_id_audio_bitrate(u"^ID_AUDIO_BITRATE=([0-9,.]+)*"_s);
+    static const QRegularExpression rx_id_audio_rate(u"^ID_AUDIO_RATE=([0-9,.]+)*"_s);
+    static const QRegularExpression rx_id_audio_nch(u"^ID_AUDIO_NCH=([0-9,.]+)*"_s);
+    static const QRegularExpression rx_id_audio_codec(u"^ID_AUDIO_CODEC=(.*)"_s);
+    const QStringList args = { u"-slave"_s, u"-identify"_s, u"-frames"_s, u"0"_s, u"-vo"_s, u"null"_s, u"-ao"_s, u"null"_s, path };
     QProcess mplayer_process;
-    mplayer_process.start("mplayer", args);
+    mplayer_process.start(u"mplayer"_s, args);
     mplayer_process.waitForFinished(1500);
     mplayer_process.kill();
     QString str = QString::fromLocal8Bit(mplayer_process.readAll()).trimmed();
     TrackInfo *info = new TrackInfo(path);
-    const QStringList lines = str.split("\n");
-    for(const QString &line : qAsConst(lines))
+    const QStringList lines = str.split(QChar::LineFeed);
+    for(const QString &line : std::as_const(lines))
     {
         QRegularExpressionMatch match;
 
@@ -67,35 +66,36 @@ TrackInfo *MplayerInfo::createTrackInfo(const QString &path)
             info->setValue(Qmmp::FORMAT_NAME, match.captured(1));
     }
     info->setValue(Qmmp::BITS_PER_SAMPLE, 32);
-    info->setValue(Qmmp::DECODER, "mplayer");
+    info->setValue(Qmmp::DECODER, u"mplayer"_s);
     info->setValue(Qmmp::FILE_SIZE, QFileInfo(path).size());
 #ifdef MPLAYER_DEBUG
-    qDebug("%s",qPrintable(str));
+    qCDebug(plugin) << str;
 #endif
     return info;
 }
 
 const QStringList &MplayerInfo::filters()
 {
-    static const QStringList filters = { "*.avi", "*.mpg", "*.mpeg", "*.divx", "*.qt", "*.mov", "*.wmv", "*.asf",
-                                         "*.flv", "*.3gp", "*.mkv", "*.mp4", "*.webm" };
+    static const QStringList filters = { u"*.avi"_s, u"*.mpg"_s, u"*.mpeg"_s, u"*.divx"_s, u"*.qt"_s,
+                                         u"*.mov"_s, u"*.wmv"_s, u"*.asf"_s, u"*.flv"_s, u"*.3gp"_s,
+                                         u"*.mkv"_s, u"*.mp4"_s, u"*.webm"_s };
     return filters;
 }
 
 bool MplayerInfo::supports(const QString &path)
 {
-    return QDir::match(filters(), path.section("/", -1));
+    return QDir::match(filters(), path.section(QLatin1Char('/'), -1));
 }
 
 MplayerEngine::MplayerEngine(QObject *parent)
         : AbstractEngine(parent)
 {
-    connect(VolumeHandler::instance(), SIGNAL(mutedChanged(bool)), SLOT(setMuted(bool)));
+    connect(VolumeHandler::instance(), &VolumeHandler::mutedChanged, this, &MplayerEngine::setMuted);
 }
 
 MplayerEngine::~MplayerEngine()
 {
-    qDebug("%s",__FUNCTION__);
+    qCDebug(plugin) << Q_FUNC_INFO;
     if(m_process)
         m_process->kill();
     while(!m_sources.isEmpty())
@@ -129,22 +129,22 @@ bool MplayerEngine::initialize()
     m_length = info->duration();
     delete info;
     m_args.clear();
-    m_args << "-slave";
+    m_args << u"-slave"_s;
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    QString ao_str = settings.value("mplayer/ao","default").toString();
-    QString vo_str = settings.value("mplayer/vo","default").toString();
-    if (ao_str != "default")
-        m_args << "-ao" << ao_str;
-    if (vo_str != "default")
-        m_args << "-vo" << vo_str;
+    QString ao_str = settings.value(u"mplayer/ao"_s, u"default"_s).toString();
+    QString vo_str = settings.value(u"mplayer/vo"_s, u"default"_s).toString();
+    if (ao_str != "default"_L1)
+        m_args << u"-ao"_s << ao_str;
+    if (vo_str != "default"_L1)
+        m_args << u"-vo"_s << vo_str;
 
-    if (settings.value("autosync", false).toBool())
-        m_args << "-autosync" << QString("%1").arg(settings.value("autosync_factor", 100).toInt());
+    if (settings.value(u"autosync"_s, false).toBool())
+        m_args << u"-autosync"_s << QString::number(settings.value(u"autosync_factor"_s, 100).toInt());
 
-    m_args << settings.value("cmd_options").toString().split(" ", QString::SkipEmptyParts);
+    m_args << settings.value(u"cmd_options"_s).toString().split(QChar::Space, Qt::SkipEmptyParts);
 
     if(m_source->offset() > 0)
-        m_args << "-ss" << QString("%1").arg(m_source->offset()/1000);
+        m_args << u"-ss"_s << QString::number(m_source->offset() / 1000);
     m_args << m_source->path();
     return true;
 }
@@ -152,7 +152,7 @@ bool MplayerEngine::initialize()
 void MplayerEngine::seek(qint64 pos)
 {
     if (m_process && m_process->state() == QProcess::Running)
-        m_process->write(QString("seek %1\n").arg(pos/1000 - m_currentTime).toLocal8Bit ());
+        m_process->write(QStringLiteral("seek %1\n").arg(pos/1000 - m_currentTime).toLocal8Bit());
 }
 
 void MplayerEngine::stop()
@@ -185,15 +185,15 @@ void MplayerEngine::setMuted(bool muted)
 
 void MplayerEngine::readStdOut()
 {
-    static const QRegularExpression rx_av("^[AV]: *([0-9,:.-]+)");
-    static const QRegularExpression rx_pause("^(.*)=(.*)PAUSE(.*)");
-    static const QRegularExpression rx_end("^(.*)End of file(.*)");
-    static const QRegularExpression rx_quit("^(.*)Quit(.*)");
-    static const QRegularExpression rx_audio("^AUDIO: *([0-9,.]+) *Hz.*([0-9,.]+) *ch.*([0-9]+).* ([0-9,.]+) *kbit.*");
-    static const QRegularExpression rx_audio2("^AUDIO: *([0-9,.]+) *Hz.*([0-9,.]+) *ch.*([a-z]+).* ([0-9,.]+) *kbit.*");
+    static const QRegularExpression rx_av(u"^[AV]: *([0-9,:.-]+)"_s);
+    static const QRegularExpression rx_pause(u"^(.*)=(.*)PAUSE(.*)"_s);
+    static const QRegularExpression rx_end(u"^(.*)End of file(.*)"_s);
+    static const QRegularExpression rx_quit(u"^(.*)Quit(.*)"_s);
+    static const QRegularExpression rx_audio(u"^AUDIO: *([0-9,.]+) *Hz.*([0-9,.]+) *ch.*([0-9]+).* ([0-9,.]+) *kbit.*"_s);
+    static const QRegularExpression rx_audio2(u"^AUDIO: *([0-9,.]+) *Hz.*([0-9,.]+) *ch.*([a-z]+).* ([0-9,.]+) *kbit.*"_s);
 
-    const QStringList lines = QString::fromLocal8Bit(m_process->readAll()).trimmed().split("\n");
-    for(const QString &line : qAsConst(lines))
+    const QStringList lines = QString::fromLocal8Bit(m_process->readAll()).trimmed().split(QChar::LineFeed);
+    for(const QString &line : std::as_const(lines))
     {
         QRegularExpressionMatch match;
 
@@ -253,7 +253,7 @@ void MplayerEngine::readStdOut()
         }
 #ifdef MPLAYER_DEBUG
         else
-            qDebug("%s",qPrintable(line));
+            qCDebug(plugin) << line;
 #endif
     }
 }
@@ -262,7 +262,7 @@ void MplayerEngine::onError(QProcess::ProcessError error)
 {
     if(error == QProcess::FailedToStart || error == QProcess::Crashed)
         StateHandler::instance()->dispatch(Qmmp::FatalError);
-    qWarning("MplayerEngine: process error: %d", error);
+    qCWarning(plugin, "process error: %d", error);
 }
 
 void MplayerEngine::onStateChanged(QProcess::ProcessState state)
@@ -274,13 +274,12 @@ void MplayerEngine::onStateChanged(QProcess::ProcessState state)
 void MplayerEngine::startMplayerProcess()
 {
     initialize();
-    if(m_process)
-        delete m_process;
+    delete m_process;
     m_process = new QProcess(this);
-    connect(m_process, SIGNAL(readyReadStandardOutput()), SLOT(readStdOut()));
-    connect(m_process, SIGNAL(error(QProcess::ProcessError)), SLOT(onError(QProcess::ProcessError)));
-    connect(m_process, SIGNAL(stateChanged(QProcess::ProcessState)), SLOT(onStateChanged(QProcess::ProcessState)));
-    m_process->start ("mplayer", m_args);
+    connect(m_process, &QProcess::readyReadStandardOutput, this, &MplayerEngine::readStdOut);
+    connect(m_process, &QProcess::errorOccurred, this, &MplayerEngine::onError);
+    connect(m_process, &QProcess::stateChanged, this, &MplayerEngine::onStateChanged);
+    m_process->start(u"mplayer"_s, m_args);
     StateHandler::instance()->dispatch(Qmmp::Playing);
     StateHandler::instance()->dispatch(m_length);
     TrackInfo *info = MplayerInfo::createTrackInfo(m_source->path());
