@@ -16,7 +16,7 @@
     <message>
         <location filename="../twopanelfiledialog.ui" line="80"/>
         <source>Files of type:</source>
-        <translation>Тип файлу:</translation>
+        <translation>Типи файлів:</translation>
     </message>
     <message>
         <location filename="../twopanelfiledialog.ui" line="117"/>
@@ -61,27 +61,27 @@
 <context>
     <name>TwoPanelFileDialogImpl</name>
     <message>
-        <location filename="../twopanelfiledialogimpl.cpp" line="338"/>
-        <location filename="../twopanelfiledialogimpl.cpp" line="354"/>
+        <location filename="../twopanelfiledialogimpl.cpp" line="321"/>
+        <location filename="../twopanelfiledialogimpl.cpp" line="337"/>
         <source>Add</source>
         <translation>Додати</translation>
     </message>
     <message>
-        <location filename="../twopanelfiledialogimpl.cpp" line="356"/>
+        <location filename="../twopanelfiledialogimpl.cpp" line="339"/>
         <source>Directories</source>
         <translation>Теки</translation>
     </message>
     <message>
-        <location filename="../twopanelfiledialogimpl.cpp" line="368"/>
+        <location filename="../twopanelfiledialogimpl.cpp" line="351"/>
         <source>Save</source>
         <translation>Зберегти</translation>
     </message>
     <message>
-        <location filename="../twopanelfiledialogimpl.cpp" line="478"/>
+        <location filename="../twopanelfiledialogimpl.cpp" line="457"/>
         <source>%1 already exists.
 Do you want to replace it?</source>
-        <translation>%1 вже існує.
-Бажаєте замінити?</translation>
+        <translation>%1 існує.
+Ви бажаєте замінити?</translation>
     </message>
 </context>
 </TS>
