@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2016 by Ilya Kotov                                      *
+*   Copyright (C) 2016-2024 by Ilya Kotov                                 *
 *   forkotov02@ya.ru                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -27,12 +27,12 @@
 TwoPanelFileDialog::TwoPanelFileDialog()
 {
     m_dialog = new TwoPanelFileDialogImpl();
-    connect(m_dialog, SIGNAL(filesSelected(QStringList, bool)), SIGNAL(filesSelected(QStringList,bool)));
+    connect(m_dialog, SIGNAL(filesSelected(QStringList,bool)), SIGNAL(filesSelected(QStringList,bool)));
 }
 
 TwoPanelFileDialog::~TwoPanelFileDialog()
 {
-    qWarning("%s", Q_FUNC_INFO);
+    qCWarning(plugin) << Q_FUNC_INFO;
     delete m_dialog;
 }
 void TwoPanelFileDialog::raise(const QString &dir, Mode mode, const QString &caption,
@@ -48,9 +48,9 @@ QStringList TwoPanelFileDialog::exec(QWidget *parent, const QString &dir, FileDi
 {
     TwoPanelFileDialogImpl *dialog = new TwoPanelFileDialogImpl(parent);
     dialog->setWindowTitle(caption);
-    dialog->setModeAndMask(dir, mode, filter.split(";;", QString::SkipEmptyParts));
+    dialog->setModeAndMask(dir, mode, filter.split(u";;"_s, Qt::SkipEmptyParts));
     QStringList l;
-    if (dialog->exec() == QDialog::Accepted)
+    if(dialog->exec() == QDialog::Accepted)
         l = dialog->selectedFiles();
     dialog->deleteLater();
     return l;
@@ -65,7 +65,7 @@ FileDialogProperties TwoPanelFileDialogFactory::properties() const
 {
     FileDialogProperties properties;
     properties.name = tr("Two-panel File Dialog");
-    properties.shortName = "twopanel_dialog";
+    properties.shortName = "twopanel_dialog"_L1;
     properties.hasAbout = true;
     properties.modal = false;
     return properties;
@@ -73,10 +73,10 @@ FileDialogProperties TwoPanelFileDialogFactory::properties() const
 
 void TwoPanelFileDialogFactory::showAbout(QWidget *parent)
 {
-    QMessageBox::about (parent, tr("About Two-panel File Dialog"),
-                        tr("Two-panel File Dialog") + "\n" +
-                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>") + "\n" +
-                        tr("Based on code from the Qt library"));
+    QMessageBox::about(parent, tr("About Two-panel File Dialog"),
+                       tr("Two-panel File Dialog") + QChar::LineFeed +
+                       tr("Written by: Ilya Kotov <forkotov02@ya.ru>") + QChar::LineFeed +
+                       tr("Based on code from the Qt library"));
 }
 
 QString TwoPanelFileDialogFactory::translation() const
