@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2011-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,6 +21,7 @@
 #include <stdio.h>
 #include <QStringList>
 #include <QStandardPaths>
+#include <QScopeGuard>
 #include <qmmp/inputsourcefactory.h>
 #include <qmmp/decoderfactory.h>
 #include <qmmp/metadatamanager.h>
@@ -38,7 +39,7 @@ Converter::Converter(QObject *parent) : QObject(parent), QRunnable()
 
 Converter::~Converter()
 {
-    qDebug("%s", Q_FUNC_INFO);
+    qCDebug(plugin) << Q_FUNC_INFO;
     if(m_decoder)
     {
         delete m_decoder;
@@ -51,14 +52,14 @@ Converter::~Converter()
     }
 }
 
-bool Converter::prepare(const QString &url, int row, const QVariantMap &preset)
+bool Converter::prepare(const QString &url, int row, const QVariantHash &preset)
 {
     m_row = row;
     InputSource *source = InputSource::create(url, this);
     if(!source->initialize())
     {
         delete source;
-        qWarning("Converter: Invalid url");
+        qCWarning(plugin, "invalid url");
         return false;
     }
 
@@ -67,7 +68,7 @@ bool Converter::prepare(const QString &url, int row, const QVariantMap &preset)
         if(!source->ioDevice()->open(QIODevice::ReadOnly))
         {
             source->deleteLater();
-            qWarning("Converter: cannot open input stream, error: %s",
+            qCWarning(plugin, "cannot open input stream, error: %s",
                      qPrintable(source->ioDevice()->errorString()));
             return false;
         }
@@ -75,27 +76,27 @@ bool Converter::prepare(const QString &url, int row, const QVariantMap &preset)
 
     DecoderFactory *factory = nullptr;
 
-    if(!source->path().contains("://"))
+    if(!source->path().contains(u"://"_s))
         factory = Decoder::findByFilePath(source->path());
     if(!factory)
         factory = Decoder::findByMime(source->contentType());
-    if(!factory && source->ioDevice() && source->path().contains("://")) //ignore content of local files
+    if(!factory && source->ioDevice() && source->path().contains(u"://"_s)) //ignore content of local files
         factory = Decoder::findByContent(source->ioDevice());
-    if(!factory && source->path().contains("://"))
-        factory = Decoder::findByProtocol(source->path().section("://",0,0));
+    if(!factory && source->path().contains(u"://"_s))
+        factory = Decoder::findByProtocol(source->path().section(u"://"_s, 0, 0));
     if(!factory)
     {
-        qWarning("Converter: unsupported file format");
+        qCWarning(plugin, "unsupported file format");
         source->deleteLater();
         return false;
     }
-    qDebug("Converter: selected decoder: %s",qPrintable(factory->properties().shortName));
+    qCDebug(plugin, "selected decoder: %s", qPrintable(factory->properties().shortName));
     if(factory->properties().noInput && source->ioDevice())
         source->ioDevice()->close();
     Decoder *decoder = factory->create(source->path(), source->ioDevice());
     if(!decoder->initialize())
     {
-        qWarning("Converter: invalid file format");
+        qCWarning(plugin, "invalid file format");
         source->deleteLater();
         delete decoder;
         return false;
@@ -118,7 +119,7 @@ void Converter::stop()
 
 void Converter::run()
 {
-    qDebug("Converter: staring thread");
+    qCDebug(plugin, "staring thread");
     if(m_user_stop)
     {
         emit message(m_row, tr("Cancelled"));
@@ -128,33 +129,33 @@ void Converter::run()
 
     AudioParameters ap = m_decoder->audioParameters();
     QString path = m_input->path();
-    QString out_path = m_preset["out_dir"].toString();
-    QString pattern = m_preset["file_name"].toString();
+    QString out_path = m_preset[u"out_dir"_s].toString();
+    QString pattern = m_preset[u"file_name"_s].toString();
 
     QList<TrackInfo *> list = MetaDataManager::instance()->createPlayList(path);
 
     if(list.isEmpty() || out_path.isEmpty() || pattern.isEmpty())
     {
-        qWarning("Converter: invalid parameters");
+        qCWarning(plugin, "invalid parameters");
         emit message(m_row, tr("Error"));
         return;
     }
 
-    TrackInfo info = *list.first();
+    TrackInfo info = *list.constFirst();
     qDeleteAll(list);
     list.clear();
     MetaDataFormatter formatter(pattern);
 
 
     QString name = formatter.format(info);
-    name.remove("'");
-    name.remove("\"");
-    name.remove(":");
-    QString full_path = out_path + "/" + name + "." + m_preset["ext"].toString();
+    name.remove(QLatin1Char('\''));
+    name.remove(QLatin1Char('"'));
+    name.remove(QLatin1Char('/'));
+    QString full_path = out_path + QLatin1Char('/') + name + QLatin1Char('.') + m_preset[u"ext"_s].toString();
 
     if(QFile::exists(full_path))
     {
-        if(m_preset["overwrite"].toBool()) //remove previous file
+        if(m_preset[u"overwrite"_s].toBool()) //remove previous file
             QFile::remove(full_path);
         else
         {
@@ -162,18 +163,18 @@ void Converter::run()
             while(QFile::exists(full_path)) //create file with another name
             {
                 ++i;
-                full_path = out_path + "/" + name + QString("_%1.").arg(i) + m_preset["ext"].toString();
+                full_path = out_path + QLatin1Char('/') + name + QStringLiteral("_%1.").arg(i) + m_preset[u"ext"_s].toString();
             }
         }
     }
 
-    QString command = m_preset["command"].toString();
-    command.replace("%o", "\"" + full_path + "\"");
-    QString tmp_path = QStandardPaths::writableLocation(QStandardPaths::TempLocation) + "/tmp.wav";
-    bool use_file = command.contains("%i");
-    command.replace("%i", "\"" + tmp_path + "\"");
+    QString command = m_preset[u"command"_s].toString();
+    command.replace(u"%o"_s, QLatin1Char('"') + full_path + QLatin1Char('"'));
+    QString tmp_path = QStandardPaths::writableLocation(QStandardPaths::TempLocation) + u"/tmp.wav"_s;
+    bool use_file = command.contains(u"%i"_s);
+    command.replace(u"%i"_s, QLatin1Char('"') + tmp_path + QLatin1Char('"'));
 
-    qDebug("Converter: starting task '%s'", qPrintable(m_preset["name"].toString()));
+    qCDebug(plugin) << "starting task" << m_preset[u"name"_s].toString();
     emit message(m_row, tr("Converting"));
 
     char wave_header[] = { 0x52, 0x49, 0x46, 0x46, //"RIFF"
@@ -188,7 +189,7 @@ void Converter::run()
                            0x64, 0x61, 0x74, 0x61, //"data"
                            0x00, 0x00, 0x00, 0x00 }; //chunk size*/
 
-    quint16 sample_size = m_preset["use_16bit"].toBool() ? 2 : ap.sampleSize();
+    quint16 sample_size = m_preset[u"use_16bit"_s].toBool() ? 2 : ap.sampleSize();
     quint32 sample_rate = qToLittleEndian(ap.sampleRate());
     quint16 channels = qToLittleEndian((quint16)ap.channels());
     quint16 block_align = qToLittleEndian((quint16)sample_size * ap.channels());
@@ -205,7 +206,7 @@ void Converter::run()
     FILE *enc_pipe = use_file ? fopen(qPrintable(tmp_path), "w+b") : popen(qPrintable(command), "w");
     if(!enc_pipe)
     {
-        qWarning("Converter: unable to open pipe");
+        qCWarning(plugin, "unable to open pipe");
         emit message(m_row, tr("Error"));
         return;
 
@@ -213,44 +214,44 @@ void Converter::run()
     size_t to_write = sizeof(wave_header);
     if(to_write != fwrite(&wave_header, 1, to_write, enc_pipe))
     {
-        qWarning("Converter: output file write error");
+        qCWarning(plugin, "output file write error");
         use_file ? fclose(enc_pipe) : pclose(enc_pipe);
         return;
     }
 
-    convert(m_decoder, enc_pipe, m_preset["use_16bit"].toBool());
+    convert(m_decoder, enc_pipe, m_preset[u"use_16bit"_s].toBool());
     use_file ? fclose(enc_pipe) : pclose(enc_pipe);
     m_mutex.lock();
     if(m_user_stop)
     {
-        qDebug("Converter: task '%s' aborted", qPrintable(m_preset["name"].toString()));
+        qCDebug(plugin, "task '%s' aborted", qPrintable(m_preset[u"name"_s].toString()));
         emit message(m_row, tr("Cancelled"));
         m_mutex.unlock();
         return;
     }
-    else
-        qDebug("Converter: task '%s' finished with success", qPrintable(m_preset["name"].toString()));
+
+    qCDebug(plugin, "task '%s' finished with success", qPrintable(m_preset[u"name"_s].toString()));
     m_mutex.unlock();
 
     if(use_file)
     {
-        qDebug("Converter: starting file encoding...");
+        qCDebug(plugin) << "starting file encoding...";
         emit message(m_row, tr("Encoding"));
         enc_pipe = popen(qPrintable(command), "w");
         if(!enc_pipe)
         {
-            qWarning("Converter: unable to start encoder");
+            qCWarning(plugin, "unable to start encoder");
             QFile::remove(tmp_path);
             return;
         }
         pclose(enc_pipe);
-        qDebug("Converter: encoding finished");
+        qCDebug(plugin) << "encoding finished";
         QFile::remove(tmp_path);
     }
 
-    if(m_preset["tags"].toBool())
+    if(m_preset[u"tags"_s].toBool())
     {
-        qDebug("Converter: writing tags");
+        qCDebug(plugin) << "writing tags";
         TagLib::FileRef file(qPrintable(full_path));
         if(file.tag())
         {
@@ -262,7 +263,7 @@ void Converter::run()
             file.tag()->setYear(info.value(Qmmp::YEAR).toUInt());
             file.tag()->setTrack(info.value(Qmmp::TRACK).toUInt());
 
-            if(full_path.endsWith(".mp3", Qt::CaseInsensitive))
+            if(full_path.endsWith(u".mp3"_s, Qt::CaseInsensitive))
             {
                 TagLib::MPEG::File *mpeg_file = dynamic_cast <TagLib::MPEG::File *> (file.file());
 #if ((TAGLIB_MAJOR_VERSION == 1) && (TAGLIB_MINOR_VERSION <= 11))
@@ -276,7 +277,7 @@ void Converter::run()
         }
     }
 
-    qDebug("Converter: thread finished");
+    qCDebug(plugin) << "thread finished";
     emit message(m_row, tr("Finished"));
     emit finished(this);
 }
@@ -308,16 +309,23 @@ bool Converter::convert(Decoder *decoder, FILE *file, bool use16bit)
 
     int outSampleSize = AudioParameters::sampleSize(outFormat);
 
-    unsigned char input_buffer[QMMP_BLOCK_FRAMES * ap.frameSize() * 4];
-    float converter_buffer[QMMP_BLOCK_FRAMES * ap.channels() * sizeof(float)];
-    unsigned char output_buffer[QMMP_BLOCK_FRAMES * outSampleSize * ap.channels() * 4];
+    unsigned char *input_buffer = new unsigned char[QMMP_BLOCK_FRAMES * ap.frameSize()];
+    float *converter_buffer = new float[QMMP_BLOCK_FRAMES * ap.channels()];
+    unsigned char *output_buffer = new unsigned char[QMMP_BLOCK_FRAMES * outSampleSize * ap.channels()];
+
+    auto cleanup = qScopeGuard([=] {
+        delete [] input_buffer;
+        delete [] converter_buffer;
+        delete [] output_buffer;
+
+    });
 
     emit progress(0);
 
     forever
     {
         // decode
-        len = decoder->read(input_buffer, sizeof(input_buffer));
+        len = decoder->read(input_buffer, QMMP_BLOCK_FRAMES * ap.frameSize());
 
         if (len > 0)
         {
@@ -334,7 +342,7 @@ bool Converter::convert(Decoder *decoder, FILE *file, bool use16bit)
                 len = fwrite(output_buffer, 1, output_at, file);
                 if(len == 0)
                 {
-                    qWarning("Converter: error");
+                    qCWarning(plugin, "error");
                     return false;
                 }
                 output_at -= len;
@@ -350,8 +358,8 @@ bool Converter::convert(Decoder *decoder, FILE *file, bool use16bit)
         else
         {
             emit progress(100);
-            qDebug("Converter: total written: %lld bytes", total);
-            qDebug("finished!");
+            qCDebug(plugin) << "total written:" << total << "bytes";
+            qCDebug(plugin) << "finished!";
             return true;
         }
 
