@@ -4,29 +4,29 @@
 <context>
     <name>Converter</name>
     <message>
-        <location filename="../converter.cpp" line="124"/>
-        <location filename="../converter.cpp" line="227"/>
+        <location filename="../converter.cpp" line="125"/>
+        <location filename="../converter.cpp" line="228"/>
         <source>Cancelled</source>
         <translation>Peruttu</translation>
     </message>
     <message>
-        <location filename="../converter.cpp" line="139"/>
-        <location filename="../converter.cpp" line="209"/>
+        <location filename="../converter.cpp" line="140"/>
+        <location filename="../converter.cpp" line="210"/>
         <source>Error</source>
         <translation>Virhe</translation>
     </message>
     <message>
-        <location filename="../converter.cpp" line="177"/>
+        <location filename="../converter.cpp" line="178"/>
         <source>Converting</source>
         <translation>Muuntaminen</translation>
     </message>
     <message>
-        <location filename="../converter.cpp" line="238"/>
+        <location filename="../converter.cpp" line="239"/>
         <source>Encoding</source>
         <translation>Koodaus</translation>
     </message>
     <message>
-        <location filename="../converter.cpp" line="280"/>
+        <location filename="../converter.cpp" line="281"/>
         <source>Finished</source>
         <translation>Valmis</translation>
     </message>
@@ -79,7 +79,7 @@
         <translation>Lopeta</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="113"/>
+        <location filename="../converterdialog.cpp" line="116"/>
         <source>Choose a directory</source>
         <translation>Valitse kansio</translation>
     </message>
@@ -89,34 +89,34 @@
         <translation>Nimi</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="203"/>
+        <location filename="../converterdialog.cpp" line="205"/>
         <source>Create a Copy</source>
         <translation>Luo kopio</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="134"/>
+        <location filename="../converterdialog.cpp" line="136"/>
         <location filename="../converterdialog.cpp" line="358"/>
-        <location filename="../converterdialog.cpp" line="364"/>
+        <location filename="../converterdialog.cpp" line="365"/>
         <source>Error</source>
         <translation>Virhe</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="139"/>
+        <location filename="../converterdialog.cpp" line="141"/>
         <source>Waiting</source>
         <translation>Odottaa</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="201"/>
+        <location filename="../converterdialog.cpp" line="203"/>
         <source>Create</source>
         <translation>Luo</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="202"/>
+        <location filename="../converterdialog.cpp" line="204"/>
         <source>Edit</source>
         <translation>Muokkaa</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="204"/>
+        <location filename="../converterdialog.cpp" line="206"/>
         <source>Delete</source>
         <translation>Poista</translation>
     </message>
@@ -126,7 +126,7 @@
         <translation>&quot;%1&quot; ei voida suorittaa. Ohjelmaa ei löydy.</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="364"/>
+        <location filename="../converterdialog.cpp" line="365"/>
         <source>Process &quot;%1&quot; finished with error.</source>
         <translation>Prosessi &quot;%1&quot; valmistui virheellisesti.</translation>
     </message>
@@ -173,59 +173,62 @@
     </message>
 </context>
 <context>
-    <name>PresetEditor</name>
+    <name>ConverterPresetEditor</name>
     <message>
-        <location filename="../preseteditor.ui" line="14"/>
+        <location filename="../converterpreseteditor.ui" line="14"/>
         <source>Preset Editor</source>
         <translation>Asetettu editori</translation>
     </message>
     <message>
-        <location filename="../preseteditor.ui" line="29"/>
+        <location filename="../converterpreseteditor.ui" line="29"/>
         <source>General</source>
         <translation>Yleiset</translation>
     </message>
     <message>
-        <location filename="../preseteditor.ui" line="35"/>
+        <location filename="../converterpreseteditor.ui" line="35"/>
         <source>Name:</source>
         <translation>Nimi:</translation>
     </message>
     <message>
-        <location filename="../preseteditor.ui" line="45"/>
+        <location filename="../converterpreseteditor.ui" line="45"/>
         <source>Extension:</source>
         <translation>Laajennus:</translation>
     </message>
     <message>
-        <location filename="../preseteditor.ui" line="58"/>
+        <location filename="../converterpreseteditor.ui" line="58"/>
         <source>Command</source>
         <translation>Komento</translation>
     </message>
     <message>
-        <location filename="../preseteditor.ui" line="77"/>
+        <location filename="../converterpreseteditor.ui" line="77"/>
         <source>Options</source>
         <translation>Valinnat</translation>
     </message>
     <message>
-        <location filename="../preseteditor.ui" line="83"/>
+        <location filename="../converterpreseteditor.ui" line="83"/>
         <source>Write tags</source>
         <translation>Kirjoita hakusanat</translation>
     </message>
     <message>
-        <location filename="../preseteditor.ui" line="90"/>
+        <location filename="../converterpreseteditor.ui" line="90"/>
         <source>Convert to 16 bit</source>
         <translation>Muunna 16-bittiseksi</translation>
     </message>
+</context>
+<context>
+    <name>PresetEditor</name>
     <message>
-        <location filename="../preseteditor.cpp" line="37"/>
+        <location filename="../converterpreseteditor.cpp" line="40"/>
         <source>%1 (Read Only)</source>
         <translation>%1 (vain luku)</translation>
     </message>
     <message>
-        <location filename="../preseteditor.cpp" line="70"/>
+        <location filename="../converterpreseteditor.cpp" line="73"/>
         <source>Output file</source>
         <translation>Tallennus tiedosto</translation>
     </message>
     <message>
-        <location filename="../preseteditor.cpp" line="71"/>
+        <location filename="../converterpreseteditor.cpp" line="74"/>
         <source>Input file</source>
         <translation>Tuo tiedosto</translation>
     </message>
