@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2012 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,6 +23,7 @@
 #include <QPaintEvent>
 #include <QMenu>
 #include <QAction>
+#include <QActionGroup>
 #include <QSettings>
 #include <qmmp/qmmp.h>
 #include <qmmpui/filedialog.h>
@@ -34,7 +35,7 @@ CoverWidget::CoverWidget(QWidget *parent)
     setWindowFlags(Qt::Window);
     setAttribute(Qt::WA_DeleteOnClose, true);
     m_menu = new QMenu(this);
-    m_menu->addAction(tr("&Save As..."), this, SLOT(saveAs()), tr("Ctrl+S"));
+    m_menu->addAction(tr("&Save As..."), this, &CoverWidget::saveAs, tr("Ctrl+S"));
     QMenu *sizeMenu = m_menu->addMenu(tr("Size"));
     QActionGroup *sizeGroup = new QActionGroup(this);
     sizeGroup->addAction(tr("Actual Size"))->setData(0);
@@ -43,14 +44,14 @@ CoverWidget::CoverWidget(QWidget *parent)
     sizeGroup->addAction(tr("512x512"))->setData(512);
     sizeGroup->addAction(tr("1024x1024"))->setData(1024);
     sizeMenu->addActions(sizeGroup->actions());
-    connect(sizeMenu, SIGNAL(triggered (QAction *)), SLOT(processResizeAction(QAction *)));
-    m_menu->addAction(tr("&Close"), this, SLOT(close()), tr("Alt+F4"));
+    connect(sizeMenu, &QMenu::triggered, this, &CoverWidget::processResizeAction);
+    m_menu->addAction(tr("&Close"), this, &CoverWidget::close, tr("Alt+F4"));
     addActions(m_menu->actions());
     m_size = 0;
     //settings
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    m_size = settings.value("CoverManager/size", 0).toInt();
-    for(QAction *a : sizeMenu->actions ())
+    m_size = settings.value(u"CoverManager/size"_s, 0).toInt();
+    for(QAction *a : sizeMenu->actions())
     {
         a->setCheckable(true);
         if(a->data().toInt() == m_size)
@@ -61,22 +62,19 @@ CoverWidget::CoverWidget(QWidget *parent)
     }
 }
 
-CoverWidget::~CoverWidget()
-{}
-
-void CoverWidget::setPixmap(const QPixmap &pixmap)
+void CoverWidget::setImage(const QImage &img)
 {
-    m_pixmap = pixmap;
+    m_image = img;
     if(m_size == 0)
-       resize(m_pixmap.size());
+       resize(m_image.size());
     update();
 }
 
 void CoverWidget::paintEvent(QPaintEvent *p)
 {
     QPainter paint(this);
-    if(!m_pixmap.isNull())
-        paint.drawPixmap(0,0, m_pixmap.scaled(p->rect().size(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
+    if(!m_image.isNull())
+        paint.drawImage(0 ,0, m_image.scaled(p->rect().size(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
 }
 
 void CoverWidget::mousePressEvent(QMouseEvent *e)
@@ -87,22 +85,21 @@ void CoverWidget::mousePressEvent(QMouseEvent *e)
 
 void CoverWidget::saveAs()
 {
-    QString path = FileDialog::getSaveFileName(this, tr("Save Cover As"),
-                                                 QDir::homePath() + "/cover.jpg",
-                                                 tr("Images") +" (*.png *.jpg)");
+    QString path = FileDialog::getSaveFileName(this, tr("Save Cover As"), QDir::homePath() + u"/cover.jpg"_s,
+                                               tr("Images") + u" (*.png *.jpg)"_s);
 
     if (!path.isEmpty())
-        m_pixmap.save(path);
+        m_image.save(path);
 }
 
 void CoverWidget::processResizeAction(QAction *action)
 {
     m_size = action->data().toInt();
     if(m_size == 0)
-        resize(m_pixmap.size());
+        resize(m_image.size());
     else
         resize(m_size, m_size);
     update();
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.setValue("CoverManager/size", m_size);
+    settings.setValue(u"CoverManager/size"_s, m_size);
 }
