@@ -1,38 +1,38 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="uk">
+<TS version="2.1" language="uk_UA">
 <context>
     <name>CoverManager</name>
     <message>
         <location filename="../covermanager.cpp" line="35"/>
         <source>Show Cover</source>
-        <translation>Показати обкладинку</translation>
+        <translation>Показати шкурку</translation>
     </message>
     <message>
         <location filename="../covermanager.cpp" line="36"/>
         <source>Ctrl+M</source>
-        <translation></translation>
+        <translation>Ctrl+M</translation>
     </message>
 </context>
 <context>
     <name>CoverManagerFactory</name>
     <message>
-        <location filename="../covermanagerfactory.cpp" line="30"/>
+        <location filename="../covermanagerfactory.cpp" line="29"/>
         <source>Cover Manager Plugin</source>
-        <translation>Модуль керування обкладинками</translation>
+        <translation>Втулок керування шкурками</translation>
+    </message>
+    <message>
+        <location filename="../covermanagerfactory.cpp" line="49"/>
+        <source>About Cover Manager Plugin</source>
+        <translation>Про втулок керування шкурками</translation>
     </message>
     <message>
         <location filename="../covermanagerfactory.cpp" line="50"/>
-        <source>About Cover Manager Plugin</source>
-        <translation>Про модуль керування обкладинками</translation>
+        <source>Qmmp Cover Manager Plugin</source>
+        <translation>Втулок керування шкурками для Qmmp</translation>
     </message>
     <message>
         <location filename="../covermanagerfactory.cpp" line="51"/>
-        <source>Qmmp Cover Manager Plugin</source>
-        <translation>Модуль керування обкладинками для Qmmp</translation>
-    </message>
-    <message>
-        <location filename="../covermanagerfactory.cpp" line="52"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Розробник: Ілля Котов &lt;forkotov02@ya.ru&gt;</translation>
     </message>
@@ -40,62 +40,62 @@
 <context>
     <name>CoverWidget</name>
     <message>
-        <location filename="../coverwidget.cpp" line="37"/>
+        <location filename="../coverwidget.cpp" line="38"/>
         <source>&amp;Save As...</source>
         <translation>&amp;Зберегти як...</translation>
     </message>
     <message>
-        <location filename="../coverwidget.cpp" line="37"/>
+        <location filename="../coverwidget.cpp" line="38"/>
         <source>Ctrl+S</source>
-        <translation></translation>
+        <translation>Ctrl+S</translation>
     </message>
     <message>
-        <location filename="../coverwidget.cpp" line="38"/>
+        <location filename="../coverwidget.cpp" line="39"/>
         <source>Size</source>
         <translation>Розмір</translation>
     </message>
     <message>
-        <location filename="../coverwidget.cpp" line="40"/>
+        <location filename="../coverwidget.cpp" line="41"/>
         <source>Actual Size</source>
         <translation>Фактичний розмір</translation>
     </message>
-    <message>
-        <location filename="../coverwidget.cpp" line="41"/>
-        <source>128x128</source>
-        <translation></translation>
-    </message>
     <message>
         <location filename="../coverwidget.cpp" line="42"/>
-        <source>256x256</source>
-        <translation></translation>
+        <source>128x128</source>
+        <translation>128x128</translation>
     </message>
     <message>
         <location filename="../coverwidget.cpp" line="43"/>
-        <source>512x512</source>
-        <translation></translation>
+        <source>256x256</source>
+        <translation>256x256</translation>
     </message>
     <message>
         <location filename="../coverwidget.cpp" line="44"/>
-        <source>1024x1024</source>
-        <translation></translation>
+        <source>512x512</source>
+        <translation>512x512</translation>
     </message>
     <message>
-        <location filename="../coverwidget.cpp" line="47"/>
+        <location filename="../coverwidget.cpp" line="45"/>
+        <source>1024x1024</source>
+        <translation>1024x1024</translation>
+    </message>
+    <message>
+        <location filename="../coverwidget.cpp" line="48"/>
         <source>&amp;Close</source>
         <translation>&amp;Закрити</translation>
     </message>
     <message>
-        <location filename="../coverwidget.cpp" line="47"/>
+        <location filename="../coverwidget.cpp" line="48"/>
         <source>Alt+F4</source>
-        <translation></translation>
+        <translation>Alt+F4</translation>
     </message>
     <message>
-        <location filename="../coverwidget.cpp" line="90"/>
+        <location filename="../coverwidget.cpp" line="88"/>
         <source>Save Cover As</source>
-        <translation>Зберегти обкладинку як</translation>
+        <translation>Зберегти шкурку як</translation>
     </message>
     <message>
-        <location filename="../coverwidget.cpp" line="92"/>
+        <location filename="../coverwidget.cpp" line="89"/>
         <source>Images</source>
         <translation>Зображення</translation>
     </message>
