@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -46,29 +46,29 @@ FileOps::FileOps(QObject *parent) : QObject(parent)
     separator2->setSeparator(true);
     //load settings
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("FileOps");
-    if(!settings.value("name_0").isNull())
+    settings.beginGroup("FileOps"_L1);
+    if(!settings.value("name_0"_L1).isNull())
         UiHelper::instance()->addAction(separator1, UiHelper::PLAYLIST_MENU);
     else
         return;
 
     int i = 0;
-    while(!settings.value(QString("name_%1").arg(i)).isNull())
+    while(!settings.value(QStringLiteral("name_%1").arg(i)).isNull())
     {
-        QString name = settings.value(QString("name_%1").arg(i)).toString();
+        QString name = settings.value(QStringLiteral("name_%1").arg(i)).toString();
         QVariantMap data = {
-            { "action",  settings.value(QString("action_%1").arg(i), FileOps::COPY).toInt() },
-            { "pattern", settings.value(QString("pattern_%1").arg(i)).toString() },
-            { "destination", settings.value(QString("destination_%1").arg(i)).toString() },
-            { "command", settings.value(QString("command_%1").arg(i)).toString() },
+            { u"action"_s,  settings.value(QStringLiteral("action_%1").arg(i), FileOps::COPY).toInt() },
+            { u"pattern"_s, settings.value(QStringLiteral("pattern_%1").arg(i)).toString() },
+            { u"destination"_s, settings.value(QStringLiteral("destination_%1").arg(i)).toString() },
+            { u"command"_s, settings.value(QStringLiteral("command_%1").arg(i)).toString() },
 
         };
 
-        if(settings.value(QString("enabled_%1").arg(i), true).toBool())
+        if(settings.value(QStringLiteral("enabled_%1").arg(i), true).toBool())
         {
             QAction *action = new QAction(name, this);
             action->setData(data);
-            action->setShortcut(settings.value(QString("hotkey_%1").arg(i)).toString());
+            action->setShortcut(settings.value(QStringLiteral("hotkey_%1").arg(i)).toString());
             connect(action, &QAction::triggered, this, &FileOps::execAction);
             UiHelper::instance()->addAction(action, UiHelper::PLAYLIST_MENU);
         }
@@ -87,10 +87,10 @@ void FileOps::execAction()
     QAction *action = qobject_cast<QAction *>(sender());
     QVariantMap data = action->data().toMap();
 
-    int type = data["action"].toInt();
-    QString pattern = data["pattern"].toString();
-    QString destination = data["destination"].toString();
-    QString command = data["command"].toString();
+    int type = data[u"action"_s].toInt();
+    QString pattern = data[u"pattern"_s].toString();
+    QString destination = data[u"destination"_s].toString();
+    QString command = data[u"command"_s].toString();
 
     MetaDataFormatter formatter(type == EXECUTE ? command : pattern);
 
@@ -101,7 +101,7 @@ void FileOps::execAction()
     {
     case COPY:
     {
-        qDebug("FileOps: copy");
+        qCDebug(plugin, "copy");
         if(!QDir(destination).exists ())
         {
             QMessageBox::critical (qApp->activeWindow (), tr("Error"),
@@ -113,13 +113,13 @@ void FileOps::execAction()
     }
     case RENAME:
     {
-        qDebug("FileOps: rename");
+        qCDebug(plugin, "rename");
         rename(tracks, &formatter, model);
         break;
     }
     case REMOVE:
     {
-        qDebug("FileOps: remove");
+        qCDebug(plugin, "remove");
         if(QMessageBox::question (qApp->activeWindow (), tr("Remove Files"),
                                    tr("Are you sure you want to remove %n file(s) from disk?",
                                       "",tracks.size()),
@@ -129,7 +129,7 @@ void FileOps::execAction()
         if(PlayListManager::instance()->selectedPlayList() != model)
             break;
 
-        for(PlayListTrack *track : qAsConst(tracks))
+        for(PlayListTrack *track : std::as_const(tracks))
         {
             if(PlayListManager::instance()->selectedPlayList() != model)
                 break;
@@ -144,7 +144,7 @@ void FileOps::execAction()
     }
     case MOVE:
     {
-        qDebug("FileOps: move");
+        qCDebug(plugin, "move");
         if(!QDir(destination).exists ())
         {
             QMessageBox::critical (qApp->activeWindow (), tr("Error"),
@@ -163,7 +163,7 @@ void FileOps::execAction()
     }
     case EXECUTE:
     {
-        qDebug("FileOps: execute");
+        qCDebug(plugin, "execute");
         execute(tracks, &formatter, model);
         break;
     }
@@ -179,25 +179,25 @@ void FileOps::copy(const QList<PlayListTrack *> &tracks, const QString &dest, co
     progress.show();
     progress.setAutoClose(false);
     int i  = 0;
-    for(PlayListTrack *track : qAsConst(tracks))
+    for(PlayListTrack *track : std::as_const(tracks))
     {
         if(!isValid(track) || !QFile::exists(track->path()))
             continue;
 
         QString fileName = formatter->format(track); //generate file name
 
-        QString ext = QString(".") + track->path().section(".", -1).toLower();
+        QString ext = QStringLiteral(".") + track->path().section(QLatin1Char('.'), -1).toLower();
         if(!ext.isEmpty() && !fileName.endsWith(ext, Qt::CaseInsensitive))
             fileName += ext; //append extension
 
         //create destination path
-        QString path = dest + "/" + fileName;
+        QString path = dest + QLatin1Char('/') + fileName;
         QDir dir = QFileInfo(path).dir();
         if(!dir.exists())
         {
             if(!dir.mkpath(dir.absolutePath()))
             {
-                qWarning("FileOps: unable to create directory");
+                qCWarning(plugin, "unable to create directory");
                 continue;
             }
         }
@@ -209,12 +209,12 @@ void FileOps::copy(const QList<PlayListTrack *> &tracks, const QString &dest, co
         QFile out(path);
         if(!in.open(QIODevice::ReadOnly))
         {
-            qWarning("FileOps: %s", qPrintable(in.errorString ()));
+            qCWarning(plugin) << in.errorString();
             continue;
         }
         if(!out.open(QIODevice::WriteOnly))
         {
-            qWarning("FileOps: %s", qPrintable(out.errorString ()));
+            qCWarning(plugin) << out.errorString();
             continue;
         }
 
@@ -237,7 +237,7 @@ void FileOps::copy(const QList<PlayListTrack *> &tracks, const QString &dest, co
 
 void FileOps::rename(const QList<PlayListTrack *> &tracks, const MetaDataFormatter *formatter, PlayListModel *model)
 {
-    for(PlayListTrack *track : qAsConst(tracks))
+    for(PlayListTrack *track : std::as_const(tracks))
     {
         if(!isValid(track) || !QFile::exists(track->path())) //is it file?
             continue;
@@ -250,15 +250,15 @@ void FileOps::rename(const QList<PlayListTrack *> &tracks, const MetaDataFormatt
 
         QString fileName = formatter->format(track); //generate file name
 
-        QString ext = QString(".") + track->path().section(".", -1).toLower();
+        QString ext = QStringLiteral(".") + track->path().section(QLatin1Char('.'), -1).toLower();
         if(!ext.isEmpty() && !fileName.endsWith(ext, Qt::CaseInsensitive))
             fileName += ext; //append extension
         //rename file
         QFile file(track->path());
         QString dest = QFileInfo(track->path()).absolutePath ();
-        if(isValid(track) && file.rename(dest + "/" + fileName) && isValid(track))
+        if(isValid(track) && file.rename(dest + QLatin1Char('/') + fileName) && isValid(track))
         {
-            track->setPath(dest + "/" + fileName);
+            track->setPath(dest + QLatin1Char('/') + fileName);
             track->updateMetaData();
             model->doCurrentVisibleRequest();
         }
@@ -276,7 +276,7 @@ void FileOps::move(const QList<PlayListTrack *> &tracks, const QString &dest, co
     progress.show();
     progress.setAutoClose (false);
     int i  = 0;
-    for(PlayListTrack *track : qAsConst(tracks))
+    for(PlayListTrack *track : std::as_const(tracks))
     {
         if(!isValid(track) || !QFile::exists(track->path()))
             continue;
@@ -289,11 +289,11 @@ void FileOps::move(const QList<PlayListTrack *> &tracks, const QString &dest, co
 
         QString fileName = formatter->format(track); //generate file name
 
-        QString ext = QString(".") + track->path().section(".", -1).toLower();
+        QString ext = QStringLiteral(".") + track->path().section(QLatin1Char('.'), -1).toLower();
         if(!ext.isEmpty() && !fileName.endsWith(ext, Qt::CaseInsensitive))
             fileName += ext;  //append extension
         //create destination path
-        QString path = dest + "/" + fileName;
+        QString path = dest + QLatin1Char('/') + fileName;
         //skip moved files
         if(path == track->path())
             continue;
@@ -303,7 +303,7 @@ void FileOps::move(const QList<PlayListTrack *> &tracks, const QString &dest, co
         {
             if(!dir.mkpath(dir.absolutePath()))
             {
-                qWarning("FileOps: unable to create directory");
+                qCWarning(plugin, "unable to create directory");
                 continue;
             }
         }
@@ -331,12 +331,12 @@ void FileOps::move(const QList<PlayListTrack *> &tracks, const QString &dest, co
         QFile out(path);
         if(!in.open(QIODevice::ReadOnly))
         {
-            qWarning("FileOps: %s", qPrintable(in.errorString ()));
+            qCWarning(plugin) << in.errorString();
             continue;
         }
         if(!out.open(QIODevice::WriteOnly))
         {
-            qWarning("FileOps: %s", qPrintable(out.errorString ()));
+            qCWarning(plugin) << out.errorString();
             continue;
         }
 
@@ -358,7 +358,7 @@ void FileOps::move(const QList<PlayListTrack *> &tracks, const QString &dest, co
             continue;
 
         if(!QFile::remove(track->path()))
-            qWarning("FileOps: unable to remove file '%s'", qPrintable(track->path()));
+            qCWarning(plugin, "unable to remove file '%s'", qPrintable(track->path()));
 
         track->setPath(path);
         model->doCurrentVisibleRequest();
@@ -371,7 +371,7 @@ void FileOps::move(const QList<PlayListTrack *> &tracks, const QString &dest, co
 
 void FileOps::execute(const QList<PlayListTrack *> &tracks, const MetaDataFormatter *formatter, PlayListModel *model)
 {
-    for(PlayListTrack *track : qAsConst(tracks))
+    for(PlayListTrack *track : std::as_const(tracks))
     {
         if(!isValid(track) || !QFile::exists(track->path())) //is it file?
             continue;
@@ -380,14 +380,14 @@ void FileOps::execute(const QList<PlayListTrack *> &tracks, const MetaDataFormat
             break;
 
         QString command = formatter->format(track); //generate file name
-        qDebug("FileOps: exec command: %s", qPrintable(command));
+        qCDebug(plugin, "exec command: %s", qPrintable(command));
 
 #ifdef Q_OS_WIN
-        QStringList args = { "/C", command };
-        QProcess::startDetached("cmd.exe", args);
+        QStringList args = { u"/C"_s, command };
+        QProcess::startDetached(u"cmd.exe"_s, args);
 #else
-        QStringList args = { "-c", command };
-        QProcess::startDetached("sh", args);
+        QStringList args = { u"-c"_s, command };
+        QProcess::startDetached(u"sh"_s, args);
 #endif
     }
 }
