@@ -156,37 +156,37 @@
         <translation>Genre</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="128"/>
+        <location filename="../historywindow.cpp" line="126"/>
         <source>dd MMMM yyyy</source>
         <translation>jj MMMM aaaa</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="129"/>
+        <location filename="../historywindow.cpp" line="127"/>
         <source>hh:mm:ss</source>
         <translation>hh:mm:ss</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="196"/>
+        <location filename="../historywindow.cpp" line="194"/>
         <source>MM-yyyy</source>
         <translation>MM-aaaa</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="197"/>
+        <location filename="../historywindow.cpp" line="195"/>
         <source>dd MMMM</source>
         <translation>jj MMMM</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="498"/>
+        <location filename="../historywindow.cpp" line="495"/>
         <source>Add to Playlist</source>
-        <translation type="unfinished"></translation>
+        <translation>Ajouter à la liste</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="499"/>
+        <location filename="../historywindow.cpp" line="496"/>
         <source>&amp;View Track Details</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Voir les détails du morceau</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="501"/>
+        <location filename="../historywindow.cpp" line="498"/>
         <source>Remove from History</source>
         <translation type="unfinished"></translation>
     </message>
