@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="ja_JP">
+<TS version="2.1" language="ja">
 <context>
     <name>DateInputDialog</name>
     <message>
@@ -156,37 +156,37 @@
         <translation>ジャンル</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="128"/>
+        <location filename="../historywindow.cpp" line="126"/>
         <source>dd MMMM yyyy</source>
         <translation>yyyy年MM月dd日</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="129"/>
+        <location filename="../historywindow.cpp" line="127"/>
         <source>hh:mm:ss</source>
         <translation>hh:mm:ss</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="196"/>
+        <location filename="../historywindow.cpp" line="194"/>
         <source>MM-yyyy</source>
         <translation>yyyy年MM月</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="197"/>
+        <location filename="../historywindow.cpp" line="195"/>
         <source>dd MMMM</source>
         <translation>MM月dd日</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="498"/>
+        <location filename="../historywindow.cpp" line="495"/>
         <source>Add to Playlist</source>
-        <translation type="unfinished"></translation>
+        <translation>プレイリストに追加</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="499"/>
+        <location filename="../historywindow.cpp" line="496"/>
         <source>&amp;View Track Details</source>
-        <translation type="unfinished"></translation>
+        <translation>トラックの詳細を表示(&amp;D)</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="501"/>
+        <location filename="../historywindow.cpp" line="498"/>
         <source>Remove from History</source>
         <translation type="unfinished"></translation>
     </message>
