@@ -156,37 +156,37 @@
         <translation>Gênero</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="128"/>
+        <location filename="../historywindow.cpp" line="126"/>
         <source>dd MMMM yyyy</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="129"/>
+        <location filename="../historywindow.cpp" line="127"/>
         <source>hh:mm:ss</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="196"/>
+        <location filename="../historywindow.cpp" line="194"/>
         <source>MM-yyyy</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="197"/>
+        <location filename="../historywindow.cpp" line="195"/>
         <source>dd MMMM</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="498"/>
+        <location filename="../historywindow.cpp" line="495"/>
         <source>Add to Playlist</source>
-        <translation type="unfinished"></translation>
+        <translation>Adicionar à lista de reprodução</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="499"/>
+        <location filename="../historywindow.cpp" line="496"/>
         <source>&amp;View Track Details</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Ver detalhes da faixa</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="501"/>
+        <location filename="../historywindow.cpp" line="498"/>
         <source>Remove from History</source>
         <translation type="unfinished"></translation>
     </message>
