@@ -87,11 +87,11 @@ HotkeyManager::HotkeyManager(QObject *parent) : QObject(parent)
     QCoreApplication::instance()->installEventFilter(this);
     WId rootWindow = DefaultRootWindow(QX11Info::display());
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat); //load settings
-    settings.beginGroup("Hotkey");
+    settings.beginGroup("Hotkey"_L1);
     for (int i = Hotkey::PLAY, j = 0; i <= Hotkey::VOLUME_MUTE; ++i, ++j)
     {
-        quint32 key = settings.value(QString("key_%1").arg(i), Hotkey::defaultKey(i)).toUInt();
-        quint32 mod = settings.value(QString("modifiers_%1").arg(i), 0).toUInt();
+        quint32 key = settings.value(QStringLiteral("key_%1").arg(i), Hotkey::defaultKey(i)).toUInt();
+        quint32 mod = settings.value(QStringLiteral("modifiers_%1").arg(i), 0).toUInt();
 
         if (key)
         {
@@ -133,15 +133,15 @@ HotkeyManager::~HotkeyManager()
 
 const QString HotkeyManager::getKeyString(quint32 key, quint32 modifiers)
 {
-    QString strModList[] = { "Control", "Shift", "Alt", "Mod2", "Mod3", "Super", "Mod5" };
+    QString strModList[] = { "Control"_L1, "Shift"_L1, "Alt"_L1, "Mod2"_L1, "Mod3"_L1, "Super"_L1, "Mod5"_L1 };
     quint32 modList[] = { ControlMask, ShiftMask, Mod1Mask, Mod2Mask, Mod3Mask, Mod4Mask, Mod5Mask };
     QString keyStr;
     for (int j = 0; j < 7; j++)
     {
         if (modifiers & modList[j])
-            keyStr.append(strModList[j] + "+");
+            keyStr.append(strModList[j] + "+"_L1);
     }
-    keyStr.append(XKeysymToString(key));
+    keyStr.append(QString::fromLatin1(XKeysymToString(key)));
     return keyStr;
 }
 
