@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2020-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2020-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,19 +22,21 @@
 #include <QSqlQuery>
 #include <QSqlError>
 #include <QSettings>
-#include <QtDebug>
 #include <QMimeData>
 #include <QHash>
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QWidget>
+#include <QMessageBox>
 #include <qmmp/qmmp.h>
+#include <qmmp/soundcore.h>
 #include <qmmpui/playlistparser.h>
 #include <qmmpui/playlistmanager.h>
 #include <qmmpui/detailsdialog.h>
+#include <qmmpui/mediaplayer.h>
 #include "librarymodel.h"
 
-#define CONNECTION_NAME "qmmp_library_view"
+#define CONNECTION_NAME u"qmmp_library_view"_s
 
 class LibraryTreeItem
 {
@@ -65,7 +67,7 @@ LibraryModel::LibraryModel(QObject *parent) : QAbstractItemModel(parent)
 {
     m_rootItem = new LibraryTreeItem;
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    m_showYear = settings.value("Library/show_year", false).toBool();
+    m_showYear = settings.value(u"Library/show_year"_s, false).toBool();
     refresh();
 }
 
@@ -84,13 +86,13 @@ Qt::ItemFlags LibraryModel::flags(const QModelIndex &index) const
 {
     if(index.isValid())
         return QAbstractItemModel::flags(index) | Qt::ItemIsDragEnabled;
-    else
-        return QAbstractItemModel::flags(index);
+
+    return QAbstractItemModel::flags(index);
 }
 
 QStringList LibraryModel::mimeTypes() const
 {
-    return QStringList("application/json");
+    return { u"application/json"_s };
 }
 
 QMimeData *LibraryModel::mimeData(const QModelIndexList &indexes) const
@@ -100,7 +102,7 @@ QMimeData *LibraryModel::mimeData(const QModelIndexList &indexes) const
     if(!tracks.isEmpty())
     {
         QMimeData *mimeData = new QMimeData;
-        mimeData->setData("application/json", PlayListParser::serialize(tracks));
+        mimeData->setData(u"application/json"_s, PlayListParser::serialize(tracks));
         qDeleteAll(tracks);
         return mimeData;
     }
@@ -116,8 +118,8 @@ bool LibraryModel::canFetchMore(const QModelIndex &parent) const
     LibraryTreeItem *parentItem = static_cast<LibraryTreeItem *>(parent.internalPointer());
     if(parentItem == m_rootItem || parentItem->type == Qmmp::TITLE)
         return false;
-    else
-        return parentItem->children.isEmpty();
+
+    return parentItem->children.isEmpty();
 }
 
 void LibraryModel::fetchMore(const QModelIndex &parent)
@@ -136,26 +138,26 @@ void LibraryModel::fetchMore(const QModelIndex &parent)
         QSqlQuery query(db);
         if(m_filter.isEmpty())
         {
-            query.prepare("SELECT DISTINCT Album, Year from track_library WHERE Artist = :artist");
+            query.prepare(u"SELECT DISTINCT Album, Year from track_library WHERE Artist = :artist"_s);
         }
         else
         {
-            query.prepare("SELECT DISTINCT Album, Year from track_library WHERE Artist = :artist AND SearchString LIKE :filter");
-            query.bindValue(":filter", QString("%%1%").arg(m_filter.toLower()));
+            query.prepare(u"SELECT DISTINCT Album, Year from track_library WHERE Artist = :artist AND SearchString LIKE :filter"_s);
+            query.bindValue(u":filter"_s, QStringLiteral("%%1%").arg(m_filter.toLower()));
         }
-        query.bindValue(":artist", parentItem->name);
+        query.bindValue(u":artist"_s, parentItem->name);
 
         if(!query.exec())
         {
-            qWarning("Library: exec error: %s", qPrintable(query.lastError().text()));
+            qCWarning(plugin, "exec error: %s", qPrintable(query.lastError().text()));
             return;
         }
 
         while(query.next())
         {
             LibraryTreeItem *item = new LibraryTreeItem;
-            item->name = query.value("Album").toString();
-            item->year = query.value("Year").toInt();
+            item->name = query.value(u"Album"_s).toString();
+            item->year = query.value(u"Year"_s).toInt();
             item->type = Qmmp::ALBUM;
             item->parent = parentItem;
             parentItem->children << item;
@@ -166,27 +168,27 @@ void LibraryModel::fetchMore(const QModelIndex &parent)
         QSqlQuery query(db);
         if(m_filter.isEmpty())
         {
-            query.prepare("SELECT Title from track_library WHERE Artist = :artist AND Album = :album");
+            query.prepare(u"SELECT Title from track_library WHERE Artist = :artist AND Album = :album"_s);
         }
         else
         {
-            query.prepare("SELECT Title from track_library WHERE Artist = :artist AND Album = :album "
-                          "AND SearchString LIKE :filter");
-            query.bindValue(":filter", QString("%%1%").arg(m_filter.toLower()));
+            query.prepare(u"SELECT Title from track_library WHERE Artist = :artist AND Album = :album "
+                          "AND SearchString LIKE :filter"_s);
+            query.bindValue(u":filter"_s, QStringLiteral("%%1%").arg(m_filter.toLower()));
         }
-        query.bindValue(":artist", parentItem->parent->name);
-        query.bindValue(":album", parentItem->name);
+        query.bindValue(u":artist"_s, parentItem->parent->name);
+        query.bindValue(u":album"_s, parentItem->name);
 
         if(!query.exec())
         {
-            qWarning("Library: exec error: %s", qPrintable(query.lastError().text()));
+            qCWarning(plugin, "exec error: %s", qPrintable(query.lastError().text()));
             return;
         }
 
         while(query.next())
         {
             LibraryTreeItem *item = new LibraryTreeItem;
-            item->name = query.value("Title").toString();
+            item->name = query.value(u"Title"_s).toString();
             item->type = Qmmp::TITLE;
             item->parent = parentItem;
             parentItem->children << item;
@@ -202,8 +204,8 @@ QVariant LibraryModel::data(const QModelIndex &index, int role) const
     LibraryTreeItem *item = static_cast<LibraryTreeItem *>(index.internalPointer());
     if(item->type == Qmmp::ALBUM && m_showYear && item->year > 0)
         return tr("%1 - %2").arg(item->year).arg(item->name);
-    else
-        return item->name;
+
+    return item->name;
 }
 
 QModelIndex LibraryModel::parent(const QModelIndex &child) const
@@ -230,8 +232,8 @@ QModelIndex LibraryModel::index(int row, int column, const QModelIndex &parent)
 
     if(row >= 0 && row < parentItem->children.count())
         return createIndex(row, column, parentItem->children.at(row));
-    else
-        return QModelIndex();
+
+    return QModelIndex();
 }
 
 int LibraryModel::columnCount(const QModelIndex &parent) const
@@ -248,8 +250,8 @@ int LibraryModel::rowCount(const QModelIndex &parent) const
     LibraryTreeItem *parentItem = static_cast<LibraryTreeItem *>(parent.internalPointer());
     if(parentItem->type == Qmmp::TITLE)
         return 0;
-    else
-        return qMax(1, parentItem->children.count());
+
+    return qMax(1, parentItem->children.count());
 }
 
 void LibraryModel::setFilter(const QString &filter)
@@ -270,8 +272,8 @@ void LibraryModel::refresh()
     }
     else
     {
-        db = QSqlDatabase::addDatabase("QSQLITE", CONNECTION_NAME);
-        db.setDatabaseName(Qmmp::configDir() + "/" + "library.sqlite");
+        db = QSqlDatabase::addDatabase(u"QSQLITE"_s, CONNECTION_NAME);
+        db.setDatabaseName(Qmmp::configDir() + u"/library.sqlite"_s);
         db.open();
     }
 
@@ -284,21 +286,21 @@ void LibraryModel::refresh()
     QSqlQuery query(db);
     if(m_filter.isEmpty())
     {
-        query.prepare("SELECT DISTINCT Artist from track_library ORDER BY Artist");
+        query.prepare(u"SELECT DISTINCT Artist from track_library ORDER BY Artist"_s);
     }
     else
     {
-        query.prepare("SELECT DISTINCT Artist from track_library WHERE SearchString LIKE :filter ORDER BY Artist");
-        query.bindValue(":filter", QString("%%1%").arg(m_filter.toLower()));
+        query.prepare(u"SELECT DISTINCT Artist from track_library WHERE SearchString LIKE :filter ORDER BY Artist"_s);
+        query.bindValue(u":filter"_s, QStringLiteral("%%1%").arg(m_filter.toLower()));
     }
 
     if(!query.exec())
-        qWarning("Library: exec error: %s", qPrintable(query.lastError().text()));
+        qCWarning(plugin, "exec error: %s", qPrintable(query.lastError().text()));
 
     while(query.next())
     {
         LibraryTreeItem *item = new LibraryTreeItem;
-        item->name = query.value("Artist").toString();
+        item->name = query.value(u"Artist"_s).toString();
         item->type = Qmmp::ARTIST;
         item->parent = m_rootItem;
         m_rootItem->children << item;
@@ -308,10 +310,33 @@ void LibraryModel::refresh()
 
 void LibraryModel::add(const QModelIndexList &indexes)
 {
-    PlayListManager::instance()->add(getTracks(indexes));
+    PlayListManager::instance()->addTracks(getTracks(indexes));
 }
 
-void LibraryModel::showInformation(const QModelIndexList &indexes, QWidget *parent)
+void LibraryModel::replace(const QModelIndexList &indexes)
+{
+    QList<PlayListTrack *> tracks = getTracks(indexes);
+    if(tracks.isEmpty())
+        return;
+
+    SoundCore *core = SoundCore::instance();
+    PlayListManager *manager = PlayListManager::instance();
+    PlayListModel *model = PlayListManager::instance()->selectedPlayList();
+
+    bool play = (core->state() == Qmmp::Playing || core->state() == Qmmp::Paused || core->state() == Qmmp::Buffering) &&
+            model == manager->currentPlayList();
+
+    model->clear();
+    model->addTracks(tracks);
+
+    if(play)
+    {
+        core->stop();
+        MediaPlayer::instance()->play();
+    }
+}
+
+void LibraryModel::showTrackInformation(const QModelIndexList &indexes, QWidget *parent)
 {
     QList<PlayListTrack *> tracks = getTracks(indexes);
 
@@ -321,6 +346,55 @@ void LibraryModel::showInformation(const QModelIndexList &indexes, QWidget *pare
     connect(dialog, &QObject::destroyed, [=]() { qDeleteAll(tracks); });
 }
 
+void LibraryModel::showLibraryInformation(QWidget *parent)
+{
+    QSqlDatabase db = QSqlDatabase::database(CONNECTION_NAME);
+    if(!db.isOpen())
+    {
+        QMessageBox::critical(parent, tr("Error"), tr("Unable to connect to database"));
+        return;
+    }
+
+    QSqlQuery query(db);
+    query.prepare(u"select COUNT(id),COUNT(DISTINCT Album||Artist),COUNT(DISTINCT Artist),SUM(Duration) from track_library"_s);
+
+    if(!query.exec())
+    {
+        qCWarning(plugin, "exec error: %s", qPrintable(query.lastError().text()));
+        return;
+    }
+    query.next();
+
+    int tracks = query.value(0).toInt();
+    int albums = query.value(1).toInt();
+    int artists = query.value(2).toInt();
+    qint64 duration = query.value(3).toLongLong() / 1000;
+    int days = duration / (3600 * 24);
+    int hours = (duration / 3600) % 24;
+
+    QString daysText = tr("%n day(s)", "", days);
+    QString hoursText = tr("%n hour(s)", "", hours);
+    QString minutesText = tr("%n minute(s)", "", duration % 3600 / 60);
+    QString secondsText = tr("%n second(s)", "", duration % 60);
+    QString durationText;
+
+    if(days > 0)
+        durationText = tr("%1 %2 %3 %4", "days hours minutes seconds").arg(daysText, hoursText, minutesText, secondsText);
+    else if(hours > 0)
+        durationText = tr("%1 %2 %3", "hours minutes seconds").arg(hoursText, minutesText, secondsText);
+    else
+        durationText = tr("%1 %2", "minutes seconds").arg(minutesText, secondsText);
+
+    QStringList lines = {
+        tr("Number of tracks: <b>%1</b>").arg(tracks),
+        tr("Number of albums: <b>%1</b>").arg(albums),
+        tr("Number of artists: <b>%1</b>").arg(artists),
+        tr("Total duration: <b>%1</b>").arg(durationText),
+    };
+
+    QMessageBox::information(parent, tr("Library Information"), lines.join(u"<br>"_s));
+}
+
 QList<PlayListTrack *> LibraryModel::getTracks(const QModelIndexList &indexes) const
 {
     QList<PlayListTrack *> tracks;
@@ -348,14 +422,14 @@ QList<PlayListTrack *> LibraryModel::getTracks(const QModelIndex &index) const
     if(item->type == Qmmp::TITLE)
     {
         QSqlQuery query(db);
-        query.prepare("SELECT * from track_library WHERE Artist = :artist AND Album = :album AND Title = :title");
-        query.bindValue(":artist", item->parent->parent->name);
-        query.bindValue(":album", item->parent->name);
-        query.bindValue(":title", item->name);
+        query.prepare(u"SELECT * from track_library WHERE Artist = :artist AND Album = :album AND Title = :title"_s);
+        query.bindValue(u":artist"_s, item->parent->parent->name);
+        query.bindValue(u":album"_s, item->parent->name);
+        query.bindValue(u":title"_s, item->name);
 
         if(!query.exec())
         {
-            qWarning("Library: exec error: %s", qPrintable(query.lastError().text()));
+            qCWarning(plugin, "exec error: %s", qPrintable(query.lastError().text()));
             return tracks;
         }
 
@@ -367,13 +441,13 @@ QList<PlayListTrack *> LibraryModel::getTracks(const QModelIndex &index) const
     else if(item->type == Qmmp::ALBUM)
     {
         QSqlQuery query(db);
-        query.prepare("SELECT * from track_library WHERE Artist = :artist AND Album = :album");
-        query.bindValue(":artist", item->parent->name);
-        query.bindValue(":album", item->name);
+        query.prepare(u"SELECT * from track_library WHERE Artist = :artist AND Album = :album"_s);
+        query.bindValue(u":artist"_s, item->parent->name);
+        query.bindValue(u":album"_s, item->name);
 
         if(!query.exec())
         {
-            qWarning("Library: exec error: %s", qPrintable(query.lastError().text()));
+            qCWarning(plugin, "exec error: %s", qPrintable(query.lastError().text()));
             return tracks;
         }
 
@@ -385,12 +459,12 @@ QList<PlayListTrack *> LibraryModel::getTracks(const QModelIndex &index) const
     else if(item->type == Qmmp::ARTIST)
     {
         QSqlQuery query(db);
-        query.prepare("SELECT * from track_library WHERE Artist = :artist");
-        query.bindValue(":artist", item->name);
+        query.prepare(u"SELECT * from track_library WHERE Artist = :artist"_s);
+        query.bindValue(u":artist"_s, item->name);
 
         if(!query.exec())
         {
-            qWarning("Library: exec error: %s", qPrintable(query.lastError().text()));
+            qCWarning(plugin, "exec error: %s", qPrintable(query.lastError().text()));
             return tracks;
         }
 
@@ -405,37 +479,37 @@ QList<PlayListTrack *> LibraryModel::getTracks(const QModelIndex &index) const
 
 PlayListTrack *LibraryModel::createTrack(const QSqlQuery &query) const
 {
-    static const QHash<int, QString> metaColumns = {
-        { Qmmp::TITLE, "Title" },
-        { Qmmp::ARTIST, "Artist" },
-        { Qmmp::ALBUMARTIST, "AlbumArtist" },
-        { Qmmp::ALBUM, "Album" },
-        { Qmmp::COMMENT, "Comment" },
-        { Qmmp::GENRE, "Genre" },
-        { Qmmp::COMPOSER, "Composer" },
-        { Qmmp::YEAR, "Year" },
-        { Qmmp::TRACK, "Track" },
-        { Qmmp::DISCNUMBER, "DiscNumber" }
+    static const QHash<Qmmp::MetaData , QString> metaColumns = {
+        { Qmmp::TITLE, u"Title"_s },
+        { Qmmp::ARTIST, u"Artist"_s },
+        { Qmmp::ALBUMARTIST, u"AlbumArtist"_s },
+        { Qmmp::ALBUM, u"Album"_s },
+        { Qmmp::COMMENT, u"Comment"_s },
+        { Qmmp::GENRE, u"Genre"_s },
+        { Qmmp::COMPOSER, u"Composer"_s },
+        { Qmmp::YEAR, u"Year"_s },
+        { Qmmp::TRACK, u"Track"_s },
+        { Qmmp::DISCNUMBER, u"DiscNumber"_s }
     };
 
     PlayListTrack *track = new PlayListTrack;
-    track->setPath(query.value("URL").toString());
-    track->setDuration(query.value("Duration").toLongLong());
+    track->setPath(query.value(u"URL"_s).toString());
+    track->setDuration(query.value(u"Duration"_s).toLongLong());
 
-    for(int key = Qmmp::TITLE; key <= Qmmp::DISCNUMBER; ++key)
+    for(auto it = metaColumns.cbegin(); it != metaColumns.cend(); ++it)
     {
-       QString value = query.value(metaColumns.value(key)).toString();
-       track->setValue(static_cast<Qmmp::MetaData>(key), value);
+       QString value = query.value(it.value()).toString();
+       track->setValue(it.key(), value);
     }
 
-    QJsonDocument document = QJsonDocument::fromJson(query.value("AudioInfo").toByteArray());
+    QJsonDocument document = QJsonDocument::fromJson(query.value(u"AudioInfo"_s).toByteArray());
     QJsonObject obj = document.object();
-    track->setValue(Qmmp::BITRATE, obj.value("bitrate").toInt());
-    track->setValue(Qmmp::SAMPLERATE, obj.value("samplerate").toInt());
-    track->setValue(Qmmp::CHANNELS, obj.value("channels").toInt());
-    track->setValue(Qmmp::BITS_PER_SAMPLE, obj.value("bitsPerSample").toInt());
-    track->setValue(Qmmp::FORMAT_NAME, obj.value("formatName").toString());
-    track->setValue(Qmmp::DECODER, obj.value("decoder").toString());
-    track->setValue(Qmmp::FILE_SIZE, qint64(obj.value("fileSize").toDouble()));
+    track->setValue(Qmmp::BITRATE, obj.value(u"bitrate"_s).toInt());
+    track->setValue(Qmmp::SAMPLERATE, obj.value(u"samplerate"_s).toInt());
+    track->setValue(Qmmp::CHANNELS, obj.value(u"channels"_s).toInt());
+    track->setValue(Qmmp::BITS_PER_SAMPLE, obj.value(u"bitsPerSample"_s).toInt());
+    track->setValue(Qmmp::FORMAT_NAME, obj.value(u"formatName"_s).toString());
+    track->setValue(Qmmp::DECODER, obj.value(u"decoder"_s).toString());
+    track->setValue(Qmmp::FILE_SIZE, qint64(obj.value(u"fileSize"_s).toDouble()));
     return track;
 }
