@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -34,8 +34,8 @@ Lyrics::Lyrics(QPointer<LyricsWidget> *lyricsWidget, QObject *parent) : QObject(
     m_action = new QAction(tr("View Lyrics"), this);
     m_action->setShortcut(tr("Ctrl+L"));
     UiHelper::instance()->addAction(m_action, UiHelper::PLAYLIST_MENU);
-    connect(m_action, SIGNAL(triggered ()), SLOT(showLyrics()));
-    connect(SoundCore::instance(), SIGNAL(trackInfoChanged()), SLOT(onTrackInfoChanged()));
+    connect(m_action, &QAction::triggered, this, &Lyrics::showLyrics);
+    connect(SoundCore::instance(), &SoundCore::trackInfoChanged, this, &Lyrics::onTrackInfoChanged);
 }
 
 Lyrics::~Lyrics()
@@ -44,20 +44,20 @@ Lyrics::~Lyrics()
 void Lyrics::showLyrics()
 {
     PlayListManager *pl_manager = MediaPlayer::instance()->playListManager();
-    QList <PlayListTrack *> tracks = pl_manager->selectedPlayList()->selectedTracks();
+    QList<PlayListTrack *> tracks = pl_manager->selectedPlayList()->selectedTracks();
     if (!tracks.isEmpty())
     {
-        if (tracks.at(0)->value(Qmmp::ARTIST).isEmpty() || tracks.at(0)->value(Qmmp::TITLE).isEmpty())
+        if (tracks.constFirst()->value(Qmmp::ARTIST).isEmpty() || tracks.constFirst()->value(Qmmp::TITLE).isEmpty())
             return;
 
         if(!m_lyricsWidget->isNull() && m_lyricsWidget->data()->isVisible())
         {
-            m_lyricsWidget->data()->fetch(tracks.first());
+            m_lyricsWidget->data()->fetch(tracks.constFirst());
         }
         else
         {
             LyricsWidget *w = new LyricsWidget(true, qApp->activeWindow());
-            w->fetch(tracks.first());
+            w->fetch(tracks.constFirst());
             w->show();
         }
     }
