@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2010-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,6 +23,7 @@
 #include <QDBusArgument>
 #include <QDBusMessage>
 #include <QDBusConnection>
+#include <QRandomGenerator>
 #include <qmmp/soundcore.h>
 #include <qmmp/metadatamanager.h>
 #include <qmmpui/mediaplayer.h>
@@ -36,17 +37,16 @@ Player2Object::Player2Object(QObject *parent) : QDBusAbstractAdaptor(parent)
     m_player = MediaPlayer::instance();
     m_pl_manager =  m_player->playListManager();
     m_ui_settings = QmmpUiSettings::instance();
-    connect(m_core, SIGNAL(trackInfoChanged()), SLOT(updateId()));
-    connect(m_core, SIGNAL(trackInfoChanged()), SLOT(emitPropertiesChanged()));
-    connect(m_core, SIGNAL(stateChanged (Qmmp::State)), SLOT(checkState(Qmmp::State)));
-    connect(m_core, SIGNAL(stateChanged (Qmmp::State)), SLOT(emitPropertiesChanged()));
-    connect(m_core, SIGNAL(volumeChanged(int,int)), SLOT(emitPropertiesChanged()));
-    connect(m_core, SIGNAL(elapsedChanged(qint64)), SLOT(checkSeeking(qint64)));
-    connect(m_ui_settings, SIGNAL(repeatableListChanged(bool)), SLOT(emitPropertiesChanged()));
-    connect(m_ui_settings, SIGNAL(repeatableTrackChanged(bool)), SLOT(emitPropertiesChanged()));
-    connect(m_ui_settings, SIGNAL(shuffleChanged(bool)), SLOT(emitPropertiesChanged()));
-    connect(m_pl_manager, SIGNAL(currentPlayListChanged(PlayListModel*,PlayListModel*)),
-            SLOT(setModel(PlayListModel*,PlayListModel*)));
+    connect(m_core, &SoundCore::trackInfoChanged, this, &Player2Object::updateId);
+    connect(m_core, &SoundCore::trackInfoChanged, this, &Player2Object::emitPropertiesChanged);
+    connect(m_core, &SoundCore::stateChanged, this, &Player2Object::checkState);
+    connect(m_core, &SoundCore::stateChanged, this, &Player2Object::emitPropertiesChanged);
+    connect(m_core, &SoundCore::volumeChanged, this, &Player2Object::emitPropertiesChanged);
+    connect(m_core, &SoundCore::elapsedChanged, this, &Player2Object::checkSeeking);
+    connect(m_ui_settings, &QmmpUiSettings::repeatableListChanged, this, &Player2Object::emitPropertiesChanged);
+    connect(m_ui_settings, &QmmpUiSettings::repeatableTrackChanged, this, &Player2Object::emitPropertiesChanged);
+    connect(m_ui_settings, &QmmpUiSettings::shuffleChanged, this, &Player2Object::emitPropertiesChanged);
+    connect(m_pl_manager, &PlayListManager::currentPlayListChanged, this, &Player2Object::setModel);
     setModel(m_pl_manager->currentPlayList(), nullptr);
     updateId();
     syncProperties();
@@ -87,21 +87,22 @@ bool Player2Object::canSeek() const
 QString Player2Object::loopStatus() const
 {
     if(m_ui_settings->isRepeatableTrack())
-        return "Track";
-    else if(m_ui_settings->isRepeatableList())
-        return "Playlist";
-    else
-        return "None";
+        return u"Track"_s;
+
+    if(m_ui_settings->isRepeatableList())
+        return u"Playlist"_s;
+
+    return u"None"_s;
 }
 
 void Player2Object::setLoopStatus(const QString &value)
 {
-    if(value == "Track")
+    if(value == "Track"_L1)
     {
         m_ui_settings->setRepeatableList(false);
         m_ui_settings->setRepeatableTrack(true);
     }
-    else if(value == "Playlist")
+    else if(value == "Playlist"_L1)
     {
         m_ui_settings->setRepeatableList(true);
         m_ui_settings->setRepeatableTrack(false);
@@ -125,37 +126,37 @@ QVariantMap Player2Object::metadata() const
         return QVariantMap();
     QVariantMap map;
     TrackInfo info = m_core->trackInfo();
-    map["mpris:length"] = qMax(m_core->duration() * 1000 , qint64(0));
+    map[u"mpris:length"_s] = qMax(m_core->duration() * 1000 , qint64(0));
     if(!MetaDataManager::instance()->getCoverPath(info.path()).isEmpty())
     {
-        map["mpris:artUrl"] = QUrl::fromLocalFile(
+        map[u"mpris:artUrl"_s] = QUrl::fromLocalFile(
                     MetaDataManager::instance()->getCoverPath(info.path())).toString();
     }
     if(!info.value(Qmmp::ALBUM).isEmpty())
-        map["xesam:album"] = info.value(Qmmp::ALBUM);
+        map[u"xesam:album"_s] = info.value(Qmmp::ALBUM);
     if(!info.value(Qmmp::ARTIST).isEmpty())
-        map["xesam:artist"] = QStringList() << info.value(Qmmp::ARTIST);
+        map[u"xesam:artist"_s] = QStringList() << info.value(Qmmp::ARTIST);
     if(!info.value(Qmmp::ALBUMARTIST).isEmpty())
-        map["xesam:albumArtist"] = QStringList() << info.value(Qmmp::ALBUMARTIST);
+        map[u"xesam:albumArtist"_s] = QStringList() << info.value(Qmmp::ALBUMARTIST);
     if(!info.value(Qmmp::COMMENT).isEmpty())
-        map["xesam:comment"] = QStringList() << info.value(Qmmp::COMMENT);
+        map[u"xesam:comment"_s] = QStringList() << info.value(Qmmp::COMMENT);
     if(!info.value(Qmmp::COMPOSER).isEmpty())
-        map["xesam:composer"] = QStringList() << info.value(Qmmp::COMPOSER);
+        map[u"xesam:composer"_s] = QStringList() << info.value(Qmmp::COMPOSER);
     if(!info.value(Qmmp::DISCNUMBER).isEmpty())
-        map["xesam:discNumber"] = info.value(Qmmp::DISCNUMBER).toInt();
+        map[u"xesam:discNumber"_s] = info.value(Qmmp::DISCNUMBER).toInt();
     if(!info.value(Qmmp::GENRE).isEmpty())
-        map["xesam:genre"] = QStringList() << info.value(Qmmp::GENRE);
+        map[u"xesam:genre"_s] = QStringList() << info.value(Qmmp::GENRE);
     if(!info.value(Qmmp::TITLE).isEmpty())
-        map["xesam:title"] = info.value(Qmmp::TITLE);
+        map[u"xesam:title"_s] = info.value(Qmmp::TITLE);
     if(!info.value(Qmmp::TRACK).isEmpty())
-        map["xesam:trackNumber"] = info.value(Qmmp::TRACK).toInt();
+        map[u"xesam:trackNumber"_s] = info.value(Qmmp::TRACK).toInt();
     if(!info.value(Qmmp::YEAR).isEmpty())
-        map["xesam:contentCreated"] = info.value(Qmmp::YEAR);
-    map["mpris:trackid"] = QVariant::fromValue<QDBusObjectPath>(m_trackID);
-    if(info.path().startsWith("/"))
-        map["xesam:url"] =  QUrl::fromLocalFile(info.path()).toString();
+        map[u"xesam:contentCreated"_s] = info.value(Qmmp::YEAR);
+    map[u"mpris:trackid"_s] = QVariant::fromValue<QDBusObjectPath>(m_trackID);
+    if(info.path().startsWith(QLatin1Char('/')))
+        map[u"xesam:url"_s] =  QUrl::fromLocalFile(info.path()).toString();
     else
-        map["xesam:url"] = info.path();
+        map[u"xesam:url"_s] = info.path();
     return map;
 }
 
@@ -167,10 +168,12 @@ double Player2Object::minimumRate() const
 QString Player2Object::playbackStatus() const
 {
     if(m_core->state() == Qmmp::Playing)
-        return "Playing";
-    else if (m_core->state() == Qmmp::Paused)
-        return "Paused";
-    return "Stopped";
+        return u"Playing"_s;
+
+    if (m_core->state() == Qmmp::Paused)
+        return u"Paused"_s;
+
+    return u"Stopped"_s;
 }
 
 qlonglong Player2Object::position() const
@@ -200,15 +203,13 @@ void Player2Object::setShuffle(bool value)
 
 double Player2Object::volume() const
 {
-    return qMax(m_core->leftVolume(), m_core->rightVolume())/100.0;
+    return qMax(m_core->leftVolume(), m_core->rightVolume()) / 100.0;
 }
 
 void Player2Object::Player2Object::setVolume(double value)
 {
     value = qBound(0.0, value ,1.0);
-    int balance = (volume() > 0) ? (m_core->rightVolume() - m_core->leftVolume())/volume() : 0;
-    m_core->setVolume(value*100 - qMax(balance,0)*value,
-                      value*100 + qMin(balance,0)*value);
+    m_core->setVolume(value * 100);
 }
 
 void Player2Object::Next()
@@ -219,7 +220,7 @@ void Player2Object::Next()
 void Player2Object::OpenUri(const QString &in0)
 {
     QString path = in0;
-    if(in0.startsWith("file://"))
+    if(in0.startsWith(u"file://"_s))
     {
         path = QUrl(in0).toLocalFile ();
         if(!QFile::exists(path))
@@ -228,11 +229,10 @@ void Player2Object::OpenUri(const QString &in0)
     if(!m_pl_manager->currentPlayList()->isLoaderRunning())
     {
         m_pl_manager->selectPlayList(m_pl_manager->currentPlayList());
-        connect(m_pl_manager->currentPlayList(), SIGNAL(trackAdded(PlayListTrack*)),
-                SLOT(playTrack(PlayListTrack*)));
-        connect(m_pl_manager->currentPlayList(), SIGNAL(loaderFinished()), this, SLOT(disconnectPl()));
+        connect(m_pl_manager->currentPlayList(), &PlayListModel::tracksAdded, this, &Player2Object::playTrack);
+        connect(m_pl_manager->currentPlayList(), &PlayListModel::loaderFinished, this, &Player2Object::disconnectPl);
     }
-    m_pl_manager->currentPlayList()->add(path);
+    m_pl_manager->currentPlayList()->addPath(path);
 }
 
 void Player2Object::Pause()
@@ -264,14 +264,14 @@ void Player2Object::Previous()
 
 void Player2Object::Seek(qlonglong Offset)
 {
-    m_core->seek(qMax(qint64(0), m_core->elapsed() +  Offset/1000));
+    m_core->seek(qMax(qint64(0), m_core->elapsed() + Offset / 1000));
 }
 void Player2Object::SetPosition(const QDBusObjectPath &TrackId, qlonglong Position)
 {
     if(m_trackID == TrackId)
-        m_core->seek(Position/1000);
+        m_core->seek(Position / 1000);
     else
-        qWarning("Player2Object: SetPosition() called with a invalid trackId");
+        qCWarning(plugin, "SetPosition() called with a invalid trackId");
 }
 
 void Player2Object::Stop()
@@ -295,9 +295,9 @@ void Player2Object::emitPropertiesChanged()
     if(map.isEmpty())
         return;
 
-    QDBusMessage msg = QDBusMessage::createSignal("/org/mpris/MediaPlayer2",
-                                                  "org.freedesktop.DBus.Properties", "PropertiesChanged");
-    msg << "org.mpris.MediaPlayer2.Player";
+    QDBusMessage msg = QDBusMessage::createSignal(u"/org/mpris/MediaPlayer2"_s,
+                                                  u"org.freedesktop.DBus.Properties"_s, u"PropertiesChanged"_s);
+    msg << u"org.mpris.MediaPlayer2.Player"_s;
     msg << map;
     msg << QStringList();
     QDBusConnection::sessionBus().send(msg);
@@ -307,7 +307,8 @@ void Player2Object::updateId()
 {
     if(m_prev_track != m_pl_manager->currentPlayList()->currentTrack())
     {
-        m_trackID = QDBusObjectPath(QString("%1/Track/%2").arg("/org/qmmp/MediaPlayer2").arg(qrand()));
+        m_trackID = QDBusObjectPath(QStringLiteral("/org/qmmp/MediaPlayer2/Track/%1")
+                                    .arg(QRandomGenerator::global()->generate()));
         m_prev_track = m_pl_manager->currentPlayList()->currentTrack();
     }
 }
@@ -330,13 +331,13 @@ void Player2Object::checkSeeking(qint64 elapsed)
     m_previous_pos = elapsed;
 }
 
-void Player2Object::playTrack(PlayListTrack *item)
+void Player2Object::playTrack(const QList<PlayListTrack *> &tracks)
 {
     PlayListModel *model = qobject_cast<PlayListModel*>(sender());
     m_pl_manager->selectPlayList(model);
     m_pl_manager->activatePlayList(model);
-    disconnect(model, SIGNAL(trackAdded(PlayListTrack*)), this, SLOT(playTrack(PlayListTrack*)));
-    if(!m_pl_manager->currentPlayList()->setCurrent(item))
+    disconnect(m_pl_manager->currentPlayList(), &PlayListModel::tracksAdded, this, &Player2Object::playTrack);
+    if(!m_pl_manager->currentPlayList()->setCurrent(tracks.constFirst()))
         return;
     m_core->stop();
     m_player->play();
@@ -344,30 +345,29 @@ void Player2Object::playTrack(PlayListTrack *item)
 
 void Player2Object::disconnectPl()
 {
-    disconnect(sender(), SIGNAL(trackAdded(PlayListTrack*)),
-               this, SLOT(playTrack(PlayListTrack*)));
+    disconnect(qobject_cast<PlayListModel *>(sender()), &PlayListModel::tracksAdded, this, &Player2Object::playTrack);
 }
 
 void Player2Object::setModel(PlayListModel *selected, PlayListModel *previous)
 {
     if(previous)
         disconnect(previous, nullptr, this, nullptr); //disconnect previous model
-    connect(selected, SIGNAL(listChanged(int)), SLOT(emitPropertiesChanged()));
+    connect(selected, &PlayListModel::listChanged, this, &Player2Object::emitPropertiesChanged);
 }
 
 void Player2Object::syncProperties()
 {
-    m_props["CanGoNext"] = canGoNext();
-    m_props["CanGoPrevious"] = canGoPrevious();
-    m_props["CanPause"] = canPause();
-    m_props["CanPlay"] = canPlay();
-    m_props["CanSeek"] = canSeek();
-    m_props["LoopStatus"] = loopStatus();
-    m_props["MaximumRate"] = maximumRate();
-    m_props["MinimumRate"] = minimumRate();
-    m_props["PlaybackStatus"] = playbackStatus();
-    m_props["Rate"] = rate();
-    m_props["Shuffle"] = shuffle();
-    m_props["Volume"] = volume();
-    m_props["Metadata"] = metadata();
+    m_props[u"CanGoNext"_s] = canGoNext();
+    m_props[u"CanGoPrevious"_s] = canGoPrevious();
+    m_props[u"CanPause"_s] = canPause();
+    m_props[u"CanPlay"_s] = canPlay();
+    m_props[u"CanSeek"_s] = canSeek();
+    m_props[u"LoopStatus"_s] = loopStatus();
+    m_props[u"MaximumRate"_s] = maximumRate();
+    m_props[u"MinimumRate"_s] = minimumRate();
+    m_props[u"PlaybackStatus"_s] = playbackStatus();
+    m_props[u"Rate"_s] = rate();
+    m_props[u"Shuffle"_s] = shuffle();
+    m_props[u"Volume"_s] = volume();
+    m_props[u"Metadata"_s] = metadata();
 }
