@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2010-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,11 +26,11 @@
 #include <QMap>
 #include <QUuid>
 #include <qmmp/qmmp.h>
+#include <qmmpui/playlisttrack.h>
 
 class SoundCore;
 class MediaPlayer;
 class PlayListManager;
-class PlayListTrack;
 class PlayListModel;
 class QmmpUiSettings;
 
@@ -98,7 +98,7 @@ private slots:
     void updateId();
     void checkState(Qmmp::State state);
     void checkSeeking(qint64 elapsed);
-    void playTrack(PlayListTrack *item);
+    void playTrack(const QList<PlayListTrack *> &tracks);
     void disconnectPl();
     void setModel(PlayListModel *selected, PlayListModel *previous);
 
