@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2010-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,7 +23,6 @@
 #include <qmmp/decoderfactory.h>
 #include <qmmp/abstractengine.h>
 #include <qmmp/enginefactory.h>
-#include <qmmp/enginefactory.h>
 #include <qmmp/inputsource.h>
 #include <qmmp/inputsourcefactory.h>
 #include <qmmp/metadatamanager.h>
@@ -49,7 +48,7 @@ bool Root2Object::canRaise() const
 
 QString Root2Object::desktopEntry() const
 {
-    return "qmmp-1";
+    return u"qmmp"_s;
 }
 
 bool Root2Object::hasTrackList() const
@@ -58,7 +57,7 @@ bool Root2Object::hasTrackList() const
 }
 QString Root2Object::identity() const
 {
-    return "Qmmp";
+    return u"Qmmp"_s;
 }
 
 QStringList Root2Object::supportedMimeTypes() const
@@ -73,8 +72,8 @@ QStringList Root2Object::supportedMimeTypes() const
 QStringList Root2Object::supportedUriSchemes() const
 {
     QStringList protocols = MetaDataManager::instance()->protocols();
-    if(!protocols.contains("file")) //append file if needed
-        protocols.append("file");
+    if(!protocols.contains(u"file"_s)) //append file if needed
+        protocols.append(u"file"_s);
     return protocols;
 }
 
