@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2016 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -25,6 +25,10 @@
 #include <qmmpui/general.h>
 #include <qmmp/qmmp.h>
 
+#ifdef X11_FOUND
+typedef struct _XDisplay Display;
+#endif
+
 class PopupWidget;
 class SoundCore;
 
@@ -42,17 +46,18 @@ public:
 
 private slots:
     void showMetaData();
-    void showVolume(int, int);
+    void showVolume(int v);
     void setState(Qmmp::State state);
 
 private:
     void removePsiTuneFiles();
     bool hasFullscreenWindow() const;
+
     QPointer<PopupWidget> m_popupWidget;
     bool m_desktop, m_showVolume;
     bool m_psi;
-    int m_l, m_r;
-    bool m_isPaused;
+    int m_volume = -1;
+    bool m_isPaused = false;
     bool m_resumeNotification;
     bool m_disableForFullScreen;
     SoundCore *m_core;
