@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,11 +26,11 @@
 ScrobblerHandler::ScrobblerHandler(QObject *parent) : QObject(parent)
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("Scrobbler");
-    if(settings.value("use_lastfm", false).toBool())
-        new Scrobbler(SCROBBLER_LASTFM_URL, "lastfm", this);
-    if(settings.value("use_librefm", false).toBool())
-        new Scrobbler(SCROBBLER_LIBREFM_URL, "librefm", this);
+    settings.beginGroup(u"Scrobbler"_s);
+    if(settings.value(u"use_lastfm"_s, false).toBool())
+        new Scrobbler(SCROBBLER_LASTFM_URL, u"lastfm"_s, this);
+    if(settings.value(u"use_librefm"_s, false).toBool())
+        new Scrobbler(SCROBBLER_LIBREFM_URL, u"librefm"_s, this);
     settings.endGroup();
 }
 
