@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,13 +20,12 @@
 #ifndef STATUSICON_H
 #define STATUSICON_H
 
-#include <QMap>
 #include <qmmpui/general.h>
 #include <qmmp/qmmp.h>
 #include <qmmpui/metadataformatter.h>
 #include "qmmptrayicon.h"
 
-#define DEFAULT_TEMPLATE "<b>%if(%t,%t,%f)</b>\n%if(%p,<br>%p,)\n%if(%a,<br>%a,)\n%if(%l,<br><b>%l</b>,)"
+#define DEFAULT_TEMPLATE u"<b>%if(%t,%t,%f)</b>\n%if(%p,<br>%p,)\n%if(%a,<br>%a,)\n%if(%l,<br><b>%l</b>,)"_s
 
 class SoundCore;
 class MediaPlayer;
@@ -52,7 +51,6 @@ private slots:
 private:
     QmmpTrayIcon *m_tray;
     bool m_showMessage;
-    bool m_hideToTray;
     bool m_useStandardIcons;
     bool m_showToolTip;
     QString m_toolTipTemplate;
