@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2018-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2018-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,6 +20,7 @@
 
 #include <QPushButton>
 #include <QUrl>
+#include <qmmp/qmmp.h>
 #include "editstreamdialog.h"
 #include "ui_editstreamdialog.h"
 
@@ -28,14 +29,10 @@ EditStreamDialog::EditStreamDialog(QWidget *parent) :
     m_ui(new Ui::EditStreamDialog)
 {
     m_ui->setupUi(this);
-    connect(m_ui->nameLineEdit, SIGNAL(textChanged(QString)), SLOT(validate()));
-    connect(m_ui->urlLineEdit, SIGNAL(textChanged(QString)), SLOT(validate()));
+    connect(m_ui->nameLineEdit, &QLineEdit::textChanged, this, &EditStreamDialog::validate);
+    connect(m_ui->urlLineEdit, &QLineEdit::textChanged, this, &EditStreamDialog::validate);
     m_ui->buttonBox->button(QDialogButtonBox::Ok)->setEnabled(false);
-    m_ui->typeComboBox->addItems(QStringList()
-                                 << "application/ogg"
-                                 << "audio/aac"
-                                 << "audio/aacp"
-                                 << "audio/mpeg");
+    m_ui->typeComboBox->addItems({ u"application/ogg"_s, u"audio/aac"_s, u"audio/aacp"_s, u"audio/mpeg"_s });
 }
 
 EditStreamDialog::~EditStreamDialog()
@@ -43,6 +40,21 @@ EditStreamDialog::~EditStreamDialog()
     delete m_ui;
 }
 
+void EditStreamDialog::setValues(const QHash<EditStreamDialog::Key, QString> &values)
+{
+    m_values = values;
+    m_ui->urlLineEdit->setText(values.value(URL));
+    m_ui->nameLineEdit->setText(values.value(NAME));
+    m_ui->genreLineEdit->setText(values.value(GENRE));
+    m_ui->bitrateLineEdit->setText(values.value(BITRATE));
+    m_ui->typeComboBox->setEditText(values.value(TYPE));
+}
+
+QHash<EditStreamDialog::Key, QString> EditStreamDialog::values() const
+{
+    return m_values;
+}
+
 void EditStreamDialog::accept()
 {
     m_values[URL] = m_ui->urlLineEdit->text();
@@ -53,21 +65,6 @@ void EditStreamDialog::accept()
     QDialog::accept();
 }
 
-void EditStreamDialog::setValues(const QMap<EditStreamDialog::Key, QString> &values)
-{
-    m_values = values;
-    m_ui->urlLineEdit->setText(values.value(URL));
-    m_ui->nameLineEdit->setText(values.value(NAME));
-    m_ui->genreLineEdit->setText(values.value(GENRE));
-    m_ui->bitrateLineEdit->setText(values.value(BITRATE));
-    m_ui->typeComboBox->setEditText(values.value(TYPE));
-}
-
-const QMap<EditStreamDialog::Key, QString> &EditStreamDialog::values() const
-{
-    return m_values;
-}
-
 void EditStreamDialog::validate()
 {
     bool ok = !m_ui->nameLineEdit->text().isEmpty();
