@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2012-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2012-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -30,15 +30,12 @@
 
 StreamBrowser::StreamBrowser(QObject *parent) : QObject(parent)
 {
-    m_action = new QAction(QIcon::fromTheme("applications-internet"), tr("Add Stream"), this);
+    m_action = new QAction(QIcon::fromTheme(u"applications-internet"_s), tr("Add Stream"), this);
     m_action->setShortcut(tr("Ctrl+U"));
     UiHelper::instance()->addAction(m_action, UiHelper::ADD_MENU);
-    connect (m_action, SIGNAL(triggered ()), SLOT(showStreamWindow()));
+    connect(m_action, &QAction::triggered, this, &StreamBrowser::showStreamWindow);
 }
 
-StreamBrowser::~StreamBrowser()
-{}
-
 void StreamBrowser::showStreamWindow()
 {
     if(!m_streamWindow)
