@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -34,20 +34,20 @@ TrackChange::TrackChange(QObject *parent) : QObject(parent)
 {
     m_core = SoundCore::instance();
     m_plManager = PlayListManager::instance();
-    connect(m_core, SIGNAL(stateChanged(Qmmp::State)), SLOT(onStateChanged(Qmmp::State)));
-    connect(m_core, SIGNAL(trackInfoChanged()), SLOT(onTrackInfoChanged()));
-    connect(m_core, SIGNAL(finished()), SLOT(onFinised()));
+    connect(m_core, &SoundCore::stateChanged, this, &TrackChange::onStateChanged);
+    connect(m_core, &SoundCore::trackInfoChanged, this, &TrackChange::onTrackInfoChanged);
+    connect(m_core, &SoundCore::finished, this, &TrackChange::onFinised);
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("TrackChange");
-    m_newTrackCommand = settings.value("new_track_command").toString();
-    m_endOfTrackCommand = settings.value("end_of_track_command").toString();
-    m_endOfPlCommand = settings.value("end_of_pl_command").toString();
-    m_titleChangeCommand = settings.value("title_change_command").toString();
-    m_appStartupCommand = settings.value("application_startup_command").toString();
-    m_appExitCommand = settings.value("application_exit_command").toString();
+    settings.beginGroup(u"TrackChange"_s);
+    m_newTrackCommand = settings.value(u"new_track_command"_s).toString();
+    m_endOfTrackCommand = settings.value(u"end_of_track_command"_s).toString();
+    m_endOfPlCommand = settings.value(u"end_of_pl_command"_s).toString();
+    m_titleChangeCommand = settings.value(u"title_change_command"_s).toString();
+    m_appStartupCommand = settings.value(u"application_startup_command"_s).toString();
+    m_appExitCommand = settings.value(u"application_exit_command"_s).toString();
     settings.endGroup();
 
-    connect(qApp, SIGNAL(aboutToQuit()), SLOT(onAppExit()));
+    connect(qApp, &QCoreApplication::aboutToQuit, this, &TrackChange::onAppExit);
     onAppStartup();
 }
 
@@ -74,7 +74,7 @@ void TrackChange::onTrackInfoChanged()
         {
             if(!m_titleChangeCommand.isEmpty())
             {
-                qDebug("TrackChange: starting title change command..");
+                qCDebug(plugin, "starting title change command..");
                 executeCommand(info, m_titleChangeCommand);
             }
         }
@@ -82,7 +82,7 @@ void TrackChange::onTrackInfoChanged()
         {
             if(!m_newTrackCommand.isEmpty())
             {
-                qDebug("TrackChange: starting new track command..");
+                qCDebug(plugin, "starting new track command..");
                 executeCommand(info, m_newTrackCommand);
             }
         }
@@ -94,12 +94,12 @@ void TrackChange::onFinised()
 {
     if(!m_endOfTrackCommand.isEmpty())
     {
-        qDebug("TrackChange: starting end of track command..");
+        qCDebug(plugin, "starting end of track command..");
         executeCommand(m_prevInfo, m_endOfTrackCommand);
     }
     if(!m_endOfPlCommand.isEmpty() && !m_plManager->currentPlayList()->nextTrack())
     {
-        qDebug("TrackChange: starting end of playlist command..");
+        qCDebug(plugin, "tarting end of playlist command..");
         executeCommand(m_prevInfo, m_endOfPlCommand);
     }
 }
@@ -109,10 +109,11 @@ void TrackChange::onAppStartup()
     if(QApplication::allWindows().count() == 1 && !m_appStartupCommand.isEmpty()) //detect startup
     {
 #ifdef Q_OS_WIN
-        QProcess::startDetached(QString("cmd.exe /C %1").arg(m_appStartupCommand));
+        QStringList args = { u"/C"_s, m_appStartupCommand };
+        QProcess::startDetached(QStringLiteral("cmd.exe"), args);
 #else
-        QStringList args = { "-c", m_appStartupCommand };
-        QProcess::startDetached("sh", args);
+        QStringList args = { u"-c"_s, m_appStartupCommand };
+        QProcess::startDetached(u"sh"_s, args);
 #endif
     }
 }
@@ -122,10 +123,11 @@ void TrackChange::onAppExit()
     if(!m_appExitCommand.isEmpty())
     {
 #ifdef Q_OS_WIN
-        QProcess::startDetached(QString("cmd.exe /C %1").arg(m_appExitCommand));
+        QStringList args = { u"/C"_s, m_appExitCommand };
+        QProcess::startDetached(QStringLiteral("cmd.exe"), args);
 #else
-        QStringList args = { "-c", m_appExitCommand };
-        QProcess::startDetached("sh", args);
+        QStringList args = { u"-c"_s, m_appExitCommand };
+        QProcess::startDetached(u"sh"_s, args);
 #endif
     }
 }
@@ -138,9 +140,9 @@ bool TrackChange::executeCommand(const TrackInfo &info, const QString &format)
     while(it != metaData.end())
     {
 #ifdef Q_OS_WIN
-        it.value() = it.value().replace("'", "^'");
+        it.value() = it.value().replace(u"'"_s, u"^'"_s);
 #else
-        it.value() = it.value().replace("'", "'\\''");
+        it.value() = it.value().replace(u"'"_s, u"'\\''"_s);
 #endif
         ++it;
     }
@@ -148,12 +150,13 @@ bool TrackChange::executeCommand(const TrackInfo &info, const QString &format)
     MetaDataFormatter formatter(format);
     QString command = formatter.format(tmp);
 #ifdef Q_OS_WIN
-    bool ok = QProcess::startDetached(QString("cmd.exe /C %1").arg(command));
+    QStringList args = { u"/C"_s, command };
+    bool ok = QProcess::startDetached(QStringLiteral("cmd.exe"), args);
 #else
-    QStringList args = { "-c", command };
-    bool ok = QProcess::startDetached("sh", args);
+    QStringList args = { u"-c"_s, command };
+    bool ok = QProcess::startDetached(u"sh"_s, args);
 #endif
     if(!ok)
-        qWarning("TrackChange: unable to start command '%s'", qPrintable(command));
+        qCWarning(plugin, "unable to start command '%s'", qPrintable(command));
     return ok;
 }
