@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,25 +22,25 @@
 #include <QDBusConnection>
 #include <QByteArray>
 #include <QDBusMetaType>
-#if (QT_VERSION < QT_VERSION_CHECK(5, 7, 0)) //qAsConst template
 #include <qmmp/qmmp.h>
-#endif
 #include "udisksdevice.h"
 
+using namespace Qt::Literals::StringLiterals;
+
 UDisksDevice::UDisksDevice(QDBusObjectPath o, QObject *parent) : QObject(parent)
 {
-    m_block_interface = new QDBusInterface("org.freedesktop.UDisks2", o.path(),
-                                           "org.freedesktop.UDisks2.Block", QDBusConnection::systemBus(),
+    m_block_interface = new QDBusInterface(u"org.freedesktop.UDisks2"_s, o.path(),
+                                           u"org.freedesktop.UDisks2.Block"_s, QDBusConnection::systemBus(),
                                            this);
 
-    QDBusObjectPath drive_object = property("Drive").value<QDBusObjectPath>();
+    QDBusObjectPath drive_object = property(u"Drive"_s).value<QDBusObjectPath>();
 
-    QDBusConnection::systemBus().connect("org.freedesktop.UDisks2", o.path(),
-                                         "org.freedesktop.DBus.Properties","PropertiesChanged",
+    QDBusConnection::systemBus().connect(u"org.freedesktop.UDisks2"_s, o.path(),
+                                         u"org.freedesktop.DBus.Properties"_s, u"PropertiesChanged"_s,
                                          this, SIGNAL(changed()));
 
-    m_drive_interface = new QDBusInterface("org.freedesktop.UDisks2", drive_object.path(),
-                                           "org.freedesktop.UDisks2.Drive", QDBusConnection::systemBus(),
+    m_drive_interface = new QDBusInterface(u"org.freedesktop.UDisks2"_s, drive_object.path(),
+                                           u"org.freedesktop.UDisks2.Drive"_s, QDBusConnection::systemBus(),
                                            this);
     m_path = o;
 }
@@ -82,18 +82,18 @@ bool UDisksDevice::isOptical() const
 QStringList UDisksDevice::mountPoints() const
 {
     QStringList points;
-    QDBusMessage message = QDBusMessage::createMethodCall("org.freedesktop.UDisks2", m_path.path(),
-                                                          "org.freedesktop.DBus.Properties", "Get");
+    QDBusMessage message = QDBusMessage::createMethodCall(u"org.freedesktop.UDisks2"_s, m_path.path(),
+                                                          u"org.freedesktop.DBus.Properties"_s, u"Get"_s);
 
     QList<QVariant> arguments;
-    arguments << "org.freedesktop.UDisks2.Filesystem" << "MountPoints";
+    arguments << u"org.freedesktop.UDisks2.Filesystem"_s << u"MountPoints"_s;
     message.setArguments(arguments);
 
     QDBusMessage reply = QDBusConnection::systemBus().call(message);
 
     const QList<QVariant> args = reply.arguments();
 
-    for(const QVariant &arg : qAsConst(args))
+    for(const QVariant &arg : std::as_const(args))
     {
         QByteArrayList list;
         QDBusArgument a = arg.value<QDBusVariant>().variant().value<QDBusArgument>();
@@ -101,8 +101,8 @@ QStringList UDisksDevice::mountPoints() const
             continue;
         a >> list;
 
-        for(const QByteArray &p : qAsConst(list))
-            points.append(p);
+        for(const QByteArray &p : std::as_const(list))
+            points.append(QString::fromLocal8Bit(p));
     }
     return points;
 }
