@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,20 +20,17 @@
 
 
 #include <QObject>
-#include <QRegularExpression>
 #include <QSettings>
 #include <QFileInfo>
 #include <QDir>
 #include <cdio/cdio.h>
-#if LIBCDIO_VERSION_NUM <= 83
-#include <cdio/cdda.h>
-#else
 #include <cdio/paranoia/cdda.h>
-#endif
 #include <cdio/audio.h>
 #include <cdio/cd_types.h>
 #include <cdio/logging.h>
+#ifdef WITH_LIBCDDB
 #include <cddb/cddb.h>
+#endif
 #include <qmmp/buffer.h>
 #include <qmmp/output.h>
 #include <qmmp/qmmpsettings.h>
@@ -43,7 +40,7 @@
 
 #include "decoder_cdaudio.h"
 
-QList <CDATrack> DecoderCDAudio::m_track_cache;
+QList<CDATrack> DecoderCDAudio::m_track_cache;
 
 static void log_handler (cdio_log_level_t level, const char *message)
 {
@@ -51,31 +48,33 @@ static void log_handler (cdio_log_level_t level, const char *message)
     switch (level)
     {
     case CDIO_LOG_DEBUG:
-        qDebug("DecoderCDAudio: cdio message: %s (level=debug)", qPrintable(str));
+        qCDebug(plugin, "cdio message: %s (level=debug)", qPrintable(str));
         return;
     case CDIO_LOG_INFO:
-        qDebug("DecoderCDAudio: cdio message: %s (level=info)", qPrintable(str));
+        qCDebug(plugin, "cdio message: %s (level=info)", qPrintable(str));
         return;
     default:
-        qWarning("DecoderCDAudio: cdio message: %s (level=error)", qPrintable(str));
+        qCWarning(plugin, "cdio message: %s (level=error)", qPrintable(str));
     }
 }
 
+#ifdef WITH_LIBCDDB
 static void cddb_log_handler(cddb_log_level_t level, const char *message)
 {
     QString str = QString::fromLocal8Bit(message).trimmed();
     switch (level)
     {
     case CDDB_LOG_DEBUG:
-        qDebug("DecoderCDAudio: cddb message: %s (level=debug)", qPrintable(str));
+        qCDebug(plugin, "cddb message: %s (level=debug)", qPrintable(str));
         return;
     case CDDB_LOG_INFO:
-        qDebug("DecoderCDAudio: cddb message: %s (level=info)", qPrintable(str));
+        qCDebug(plugin, "cddb message: %s (level=info)", qPrintable(str));
         return;
     default:
-        qWarning("DecoderCDAudio: cddb message: %s (level=error)", qPrintable(str));
+        qCWarning(plugin, "cddb message: %s (level=error)", qPrintable(str));
     }
 }
+#endif
 
 // Decoder class
 
@@ -99,15 +98,15 @@ QList<CDATrack> DecoderCDAudio::generateTrackList(const QString &device, TrackIn
 {
     //read settings
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    int cd_speed = settings.value("cdaudio/speed", 0).toInt();
-    bool use_cd_text = settings.value("cdaudio/cdtext", true).toBool();
-    QList <CDATrack> tracks;
+    int cd_speed = settings.value(u"cdaudio/speed"_s, 0).toInt();
+    bool use_cd_text = settings.value(u"cdaudio/cdtext"_s, true).toBool();
+    QList<CDATrack> tracks;
     cdio_log_set_handler(log_handler); //setup cdio log handler
     CdIo_t *cdio = nullptr;
     QString device_path = device;
-    if (device_path.isEmpty() || device_path == "/")
-        device_path = settings.value("cdaudio/device").toString();
-    if (device_path.isEmpty() || device_path == "/")
+    if (device_path.isEmpty() || device_path == "/"_L1)
+        device_path = settings.value(u"cdaudio/device"_s).toString();
+    if (device_path.isEmpty() || device_path == "/"_L1)
     {
         char **cd_drives = cdio_get_devices_with_cap(nullptr, CDIO_FS_AUDIO, true); //get drive list with CDA disks
         // open first audio capable cd drive
@@ -116,17 +115,17 @@ QList<CDATrack> DecoderCDAudio::generateTrackList(const QString &device, TrackIn
             cdio = cdio_open_cd(*cd_drives);
             if (!cdio)
             {
-                qWarning("DecoderCDAudio: failed to open CD.");
+                qCWarning(plugin, "failed to open CD.");
                 cdio_free_device_list(cd_drives);
                 return tracks;
             }
-            qDebug("DecoderCDAudio: found cd audio capable drive \"%s\"", *cd_drives);
-            device_path = QString(*cd_drives);
+            qCDebug(plugin, "found cd audio capable drive \"%s\"", *cd_drives);
+            device_path = QString::fromLatin1(*cd_drives);
             cdio_free_device_list(cd_drives); //free device list
         }
         else
         {
-            qWarning("DecoderCDAudio: unable to find cd audio drive.");
+            qCWarning(plugin, "unable to find cd audio drive.");
             cdio_free_device_list(cd_drives);
             return tracks;
         }
@@ -136,24 +135,24 @@ QList<CDATrack> DecoderCDAudio::generateTrackList(const QString &device, TrackIn
         cdio = cdio_open_cd(device_path.toLatin1().constData());
         if (!cdio)
         {
-            qWarning("DecoderCDAudio: failed to open CD.");
+            qCWarning(plugin, "failed to open CD.");
             return tracks;
         }
-        qDebug("DecoderCDAudio: using cd audio capable drive \"%s\"", qPrintable(device_path));
+        qCDebug(plugin, "using cd audio capable drive \"%s\"", qPrintable(device_path));
     }
 
     if(!m_track_cache.isEmpty() && !cdio_get_media_changed(cdio))
     {
-        qDebug("DecoderCDAudio: using track cache...");
+        qCDebug(plugin, "using track cache...");
         cdio_destroy(cdio);
         return m_track_cache;
     }
 
     if (cd_speed)
     {
-        qDebug("DecoderCDAudio: setting drive speed to %dX.", cd_speed);
+        qCDebug(plugin, "setting drive speed to %dX.", cd_speed);
         if (cdio_set_speed(cdio, 1) != DRIVER_OP_SUCCESS)
-            qWarning("DecoderCDAudio: unable to set drive speed to %dX.", cd_speed);
+            qCWarning(plugin, "unable to set drive speed to %dX.", cd_speed);
     }
 
     cdrom_drive_t *pcdrom_drive = cdio_cddap_identify_cdio(cdio, 1, nullptr); //create paranoya CD-ROM object
@@ -163,12 +162,14 @@ QList<CDATrack> DecoderCDAudio::generateTrackList(const QString &device, TrackIn
 
     if ((first_track_number == CDIO_INVALID_TRACK) || (last_track_number == CDIO_INVALID_TRACK))
     {
-        qWarning("DecoderCDAudio: invalid first (last) track number.");
+        qCWarning(plugin, "invalid first (last) track number.");
         cdio_destroy(cdio);
         cdio = nullptr;
         return tracks;
     }
+#ifdef WITH_LIBCDDB
     bool use_cddb = true;
+#endif
     //fill track list
     for (int i = first_track_number; i <= last_track_number; ++i)
     {
@@ -177,7 +178,7 @@ QList<CDATrack> DecoderCDAudio::generateTrackList(const QString &device, TrackIn
         t.last_sector = cdio_get_track_last_lsn(pcdrom_drive->p_cdio, i);
         t.info.setDuration((t.last_sector - t.first_sector +1) * 1000 / 75);
         t.info.setValue(Qmmp::TRACK, i);
-        t.info.setPath(QString("cdda://%1#%2").arg(device_path).arg(i));
+        t.info.setPath(QStringLiteral("cdda://%1#%2").arg(device_path).arg(i));
 
         if(parts & TrackInfo::Properties)
         {
@@ -190,25 +191,13 @@ QList<CDATrack> DecoderCDAudio::generateTrackList(const QString &device, TrackIn
 
         if ((t.first_sector == CDIO_INVALID_LSN) || (t.last_sector== CDIO_INVALID_LSN))
         {
-            qWarning("DecoderCDAudio: invalid stard(end) lsn for the track %d.", i);
+            qCWarning(plugin, "invalid stard(end) lsn for the track %d.", i);
             tracks.clear();
             cdio_destroy(cdio);
             cdio = nullptr;
             return tracks;
         }
         //cd text
-#if LIBCDIO_VERSION_NUM <= 83
-        cdtext_t *cdtext = use_cd_text ? cdio_get_cdtext(pcdrom_drive->p_cdio, i) : nullptr;
-        if (cdtext && cdtext->field[CDTEXT_TITLE])
-        {
-            t.info.setValue(Qmmp::TITLE, QString::fromLocal8Bit(cdtext->field[CDTEXT_TITLE]));
-            t.info.setValue(Qmmp::ARTIST, QString::fromLocal8Bit(cdtext->field[CDTEXT_PERFORMER]));
-            t.info.setValue(Qmmp::GENRE, QString::fromLocal8Bit(cdtext->field[CDTEXT_GENRE]));
-            t.info.setValue(Qmmp::COMMENT, QString::fromLocal8Bit(cdtext->field[CDTEXT_MESSAGE]));
-            t.info.setValue(Qmmp::COMPOSER, QString::fromLocal8Bit(cdtext->field[CDTEXT_COMPOSER]));
-            use_cddb = false;
-        }
-#else
         cdtext_t *cdtext = use_cd_text ? cdio_get_cdtext(pcdrom_drive->p_cdio) : nullptr;
         if (cdtext)
         {
@@ -217,46 +206,48 @@ QList<CDATrack> DecoderCDAudio::generateTrackList(const QString &device, TrackIn
             t.info.setValue(Qmmp::GENRE, QString::fromUtf8(cdtext_get_const(cdtext,CDTEXT_FIELD_GENRE,i)));
             t.info.setValue(Qmmp::COMMENT, QString::fromUtf8(cdtext_get_const(cdtext,CDTEXT_FIELD_MESSAGE,i)));
             t.info.setValue(Qmmp::COMPOSER, QString::fromUtf8(cdtext_get_const(cdtext,CDTEXT_FIELD_COMPOSER,i)));
+#ifdef WITH_LIBCDDB
             use_cddb = false;
-        }
 #endif
+        }
         else
-            t.info.setValue(Qmmp::TITLE, QString("CDA Track %1").arg(i, 2, 10, QChar('0')));
+            t.info.setValue(Qmmp::TITLE, QStringLiteral("CDA Track %1").arg(i, 2, 10, QLatin1Char('0')));
         tracks  << t;
     }
-    qDebug("DecoderCDAudio: found %d audio tracks", tracks.size());
+    qCDebug(plugin) << "found" << tracks.size() << "audio tracks";
 
-    use_cddb = use_cddb && settings.value("cdaudio/use_cddb", false).toBool();
+#ifdef WITH_LIBCDDB
+    use_cddb = use_cddb && settings.value(u"cdaudio/use_cddb"_s, false).toBool();
     if(use_cddb)
     {
-        qDebug("DecoderCDAudio: reading CDDB...");
+        qCDebug(plugin, "reading CDDB...");
         cddb_log_set_handler(cddb_log_handler);
         cddb_conn_t *cddb_conn = cddb_new ();
         cddb_disc_t *cddb_disc = nullptr;
         lba_t lba;
         if (!cddb_conn)
-            qWarning ("DecoderCDAudio: unable to create cddb connection");
+           qCWarning(plugin) << "unable to create cddb connection";
         else
         {
-            cddb_cache_disable (cddb_conn); //disable libcddb cache, use own cache implementation instead
-            settings.beginGroup("cdaudio");
-            cddb_set_server_name (cddb_conn, settings.value("cddb_server", "gnudb.org").toByteArray().constData());
-            cddb_set_server_port (cddb_conn, settings.value("cddb_port", 8880).toInt());
+            cddb_cache_disable(cddb_conn); //disable libcddb cache, use own cache implementation instead
+            settings.beginGroup(u"cdaudio"_s);
+            cddb_set_server_name(cddb_conn, settings.value(u"cddb_server"_s, u"gnudb.org"_s).toByteArray().constData());
+            cddb_set_server_port(cddb_conn, settings.value(u"cddb_port"_s, 8880).toInt());
 
-            if (settings.value("cddb_http", false).toBool())
+            if (settings.value(u"cddb_http"_s, false).toBool())
             {
                 cddb_http_enable (cddb_conn);
-                cddb_set_http_path_query (cddb_conn, settings.value("cddb_path").toByteArray().constData());
+                cddb_set_http_path_query (cddb_conn, settings.value(u"cddb_path"_s).toByteArray().constData());
                 if (QmmpSettings::instance()->isProxyEnabled() && QmmpSettings::instance()->proxyType() == QmmpSettings::HTTP_PROXY)
                 {
                     QUrl proxy = QmmpSettings::instance()->proxy();
-                    cddb_http_proxy_enable (cddb_conn);
-                    cddb_set_http_proxy_server_name (cddb_conn, proxy.host().toLatin1().constData());
-                    cddb_set_http_proxy_server_port (cddb_conn, proxy.port());
+                    cddb_http_proxy_enable(cddb_conn);
+                    cddb_set_http_proxy_server_name(cddb_conn, proxy.host().toLatin1().constData());
+                    cddb_set_http_proxy_server_port(cddb_conn, proxy.port());
                     if(QmmpSettings::instance()->useProxyAuth())
                     {
-                        cddb_set_http_proxy_username (cddb_conn, proxy.userName().toLatin1().constData());
-                        cddb_set_http_proxy_password (cddb_conn, proxy.password().toLatin1().constData());
+                        cddb_set_http_proxy_username(cddb_conn, proxy.userName().toLatin1().constData());
+                        cddb_set_http_proxy_password(cddb_conn, proxy.password().toLatin1().constData());
                     }
                 }
             }
@@ -275,22 +266,22 @@ QList<CDATrack> DecoderCDAudio::generateTrackList(const QString &device, TrackIn
 
             cddb_disc_calc_discid (cddb_disc);
             uint id = cddb_disc_get_discid (cddb_disc);
-            qDebug ("DecoderCDAudio: disc id = %x", id);
+            qCDebug(plugin, "disc id = %x", id);
 
 
             if(readFromCache(&tracks, id))
-                qDebug("DecoderCDAudio: using local cddb cache");
+                qCDebug(plugin, "using local cddb cache");
             else
             {
                 int matches = cddb_query (cddb_conn, cddb_disc);
                 if(matches == -1)
                 {
-                    qWarning ("DecoderCDAudio: unable to query the CDDB server, error: %s",
-                              cddb_error_str (cddb_errno(cddb_conn)));
+                    qCWarning(plugin, "unable to query the CDDB server, error: %s",
+                             cddb_error_str (cddb_errno(cddb_conn)));
                 }
                 else if(matches == 0)
                 {
-                    qDebug ("DecoderCDAudio: no CDDB info found");
+                    qCDebug(plugin, "no CDDB info found");
                 }
                 else if(cddb_read(cddb_conn, cddb_disc))
                 {
@@ -308,8 +299,8 @@ QList<CDATrack> DecoderCDAudio::generateTrackList(const QString &device, TrackIn
                 }
                 else
                 {
-                    qWarning ("DecoderCDAudio: unable to read the CDDB info: %s",
-                              cddb_error_str (cddb_errno(cddb_conn)));
+                    qCWarning(plugin, "unable to read the CDDB info: %s",
+                              cddb_error_str(cddb_errno(cddb_conn)));
                 }
             }
         }
@@ -319,6 +310,7 @@ QList<CDATrack> DecoderCDAudio::generateTrackList(const QString &device, TrackIn
         if (cddb_conn)
             cddb_destroy (cddb_conn);
     }
+#endif
 
     cdio_destroy(cdio);
     cdio = nullptr;
@@ -326,45 +318,45 @@ QList<CDATrack> DecoderCDAudio::generateTrackList(const QString &device, TrackIn
     return tracks;
 }
 
-void DecoderCDAudio::saveToCache(QList <CDATrack> tracks,  uint disc_id)
+void DecoderCDAudio::saveToCache(QList<CDATrack> tracks,  uint disc_id)
 {
-    QDir dir(Qmmp::configDir());
-    if(!dir.exists("cddbcache"))
-        dir.mkdir("cddbcache");
-    dir.cd("cddbcache");
-    QString path = dir.absolutePath() + QString("/%1").arg(disc_id, 0, 16);
+    QDir dir(Qmmp::cacheDir());
+    if(!dir.exists(u"cddbcache"_s))
+        dir.mkdir(u"cddbcache"_s);
+    dir.cd(u"cddbcache"_s);
+    QString path = QStringLiteral("%1/%2").arg( dir.absolutePath()).arg(disc_id, 0, 16);
     QSettings settings(path, QSettings::IniFormat);
     settings.clear();
-    settings.setValue("count", tracks.size());
+    settings.setValue(u"count"_s, tracks.size());
     for(int i = 0; i < tracks.size(); ++i)
     {
         CDATrack track = tracks[i];
         QMap<Qmmp::MetaData, QString> meta = track.info.metaData();
-        settings.setValue(QString("artist%1").arg(i), meta[Qmmp::ARTIST]);
-        settings.setValue(QString("title%1").arg(i), meta[Qmmp::TITLE]);
-        settings.setValue(QString("genre%1").arg(i), meta[Qmmp::GENRE]);
-        settings.setValue(QString("album%1").arg(i), meta[Qmmp::ALBUM]);
-        settings.setValue(QString("year%1").arg(i), meta[Qmmp::YEAR]);
+        settings.setValue(QStringLiteral("artist%1").arg(i), meta[Qmmp::ARTIST]);
+        settings.setValue(QStringLiteral("title%1").arg(i), meta[Qmmp::TITLE]);
+        settings.setValue(QStringLiteral("genre%1").arg(i), meta[Qmmp::GENRE]);
+        settings.setValue(QStringLiteral("album%1").arg(i), meta[Qmmp::ALBUM]);
+        settings.setValue(QStringLiteral("year%1").arg(i), meta[Qmmp::YEAR]);
     }
 }
 
-bool DecoderCDAudio::readFromCache(QList <CDATrack> *tracks, uint disc_id)
+bool DecoderCDAudio::readFromCache(QList<CDATrack> *tracks, uint disc_id)
 {
     QString path = Qmmp::configDir();
-    path += QString("/cddbcache/%1").arg(disc_id, 0, 16);
+    path += QStringLiteral("/cddbcache/%1").arg(disc_id, 0, 16);
     if(!QFile::exists(path))
         return false;
     QSettings settings(path, QSettings::IniFormat);
-    int count = settings.value("count").toInt();
+    int count = settings.value(u"count"_s).toInt();
     if(count != tracks->count())
         return false;
     for(int i = 0; i < count; ++i)
     {
-        (*tracks)[i].info.setValue(Qmmp::ARTIST, settings.value(QString("artist%1").arg(i)).toString());
-        (*tracks)[i].info.setValue(Qmmp::TITLE, settings.value(QString("title%1").arg(i)).toString());
-        (*tracks)[i].info.setValue(Qmmp::GENRE, settings.value(QString("genre%1").arg(i)).toString());
-        (*tracks)[i].info.setValue(Qmmp::ALBUM, settings.value(QString("album%1").arg(i)).toString());
-        (*tracks)[i].info.setValue(Qmmp::YEAR, settings.value(QString("year%1").arg(i)).toString());
+        (*tracks)[i].info.setValue(Qmmp::ARTIST, settings.value(QStringLiteral("artist%1").arg(i)).toString());
+        (*tracks)[i].info.setValue(Qmmp::TITLE, settings.value(QStringLiteral("title%1").arg(i)).toString());
+        (*tracks)[i].info.setValue(Qmmp::GENRE, settings.value(QStringLiteral("genre%1").arg(i)).toString());
+        (*tracks)[i].info.setValue(Qmmp::ALBUM, settings.value(QStringLiteral("album%1").arg(i)).toString());
+        (*tracks)[i].info.setValue(Qmmp::YEAR, settings.value(QStringLiteral("year%1").arg(i)).toString());
     }
     return true;
 }
@@ -384,16 +376,14 @@ bool DecoderCDAudio::initialize()
     m_bitrate = 0;
     m_totalTime = 0;
     //extract track from url
-    int track_number = m_url.section("#", -1).toInt();
-    QString device_path = m_url;
-    device_path.remove("cdda://");
-    device_path.remove(QRegularExpression("#\\d+$"));
+    int track_number = -1;
+    QString device_path = TrackInfo::pathFromUrl(m_url, &track_number);
 
     track_number = qMax(track_number, 1);
-    QList <CDATrack> tracks = DecoderCDAudio::generateTrackList(device_path); //generate track list
+    QList<CDATrack> tracks = DecoderCDAudio::generateTrackList(device_path); //generate track list
     if (tracks.isEmpty())
     {
-        qWarning("DecoderCDAudio: initialize failed");
+        qCWarning(plugin, "initialize failed");
         return false;
     }
     //find track by number
@@ -406,18 +396,18 @@ bool DecoderCDAudio::initialize()
         }
     if (track_at < 0)
     {
-        qWarning("DecoderCDAudio: invalid track number");
+        qCWarning(plugin, "invalid track number");
         return false;
     }
 
-    if (device_path.isEmpty() || device_path == "/") //try default path from config
+    if (device_path.isEmpty() || device_path == "/"_L1) //try default path from config
     {
         QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-        device_path = settings.value("cdaudio/device").toString();
-        m_url = QString("cdda://%1#%2").arg(device_path).arg(track_number);
+        device_path = settings.value("cdaudio/device"_L1).toString();
+        m_url = QStringLiteral("cdda://%1#%2").arg(device_path).arg(track_number);
     }
 
-    if (device_path.isEmpty() || device_path == "/")
+    if (device_path.isEmpty() || device_path == "/"_L1)
     {
         char **cd_drives = cdio_get_devices_with_cap(nullptr, CDIO_FS_AUDIO, true); //get drive list with CDA disks
         // open first audio capable cd drive
@@ -426,16 +416,16 @@ bool DecoderCDAudio::initialize()
             m_cdio = cdio_open_cd(*cd_drives);
             if (!m_cdio)
             {
-                qWarning("DecoderCDAudio: failed to open CD.");
+                qCWarning(plugin, "failed to open CD.");
                 cdio_free_device_list(cd_drives);
                 return false;
             }
-            qDebug("DecoderCDAudio: found cd audio capable drive \"%s\"", *cd_drives);
+            qCDebug(plugin, "found cd audio capable drive \"%s\"", *cd_drives);
             cdio_free_device_list(cd_drives);  //free device list
         }
         else
         {
-            qWarning("DecoderCDAudio: unable to find cd audio drive.");
+            qCWarning(plugin, "unable to find cd audio drive.");
             return false;
         }
     }
@@ -444,10 +434,10 @@ bool DecoderCDAudio::initialize()
         m_cdio = cdio_open_cd(device_path.toLatin1().constData());
         if (!m_cdio)
         {
-            qWarning("DecoderCDAudio: failed to open CD.");
+            qCWarning(plugin, "failed to open CD.");
             return false;
         }
-        qDebug("DecoderCDAudio: using cd audio capable drive \"%s\"", qPrintable(device_path));
+        qCDebug(plugin, "using cd audio capable drive \"%s\"", qPrintable(device_path));
     }
     configure(44100, 2, Qmmp::PCM_S16LE);
     m_bitrate = 1411;
@@ -456,9 +446,9 @@ bool DecoderCDAudio::initialize()
     m_current_sector = tracks[track_at].first_sector;
     m_last_sector = tracks[track_at].last_sector;
     addMetaData(tracks[track_at].info.metaData()); //send metadata
-    setProperty(Qmmp::FORMAT_NAME, "CDDA");
+    setProperty(Qmmp::FORMAT_NAME, u"CDDA"_s);
     setProperty(Qmmp::BITRATE, m_bitrate);
-    qDebug("DecoderCDAudio: initialize succes");
+    qCDebug(plugin, "initialize succes");
     return true;
 }
 
@@ -489,11 +479,9 @@ qint64 DecoderCDAudio::read(unsigned char *audio, qint64 maxSize)
             m_buffer_at = 0;
             return -1;
         }
-        else
-        {
-            m_buffer_at = secorts_to_read * CDIO_CD_FRAMESIZE_RAW;
-            m_current_sector += secorts_to_read;
-        }
+
+        m_buffer_at = secorts_to_read * CDIO_CD_FRAMESIZE_RAW;
+        m_current_sector += secorts_to_read;
     }
 
     if(m_buffer_at > 0)
