@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,8 +21,10 @@
 #include <QMessageBox>
 #include <QSettings>
 #include <cdio/version.h>
+#ifdef WITH_LIBCDDB
 #include <cddb/version.h>
-#include "settingsdialog.h"
+#endif
+#include "cdaudiosettingsdialog.h"
 #include "decoder_cdaudio.h"
 #include "decodercdaudiofactory.h"
 
@@ -32,10 +34,10 @@
 DecoderCDAudioFactory::DecoderCDAudioFactory()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    if(settings.value("cdaudio/cddb_server").toByteArray() == "freedb.org")
+    if(settings.value("cdaudio/cddb_server"_L1).toByteArray() == "freedb.org")
     {
-        qDebug("DecoderCDAudioFactory: switching to gnudb.org");
-        settings.setValue("cdaudio/cddb_server", "gnudb.org");
+        qCDebug(plugin, "switching to gnudb.org");
+        settings.setValue(u"cdaudio/cddb_server"_s, u"gnudb.org"_s);
     }
 }
 
@@ -48,8 +50,8 @@ DecoderProperties DecoderCDAudioFactory::properties() const
 {
     DecoderProperties properties;
     properties.name = tr("CD Audio Plugin");
-    properties.shortName = "cdaudio";
-    properties.protocols = QStringList { "cdda" };
+    properties.shortName = "cdaudio"_L1;
+    properties.protocols = QStringList { u"cdda"_s };
     properties.hasAbout = true;
     properties.noInput = true;
     properties.hasSettings = true;
@@ -66,13 +68,13 @@ QList<TrackInfo *> DecoderCDAudioFactory::createPlayList(const QString &path, Tr
 {
     QList<TrackInfo*> list;
 
-    if(path.contains("#"))
+    if(path.contains(QLatin1Char('#')))
         return list;
 
     QString device_path = path;
-    device_path.remove("cdda://");
-    QList <CDATrack> tracks = DecoderCDAudio::generateTrackList(device_path, parts);
-    for(const CDATrack &t : qAsConst(tracks))
+    device_path.remove(u"cdda://"_s);
+    QList<CDATrack> tracks = DecoderCDAudio::generateTrackList(device_path, parts);
+    for(const CDATrack &t : std::as_const(tracks))
     {
         list << new TrackInfo(t.info);
     }
@@ -86,20 +88,24 @@ MetaDataModel* DecoderCDAudioFactory::createMetaDataModel(const QString &path, b
     return nullptr;
 }
 
-void DecoderCDAudioFactory::showSettings(QWidget *parent)
+QDialog *DecoderCDAudioFactory::createSettings(QWidget *parent)
 {
-    SettingsDialog *d = new SettingsDialog(parent);
-    d->show();
+    return new CDAudioSettingsDialog(parent);
 }
 
 void DecoderCDAudioFactory::showAbout(QWidget *parent)
 {
-    QMessageBox::about (parent, tr("About CD Audio Plugin"),
-                        tr("Qmmp CD Audio Plugin")+"\n"+
-                        QString(tr("Compiled against libcdio-%1 and libcddb-%2")).arg(CDIO_VERSION)
-                        .arg(CDDB_VERSION) + "\n" +
-                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>")+"\n"+
-                        tr("Usage: open cdda:/// using Add URL dialog or command line"));
+    QMessageBox::about(parent, tr("About CD Audio Plugin"),
+                       tr("Qmmp CD Audio Plugin") + QChar::LineFeed +
+#ifdef WITH_LIBCDDB
+                       tr("Compiled against libcdio-%1 and libcddb-%2").arg(QLatin1StringView(CDIO_VERSION),
+                                                                            QLatin1StringView(CDDB_VERSION)) +
+#else
+                       tr("Compiled against libcdio-%1").arg(QLatin1StringView(CDIO_VERSION)) +
+#endif
+                       QChar::LineFeed +
+                       tr("Written by: Ilya Kotov <forkotov02@ya.ru>") + QChar::LineFeed +
+                       tr("Usage: open cdda:/// using Add URL dialog or command line"));
 }
 
 QString DecoderCDAudioFactory::translation() const
