@@ -2,89 +2,94 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="it">
 <context>
-    <name>DecoderCDAudioFactory</name>
+    <name>CDAudioSettingsDialog</name>
     <message>
-        <location filename="../decodercdaudiofactory.cpp" line="50"/>
-        <source>CD Audio Plugin</source>
-        <translation>Estensione CD Audio</translation>
-    </message>
-    <message>
-        <location filename="../decodercdaudiofactory.cpp" line="97"/>
-        <source>About CD Audio Plugin</source>
-        <translation>Informazioni sull&apos;estensione CD Audio</translation>
-    </message>
-    <message>
-        <location filename="../decodercdaudiofactory.cpp" line="98"/>
-        <source>Qmmp CD Audio Plugin</source>
-        <translation>Estensione CD Audio per Qmmp</translation>
-    </message>
-    <message>
-        <location filename="../decodercdaudiofactory.cpp" line="99"/>
-        <source>Compiled against libcdio-%1 and libcddb-%2</source>
-        <translation>Compilato con libcdio-%1 e libcddb-%2</translation>
-    </message>
-    <message>
-        <location filename="../decodercdaudiofactory.cpp" line="101"/>
-        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation>Autori: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
-    </message>
-    <message>
-        <location filename="../decodercdaudiofactory.cpp" line="102"/>
-        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
-        <translation>Uso: aprire cdda:/// dalla finestra di dialogo di aggiunta URL, o via riga di comando</translation>
-    </message>
-</context>
-<context>
-    <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="14"/>
         <source>CD Audio Plugin Settings</source>
         <translation>Impostazioni dell&apos;estensione CD Audio</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="29"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="139"/>
         <source>Override device:</source>
         <translation>Sovrascrivi dispositivo:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="42"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="129"/>
         <source>Limit cd speed:</source>
         <translation>Limita la velocità del CD:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="62"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="122"/>
         <source>Use cd-text</source>
         <translation>Usa CD Text</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="69"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="39"/>
         <source>CDDB</source>
         <translation>CDDB</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="78"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="48"/>
         <source>Use HTTP instead of CDDBP</source>
         <translation>Usa HTTP invece di CDDBP</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="88"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="58"/>
         <source>Server:</source>
         <translation>Server:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="95"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="65"/>
         <source>Path:</source>
         <translation>Percorso:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="105"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="75"/>
         <source>Port:</source>
         <translation>Porta:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="117"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="87"/>
         <source>Clear CDDB cache</source>
         <translation>Pulisci la cache CDDB</translation>
     </message>
 </context>
+<context>
+    <name>DecoderCDAudioFactory</name>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="52"/>
+        <source>CD Audio Plugin</source>
+        <translation>Estensione CD Audio</translation>
+    </message>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="98"/>
+        <source>About CD Audio Plugin</source>
+        <translation>Informazioni sull&apos;estensione CD Audio</translation>
+    </message>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="99"/>
+        <source>Qmmp CD Audio Plugin</source>
+        <translation>Estensione CD Audio per Qmmp</translation>
+    </message>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="101"/>
+        <source>Compiled against libcdio-%1 and libcddb-%2</source>
+        <translation>Compilato con libcdio-%1 e libcddb-%2</translation>
+    </message>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="104"/>
+        <source>Compiled against libcdio-%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="107"/>
+        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
+        <translation>Autori: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
+    </message>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="108"/>
+        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
+        <translation>Uso: aprire cdda:/// dalla finestra di dialogo di aggiunta URL, o via riga di comando</translation>
+    </message>
+</context>
 </TS>
