@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,7 +24,6 @@
 #include <QSettings>
 #include <QTextStream>
 #include <QTextCodec>
-#include <QRegularExpression>
 #include <qmmp/decoder.h>
 #include <qmmp/metadatamanager.h>
 #ifdef WITH_ENCA
@@ -34,32 +33,26 @@
 
 CueFile::CueFile(const QString &path) : CueParser()
 {
-    m_filePath = path;
-
-    if(path.contains("://"))
-    {
-        m_filePath.remove("cue://");
-        m_filePath.remove(QRegularExpression("#\\d+$"));
-    }
+    m_filePath = path.contains(u"://"_s) ? TrackInfo::pathFromUrl(path) : path;
 
     QFile file(m_filePath);
     if (!file.open(QIODevice::ReadOnly))
     {
-        qDebug("CueFile: error: %s", qPrintable(file.errorString()));
+        qCDebug(plugin, "error: %s", qPrintable(file.errorString()));
         return;
     }
     QByteArray data = file.readAll();
     file.close();
 
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("CUE");
-    m_dirty = settings.value("dirty_cue", false).toBool();
+    settings.beginGroup(u"CUE"_s);
+    m_dirty = settings.value(u"dirty_cue"_s, false).toBool();
     QTextCodec *codec = nullptr;
 #ifdef WITH_ENCA
     EncaAnalyser analyser = nullptr;
-    if(settings.value("use_enca", false).toBool())
+    if(settings.value(u"use_enca"_s, false).toBool())
     {
-        analyser = enca_analyser_alloc(settings.value("enca_lang").toByteArray ().constData());
+        analyser = enca_analyser_alloc(settings.value(u"enca_lang"_s).toByteArray ().constData());
 
         if(analyser)
         {
@@ -68,21 +61,21 @@ CueFile::CueFile(const QString &path) : CueParser()
             if(encoding.charset != ENCA_CS_UNKNOWN)
             {
                 codec = QTextCodec::codecForName(enca_charset_name(encoding.charset,ENCA_NAME_STYLE_ENCA));
-                //qDebug("CUEParser: detected charset: %s",
-                  //     enca_charset_name(encoding.charset,ENCA_NAME_STYLE_ENCA));
+                //qCDebug(plugin, "detected charset: %s",
+                //       enca_charset_name(encoding.charset,ENCA_NAME_STYLE_ENCA));
             }
             enca_analyser_free(analyser);
         }
     }
 #endif
     if(!codec)
-        codec = QTextCodec::codecForName(settings.value("encoding","UTF-8").toByteArray ());
+        codec = QTextCodec::codecForName(settings.value(u"encoding"_s, u"UTF-8"_s).toByteArray ());
     if(!codec)
         codec = QTextCodec::codecForName("UTF-8");
     settings.endGroup();
-    //qDebug("CUEParser: using %s encoding", codec->name().constData());
+    //qCDebug(plugin, "using %s encoding", codec->name().constData());
     loadData(data, codec);
-    setUrl("cue", m_filePath);
+    setUrl(u"cue"_s, m_filePath);
     for(const QString &dataFileName : files())
     {
         QString dataFilePath = getDirtyPath(m_filePath, QFileInfo(m_filePath).dir().filePath(dataFileName));
@@ -90,18 +83,18 @@ CueFile::CueFile(const QString &path) : CueParser()
         QList<TrackInfo *> pl = MetaDataManager::instance()->createPlayList(dataFilePath, TrackInfo::Properties);
         if(!pl.isEmpty())
         {
-            setProperties(dataFileName, pl.first()->properties());
-            setDuration(dataFileName, pl.first()->duration());
+            setProperties(dataFileName, pl.constFirst()->properties());
+            setDuration(dataFileName, pl.constFirst()->duration());
             qDeleteAll(pl);
             pl.clear();
         }
     }
 
-    for(const QString &p : m_dataFiles.values())
+    for(const QString &p : std::as_const(m_dataFiles))
     {
         if(!QFile::exists(p))
         {
-            qDebug("CueFile: unable to find file: %s", qPrintable(p));
+            qCDebug(plugin, "unable to find file: %s", qPrintable(p));
             clear();
             return;
         }
@@ -128,33 +121,33 @@ QStringList CueFile::dataFilePaths() const
 
 QStringList CueFile::splitLine(const QString &line)
 {
-    //qDebug("raw string = %s",qPrintable(line));
+    //qCDebug(plugin, "raw string = %s",qPrintable(line));
     QStringList list;
     QString buf = line.trimmed();
     if (buf.isEmpty())
         return list;
     while (!buf.isEmpty())
     {
-        //qDebug(qPrintable(buf));
-        if (buf.startsWith('"'))
+        //qCDebug(plugin) << buf;
+        if (buf.startsWith(QLatin1Char('"')))
         {
-            int end = buf.indexOf('"',1);
+            int end = buf.indexOf(QLatin1Char('"'), 1);
             if(end == -1) //ignore invalid line
             {
                 list.clear();
-                qWarning("CUEParser: unable to parse line: %s",qPrintable(line));
+                qCWarning(plugin, "unable to parse line: %s",qPrintable(line));
                 return list;
             }
             list << buf.mid (1, end - 1);
-            buf.remove (0, end+1);
+            buf.remove (0, end + 1);
         }
         else
         {
-            int end = buf.indexOf(' ', 0);
+            int end = buf.indexOf(QChar::Space, 0);
             if (end < 0)
                 end = buf.size();
-            list << buf.mid (0, end);
-            buf.remove (0, end);
+            list << buf.mid(0, end);
+            buf.remove(0, end);
         }
         buf = buf.trimmed();
     }
@@ -183,13 +176,14 @@ QString CueFile::getDirtyPath(const QString &cue_path, const QString &path)
 
     if (candidates.isEmpty())
         return path;
-    else if (candidates.count() == 1)
-        return candidates.first();
 
-    int dot = cue_path.lastIndexOf('.');
+    if (candidates.count() == 1)
+        return candidates.constFirst();
+
+    int dot = cue_path.lastIndexOf(QLatin1Char('.'));
     if (dot != -1)
     {
-        QRegularExpression r(QRegularExpression::escape(cue_path.left(dot)) + "\\.[^\\.]+$");
+        QRegularExpression r(QRegularExpression::escape(cue_path.left(dot)) + u"\\.[^\\.]+$"_s);
 
         int index = candidates.indexOf(r);
         int rindex = candidates.lastIndexOf(r);
@@ -197,10 +191,10 @@ QString CueFile::getDirtyPath(const QString &cue_path, const QString &path)
         if ((index != -1) && (index == rindex))
             return candidates[index];
     }
-    dot = path.lastIndexOf('.');
+    dot = path.lastIndexOf(QLatin1Char('.'));
     if (dot != -1)
     {
-        QRegularExpression r(QRegularExpression::escape(path.left(dot)) + "\\.[^\\.]+$");
+        QRegularExpression r(QRegularExpression::escape(path.left(dot)) + u"\\.[^\\.]+$"_s);
 
         int index = candidates.indexOf(r);
         int rindex = candidates.lastIndexOf(r);
