@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -33,10 +33,10 @@ CUEMetaDataModel::CUEMetaDataModel(bool readOnly, const QString &url) : MetaData
     CueFile file(url);
     if(file.isEmpty())
     {
-        qWarning("CUEMetaDataModel: invalid cue file");
+        qCWarning(plugin, "invalid cue file");
         return;
     }
-    int track = url.section("#", -1).toInt();
+    int track = url.section(QLatin1Char('#'), -1).toInt();
     m_dataFilePath = file.dataFilePath(track);
     m_cueFilePath = file.cueFilePath();
 }
@@ -73,12 +73,12 @@ QString CUEMetaDataModel::cue() const
     QByteArray data = file.readAll();
 
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("CUE");
+    settings.beginGroup(u"CUE"_s);
 #ifdef WITH_ENCA
     EncaAnalyser analyser = nullptr;
-    if(settings.value("use_enca", false).toBool())
+    if(settings.value(u"use_enca"_s, false).toBool())
     {
-        analyser = enca_analyser_alloc(settings.value("enca_lang").toByteArray ().constData());
+        analyser = enca_analyser_alloc(settings.value(u"enca_lang"_s).toByteArray ().constData());
 
         if(analyser)
         {
@@ -93,7 +93,7 @@ QString CUEMetaDataModel::cue() const
     }
 #endif
     if(!m_codec)
-        m_codec = QTextCodec::codecForName(settings.value("encoding", "UTF-8").toByteArray());
+        m_codec = QTextCodec::codecForName(settings.value(u"encoding"_s, "UTF-8"_L1).toByteArray());
     settings.endGroup();
 
     return m_codec->toUnicode(data);
@@ -104,7 +104,7 @@ void CUEMetaDataModel::setCue(const QString &content)
     if(!m_codec)
     {
         QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-        m_codec = QTextCodec::codecForName(settings.value("CUE/encoding", "UTF-8").toByteArray());
+        m_codec = QTextCodec::codecForName(settings.value(u"CUE/encoding"_s, "UTF-8"_L1).toByteArray());
     }
 
     QFile file(m_cueFilePath);
