@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2010-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,7 +18,6 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#include <QRegularExpression>
 #include <QSettings>
 #include <qmmp/qmmp.h>
 #include "gmehelper.h"
@@ -28,8 +27,8 @@ GmeHelper::GmeHelper()
      m_emu = nullptr;
 
      QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-     m_fade_length = settings.value("GME/fadeout_length", 7000).toInt();
-     if(settings.value("GME/fadeout", false).toBool())
+     m_fade_length = settings.value(u"GME/fadeout_length"_s, 7000).toInt();
+     if(settings.value(u"GME/fadeout"_s, false).toBool())
          m_fade_length = 0;
 }
 
@@ -45,36 +44,31 @@ Music_Emu *GmeHelper::load(const QString &url, int sample_rate)
     if(m_emu)
         gme_delete(m_emu);
     m_emu = nullptr;
-    QString path = url;
-    if(url.contains("://"))
-    {
-        path.remove("gme://");
-        path.remove(QRegularExpression("#\\d+$"));
-    }
+    QString path = url.contains(u"://"_s) ? TrackInfo::pathFromUrl(url) : url;
     const char *err = nullptr;
     gme_type_t file_type;
-    if((err = gme_identify_file(qPrintable(path),&file_type)))
+    if((err = gme_identify_file(qPrintable(path), &file_type)))
     {
-        qWarning("GmeHelper: %s", err);
+        qCWarning(plugin) << err;
         return nullptr;
     }
     if(!file_type)
     {
-        qWarning("DecoderGme: unsupported music type");
+        qCWarning(plugin, "unsupported music type");
         return nullptr;
     }
     if(!(m_emu = gme_new_emu(file_type, sample_rate)))
     {
-        qWarning("GmeHelper: out of memory");
+        qCWarning(plugin, "out of memory");
         return nullptr;
     }
     if((err = gme_load_file(m_emu, qPrintable(path))))
     {
-        qWarning("GmeHelper: %s", err);
+        qCWarning(plugin) << err;
         return nullptr;
     }
-    QString m3u_path = path.left(path.lastIndexOf("."));
-    m3u_path.append(".m3u");
+    QString m3u_path = path.left(path.lastIndexOf(QLatin1Char('.')));
+    m3u_path.append(u".m3u"_s);
     gme_load_m3u(m_emu, qPrintable(m3u_path));
     m_path = path;
     return m_emu;
@@ -116,7 +110,7 @@ QList<TrackInfo *> GmeHelper::createPlayList(TrackInfo::Parts parts)
             info->setValue(Qmmp::FORMAT_NAME, track_info->system);
         }
 
-        info->setPath("gme://" + m_path + QString("#%1").arg(i+1));
+        info->setPath(u"gme://"_s + m_path + QStringLiteral("#%1").arg(i+1));
         info->setDuration(track_info->length);
         gme_free_info(track_info);
         list << info;
