@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,7 +23,6 @@
 #include <QSettings>
 #include <QFile>
 #include <QTextCodec>
-#include <QtDebug>
 #include <taglib/tag.h>
 #include <taglib/fileref.h>
 #include <taglib/id3v1tag.h>
@@ -32,13 +31,12 @@
 #include <taglib/tfile.h>
 #include <taglib/mpegfile.h>
 #include <taglib/tfilestream.h>
-#include <taglib/id3v2tag.h>
 #include <taglib/id3v2header.h>
 #include <taglib/textidentificationframe.h>
 #include <taglib/id3v2framefactory.h>
 #include "tagextractor.h"
 #include "mpegmetadatamodel.h"
-#include "settingsdialog.h"
+#include "mpegsettingsdialog.h"
 #ifdef WITH_MAD
 #include "decoder_mad.h"
 #endif
@@ -51,7 +49,7 @@
 
 // DecoderMPEGFactory
 
-DecoderMPEGFactory::DecoderMPEGFactory()
+DecoderMpegFactory::DecoderMpegFactory()
 {
     //detecting rusxmms patch
     m_using_rusxmms = false;
@@ -60,13 +58,13 @@ DecoderMPEGFactory::DecoderMPEGFactory()
     TagLib::String tstr(str);
     if(codec->toUnicode(str) == QString::fromUtf8(tstr.toCString(true)))
     {
-        qDebug("DecoderMADFactory: found taglib with rusxmms patch");
+        qCDebug(plugin, "found taglib with rusxmms patch");
         m_using_rusxmms = true;
         TagExtractor::setForceUtf8(m_using_rusxmms);
     }
 }
 
-bool DecoderMPEGFactory::canDecode(QIODevice *input) const
+bool DecoderMpegFactory::canDecode(QIODevice *input) const
 {
     char buf[8192];
     qint64 dataSize = sizeof(buf);
@@ -108,7 +106,7 @@ bool DecoderMPEGFactory::canDecode(QIODevice *input) const
     QString decoderName;
 #if defined(WITH_MAD) && defined(WITH_MPG123)
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    decoderName = settings.value("MPEG/decoder", "mad").toString();
+    decoderName = settings.value(u"MPEG/decoder"_s, u"mad"_s).toString();
 #elif defined(WITH_MAD)
     decoderName = "mad";
 #elif defined(WITH_MPG123)
@@ -116,7 +114,7 @@ bool DecoderMPEGFactory::canDecode(QIODevice *input) const
 #endif
 
 #ifdef WITH_MAD
-    if(decoderName != "mpg123")
+    if(decoderName != "mpg123"_L1)
     {
         struct mad_stream stream;
         struct mad_header header;
@@ -147,7 +145,7 @@ bool DecoderMPEGFactory::canDecode(QIODevice *input) const
 #endif
 
 #ifdef WITH_MPG123
-    if (decoderName == "mpg123")
+    if (decoderName == "mpg123"_L1)
     {
         mpg123_init();
         mpg123_handle *handle = mpg123_new(nullptr, nullptr);
@@ -174,38 +172,38 @@ bool DecoderMPEGFactory::canDecode(QIODevice *input) const
     return false;
 }
 
-DecoderProperties DecoderMPEGFactory::properties() const
+DecoderProperties DecoderMpegFactory::properties() const
 {
     DecoderProperties properties;
     properties.name = tr("MPEG Plugin");
-    properties.shortName = "mpeg";
-    properties.filters = QStringList { "*.mp1", "*.mp2", "*.mp3", "*.wav" };
+    properties.shortName = "mpeg"_L1;
+    properties.filters = QStringList { u"*.mp1"_s, u"*.mp2"_s, u"*.mp3"_s, u"*.wav"_s };
     properties.description = tr("MPEG Files");
-    properties.contentTypes = QStringList { "audio/mp3", "audio/mpeg" };
+    properties.contentTypes = QStringList { u"audio/mp3"_s, u"audio/mpeg"_s };
     properties.hasAbout = true;
     properties.hasSettings = true;
     return properties;
 }
 
-Decoder *DecoderMPEGFactory::create(const QString &, QIODevice *input)
+Decoder *DecoderMpegFactory::create(const QString &, QIODevice *input)
 {
     Decoder *d = nullptr;
 #if defined(WITH_MAD) && defined(WITH_MPG123)
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    if(settings.value("MPEG/decoder", "mad").toString() == "mpg123")
+    if(settings.value(u"MPEG/decoder"_s, u"mad"_s).toString() == "mpg123"_L1)
     {
-        qDebug("DecoderMPEGFactory: using mpg123 decoder");
+        qCDebug(plugin, "using mpg123 decoder");
         d = new DecoderMPG123(input);
     }
     else
     {
-        qDebug("DecoderMPEGFactory: using MAD decoder");
-        bool crc = settings.value("MPEG/enable_crc", false).toBool();
+        qCDebug(plugin, "using MAD decoder");
+        bool crc = settings.value(u"MPEG/enable_crc"_s, false).toBool();
         d = new DecoderMAD(crc, input);
     }
 #elif defined(WITH_MAD)
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    bool crc = settings.value("MPEG/enable_crc", false).toBool();
+    bool crc = settings.value(u"MPEG/enable_crc"_s, false).toBool();
     d = new DecoderMAD(crc, input);
 #elif defined(WITH_MPG123)
     d = new DecoderMPG123(input);
@@ -213,7 +211,7 @@ Decoder *DecoderMPEGFactory::create(const QString &, QIODevice *input)
     return d;
 }
 
-QList<TrackInfo *> DecoderMPEGFactory::createPlayList(const QString &path, TrackInfo::Parts parts, QStringList *)
+QList<TrackInfo *> DecoderMpegFactory::createPlayList(const QString &path, TrackInfo::Parts parts, QStringList *)
 {
     TrackInfo *info = new TrackInfo(path);
 
@@ -230,56 +228,55 @@ QList<TrackInfo *> DecoderMPEGFactory::createPlayList(const QString &path, Track
     if (parts & TrackInfo::MetaData)
     {
         QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-        settings.beginGroup("MPEG");
+        settings.beginGroup("MPEG"_L1);
 
         QList< QMap<Qmmp::MetaData, QString> > metaData;
         uint tag_array[3];
-        tag_array[0] = settings.value("tag_1", SettingsDialog::ID3v2).toInt();
-        tag_array[1] = settings.value("tag_2", SettingsDialog::APE).toInt();
-        tag_array[2] = settings.value("tag_3", SettingsDialog::ID3v1).toInt();
-        bool merge = settings.value("merge_tags", false).toBool();
+        tag_array[0] = settings.value(u"tag_1"_s, MpegSettingsDialog::ID3v2).toInt();
+        tag_array[1] = settings.value(u"tag_2"_s, MpegSettingsDialog::APE).toInt();
+        tag_array[2] = settings.value(u"tag_3"_s, MpegSettingsDialog::ID3v1).toInt();
+        bool merge = settings.value(u"merge_tags"_s, false).toBool();
 
         for (int i = 0; i < 3; ++i)
         {
-            QTextCodec *codec = nullptr;
             TagLib::Tag *tag = nullptr;
             QByteArray codecName;
 
             switch ((uint) tag_array[i])
             {
-            case SettingsDialog::ID3v1:
-                codecName = settings.value("ID3v1_encoding","ISO-8859-1").toByteArray();
+            case MpegSettingsDialog::ID3v1:
+                codecName = settings.value(u"ID3v1_encoding"_s, u"ISO-8859-1"_s).toByteArray();
                 tag = fileRef.ID3v1Tag();
                 break;
-            case SettingsDialog::ID3v2:
-                codecName = settings.value("ID3v2_encoding","UTF-8").toByteArray();
+            case MpegSettingsDialog::ID3v2:
+                codecName = settings.value(u"ID3v2_encoding"_s, u"UTF-8"_s).toByteArray();
                 tag = fileRef.ID3v2Tag();
                 break;
-            case SettingsDialog::APE:
+            case MpegSettingsDialog::APE:
                 codecName = "UTF-8";
                 tag = fileRef.APETag();
                 break;
-            case SettingsDialog::Disabled:
+            case MpegSettingsDialog::Disabled:
                 break;
             }
 
-            if(m_using_rusxmms || codecName.contains("UTF"))
-                codec = QTextCodec::codecForName("UTF-8");
-            else if(!codecName.isEmpty())
-                codec = QTextCodec::codecForName(codecName);
+            if(m_using_rusxmms || codecName.contains("UTF") || codecName.isEmpty())
+                codecName = "UTF-8";
 
-            if (!codec)
-                codec = QTextCodec::codecForName("UTF-8");
-
-            if (tag && codec && !tag->isEmpty())
+            if (tag && !tag->isEmpty())
             {
                 if((tag == fileRef.ID3v1Tag() || tag == fileRef.ID3v2Tag()) && !m_using_rusxmms &&
-                        settings.value("detect_encoding", false).toBool())
+                        settings.value(u"detect_encoding"_s, false).toBool())
                 {
-                    QTextCodec *detectedCodec = TagExtractor::detectCharset(tag);
-                    codec = detectedCodec ? detectedCodec : codec;
+                    QByteArray detectedCharset = TagExtractor::detectCharset(tag);
+                    if(!detectedCharset.isEmpty())
+                        codecName = detectedCharset;
                 }
 
+                QTextCodec *codec = QTextCodec::codecForName(codecName);
+                if(!codec)
+                    codec = QTextCodec::codecForName("UTF-8");
+
                 bool utf = codec->name().contains("UTF");
 
                 QMap<Qmmp::MetaData, QString> tags = {
@@ -327,7 +324,7 @@ QList<TrackInfo *> DecoderMPEGFactory::createPlayList(const QString &path, Track
         }
         settings.endGroup();
 
-        for(const QMap<Qmmp::MetaData, QString> &tags : qAsConst(metaData))
+        for(const QMap<Qmmp::MetaData, QString> &tags : std::as_const(metaData))
         {
             for(int i = Qmmp::TITLE; i <= Qmmp::DISCNUMBER; ++i)
             {
@@ -347,17 +344,17 @@ QList<TrackInfo *> DecoderMPEGFactory::createPlayList(const QString &path, Track
         switch(fileRef.audioProperties()->version())
         {
         case TagLib::MPEG::Header::Version1:
-            info->setValue(Qmmp::FORMAT_NAME, QString("MPEG-1 layer %1").arg(fileRef.audioProperties()->layer()));
+            info->setValue(Qmmp::FORMAT_NAME, QStringLiteral("MPEG-1 layer %1").arg(fileRef.audioProperties()->layer()));
             break;
         case TagLib::MPEG::Header::Version2:
-            info->setValue(Qmmp::FORMAT_NAME, QString("MPEG-2 layer %1").arg(fileRef.audioProperties()->layer()));
+            info->setValue(Qmmp::FORMAT_NAME, QStringLiteral("MPEG-2 layer %1").arg(fileRef.audioProperties()->layer()));
             break;
         case TagLib::MPEG::Header::Version2_5:
-            info->setValue(Qmmp::FORMAT_NAME, QString("MPEG-2.5 layer %1").arg(fileRef.audioProperties()->layer()));
+            info->setValue(Qmmp::FORMAT_NAME, QStringLiteral("MPEG-2.5 layer %1").arg(fileRef.audioProperties()->layer()));
             break;
 #if TAGLIB_MAJOR_VERSION >= 2
         case TagLib::MPEG::Header::Version4:
-            info->setValue(Qmmp::FORMAT_NAME, QString("MPEG-4 layer %1").arg(fileRef.audioProperties()->layer()));
+            info->setValue(Qmmp::FORMAT_NAME, QStringLiteral("MPEG-4 layer %1").arg(fileRef.audioProperties()->layer()));
 #endif
         }
         info->setDuration(fileRef.audioProperties()->lengthInMilliseconds());
@@ -405,40 +402,39 @@ QList<TrackInfo *> DecoderMPEGFactory::createPlayList(const QString &path, Track
     return QList<TrackInfo*>() << info;
 }
 
-MetaDataModel* DecoderMPEGFactory::createMetaDataModel(const QString &path, bool readOnly)
+MetaDataModel* DecoderMpegFactory::createMetaDataModel(const QString &path, bool readOnly)
 {
    return new MPEGMetaDataModel(m_using_rusxmms, path, readOnly);
 }
 
-void DecoderMPEGFactory::showSettings(QWidget *parent)
+QDialog *DecoderMpegFactory::createSettings(QWidget *parent)
 {
-    SettingsDialog *s = new SettingsDialog(m_using_rusxmms, parent);
-    s->show();
+    return new MpegSettingsDialog(m_using_rusxmms, parent);
 }
 
-void DecoderMPEGFactory::showAbout(QWidget *parent)
+void DecoderMpegFactory::showAbout(QWidget *parent)
 {
-    QMessageBox::about (parent, tr("About MPEG Audio Plugin"),
-                        tr("MPEG 1.0/2.0/2.5 layer 1/2/3 audio decoder")+"\n"+
-                        tr("Compiled against:") + "\n" +
+    QMessageBox::about(parent, tr("About MPEG Audio Plugin"),
+                       tr("MPEG 1.0/2.0/2.5 layer 1/2/3 audio decoder") + QChar::LineFeed +
+                       tr("Compiled against:") + QChar::LineFeed +
 #ifdef WITH_MAD
-                        QString("libmad-%1.%2.%3%4")
-                        .arg(MAD_VERSION_MAJOR)
-                        .arg(MAD_VERSION_MINOR)
-                        .arg(MAD_VERSION_PATCH)
-                        .arg(MAD_VERSION_EXTRA) + "\n" +
+                       QStringLiteral("libmad-%1.%2.%3%4")
+                       .arg(MAD_VERSION_MAJOR)
+                       .arg(MAD_VERSION_MINOR)
+                       .arg(MAD_VERSION_PATCH)
+                       .arg(QLatin1StringView(MAD_VERSION_EXTRA)) + QChar::LineFeed +
 #endif
 #ifdef WITH_MPG123
                         tr("mpg123, API version: %1")
-                        .arg(MPG123_API_VERSION) + "\n" +
+                        .arg(MPG123_API_VERSION) + QChar::LineFeed +
 #endif
 
-                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>")+"\n"+
+                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>") + QChar::LineFeed +
                         tr("Source code based on mq3 and madplay projects")
                         );
 }
 
-QString DecoderMPEGFactory::translation() const
+QString DecoderMpegFactory::translation() const
 {
     return QLatin1String(":/mpeg_plugin_");
 }
