@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -35,8 +35,8 @@ public:
     ~MPEGMetaDataModel();
     QList<MetaDataItem> extraProperties() const override;
     QList<TagModel* > tags() const override;
-    QPixmap cover() const override;
-    void setCover(const QPixmap &pix) override;
+    QImage cover() const override;
+    void setCover(const QImage &img) override;
     void removeCover() override;
     QString lyrics() const override;
 
@@ -63,10 +63,10 @@ public:
 
 private:
     bool m_using_rusxmms;
-    QTextCodec *m_codec;
     TagLib::MPEG::File *m_file;
     TagLib::Tag *m_tag;
     TagLib::MPEG::File::TagTypes m_type;
+    QTextCodec *m_codec = nullptr;
 };
 
 #endif // MPEGMETADATAMODEL_H
