@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,9 +22,8 @@
 #include <QSettings>
 #include <QByteArray>
 #include <QBuffer>
-#include <QTextCodec>
-#include <QSettings>
 #include <QSet>
+#include <QTextCodec>
 #include <stdlib.h>
 #ifdef WITH_LIBRCD
 #include <librcd.h>
@@ -53,25 +52,25 @@ QMap<Qmmp::MetaData, QString> TagExtractor::id3v2tag() const
         return QMap<Qmmp::MetaData, QString>();
 
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("MPEG");
-    QByteArray codecName = settings.value("ID3v2_encoding","UTF-8").toByteArray ();
-    QTextCodec *codec = nullptr;
+    settings.beginGroup(u"MPEG"_s);
+    QByteArray codecName = settings.value(u"ID3v2_encoding"_s, u"UTF-8"_s).toByteArray();
 
-    if(m_using_rusxmms || codecName.contains("UTF"))
-        codec = QTextCodec::codecForName("UTF-8");
-    else if(!codecName.isEmpty())
-        codec = QTextCodec::codecForName(codecName);
+    if(m_using_rusxmms || codecName.contains("UTF") || codecName.isEmpty())
+        codecName = "UTF-8";
 
-    if (!codec)
-        codec = QTextCodec::codecForName("UTF-8");
-
-    if(!m_using_rusxmms && settings.value("detect_encoding", false).toBool())
+    if(!m_using_rusxmms && settings.value("detect_encoding"_L1, false).toBool())
     {
-        QTextCodec *detectedCodec = detectCharset(&tag);
-        codec = detectedCodec ? detectedCodec : codec;
+        QByteArray detectedCharset = TagExtractor::detectCharset(&tag);
+        if(!detectedCharset.isEmpty())
+            codecName = detectedCharset;
     }
     settings.endGroup();
 
+    QTextCodec *codec = QTextCodec::codecForName(codecName);
+
+    if(!codec)
+        codec = QTextCodec::codecForName("UTF-8");
+
     bool utf = codec->name().contains("UTF");
 
     QMap<Qmmp::MetaData, QString> tags = {
@@ -92,8 +91,9 @@ QMap<Qmmp::MetaData, QString> TagExtractor::id3v2tag() const
     if(!tag.frameListMap()["TPOS"].isEmpty())
     {
         TagLib::String disc = tag.frameListMap()["TPOS"].front()->toString();
-        tags.insert(Qmmp::DISCNUMBER, QString(disc.toCString()).trimmed());
+        tags.insert(Qmmp::DISCNUMBER, QString::fromLatin1(disc.toCString()).trimmed());
     }
+
     return tags;
 }
 
@@ -102,13 +102,12 @@ void TagExtractor::setForceUtf8(bool enabled)
     m_using_rusxmms = enabled;
 }
 
-QTextCodec *TagExtractor::detectCharset(const TagLib::Tag *tag)
+QByteArray TagExtractor::detectCharset(const TagLib::Tag *tag)
 {
     if(tag->title().isLatin1() && tag->album().isLatin1() &&
             tag->artist().isLatin1() && tag->comment().isLatin1())
     {
 #ifdef WITH_LIBRCD
-        QTextCodec *codec = nullptr;
         QSet<int> charsets;
         charsets << rcdGetRussianCharset(tag->title().toCString(), 0);
         charsets << rcdGetRussianCharset(tag->artist().toCString(), 0);
@@ -116,22 +115,20 @@ QTextCodec *TagExtractor::detectCharset(const TagLib::Tag *tag)
         charsets << rcdGetRussianCharset(tag->comment().toCString(), 0);
 
         if(charsets.contains(RUSSIAN_CHARSET_WIN))
-            codec = QTextCodec::codecForName("WINDOWS-1251");
-        else if(charsets.contains(RUSSIAN_CHARSET_ALT))
-            codec = QTextCodec::codecForName("IBM866");
-        else if(charsets.contains(RUSSIAN_CHARSET_KOI))
-            codec = QTextCodec::codecForName("KOI8-R");
-        else if(charsets.contains(RUSSIAN_CHARSET_UTF8))
-            codec = QTextCodec::codecForName("UTF-8");
-        else if(charsets.contains(RUSSIAN_CHARSET_LATIN))
-            codec = QTextCodec::codecForName("ISO-8859-1");
-
-        return codec;
+            return "WINDOWS-1251"_ba;
+        if(charsets.contains(RUSSIAN_CHARSET_ALT))
+            return "IBM866"_ba;
+        if(charsets.contains(RUSSIAN_CHARSET_KOI))
+            return "KOI8-R"_ba;
+        if(charsets.contains(RUSSIAN_CHARSET_UTF8))
+            return "UTF-8"_ba;
+        if(charsets.contains(RUSSIAN_CHARSET_LATIN))
+            return "ISO-8859-1"_ba;
 #else
-        return nullptr;
+        return QByteArray();
 #endif
     }
-    return QTextCodec::codecForName("UTF-8");
+    return "UTF-8";
 }
 
 ID3v2Tag::ID3v2Tag(QByteArray *array, long offset) : TagLib::ID3v2::Tag(),
@@ -153,7 +150,7 @@ void ID3v2Tag::read ()
     uint to_read = TagLib::ID3v2::Header::size();
     if (to_read > 2048 - uint(m_offset))
         return;
-    header()->setData(TagLib::ByteVector(m_buf->read(to_read).data(), to_read));
+    header()->setData(TagLib::ByteVector(m_buf->read(to_read).constData(), to_read));
     to_read = header()->tagSize();
     if (!to_read ||  2048 < m_offset + TagLib::ID3v2::Header::size())
         return;
