@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,7 +18,6 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#include <QRegularExpression>
 #include <sidplayfp/SidDatabase.h>
 #include "sidhelper.h"
 
@@ -27,8 +26,7 @@ SIDHelper::SIDHelper(SidDatabase *db) : m_db(db)
 
 SIDHelper::~SIDHelper()
 {
-    if(m_tune)
-        delete m_tune;
+    delete m_tune;
     m_tune = nullptr;
 }
 
@@ -39,14 +37,10 @@ SidTune *SIDHelper::load(const QString &url)
         delete m_tune;
         m_tune = nullptr;
     }
-    QString path = url;
+
     int track = 1;
-    if(url.contains("://"))
-    {
-        path.remove("sid://");
-        path.remove(QRegularExpression("#\\d+$"));
-        track = url.section("#", -1).toInt();
-    }
+    QString path = url.contains(u"://"_s) ? TrackInfo::pathFromUrl(url, &track) : url;
+
     m_tune = new SidTune(qPrintable(path));
     m_tune->selectSong(track - 1);
     m_path = path;
@@ -80,7 +74,7 @@ QList<TrackInfo *> SIDHelper::createPlayList(TrackInfo::Parts parts)
         if(length > -1)
             info->setDuration(length * 1000);
 
-        info->setPath("sid://" + m_path + QString("#%1").arg(i));
+        info->setPath(QStringLiteral("sid://%1#%2").arg(m_path).arg(i));
         list << info;
     }
     return list;
