@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -35,6 +35,7 @@
 #define WAVE_FORMAT_IEEE_FLOAT 0x0003
 #define WAVE_FORMAT_ALAW 0x0006
 #define WAVE_FORMAT_MULAW 0x0007
+#define WAVE_FORMAT_EXTENSIBLE 0xfffe
 
 // DecoderSndFileFactory
 bool DecoderSndFileFactory::canDecode(QIODevice *input) const
@@ -49,7 +50,7 @@ bool DecoderSndFileFactory::canDecode(QIODevice *input) const
 
         if(!memcmp(buf + 12, "fmt ", 4))
         {
-            subformat = (quint16(buf[21]) << 8) + buf[20];
+            subformat = buf[21] << 8 | buf[20];
         }
         else if(!input->isSequential())
         {
@@ -65,16 +66,15 @@ bool DecoderSndFileFactory::canDecode(QIODevice *input) const
                     subformat = (quint16(buf[9]) << 8) + buf[8];
                     break;
                 }
-                else if(!memcmp(buf, "JUNK", 4) || !memcmp(buf, "bext", 4) || !memcmp(buf, "fact", 4))
+
+                if(!memcmp(buf, "JUNK", 4) || !memcmp(buf, "bext", 4) || !memcmp(buf, "fact", 4))
                 {
-                    size_t size = buf[4] + (buf[5] << 8) + (buf[6] << 16) + (buf[7] << 24);
+                    size_t size = buf[4] | buf[5] << 8 | buf[6] << 16 | buf[7] << 24;
                     if(!input->seek(input->pos() + size + 8))
                         break;
                 }
-                else
-                {
-                    break;
-                }
+
+                break;
             }
             input->seek(0);
         }
@@ -86,6 +86,7 @@ bool DecoderSndFileFactory::canDecode(QIODevice *input) const
         case WAVE_FORMAT_IEEE_FLOAT:
         case WAVE_FORMAT_ALAW:
         case WAVE_FORMAT_MULAW:
+        case WAVE_FORMAT_EXTENSIBLE:
             return true;
         default:
             return false;
@@ -116,10 +117,12 @@ DecoderProperties DecoderSndFileFactory::properties() const
 {
     DecoderProperties properties;
     properties.name = tr("Sndfile Plugin");
-    properties.filters = QStringList { "*.wav", "*.au", "*.snd", "*.aif", "*.aiff", "*.8svx", "*.sph", "*.sf", "*.voc", "*.w64" };
+    properties.filters = QStringList {
+        u"*.wav"_s, u"*.au"_s, u"*.snd"_s, u"*.aif"_s, u"*.aiff"_s, u"*.8svx"_s, u"*.sph"_s, u"*.sf"_s, u"*.voc"_s, u"*.w64"_s
+    };
     properties.description = tr("PCM Files");
     //properties.contentType = "";
-    properties.shortName = "sndfile";
+    properties.shortName = "sndfile"_L1;
     properties.hasAbout = true;
     properties.hasSettings = false;
     properties.noInput = false;
@@ -213,17 +216,19 @@ MetaDataModel* DecoderSndFileFactory::createMetaDataModel(const QString&, bool)
     return nullptr;
 }
 
-void DecoderSndFileFactory::showSettings(QWidget *)
-{}
+QDialog *DecoderSndFileFactory::createSettings(QWidget *)
+{
+    return nullptr;
+}
 
 void DecoderSndFileFactory::showAbout(QWidget *parent)
 {
     char version [128] = { 0 };
     sf_command (nullptr, SFC_GET_LIB_VERSION, version, sizeof (version)) ;
-    QMessageBox::about (parent, tr("About Sndfile Audio Plugin"),
-                        tr("Qmmp Sndfile Audio Plugin")+"\n"+
-                        tr("Compiled against")+" "+QString(version)+"\n" +
-                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
+    QMessageBox::about(parent, tr("About Sndfile Audio Plugin"),
+                       tr("Qmmp Sndfile Audio Plugin") + QChar::LineFeed +
+                       tr("Compiled against %1").arg(QString::fromLatin1(version)) + QChar::LineFeed +
+                       tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
 }
 
 QString DecoderSndFileFactory::translation() const
