@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -25,7 +25,6 @@
 #include <taglib/vorbisfile.h>
 #include <taglib/xiphcomment.h>
 #include <taglib/tfilestream.h>
-#include <taglib/tfilestream.h>
 
 class VorbisCommentModel;
 
@@ -37,8 +36,8 @@ public:
     friend class VorbisCommentModel;
 
     QList<TagModel* > tags() const override;
-    QPixmap cover() const override;
-    void setCover(const QPixmap &pix) override;
+    QImage cover() const override;
+    void setCover(const QImage &pix) override;
     void removeCover() override;
     QString lyrics() const override;
 
