@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,7 +21,6 @@
 #include <QObject>
 #include <QIODevice>
 #include <QFile>
-#include <QRegularExpression>
 #include <math.h>
 #include <stdint.h>
 #include <qmmp/cueparser.h>
@@ -38,8 +37,7 @@ DecoderWavPack::DecoderWavPack(const QString &path) : Decoder(),
 DecoderWavPack::~DecoderWavPack()
 {
     deinit();
-    if (m_output_buf)
-        delete [] m_output_buf;
+    delete [] m_output_buf;
     m_output_buf = nullptr;
 }
 
@@ -49,11 +47,10 @@ bool DecoderWavPack::initialize()
     m_totalTime = 0;
 
     char err[80] = { 0 };
-    if (m_path.startsWith("wvpack://")) //embeded cue track
+    if(m_path.startsWith(u"wvpack://"_s)) //embeded cue track
     {
-        QString p = m_path;
-        p.remove("wvpack://");
-        p.remove(QRegularExpression("#\\d+$"));
+        QString p = TrackInfo::pathFromUrl(m_path);
+
 #if defined(Q_OS_WIN) && defined(OPEN_FILE_UTF8)
         m_context = WavpackOpenFileInput (p.toUtf8().constData(),
                                           err, OPEN_WVC | OPEN_TAGS | OPEN_FILE_UTF8, 0);
@@ -62,21 +59,22 @@ bool DecoderWavPack::initialize()
 #endif
         if (!m_context)
         {
-            qWarning("DecoderWavPack: error: %s", err);
+            qCWarning(plugin, "error: %s", err);
             return false;
         }
-        int cue_len = WavpackGetTagItem (m_context, "cuesheet", nullptr, 0);
+        int cue_len = WavpackGetTagItem(m_context, "cuesheet", nullptr, 0);
         if (cue_len > 0)
         {
-            char *value = (char*)malloc (cue_len * 2 + 1);
+            char *value = (char*)malloc(cue_len * 2 + 1);
             WavpackGetTagItem(m_context, "cuesheet", value, cue_len + 1);
             m_parser = new CueParser(value);
+            free(value);
             m_parser->setDuration((qint64)WavpackGetNumSamples(m_context) * 1000 / WavpackGetSampleRate(m_context));
-            m_parser->setUrl("wvpack", p);
-            m_track = m_path.section("#", -1).toInt();
+            m_parser->setUrl(u"wvpack"_s, p);
+            m_track = m_path.section(QLatin1Char('#'), -1).toInt();
             if(m_track < 1 || m_track > m_parser->count())
             {
-                qWarning("DecoderWavPack: invalid cuesheet comment");
+                qCWarning(plugin, "invalid cuesheet comment");
                 return false;
             }
             m_path = p;
@@ -95,7 +93,7 @@ bool DecoderWavPack::initialize()
 
     if (!m_context)
     {
-        qWarning("DecoderWavPack: error: %s", err);
+        qCWarning(plugin, "error: %s", err);
         return false;
     }
 
@@ -106,7 +104,7 @@ bool DecoderWavPack::initialize()
     ChannelMap chmap = findChannelMap(m_chan);
     if(chmap.isEmpty())
     {
-        qWarning("DecoderWavPack: unsupported number of channels: %d", m_chan);
+        qCWarning(plugin, "unsupported number of channels: %d", m_chan);
         return false;
     }
 
@@ -131,7 +129,7 @@ bool DecoderWavPack::initialize()
 #endif
         break;
     default:
-        qWarning("DecoderWavPack: unsupported bit depth");
+        qCWarning(plugin, "unsupported bit depth");
         return false;
     }
     if(!m_parser)
@@ -147,7 +145,7 @@ bool DecoderWavPack::initialize()
     }
     m_totalBytes = 0;
     m_frame_size = audioParameters().frameSize();
-    qDebug("DecoderWavPack: initialize succes");
+    qCDebug(plugin, "initialize succes");
     return true;
 }
 
@@ -171,8 +169,7 @@ void DecoderWavPack::deinit()
     if (m_context)
         WavpackCloseFile (m_context);
     m_context = nullptr;
-    if(m_parser)
-        delete m_parser;
+    delete m_parser;
     m_parser = nullptr;
 }
 
@@ -206,8 +203,8 @@ const QString DecoderWavPack::nextURL() const
 {
     if(m_parser && m_track +1 <= m_parser->count())
         return m_parser->url(m_track + 1);
-    else
-        return QString();
+
+    return QString();
 }
 
 void DecoderWavPack::next()
