@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,7 +21,7 @@
 #include <QMessageBox>
 #include "wildmidihelper.h"
 #include "decoder_wildmidi.h"
-#include "settingsdialog.h"
+#include "wildmidisettingsdialog.h"
 #include "decoderwildmidifactory.h"
 
 // DecoderWildMidiFactory
@@ -47,17 +47,17 @@ DecoderProperties DecoderWildMidiFactory::properties() const
 {
     DecoderProperties properties;
     properties.name = tr("WildMidi Plugin");
-    properties.filters = QStringList { "*.mid" };
+    properties.filters = QStringList { u"*.mid"_s };
 #if defined(LIBWILDMIDI_VERSION) && (LIBWILDMIDI_VERSION >= 0x000400)
-    properties.filters << QStringList { "*.mus", "*.xmi" };
+    properties.filters << QStringList { u"*.mus"_s, u"*.xmi"_s };
 #endif
     properties.description = tr("Midi Files");
     //properties.contentType = ;
-    properties.shortName = "wildmidi";
+    properties.shortName = "wildmidi"_L1;
     properties.hasAbout = true;
     properties.hasSettings = true;
     properties.noInput = true;
-    properties.protocols = QStringList { "file" };
+    properties.protocols = QStringList { u"file"_s };
     return properties;
 }
 
@@ -95,18 +95,17 @@ MetaDataModel* DecoderWildMidiFactory::createMetaDataModel(const QString &path,
     return nullptr;
 }
 
-void DecoderWildMidiFactory::showSettings(QWidget *parent)
+QDialog *DecoderWildMidiFactory::createSettings(QWidget *parent)
 {
-    SettingsDialog *d = new SettingsDialog(parent);
-    d->show();
+    return new WildMidiSettingsDialog(parent);
 }
 
 void DecoderWildMidiFactory::showAbout(QWidget *parent)
 {
-    QMessageBox::about (parent, tr("About WildMidi Audio Plugin"),
-                        tr("Qmmp WildMidi Audio Plugin")+"\n"+
-                        tr("This plugin uses WildMidi library to play midi files")+"\n"+
-                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
+    QMessageBox::about(parent, tr("About WildMidi Audio Plugin"),
+                       tr("Qmmp WildMidi Audio Plugin") + QChar::LineFeed +
+                       tr("This plugin uses WildMidi library to play midi files") + QChar::LineFeed +
+                       tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
 }
 
 QString DecoderWildMidiFactory::translation() const
