@@ -9,148 +9,75 @@
         <translation>XMP 오디오 플러그인</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="52"/>
+        <location filename="../decoderxmpfactory.cpp" line="54"/>
         <source>Module Files</source>
         <translation>모듈 파일</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="108"/>
+        <location filename="../decoderxmpfactory.cpp" line="109"/>
         <source>About XMP Audio Plugin</source>
         <translation>XMP 오디오 플러그인 정보</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="109"/>
+        <location filename="../decoderxmpfactory.cpp" line="110"/>
         <source>Qmmp XMP Audio Plugin</source>
         <translation>Qmmp XMP 오디오 플러그인</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="110"/>
+        <location filename="../decoderxmpfactory.cpp" line="111"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>작성자: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="111"/>
+        <location filename="../decoderxmpfactory.cpp" line="112"/>
         <source>Compiled against libxmp-%1</source>
         <translation>libxmp-%1에 대해 컴파일됨</translation>
     </message>
 </context>
-<context>
-    <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
-        <source>XMP Plugin Settings</source>
-        <translation>XMP 플러그인 설정</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="34"/>
-        <source>Amplification factor:</source>
-        <translation>증폭률:</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="51"/>
-        <source>Stereo mixing:</source>
-        <translation>스테레오 믹싱:</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="68"/>
-        <source> Interpolation type:</source>
-        <translation>보간 유형:</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="78"/>
-        <source>Lowpass filter effect</source>
-        <translation>로우패스 필터 효과</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="85"/>
-        <source>Use vblank timing</source>
-        <translation>vblank 타이밍 사용</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="92"/>
-        <source>Emulate Protracker 2.x FX9 bug</source>
-        <translation>Protracker 2.x FX9 버그 에뮬레이션</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="99"/>
-        <source>Sample rate:</source>
-        <translation>샘플 레이트:</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="33"/>
-        <source>22050 Hz</source>
-        <translation>22050 Hz</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="34"/>
-        <source>44100 Hz</source>
-        <translation>44100 Hz</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="35"/>
-        <source>48000 Hz</source>
-        <translation>48000 Hz</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="36"/>
-        <source>Nearest neighbor</source>
-        <translation>최근접</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="37"/>
-        <source>Linear</source>
-        <translation>선형</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="38"/>
-        <source>Cubic spline</source>
-        <translation>큐빅 스플라인</translation>
-    </message>
-</context>
 <context>
     <name>XmpMetaDataModel</name>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="52"/>
+        <location filename="../xmpmetadatamodel.cpp" line="51"/>
         <source>Volume scale</source>
         <translation>볼륨 스케일</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="53"/>
+        <location filename="../xmpmetadatamodel.cpp" line="52"/>
         <source>Number of patterns</source>
         <translation>패턴 수</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="54"/>
+        <location filename="../xmpmetadatamodel.cpp" line="53"/>
         <source>Number of tracks</source>
         <translation>트랙 수</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="55"/>
+        <location filename="../xmpmetadatamodel.cpp" line="54"/>
         <source>Tracks per pattern</source>
         <translation>패턴당 트랙 수</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="56"/>
+        <location filename="../xmpmetadatamodel.cpp" line="55"/>
         <source>Number of instruments</source>
         <translation>악기 수</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="57"/>
+        <location filename="../xmpmetadatamodel.cpp" line="56"/>
         <source>Number of samples</source>
         <translation>샘플 수</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="58"/>
+        <location filename="../xmpmetadatamodel.cpp" line="57"/>
         <source>Initial speed</source>
         <translation>초기 속도</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="59"/>
+        <location filename="../xmpmetadatamodel.cpp" line="58"/>
         <source>Initial BPM</source>
         <translation>초기 BPM</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="60"/>
+        <location filename="../xmpmetadatamodel.cpp" line="59"/>
         <source>Module length in patterns</source>
         <translation>패턴의 모듈 길이</translation>
     </message>
@@ -170,4 +97,87 @@
         <translation>해설</translation>
     </message>
 </context>
+<context>
+    <name>XmpSettingsDialog</name>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="14"/>
+        <source>XMP Plugin Settings</source>
+        <translation>XMP 플러그인 설정</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="34"/>
+        <source>Amplification factor:</source>
+        <translation>증폭률:</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="51"/>
+        <source>Stereo mixing:</source>
+        <translation>스테레오 믹싱:</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="68"/>
+        <source> Interpolation type:</source>
+        <translation>보간 유형:</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="78"/>
+        <source>Lowpass filter effect</source>
+        <translation>로우패스 필터 효과</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="85"/>
+        <source>Use vblank timing</source>
+        <translation>vblank 타이밍 사용</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="92"/>
+        <source>Emulate Protracker 2.x FX9 bug</source>
+        <translation>Protracker 2.x FX9 버그 에뮬레이션</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="99"/>
+        <source>Sample rate:</source>
+        <translation>샘플 레이트:</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="109"/>
+        <source>Emulate sample loop bug</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="116"/>
+        <source>Use Paula mixer in Amiga modules</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="33"/>
+        <source>22050 Hz</source>
+        <translation>22050 Hz</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="34"/>
+        <source>44100 Hz</source>
+        <translation>44100 Hz</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="35"/>
+        <source>48000 Hz</source>
+        <translation>48000 Hz</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="36"/>
+        <source>Nearest neighbor</source>
+        <translation>최근접</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="37"/>
+        <source>Linear</source>
+        <translation>선형</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="38"/>
+        <source>Cubic spline</source>
+        <translation>큐빅 스플라인</translation>
+    </message>
+</context>
 </TS>
