@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2017-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2017-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,15 +20,13 @@
 
 #include <QFile>
 #include <QSettings>
+#include <QRandomGenerator>
 #include <stdlib.h>
-#include <time.h>
 #include <qmmp/qmmp.h>
 #include "shoutoutput.h"
 
 ShoutOutput::ShoutOutput(ShoutClient *m) : m_client(m)
-{
-    qsrand(time(nullptr));
-}
+{}
 
 ShoutOutput::~ShoutOutput()
 {
@@ -53,8 +51,8 @@ ShoutOutput::~ShoutOutput()
 bool ShoutOutput::initialize(quint32 freq, ChannelMap map, Qmmp::AudioFormat)
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    float quality = settings.value("Shout/vorbis_quality", 0.8).toFloat();
-    quint32 outFreq = settings.value("Shout/sample_rate", 44100).toInt();
+    float quality = settings.value(u"Shout/vorbis_quality"_s, 0.8).toFloat();
+    quint32 outFreq = settings.value(u"Shout/sample_rate"_s, 44100).toInt();
 
     if(freq != outFreq)
     {
@@ -70,7 +68,7 @@ bool ShoutOutput::initialize(quint32 freq, ChannelMap map, Qmmp::AudioFormat)
     vorbis_analysis_init(&m_vd, &m_vi);
     vorbis_block_init(&m_vd,&m_vb);
 
-    ogg_stream_init(&m_os,qrand());
+    ogg_stream_init(&m_os, QRandomGenerator::system()->generate());
 
     configure(freq, map, Qmmp::PCM_FLOAT);
     return m_client->open();
@@ -97,7 +95,7 @@ qint64 ShoutOutput::writeAudio(unsigned char *data, qint64 maxSize)
             m_soxr_buf = (float *)realloc(m_soxr_buf, m_soxr_buf_frames * sizeof(float) * chan);
             if(!m_soxr_buf)
             {
-                qWarning("ShoutOutput: unable to allocate %zu bytes", m_soxr_buf_frames * sizeof(float) * chan);
+                qCWarning(plugin, "ShoutOutput: unable to allocate %zu bytes", m_soxr_buf_frames * sizeof(float) * chan);
                 m_soxr_buf_frames = 0;
                 if(tmp)
                     free(tmp);
@@ -178,13 +176,13 @@ qint64 ShoutOutput::writeAudio(unsigned char *data, qint64 maxSize)
 
     if(!ok)
     {
-        qWarning("ShoutOutput: trying to reconnect...");
+        qCWarning(plugin, "ShoutOutput: trying to reconnect...");
         m_client->close();
         if(!m_client->open())
             return -1;
 
         ogg_stream_reset(&m_os);
-        ogg_stream_init(&m_os,qrand());
+        ogg_stream_init(&m_os, QRandomGenerator::system()->generate());
 
         sendHeader();
     }
