@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2016-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2016-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -33,14 +33,13 @@
 #include <qmmp/buffer.h>
 #include "outputwasapi.h"
 
-#define WASAPI_BUFSIZE 10000000LL //1s
-
 #ifndef AUDCLNT_STREAMFLAGS_AUTOCONVERTPCM
 #define AUDCLNT_STREAMFLAGS_AUTOCONVERTPCM 0x80000000
 #endif
 
 OutputWASAPI *OutputWASAPI::instance = nullptr;
 VolumeWASAPI *OutputWASAPI::volumeControl = nullptr;
+
 OutputWASAPI::DWASAPIChannels OutputWASAPI::m_wasapi_pos[10]  = {
    {Qmmp::CHAN_FRONT_LEFT, SPEAKER_FRONT_LEFT},
    {Qmmp::CHAN_FRONT_RIGHT, SPEAKER_FRONT_RIGHT},
@@ -58,8 +57,9 @@ OutputWASAPI::OutputWASAPI() : Output()
 {
     instance = this;
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    m_id = settings.value("WASAPI/device", "default").toString();
-    m_exclusive = settings.value("WASAPI/exclusive_mode", false).toBool();
+    m_id = settings.value("WASAPI/device"_L1, u"default"_s).toString();
+    m_bufferSize = settings.value("WASAPI/buffer_size"_L1, 1000).toInt() * 1000LL;
+    m_exclusive = settings.value("WASAPI/exclusive_mode"_L1, false).toBool();
 }
 
 OutputWASAPI::~OutputWASAPI()
@@ -73,12 +73,12 @@ bool OutputWASAPI::initialize(quint32 freq, ChannelMap map, Qmmp::AudioFormat fo
     HRESULT result = CoCreateInstance(CLSID_MMDeviceEnumerator, nullptr, CLSCTX_ALL, IID_IMMDeviceEnumerator, (void**)&m_pEnumerator);
     if(result != S_OK)
     {
-        qWarning("OutputWASAPI: CoCreateInstance failed, error code = 0x%lx", result);
+        qCWarning(plugin, "CoCreateInstance failed, error code = 0x%lx", result);
         m_pEnumerator = nullptr;
         return false;
     }
 
-    if(m_id != "default" && !m_id.isEmpty())
+    if(m_id != "default"_L1 && !m_id.isEmpty())
     {
         WCHAR id[m_id.length() + 1];
         m_id.toWCharArray(id);
@@ -86,18 +86,18 @@ bool OutputWASAPI::initialize(quint32 freq, ChannelMap map, Qmmp::AudioFormat fo
 
         if((result = m_pEnumerator->GetDevice(id, &m_pDevice)) != S_OK)
         {
-            qWarning("OutputWASAPI: IMMDeviceEnumerator::GetDevice failed, error code = 0x%lx", result);
+            qCWarning(plugin, "IMMDeviceEnumerator::GetDevice failed, error code = 0x%lx", result);
             m_pDevice = nullptr;
         }
         else
-            qDebug("OutputWASAPI: using device id: %s", qPrintable(m_id));
+            qCDebug(plugin, "using device id: %s", qPrintable(m_id));
     }
 
     if(!m_pDevice)
     {
         if((result = m_pEnumerator->GetDefaultAudioEndpoint(eRender, eConsole, &m_pDevice)) != S_OK)
         {
-            qWarning("OutputWASAPI: IMMDeviceEnumerator::GetDefaultAudioEndpoint failed, error code = 0x%lx", result);
+            qCWarning(plugin, "IMMDeviceEnumerator::GetDefaultAudioEndpoint failed, error code = 0x%lx", result);
             m_pDevice = nullptr;
             return false;
         }
@@ -105,7 +105,7 @@ bool OutputWASAPI::initialize(quint32 freq, ChannelMap map, Qmmp::AudioFormat fo
 
     if((result = m_pDevice->Activate(IID_IAudioClient, CLSCTX_ALL, nullptr, (void**)&m_pAudioClient)) != S_OK)
     {
-        qWarning("OutputWASAPI: IMMDevice::Activate failed, error code = 0x%lx", result);
+        qCWarning(plugin, "IMMDevice::Activate failed, error code = 0x%lx", result);
         m_pAudioClient = nullptr;
         return false;
     }
@@ -164,37 +164,37 @@ bool OutputWASAPI::initialize(quint32 freq, ChannelMap map, Qmmp::AudioFormat fo
     if(m_pAudioClient->IsFormatSupported(mode, (WAVEFORMATEX *)&wfex, nullptr) != S_OK)
     {
         streamFlags |= AUDCLNT_STREAMFLAGS_AUTOCONVERTPCM;
-        qDebug("OutputWASAPI: format is not supported, using converter");
+        qCDebug(plugin, "format is not supported, using converter");
     }
 
-    if((result = m_pAudioClient->Initialize(mode, streamFlags, WASAPI_BUFSIZE, 0, (WAVEFORMATEX *)&wfex, nullptr)) != S_OK)
+    if((result = m_pAudioClient->Initialize(mode, streamFlags, m_bufferSize, 0, (WAVEFORMATEX *)&wfex, nullptr)) != S_OK)
     {
-        qWarning("OutputWASAPI: IAudioClient::Initialize failed, error code = 0x%lx", result);
+        qCWarning(plugin, "IAudioClient::Initialize failed, error code = 0x%lx", result);
         return false;
     }
 
     if((result = m_pAudioClient->GetBufferSize(&m_bufferFrames)) != S_OK)
     {
-        qWarning("OutputWASAPI: IAudioClient::GetBufferSize failed, error code = 0x%lx", result);
+        qCWarning(plugin, "IAudioClient::GetBufferSize failed, error code = 0x%lx", result);
         return false;
     }
 
     if((result = m_pAudioClient->GetService(IID_IAudioRenderClient, (void**)&m_pRenderClient)) != S_OK)
     {
-        qWarning("OutputWASAPI: IAudioClient::GetService failed, error code = 0x%lx", result);
+        qCWarning(plugin, "IAudioClient::GetService failed, error code = 0x%lx", result);
         return false;
     }
 
     if((result = m_pAudioClient->GetService(IID_ISimpleAudioVolume, (void**)&m_pSimpleAudioVolume)) != S_OK)
     {
-        qWarning("OutputWASAPI: IAudioClient::GetService failed, error code = 0x%lx", result);
+        qCWarning(plugin, "IAudioClient::GetService failed, error code = 0x%lx", result);
         return false;
     }
 
 
     if((result = m_pAudioClient->Start()) != S_OK)
     {
-        qWarning("OutputWASAPI: IAudioClient::Start failed, error code = 0x%lx", result);
+        qCWarning(plugin, "IAudioClient::Start failed, error code = 0x%lx", result);
         return false;
     }
 
@@ -243,7 +243,7 @@ qint64 OutputWASAPI::writeAudio(unsigned char *data, qint64 len)
 
     if((result = m_pRenderClient->GetBuffer(framesToWrite, &pData)) != S_OK)
     {
-        qWarning("OutputWASAPI: IAudioClient::GetBuffer failed, error code = 0x%lx", result);
+        qCWarning(plugin, "IAudioClient::GetBuffer failed, error code = 0x%lx", result);
         return -1;
     }
     memcpy(pData, data, framesToWrite * m_frameSize);
@@ -315,16 +315,16 @@ VolumeWASAPI::VolumeWASAPI()
 {
     OutputWASAPI::volumeControl = this;
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    m_volume.left = settings.value("WASAPI/left_volume", 100).toInt();
-    m_volume.right = settings.value("WASAPI/right_volume", 100).toInt();
+    m_volume.left = settings.value("WASAPI/left_volume"_L1, 100).toInt();
+    m_volume.right = settings.value("WASAPI/right_volume"_L1, 100).toInt();
 }
 
 VolumeWASAPI::~VolumeWASAPI()
 {
-    m_volume = volume();
+    m_volume = VolumeWASAPI::volume();
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.setValue("WASAPI/left_volume", m_volume.left);
-    settings.setValue("WASAPI/right_volume", m_volume.right);
+    settings.setValue("WASAPI/left_volume"_L1, m_volume.left);
+    settings.setValue("WASAPI/right_volume"_L1, m_volume.right);
     OutputWASAPI::volumeControl = nullptr;
 }
 
