@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -42,7 +42,7 @@ static size_t curl_write_data(void *data, size_t size, size_t nmemb,
 
     if(dl->stream()->buf_fill > MAX_BUFFER_SIZE)
     {
-        qWarning("HttpStreamReader: buffer has reached the maximum size, disconnecting...");
+        qCWarning(plugin, "buffer has reached the maximum size, disconnecting...");
         dl->stream()->aborted = true;
         dl->mutex()->unlock();
         return 0;
@@ -55,7 +55,7 @@ static size_t curl_write_data(void *data, size_t size, size_t nmemb,
         dl->stream()->buf = (char *)realloc(dl->stream()->buf, dl->stream()->buf_fill + data_size);
         if(!dl->stream()->buf)
         {
-            qWarning("HttpStreamReader: unable to allocate %zu bytes",  dl->stream()->buf_fill + data_size);
+            qCWarning(plugin, "unable to allocate %zu bytes",  dl->stream()->buf_fill + data_size);
             if(prev)
                 free(prev);
 
@@ -86,17 +86,17 @@ static size_t curl_header(void *data, size_t size, size_t nmemb,
         return data_size;
     }
 
-    //qDebug("header received: %s", (char*) data);
+    //qCDebug(plugin, "header received: %s", (char*) data);
     QByteArray header((char *) data, data_size);
     header = header.trimmed ();
     if (header.left(4).contains("HTTP"))
     {
-        qDebug("HttpStreamReader: header received");
+        qCDebug(plugin, "header received");
         //TODO open metadata socket
     }
     else if (header.left(4).contains("ICY"))
     {
-        qDebug("HttpStreamReader: shoutcast header received");
+        qCDebug(plugin, "shoutcast header received");
         //dl->stream()->icy_meta_data = true;
     }
     else
@@ -104,17 +104,21 @@ static size_t curl_header(void *data, size_t size, size_t nmemb,
         QString key = QString::fromLatin1(header.left(header.indexOf(":")).trimmed().toLower());
         QByteArray value = header.right(header.size() - header.indexOf(":") - 1).trimmed();
         dl->stream()->header.insert(key, value);
-        qDebug("HttpStreamReader: key=%s, value=%s",qPrintable(key), value.constData());
+        qCDebug(plugin, "key=%s, value=%s",qPrintable(key), value.constData());
 
-        if (key == "icy-metaint")
+        if (key == "icy-metaint"_L1)
         {
             dl->stream()->icy_metaint = value.toInt();
             dl->stream()->icy_meta_data = true;
         }
-        else if(key == "icy-name")
+        else if(key == "icy-name"_L1)
         {
             dl->stream()->icy_meta_data = true;
         }
+        else if(key == "icy-br"_L1)
+        {
+            dl->stream()->icy_br = value.toInt();
+        }
     }
     dl->mutex()->unlock();
     return data_size;
@@ -142,18 +146,19 @@ HttpStreamReader::HttpStreamReader(const QString &url, HTTPInputSource *parent)
     curl_global_init(CURL_GLOBAL_ALL);
     m_thread = new DownloadThread(this);
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("HTTP");
-    m_codec = QTextCodec::codecForName(settings.value("icy_encoding","UTF-8").toByteArray ());
-    m_prebuffer_size = settings.value("buffer_size",384).toInt() * 1000;
-    if(settings.value("override_user_agent",false).toBool())
-        m_userAgent = settings.value("user_agent").toString();
+    settings.beginGroup("HTTP"_L1);
+    m_codec = QTextCodec::codecForName(settings.value("icy_encoding"_L1, "UTF-8"_ba).toByteArray());
+    m_prebufferSize = settings.value("buffer_size"_L1, 384).toInt() * 1024;
+    m_bufferDuration = settings.value("buffer_duration"_L1, 10000).toInt();
+    if(settings.value(u"override_user_agent"_s, false).toBool())
+        m_userAgent = settings.value("user_agent"_L1).toString();
     if(m_userAgent.isEmpty())
-        m_userAgent = QString("qmmp/%1").arg(Qmmp::strVersion());;
-    if (!m_codec)
-        m_codec = QTextCodec::codecForName ("UTF-8");
+        m_userAgent = QStringLiteral("qmmp/%1").arg(Qmmp::strVersion());
+    if(!m_codec)
+        m_codec = QTextCodec::codecForName("UTF-8");
 #ifdef WITH_ENCA
-    if(settings.value("use_enca", false).toBool())
-        m_analyser = enca_analyser_alloc(settings.value("enca_lang").toByteArray ().constData());
+    if(settings.value("use_enca"_L1, false).toBool())
+        m_analyser = enca_analyser_alloc(settings.value("enca_lang"_L1).toByteArray ().constData());
     if(m_analyser)
         enca_set_threshold(m_analyser, 1.38);
 #endif
@@ -177,23 +182,23 @@ HttpStreamReader::~HttpStreamReader()
 #endif
 }
 
-bool HttpStreamReader::atEnd () const
+bool HttpStreamReader::atEnd() const
 {
     return false;
 }
 
-qint64 HttpStreamReader::bytesToWrite () const
+qint64 HttpStreamReader::bytesToWrite() const
 {
     return -1;
 }
 
-void HttpStreamReader::close ()
+void HttpStreamReader::close()
 {
     abort();
     QIODevice::close();
 }
 
-bool HttpStreamReader::isSequential () const
+bool HttpStreamReader::isSequential() const
 {
     return true;
 }
@@ -227,7 +232,6 @@ void HttpStreamReader::downloadFile()
 
 qint64 HttpStreamReader::readData(char* data, qint64 maxlen)
 {
-
     qint64 len = 0;
     m_mutex.lock();
     if(m_stream.buf_fill == 0)
@@ -274,8 +278,8 @@ QMutex *HttpStreamReader::mutex()
 
 QString HttpStreamReader::contentType()
 {
-    if (m_stream.header.contains("content-type"))
-        return m_stream.header.value("content-type").toLower();
+    if (m_stream.header.contains(u"content-type"_s))
+        return QString::fromLatin1(m_stream.header.value(u"content-type"_s)).toLower();
     return QString();
 }
 
@@ -307,7 +311,7 @@ qint64 HttpStreamReader::bytesAvailable() const
 
 void HttpStreamReader::run()
 {
-    qDebug("HttpStreamReader: starting download thread");
+    qCDebug(plugin, "starting download thread");
     char errorBuffer[CURL_ERROR_SIZE];
     memset(errorBuffer, 0, sizeof(errorBuffer));
     m_handle = curl_easy_init();
@@ -315,9 +319,9 @@ void HttpStreamReader::run()
     if (QmmpSettings::instance()->isProxyEnabled())
     {
         curl_easy_setopt(m_handle, CURLOPT_PROXY,
-                         strdup((QmmpSettings::instance()->proxy().host() + ":" +
-                                 QString("%1").arg(QmmpSettings::instance()->proxy().port())).
-                                toLatin1 ().constData ()));
+                         strdup((QmmpSettings::instance()->proxy().host() + QLatin1Char(':') +
+                                 QString::number(QmmpSettings::instance()->proxy().port())).
+                                toLatin1().constData ()));
 
         if(QmmpSettings::instance()->proxyType() == QmmpSettings::SOCKS5_PROXY)
             curl_easy_setopt(m_handle, CURLOPT_PROXYTYPE, CURLPROXY_SOCKS5);
@@ -329,7 +333,7 @@ void HttpStreamReader::run()
 
     if (QmmpSettings::instance()->useProxyAuth())
         curl_easy_setopt(m_handle, CURLOPT_PROXYUSERPWD,
-                         strdup((QmmpSettings::instance()->proxy().userName() + ":" +
+                         strdup((QmmpSettings::instance()->proxy().userName() + QLatin1Char(':') +
                                  QmmpSettings::instance()->proxy().password()).
                                 toLatin1 ().constData ()));
 
@@ -374,16 +378,16 @@ void HttpStreamReader::run()
         m_stream.buf = nullptr;
     }
     m_stream.buf_fill = 0;
-    m_stream.buf_size = m_prebuffer_size * 2;
+    m_stream.buf_size = m_prebufferSize * 2;
     m_stream.buf = (char *)malloc(m_stream.buf_size); //initial buffer
     m_stream.aborted = false;
     m_stream.header.clear();
     m_ready  = false;
     int return_code;
-    qDebug("HttpStreamReader: starting libcurl");
+    qCDebug(plugin, "starting libcurl");
     m_mutex.unlock();
     return_code = curl_easy_perform(m_handle);
-    qDebug("HttpStreamReader: curl thread finished with code %d (%s)", return_code, errorBuffer);
+    qCDebug(plugin, "curl thread finished with code %d (%s)", return_code, errorBuffer);
     if(!m_stream.aborted && !m_ready)
     {
         setErrorString(QString::fromLocal8Bit(errorBuffer));
@@ -402,10 +406,11 @@ qint64 HttpStreamReader::readBuffer(char* data, qint64 maxlen)
         memmove(m_stream.buf, m_stream.buf + len, m_stream.buf_fill);
         return len;
     }
-    else if (m_stream.aborted)
+
+    if (m_stream.aborted)
         return -1;
-    else
-        return 0;
+
+    return 0;
 }
 
 void HttpStreamReader::checkBuffer()
@@ -413,19 +418,28 @@ void HttpStreamReader::checkBuffer()
     if(m_stream.aborted || m_ready)
         return;
 
-    if (m_stream.buf_fill > m_prebuffer_size)
+    if(m_stream.icy_br > 0)
+    {
+        m_prebufferSize = m_stream.icy_br * m_bufferDuration / 8;
+        qCDebug(plugin) << "buffer duration:" << m_bufferDuration << "ms";
+        qCDebug(plugin) << "buffer size:" << m_prebufferSize << "bytes";
+        m_stream.icy_br = 0;
+    }
+
+
+    if(m_stream.buf_fill > m_prebufferSize)
     {
         m_ready  = true;
-        qDebug("HttpStreamReader: ready");
+        qCDebug(plugin, "ready");
         if(!m_meta_sent)
         {
             QMap<Qmmp::MetaData, QString> metaData;
             if(stream()->icy_meta_data)
             {
-                metaData.insert(Qmmp::TITLE, m_stream.header.value("icy-name"));
-                metaData.insert(Qmmp::GENRE, m_stream.header.value("icy-genre"));
+                metaData.insert(Qmmp::TITLE, QString::fromUtf8(m_stream.header.value(u"icy-name"_s)));
+                metaData.insert(Qmmp::GENRE, QString::fromUtf8(m_stream.header.value(u"icy-genre"_s)));
                 m_parent->addMetaData(metaData);
-                m_parent->setProperty(Qmmp::BITRATE, m_stream.header.value("icy-br"));
+                m_parent->setProperty(Qmmp::BITRATE, m_stream.header.value(u"icy-br"_s));
             }
             sendStreamInfo(m_codec);
         }
@@ -433,7 +447,7 @@ void HttpStreamReader::checkBuffer()
     }
     else
     {
-        StateHandler::instance()->dispatchBuffer(100 * m_stream.buf_fill / m_prebuffer_size);
+        StateHandler::instance()->dispatchBuffer(100 * m_stream.buf_fill / m_prebufferSize);
         qApp->processEvents();
     }
 }
@@ -454,7 +468,7 @@ void HttpStreamReader::readICYMetaData()
     if (packet_size != 0)
     {
         size_t size = packet_size * 16;
-        char packet[size];
+        char *packet = new char[size];
         while (m_stream.buf_fill < size && m_thread->isRunning())
         {
             m_mutex.unlock();
@@ -462,8 +476,9 @@ void HttpStreamReader::readICYMetaData()
             m_mutex.lock();
         }
         qint64 l = readBuffer(packet, size);
-        qDebug("HttpStreamReader: ICY metadata: %s", packet);
+        qCDebug(plugin, "ICY metadata: %s", packet);
         parseICYMetaData(packet, l);
+        delete [] packet;
     }
     m_mutex.unlock();
 }
@@ -472,37 +487,34 @@ void HttpStreamReader::parseICYMetaData(char *data, qint64 size)
 {
     if(!size)
         return;
-    QTextCodec *codec = m_codec;
 #ifdef WITH_ENCA
     if(m_analyser)
     {
         EncaEncoding encoding = enca_analyse(m_analyser, (uchar *) data, size);
+        QTextCodec *prevCodec = m_codec;
+
         if(encoding.charset != ENCA_CS_UNKNOWN)
         {
-            codec = QTextCodec::codecForName(enca_charset_name(encoding.charset,ENCA_NAME_STYLE_ENCA));
-            qDebug("HttpStreamReader: detected charset: %s",
-                   enca_charset_name(encoding.charset,ENCA_NAME_STYLE_ENCA));
-            if(!codec)
-                codec = m_codec;
-
-             m_prevCodec = codec;
+            qCDebug(plugin, "detected charset: %s", enca_charset_name(encoding.charset,ENCA_NAME_STYLE_ENCA));
+            m_codec = QTextCodec::codecForName(enca_charset_name(encoding.charset,ENCA_NAME_STYLE_ENCA));
         }
-        else if(m_prevCodec)
-            codec = m_prevCodec;
+
+        if (!m_codec)
+            m_codec = prevCodec;
     }
 #endif
-    QString str = codec->toUnicode(data).trimmed();
-    const QStringList list(str.split(";", QString::SkipEmptyParts));
-    for(QString line : qAsConst(list))
+    QString str = m_codec->toUnicode(data).trimmed();
+    const QStringList list(str.split(QLatin1Char(';'), Qt::SkipEmptyParts));
+    for(QString line : std::as_const(list))
     {
-        if (line.contains("StreamTitle="))
+        if (line.contains(u"StreamTitle="_s))
         {
-            line = line.right(line.size() - line.indexOf("=") - 1).trimmed();
-            m_title = line.remove("'");
+            line = line.right(line.size() - line.indexOf(QLatin1Char('=')) - 1).trimmed();
+            m_title = line.remove(QLatin1Char('\''));
             QMap<Qmmp::MetaData, QString> metaData;
             if (!m_title.isEmpty())
             {
-                QStringList l = m_title.split(" - ");
+                QStringList l = m_title.split(u" - "_s);
                 if(l.count() > 1)
                 {
                     metaData.insert(Qmmp::ARTIST, l.at(0));
@@ -512,10 +524,10 @@ void HttpStreamReader::parseICYMetaData(char *data, qint64 size)
                     metaData.insert(Qmmp::TITLE, m_title);
             }
             else
-                metaData.insert(Qmmp::TITLE, codec->toUnicode(m_stream.header.value("icy-name")));
-            metaData.insert(Qmmp::GENRE, codec->toUnicode(m_stream.header.value("icy-genre")));
+                metaData.insert(Qmmp::TITLE, m_codec->toUnicode(m_stream.header.value(u"icy-name"_s)));
+            metaData.insert(Qmmp::GENRE, m_codec->toUnicode(m_stream.header.value(u"icy-genre"_s)));
             m_parent->addMetaData(metaData);
-            sendStreamInfo(codec);
+            sendStreamInfo(m_codec);
             m_meta_sent = true;
             break;
         }
@@ -525,9 +537,9 @@ void HttpStreamReader::parseICYMetaData(char *data, qint64 size)
 void HttpStreamReader::sendStreamInfo(QTextCodec *codec)
 {
     QHash<QString, QString> info;
-    for(const QString &key : m_stream.header.keys())
+    for(auto it = m_stream.header.cbegin(); it != m_stream.header.cend(); ++it)
     {
-        info.insert(key, codec->toUnicode(m_stream.header.value(key)));
+        info.insert(it.key(), codec->toUnicode(it.value()));
     }
     m_parent->addStreamInfo(info);
 }
