@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -50,6 +50,7 @@ struct HttpStreamData
     QHash <QString, QByteArray> header;
     bool icy_meta_data = false;
     size_t icy_metaint = 0;
+    size_t icy_br = 0;
 };
 
 /*! @internal
@@ -106,13 +107,13 @@ private:
     QString m_title;
     bool m_ready = false;
     bool m_meta_sent = false;
-    size_t m_prebuffer_size;
-    QTextCodec *m_codec;
+    size_t m_prebufferSize;
+    int m_bufferDuration;
+    QTextCodec *m_codec = nullptr;
     DownloadThread *m_thread;
     HTTPInputSource *m_parent;
 #ifdef WITH_ENCA
     EncaAnalyser m_analyser = nullptr;
-    QTextCodec *m_prevCodec = nullptr;
 #endif
 };
 
