@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,16 +21,19 @@
 #include <QFileSystemModel>
 #include <QSortFilterProxyModel>
 #include <QListView>
+#include <QTreeView>
 #include <QVBoxLayout>
 #include <QSettings>
 #include <QAction>
 #include <QApplication>
 #include <QLineEdit>
 #include <QIcon>
+#include <QMenu>
 #include <qmmp/metadatamanager.h>
 #include <qmmpui/playlistmanager.h>
 #include <qmmpui/filedialog.h>
-#include <qmmpui/playlistmanager.h>
+#include <qmmpui/uihelper.h>
+#include <qmmp/soundcore.h>
 #include <qmmp/qmmp.h>
 #include "elidinglabel.h"
 #include "filesystembrowser.h"
@@ -54,26 +57,26 @@ protected:
 FileSystemBrowser::FileSystemBrowser(QWidget *parent) :
     QWidget(parent)
 {
-    m_listView = new QListView(this);
-    m_listView->setFrameStyle(QFrame::NoFrame);
-    m_listView->setDragEnabled(true);
-    m_listView->setSelectionMode(QAbstractItemView::ExtendedSelection);
-    connect(m_listView, SIGNAL(activated(QModelIndex)), SLOT(onListViewActivated(QModelIndex)));
+    m_treeView = new QTreeView(this);
+    m_treeView->setFrameStyle(QFrame::NoFrame);
+    m_treeView->setDragEnabled(true);
+    m_treeView->setSelectionMode(QAbstractItemView::ExtendedSelection);
+    connect(m_treeView, &QTreeView::activated, this, &FileSystemBrowser::onListViewActivated);
 
     m_label = new Utils::ElidingLabel(this);
-    m_label->setContentsMargins(5,5,5,0);
+    m_label->setContentsMargins(5, 5, 5, 0);
     m_label->setMargin(0);
 
     m_filterLineEdit = new QLineEdit(this);
-    m_filterLineEdit->setContentsMargins(5,5,5,0);
+    m_filterLineEdit->setContentsMargins(5, 5, 5, 0);
     m_filterLineEdit->setClearButtonEnabled(true);
     m_filterLineEdit->setVisible(false);
 
     QVBoxLayout *layout = new QVBoxLayout();
-    layout->setContentsMargins(0,0,0,0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(m_label);
     layout->addWidget(m_filterLineEdit);
-    layout->addWidget(m_listView);
+    layout->addWidget(m_treeView);
     setLayout(layout);
 
     m_fileSystemModel = new QFileSystemModel(this);
@@ -85,46 +88,70 @@ FileSystemBrowser::FileSystemBrowser(QWidget *parent) :
     m_proxyModel->setDynamicSortFilter(true);
     m_proxyModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
     m_proxyModel->setSourceModel(m_fileSystemModel);
-    m_listView->setModel(m_proxyModel);
+    m_treeView->setModel(m_proxyModel);
+    m_treeView->setColumnHidden(1, true);
+    m_treeView->setColumnHidden(2, true);
+    m_treeView->setColumnHidden(3, true);
+    m_treeView->setHeaderHidden(true);
+    m_treeView->setUniformRowHeights(true);
+    m_treeView->setRootIsDecorated(false);
 
     setContextMenuPolicy(Qt::ActionsContextMenu);
-    QAction *addToPlaylistAction = new QAction(QIcon::fromTheme("list-add"), tr("Add to Playlist"), this);
-    addAction(addToPlaylistAction);
-    QAction *selectDirAction = new QAction(QIcon::fromTheme("folder"), tr("Change Directory"), this);
-    addAction(selectDirAction);
+    QAction *addToPlayListAction = new QAction(QIcon::fromTheme(u"list-add"_s), tr("Add to Playlist"), this);
+    QAction *replacePlayListAction = new QAction(QIcon::fromTheme(u"media-eject"_s), tr("Replace Playlist"), this);
+    QAction *selectDirAction = new QAction(QIcon::fromTheme(u"folder"_s), tr("Change Directory"), this);
     QAction *separatorAction = new QAction(this);
     separatorAction->setSeparator(true);
-    addAction(separatorAction);
-    addAction(m_showFilterAction = new QAction(tr("Quick Search"), this));
+    m_treeModeAction = new QAction(tr("Tree View Mode"), this);
+    m_treeModeAction->setCheckable(true);
+    m_showFilterAction = new QAction(tr("Quick Search"), this);
     m_showFilterAction->setCheckable(true);
+    m_sortAction = new QAction(QIcon::fromTheme(u"view-sort-ascending"_s), tr("Sort"), this);
 
-    connect(selectDirAction, SIGNAL(triggered()), SLOT(selectDirectory()));
-    connect(addToPlaylistAction, SIGNAL(triggered()), SLOT(addToPlayList()));
-    connect(m_showFilterAction, SIGNAL(toggled(bool)), m_filterLineEdit, SLOT(setVisible(bool)));
-    connect(m_showFilterAction, SIGNAL(triggered()), m_filterLineEdit, SLOT(clear()));
-    connect(m_filterLineEdit, SIGNAL(textChanged(QString)), SLOT(onFilterLineEditTextChanged(QString)));
+    const QList<QAction *> contextMenuActions = {
+        addToPlayListAction, replacePlayListAction, selectDirAction, separatorAction,
+        m_treeModeAction, m_showFilterAction, m_sortAction
+    };
+
+    addActions(contextMenuActions);
+    QMenu *sortMenu = new QMenu(this);
+    sortMenu->addAction(tr("By Name"), this, [this]() { m_fileSystemModel->sort(0); } );
+    sortMenu->addAction(tr("By Size"), this, [this]() { m_fileSystemModel->sort(1); } );
+    sortMenu->addAction(tr("By Type"), this, [this]() { m_fileSystemModel->sort(2); } );
+    sortMenu->addAction(tr("By Date"), this, [this]() { m_fileSystemModel->sort(3); } );
+    m_sortAction->setMenu(sortMenu);
+    connect(addToPlayListAction, &QAction::triggered, this, &FileSystemBrowser::addToPlayList);
+    connect(replacePlayListAction, &QAction::triggered, this, &FileSystemBrowser::replacePlayList);
+    connect(selectDirAction, &QAction::triggered, this, &FileSystemBrowser::selectDirectory);
+    connect(m_treeModeAction, &QAction::triggered, this, &FileSystemBrowser::setTreeViewMode);
+    connect(m_showFilterAction, &QAction::toggled, m_filterLineEdit, &QLineEdit::setVisible);
+    connect(m_showFilterAction, &QAction::triggered, m_filterLineEdit, &QLineEdit::clear);
+    connect(m_filterLineEdit, &QLineEdit::textChanged, this, &FileSystemBrowser::onFilterLineEditTextChanged);
 
     readSettings();
 }
 
 FileSystemBrowser::~FileSystemBrowser()
 {
-    QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("Simple");
-    settings.setValue("fsbrowser_current_dir", m_fileSystemModel->rootDirectory().canonicalPath());
-    settings.setValue("fsbrowser_quick_search", m_showFilterAction->isChecked());
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    settings.beginGroup(u"Simple"_s);
+    settings.setValue(u"fsbrowser_current_dir"_s, m_fileSystemModel->rootDirectory().canonicalPath());
+    settings.setValue(u"fsbrowser_quick_search"_s, m_showFilterAction->isChecked());
+    settings.setValue(u"fsbrowser_tree_mode"_s, m_treeModeAction->isChecked());
     settings.endGroup();
 }
 
 void FileSystemBrowser::readSettings()
 {
-    QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("Simple");
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    settings.beginGroup(u"Simple"_s);
     if(!m_update)
     {
         m_update = true;
-        setCurrentDirectory(settings.value("fsbrowser_current_dir", QDir::homePath()).toString());
-        m_showFilterAction->setChecked(settings.value("fsbrowser_quick_search", false).toBool());
+        setCurrentDirectory(settings.value(u"fsbrowser_current_dir"_s, QDir::homePath()).toString());
+        m_showFilterAction->setChecked(settings.value(u"fsbrowser_quick_search"_s, false).toBool());
+        setTreeViewMode(settings.value(u"fsbrowser_tree_mode"_s, false).toBool());
+        m_treeModeAction->setChecked(m_treeView->rootIsDecorated());
     }
     settings.endGroup();
     m_fileSystemModel->setNameFilters(MetaDataManager::instance()->nameFilters());
@@ -139,7 +166,7 @@ void FileSystemBrowser::onListViewActivated(const QModelIndex &index)
 
     QString name = m_fileSystemModel->fileName(sourceIndex);
 
-    if(name == "..")
+    if(name == QLatin1String(".."))
     {
         setCurrentDirectory(m_fileSystemModel->fileInfo(sourceIndex).absoluteFilePath());
     }
@@ -153,16 +180,32 @@ void FileSystemBrowser::onListViewActivated(const QModelIndex &index)
 
 void FileSystemBrowser::addToPlayList()
 {
-    for(const QModelIndex &index : m_listView->selectionModel()->selectedIndexes())
-    {
-        if(!index.isValid())
-            continue;
+     PlayListManager::instance()->selectedPlayList()->addPaths(selectedPaths());
+}
 
-        QModelIndex sourceIndex = m_proxyModel->mapToSource(index);
-        QString name = m_fileSystemModel->fileName(sourceIndex);
-        if(name == "..")
-            continue;
-        PlayListManager::instance()->selectedPlayList()->add(m_fileSystemModel->filePath(sourceIndex));
+void FileSystemBrowser::replacePlayList()
+{
+    QStringList paths = selectedPaths();
+
+    if(paths.isEmpty())
+        return;
+
+    SoundCore *core = SoundCore::instance();
+    PlayListManager *manager = PlayListManager::instance();
+    PlayListModel *model = PlayListManager::instance()->selectedPlayList();
+
+    bool play = (core->state() == Qmmp::Playing || core->state() == Qmmp::Paused || core->state() == Qmmp::Buffering) &&
+            model == manager->currentPlayList();
+
+
+    if(play)
+    {
+        UiHelper::instance()->replaceAndPlay(paths);
+    }
+    else
+    {
+        manager->selectedPlayList()->clear();
+        manager->selectedPlayList()->addPaths(paths);
     }
 }
 
@@ -179,6 +222,38 @@ void FileSystemBrowser::onFilterLineEditTextChanged(const QString &str)
     m_proxyModel->setFilterFixedString(str);
 }
 
+void FileSystemBrowser::setTreeViewMode(bool enabled)
+{
+    m_treeView->setRootIsDecorated(enabled);
+    if(enabled)
+        m_fileSystemModel->setFilter(m_fileSystemModel->filter() | QDir::NoDotDot);
+    else
+        m_fileSystemModel->setFilter(m_fileSystemModel->filter() & ~QDir::NoDotDot);
+
+    int s = style()->pixelMetric(enabled ? QStyle::PM_SmallIconSize : QStyle::PM_ListViewIconSize);
+    m_treeView->setIconSize(QSize(s, s));
+}
+
+QStringList FileSystemBrowser::selectedPaths() const
+{
+    QStringList paths;
+
+    for(const QModelIndex &index : m_treeView->selectionModel()->selectedIndexes())
+    {
+        if(!index.isValid() || index.column() != 0)
+            continue;
+
+        QModelIndex sourceIndex = m_proxyModel->mapToSource(index);
+        QString name = m_fileSystemModel->fileName(sourceIndex);
+        if(name == QLatin1String(".."))
+            continue;
+
+        paths << m_fileSystemModel->filePath(sourceIndex);
+    }
+
+    return paths;
+}
+
 void FileSystemBrowser::setCurrentDirectory(const QString &path)
 {
     if(path.isEmpty())
@@ -189,7 +264,7 @@ void FileSystemBrowser::setCurrentDirectory(const QString &path)
     QModelIndex index = m_fileSystemModel->setRootPath(QDir(path).exists() ? path : QDir::homePath());
     if(index.isValid())
     {
-        m_listView->setRootIndex(m_proxyModel->mapFromSource(index));
+        m_treeView->setRootIndex(m_proxyModel->mapFromSource(index));
         m_label->setText(QDir(m_fileSystemModel->rootPath()).dirName());
     }
     else
