@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2017 by Ilya Kotov                                      *
+ *   Copyright (C) 2017-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,7 +26,7 @@
 
 class QLineEdit;
 class PlayListManager;
-class ListWidget;
+class QSUiListWidget;
 
 /**
     @author Ilya Kotov <forkotov02@ya.ru>
@@ -35,12 +35,12 @@ class QSUiQuickSearch : public QWidget
 {
     Q_OBJECT
 public:
-    explicit QSUiQuickSearch(ListWidget *listWidget, QWidget *parent = nullptr);
+    explicit QSUiQuickSearch(QSUiListWidget *listWidget, QWidget *parent = nullptr);
 
 private:
     QLineEdit *m_lineEdit;
     PlayListManager *m_manager;
-    ListWidget *m_listWidget;
+    QSUiListWidget *m_listWidget;
 
 };
 
