@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2012 by Ilya Kotov                                      *
+ *   Copyright (C) 2012-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,7 +26,7 @@ QSUiTabBar::QSUiTabBar(QWidget *parent) : QTabBar(parent)
 
 void QSUiTabBar::mouseReleaseEvent(QMouseEvent *e)
 {
-    if(e->button() == Qt::MidButton)
+    if(e->button() == Qt::MiddleButton)
     {
         int i = tabAt(e->pos());
         if(i >= 0)
