@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2012-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2012-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -36,8 +36,8 @@ QSUIVisualization::QSUIVisualization(QWidget *parent) : Visual (parent)
     m_pixLabel = new QLabel(this);
     createMenu();
 
-    m_timer = new QTimer (this);
-    connect(m_timer, SIGNAL (timeout()), this, SLOT (timeout()));
+    m_timer = new QTimer(this);
+    connect(m_timer, &QTimer::timeout, this, &QSUIVisualization::timeout);
 
     readSettings();
     clear();
@@ -45,8 +45,7 @@ QSUIVisualization::QSUIVisualization(QWidget *parent) : Visual (parent)
 
 QSUIVisualization::~QSUIVisualization()
 {
-    if(m_drawer)
-        delete m_drawer;
+    delete m_drawer;
 }
 
 void QSUIVisualization::clear()
@@ -60,7 +59,7 @@ void QSUIVisualization::clear()
 
 void QSUIVisualization::clearCover()
 {
-    m_cover = QPixmap();
+    m_cover = QImage();
     updateCover();
     update();
 }
@@ -70,9 +69,9 @@ QSize QSUIVisualization::sizeHint() const
     return QSize(200, 100);
 }
 
-void QSUIVisualization::setCover(const QPixmap &pixmap)
+void QSUIVisualization::setCover(const QImage &img)
 {
-    m_cover = pixmap;
+    m_cover = img;
     updateCover();
 }
 
@@ -89,7 +88,7 @@ void QSUIVisualization::paintEvent (QPaintEvent * e)
 {
     if(m_drawer)
     {
-        QPainter painter (this);
+        QPainter painter(this);
         painter.fillRect(e->rect(),m_bgColor);
         m_drawer->draw(&painter, m_offset);
     }
@@ -119,9 +118,9 @@ void QSUIVisualization::process()
 
 void QSUIVisualization::createMenu()
 {
-    m_menu = new QMenu (this);
-    connect(m_menu, SIGNAL(triggered (QAction *)),SLOT(writeSettings()));
-    connect(m_menu, SIGNAL(triggered (QAction *)),SLOT(readSettings()));
+    m_menu = new QMenu(this);
+    connect(m_menu, &QMenu::triggered, this, &QSUIVisualization::writeSettings);
+    connect(m_menu, &QMenu::triggered, this, &QSUIVisualization::readSettings);
 
     m_coverAction = m_menu->addAction(tr("Cover"));
     m_coverAction->setCheckable(true);
@@ -129,8 +128,8 @@ void QSUIVisualization::createMenu()
     QMenu *visMode = m_menu->addMenu(tr("Visualization Mode"));
     m_visModeGroup = new QActionGroup(this);
     m_visModeGroup->setExclusive(true);
-    m_visModeGroup->addAction(tr("Analyzer"))->setData("analyzer");
-    m_visModeGroup->addAction(tr("Scope"))->setData("scope");
+    m_visModeGroup->addAction(tr("Analyzer"))->setData(u"analyzer"_s);
+    m_visModeGroup->addAction(tr("Scope"))->setData(u"scope"_s);
     for(QAction *act : m_visModeGroup->actions())
     {
         act->setCheckable(true);
@@ -139,8 +138,8 @@ void QSUIVisualization::createMenu()
 
     QMenu *analyzerMode = m_menu->addMenu(tr("Analyzer Mode"));
     m_analyzerTypeGroup = new QActionGroup(this);
-    m_analyzerTypeGroup->addAction(tr("Cells"))->setData("cells");
-    m_analyzerTypeGroup->addAction(tr("Lines"))->setData("lines");
+    m_analyzerTypeGroup->addAction(tr("Cells"))->setData(u"cells"_s);
+    m_analyzerTypeGroup->addAction(tr("Lines"))->setData(u"lines"_s);
 
     for(QAction *act : m_analyzerTypeGroup->actions())
     {
@@ -200,7 +199,7 @@ void QSUIVisualization::updateCover()
     {
         m_offset = height();
         m_pixLabel->setGeometry(10,10, height() - 20, height() - 20);
-        m_pixLabel->setPixmap(m_cover.scaled(m_pixLabel->size(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
+        m_pixLabel->setPixmap(QPixmap::fromImage(m_cover.scaled(m_pixLabel->size(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation)));
         m_pixLabel->show();
     }
     else
@@ -219,17 +218,17 @@ void QSUIVisualization::mousePressEvent (QMouseEvent *e)
 void QSUIVisualization::readSettings()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("Simple");
+    settings.beginGroup(u"Simple"_s);
     //general settings
-    m_show_cover = settings.value("vis_show_cover", true).toBool();
-    m_timer->setInterval(1000 / settings.value("vis_refresh_rate", 25).toInt());
-    QString visName = settings.value("vis_type","analyzer").toString();
-    m_bgColor.setNamedColor(settings.value("vis_bg_color", "Black").toString());
+    m_show_cover = settings.value(u"vis_show_cover"_s, true).toBool();
+    m_timer->setInterval(1000 / settings.value(u"vis_refresh_rate"_s, 25).toInt());
+    QString visName = settings.value(u"vis_type"_s, u"analyzer"_s).toString();
+    m_bgColor.setNamedColor(settings.value(u"vis_bg_color"_s, u"Black"_s).toString());
     //analyzer settings
-    double peaks_falloff = settings.value("vis_peaks_falloff", 0.2).toDouble();
-    double analyzer_falloff = settings.value("vis_analyzer_falloff", 2.2).toDouble();
-    bool show_peaks = settings.value("vis_show_peaks", true).toBool();
-    QString analyzer_type = settings.value("vis_analyzer_type", "cells").toString();
+    double peaks_falloff = settings.value(u"vis_peaks_falloff"_s, 0.2).toDouble();
+    double analyzer_falloff = settings.value(u"vis_analyzer_falloff"_s, 2.2).toDouble();
+    bool show_peaks = settings.value(u"vis_show_peaks"_s, true).toBool();
+    QString analyzer_type = settings.value(u"vis_analyzer_type"_s, u"cells"_s).toString();
 
     if(!m_update)
     {
@@ -270,10 +269,9 @@ void QSUIVisualization::readSettings()
 
     if(!m_drawer || m_drawer->name() != visName)
     {
-        if(m_drawer)
-            delete m_drawer;
+        delete m_drawer;
 
-        if(visName == "scope")
+        if(visName == "scope"_L1)
             m_drawer = new QSUiScope;
         else
             m_drawer = new QSUiAnalyzer;
@@ -285,20 +283,20 @@ void QSUIVisualization::readSettings()
 void QSUIVisualization::writeSettings()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("Simple");
+    settings.beginGroup(u"Simple"_s);
 
     QAction *act = m_fpsGroup->checkedAction ();
-    settings.setValue("vis_refresh_rate", act ? act->data().toInt() : 25);
+    settings.setValue(u"vis_refresh_rate"_s, act ? act->data().toInt() : 25);
     act = m_peaksFalloffGroup->checkedAction ();
-    settings.setValue("vis_peaks_falloff", act ? act->data().toDouble() : 0.2);
+    settings.setValue(u"vis_peaks_falloff"_s, act ? act->data().toDouble() : 0.2);
     act = m_analyzerFalloffGroup->checkedAction ();
-    settings.setValue("vis_analyzer_falloff", act ? act->data().toDouble() : 2.2);
-    settings.setValue("vis_show_peaks", m_peaksAction->isChecked());
-    settings.setValue("vis_show_cover", m_coverAction->isChecked());
+    settings.setValue(u"vis_analyzer_falloff"_s, act ? act->data().toDouble() : 2.2);
+    settings.setValue(u"vis_show_peaks"_s, m_peaksAction->isChecked());
+    settings.setValue(u"vis_show_cover"_s, m_coverAction->isChecked());
     act = m_visModeGroup->checkedAction();
-    settings.setValue("vis_type", act ? act->data().toString() : "none");
+    settings.setValue(u"vis_type"_s, act ? act->data().toString() : u"none"_s);
     act = m_analyzerTypeGroup->checkedAction();
-    settings.setValue("vis_analyzer_type", act ? act->data().toString() : "none");
+    settings.setValue(u"vis_analyzer_type"_s, act ? act->data().toString() : u"none"_s);
     settings.endGroup();
 }
 
@@ -318,13 +316,12 @@ void QSUIVisualization::stop()
 
 QSUiScope::~QSUiScope()
 {
-    if(m_intern_vis_data)
-        delete [] m_intern_vis_data;
+    delete [] m_intern_vis_data;
 }
 
 QString QSUiScope::name() const
 {
-    return "scope";
+    return u"scope"_s;
 }
 
 void QSUiScope::process(float *buffer, int width, int height)
@@ -335,10 +332,7 @@ void QSUiScope::process(float *buffer, int width, int height)
     if(m_width != width )
     {
         m_width = width;
-
-        if(m_intern_vis_data)
-            delete [] m_intern_vis_data;
-
+        delete [] m_intern_vis_data;
         m_intern_vis_data = new int[m_width]{ 0 };
     }
 
@@ -388,10 +382,10 @@ void QSUiScope::clear()
 void QSUiScope::readSettings()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("Simple");
-    m_color1.setNamedColor(settings.value("vis_color1", "#BECBFF").toString());
-    m_color2.setNamedColor(settings.value("vis_color2", "#BECBFF").toString());
-    m_color3.setNamedColor(settings.value("vis_color3", "#BECBFF").toString());
+    settings.beginGroup(u"Simple"_s);
+    m_color1.setNamedColor(settings.value(u"vis_color1"_s, u"#BECBFF"_s).toString());
+    m_color2.setNamedColor(settings.value(u"vis_color2"_s, u"#BECBFF"_s).toString());
+    m_color3.setNamedColor(settings.value(u"vis_color3"_s, u"#BECBFF"_s).toString());
     settings.endGroup();
 }
 
@@ -400,17 +394,14 @@ QSUiVisualDrawer::~QSUiVisualDrawer()
 
 QSUiAnalyzer::~QSUiAnalyzer()
 {
-    if(m_intern_vis_data)
-        delete [] m_intern_vis_data;
-    if(m_peaks)
-        delete [] m_peaks;
-    if(m_x_scale)
-        delete [] m_x_scale;
+    delete [] m_intern_vis_data;
+    delete [] m_peaks;
+    delete [] m_x_scale;
 }
 
 QString QSUiAnalyzer::name() const
 {
-    return "analyzer";
+    return u"analyzer"_s;
 }
 
 void QSUiAnalyzer::process(float *buffer, int width, int height)
@@ -423,12 +414,9 @@ void QSUiAnalyzer::process(float *buffer, int width, int height)
     {
         m_rows = rows;
         m_cols = cols;
-        if(m_peaks)
-            delete [] m_peaks;
-        if(m_intern_vis_data)
-            delete [] m_intern_vis_data;
-        if(m_x_scale)
-            delete [] m_x_scale;
+        delete [] m_peaks;
+        delete [] m_intern_vis_data;
+        delete [] m_x_scale;
         m_peaks = new double[m_cols] { 0 };
         m_intern_vis_data = new double[m_cols] { 0 };
         m_x_scale = new int[m_cols + 1] { 0 };
@@ -519,17 +507,17 @@ void QSUiAnalyzer::clear()
 void QSUiAnalyzer::readSettings()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("Simple");
-    m_color1.setNamedColor(settings.value("vis_color1", "#BECBFF").toString());
-    m_color2.setNamedColor(settings.value("vis_color2", "#BECBFF").toString());
-    m_color3.setNamedColor(settings.value("vis_color3", "#BECBFF").toString());
-    m_peakColor.setNamedColor(settings.value("vis_peak_color", "#DDDDDD").toString());
+    settings.beginGroup(u"Simple"_s);
+    m_color1.setNamedColor(settings.value(u"vis_color1"_s, u"#BECBFF"_s).toString());
+    m_color2.setNamedColor(settings.value(u"vis_color2"_s, u"#BECBFF"_s).toString());
+    m_color3.setNamedColor(settings.value(u"vis_color3"_s, u"#BECBFF"_s).toString());
+    m_peakColor.setNamedColor(settings.value(u"vis_peak_color"_s, u"#DDDDDD"_s).toString());
     m_cell_size =  QSize(14, 8);
-    m_peaks_falloff = settings.value("vis_peaks_falloff", 0.2).toDouble();
-    m_analyzer_falloff = settings.value("vis_analyzer_falloff", 2.2).toDouble();
-    m_show_peaks = settings.value("vis_show_peaks", true).toBool();
-    QString analyzer_type = settings.value("vis_analyzer_type", "cells").toString();
-    if(analyzer_type == "lines")
+    m_peaks_falloff = settings.value(u"vis_peaks_falloff"_s, 0.2).toDouble();
+    m_analyzer_falloff = settings.value(u"vis_analyzer_falloff"_s, 2.2).toDouble();
+    m_show_peaks = settings.value(u"vis_show_peaks"_s, true).toBool();
+    QString analyzer_type = settings.value(u"vis_analyzer_type"_s, u"cells"_s).toString();
+    if(analyzer_type == "lines"_L1)
         m_analyzerType = Lines;
     else
         m_analyzerType = Cells;
