@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2020-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2020-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -40,16 +40,11 @@
 #define FLOATS_PER_LANE (4) // Number of floats fitting into a 128-bit XMM register
 #define VECTORIZE_HINT (8)
 
-static inline int gcd(int a, int b)
-{
-    return b ? gcd(b, a % b) : a;
-}
-
 QSUiWaveformSeekBar::QSUiWaveformSeekBar(QWidget *parent) : QWidget(parent)
 {
     m_core = SoundCore::instance();
-    connect(m_core, SIGNAL(stateChanged(Qmmp::State)), SLOT(onStateChanged(Qmmp::State)));
-    connect(m_core, SIGNAL(elapsedChanged(qint64)), SLOT(onElapsedChanged(qint64)));
+    connect(m_core, &SoundCore::stateChanged, this, &QSUiWaveformSeekBar::onStateChanged);
+    connect(m_core, &SoundCore::elapsedChanged, this, &QSUiWaveformSeekBar::onElapsedChanged);
     createMenu();
     readSettings();
 }
@@ -62,16 +57,16 @@ QSize QSUiWaveformSeekBar::sizeHint() const
 void QSUiWaveformSeekBar::readSettings()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("Simple");
-    m_bgColor.setNamedColor(settings.value("wfsb_bg_color", "Black").toString());
-    m_rmsColor.setNamedColor(settings.value("wfsb_rms_color", "#DDDDDD").toString());
-    m_waveFormColor.setNamedColor(settings.value("wfsb_waveform_color", "#BECBFF").toString());
-    m_progressBar.setNamedColor(settings.value("wfsb_progressbar_color", "#9633CA10").toString());
+    settings.beginGroup(u"Simple"_s);
+    m_bgColor.setNamedColor(settings.value(u"wfsb_bg_color"_s, u"Black"_s).toString());
+    m_rmsColor.setNamedColor(settings.value(u"wfsb_rms_color"_s, u"#DDDDDD"_s).toString());
+    m_waveFormColor.setNamedColor(settings.value(u"wfsb_waveform_color"_s, u"#BECBFF"_s).toString());
+    m_progressBar.setNamedColor(settings.value(u"wfsb_progressbar_color"_s, u"#9633CA10"_s).toString());
     if(!m_update)
     {
         m_update = true;
-        m_showTwoChannelsAction->setChecked(settings.value("wfsb_show_two_channels", true).toBool());
-        m_showRmsAction->setChecked(settings.value("wfsb_show_rms", true).toBool());
+        m_showTwoChannelsAction->setChecked(settings.value(u"wfsb_show_two_channels"_s, true).toBool());
+        m_showRmsAction->setChecked(settings.value(u"wfsb_show_rms"_s, true).toBool());
     }
     settings.endGroup();
     drawWaveform();
@@ -87,8 +82,8 @@ void QSUiWaveformSeekBar::onStateChanged(Qmmp::State state)
         if(!m_scanner && isVisible() && m_data.isEmpty())
         {
             m_scanner = new QSUiWaveformScanner(this);
-            connect(m_scanner, SIGNAL(finished()), SLOT(onScanFinished()));
-            connect(m_scanner, SIGNAL(dataChanged()), SLOT(onDataChanged()));
+            connect(m_scanner, &QSUiWaveformScanner::finished, this, &QSUiWaveformSeekBar::onScanFinished);
+            connect(m_scanner, &QSUiWaveformScanner::dataChanged, this, &QSUiWaveformSeekBar::onDataChanged);
         }
         if(m_scanner)
             m_scanner->scan(m_core->path());
@@ -148,16 +143,16 @@ void QSUiWaveformSeekBar::onElapsedChanged(qint64 elapsed)
 void QSUiWaveformSeekBar::writeSettings()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("Simple");
-    settings.setValue("wfsb_show_two_channels", m_showTwoChannelsAction->isChecked());
-    settings.setValue("wfsb_show_rms", m_showRmsAction->isChecked());
+    settings.beginGroup(u"Simple"_s);
+    settings.setValue(u"wfsb_show_two_channels"_s, m_showTwoChannelsAction->isChecked());
+    settings.setValue(u"wfsb_show_rms"_s, m_showRmsAction->isChecked());
     settings.endGroup();
     drawWaveform();
 }
 
 void QSUiWaveformSeekBar::paintEvent(QPaintEvent *e)
 {
-    QPainter painter (this);
+    QPainter painter(this);
     painter.fillRect(e->rect(), m_bgColor);
 
     if(!m_pixmap.isNull())
@@ -212,8 +207,7 @@ void QSUiWaveformSeekBar::mouseMoveEvent(QMouseEvent *e)
     if(m_pressedPos >= 0)
     {
         m_pressedPos = qBound(0, e->pos().x(), width());
-        QToolTip::showText(mapToGlobal(e->pos()),
-                           MetaDataFormatter::formatDuration(m_pressedPos * m_duration / width()),
+        QToolTip::showText(mapToGlobal(e->pos()), MetaDataFormatter::formatDuration(m_pressedPos * m_duration / width()),
                            this, QRect());
         update();
     }
@@ -331,10 +325,10 @@ void QSUiWaveformSeekBar::drawWaveform()
 void QSUiWaveformSeekBar::createMenu()
 {
     m_menu = new QMenu(this);
-    m_showTwoChannelsAction = m_menu->addAction(tr("2 Channels"), this, SLOT(writeSettings()));
+    m_showTwoChannelsAction = m_menu->addAction(tr("2 Channels"), this, &QSUiWaveformSeekBar::writeSettings);
     m_showTwoChannelsAction->setCheckable(true);
     //: Root mean square
-    m_showRmsAction = m_menu->addAction(tr("RMS"), this, SLOT(writeSettings()));
+    m_showRmsAction = m_menu->addAction(tr("RMS"), this, &QSUiWaveformSeekBar::writeSettings);
     m_showRmsAction->setCheckable(true);
 }
 
@@ -349,21 +343,21 @@ QSUiWaveformScanner::~QSUiWaveformScanner()
 bool QSUiWaveformScanner::scan(const QString &path)
 {
     //skip streams
-    if(path.contains("://") && InputSource::findByUrl(path))
+    if(path.contains(u"://"_s) && InputSource::findByUrl(path))
         return false;
 
     InputSource *source = InputSource::create(path, this);
     if(!source->initialize())
     {
         delete source;
-        qWarning("QSUIWaveformScanner: invalid path");
+        qCWarning(plugin, "invalid path");
         return false;
     }
 
     if(source->ioDevice() && !source->ioDevice()->open(QIODevice::ReadOnly))
     {
         source->deleteLater();
-        qWarning("QSUIWaveformScanner: cannot open input stream, error: %s",
+        qCWarning(plugin, "cannot open input stream, error: %s",
                  qPrintable(source->ioDevice()->errorString()));
         return false;
 
@@ -371,27 +365,27 @@ bool QSUiWaveformScanner::scan(const QString &path)
 
     DecoderFactory *factory = nullptr;
 
-    if(!source->path().contains("://"))
+    if(!source->path().contains(u"://"_s))
         factory = Decoder::findByFilePath(source->path(), QmmpSettings::instance()->determineFileTypeByContent());
     if(!factory)
         factory = Decoder::findByMime(source->contentType());
-    if(!factory && source->ioDevice() && source->path().contains("://")) //ignore content of local files
+    if(!factory && source->ioDevice() && source->path().contains(u"://"_s)) //ignore content of local files
         factory = Decoder::findByContent(source->ioDevice());
-    if(!factory && source->path().contains("://"))
-        factory = Decoder::findByProtocol(source->path().section("://",0,0));
-    if(!factory || source->path().startsWith(QStringLiteral("cdda://")))
+    if(!factory && source->path().contains(u"://"_s))
+        factory = Decoder::findByProtocol(source->path().section(u"://"_s, 0, 0));
+    if(!factory || source->path().startsWith(u"cdda://"_s))
     {
-        qWarning("QSUIWaveformScanner: unsupported file format");
+        qCWarning(plugin, "unsupported file format");
         source->deleteLater();
         return false;
     }
-    qDebug("QSUIWaveformScanner: selected decoder: %s",qPrintable(factory->properties().shortName));
+    qCDebug(plugin, "selected decoder: %s",qPrintable(factory->properties().shortName));
     if(factory->properties().noInput && source->ioDevice())
         source->ioDevice()->close();
     Decoder *decoder = factory->create(source->path(), source->ioDevice());
     if(!decoder->initialize())
     {
-        qWarning("QSUIWaveformScanner: invalid file format");
+        qCWarning(plugin, "invalid file format");
         source->deleteLater();
         delete decoder;
         return false;
@@ -472,7 +466,7 @@ void QSUiWaveformScanner::run()
     // For layouts containing less than 16 items, GCC or Clang do not produce
     // vectorized code at -O2. However, multiplying 'samples_per_stat' by a constant
     // results in the desired output.
-    int samples_per_stat = FLOATS_PER_LANE * channels / gcd(FLOATS_PER_LANE, channels) * VECTORIZE_HINT;
+    int samples_per_stat = std::lcm(FLOATS_PER_LANE, channels) * VECTORIZE_HINT;
     int frames_per_stat = samples_per_stat / channels;
 
     float *vmax = new float[samples_per_stat]{ -1.f };
