@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2016 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -39,12 +39,12 @@ ToolBarEditor::ToolBarEditor(QWidget *parent) :
     m_ui->addToolButton->setIcon(qApp->style()->standardIcon(QStyle::SP_ArrowRight));
     m_ui->removeToolButton->setIcon(qApp->style()->standardIcon(QStyle::SP_ArrowLeft));
 
-    connect(m_ui->actionsListWidget->model(), SIGNAL(rowsAboutToBeRemoved(const QModelIndex &,int,int)),
-            SLOT(onRowsAboutToBeRemoved(const QModelIndex &, int, int)));
-    connect(m_ui->activeActionsListWidget->model(), SIGNAL(rowsAboutToBeRemoved(const QModelIndex &,int,int)),
-            SLOT(onRowsAboutToBeRemoved(const QModelIndex &, int, int)));
+    connect(m_ui->actionsListWidget->model(), &QAbstractItemModel::rowsAboutToBeRemoved,
+            this, &ToolBarEditor::onRowsAboutToBeRemoved);
+    connect(m_ui->activeActionsListWidget->model(), &QAbstractItemModel::rowsAboutToBeRemoved,
+            this, &ToolBarEditor::onRowsAboutToBeRemoved);
 
-    m_toolBarInfoList = ActionManager::instance()->readToolBarSettings();
+    m_toolBarInfoList = QSUiActionManager::instance()->readToolBarSettings();
 
     m_previousIndex = -1;
     populateActionList();
@@ -58,7 +58,7 @@ ToolBarEditor::~ToolBarEditor()
 void ToolBarEditor::accept()
 {
     on_toolbarNameComboBox_activated(m_ui->toolbarNameComboBox->currentIndex());
-    ActionManager::instance()->writeToolBarSettings(m_toolBarInfoList);
+    QSUiActionManager::instance()->writeToolBarSettings(m_toolBarInfoList);
     QDialog::accept();
 }
 
@@ -71,18 +71,18 @@ void ToolBarEditor::populateActionList(bool reset)
     if(reset)
     {
         m_toolBarInfoList.clear();
-        m_toolBarInfoList.append(ActionManager::instance()->defaultToolBar());
+        m_toolBarInfoList.append(QSUiActionManager::instance()->defaultToolBar());
         m_previousIndex = -1;
     }
 
     QStringList actionNames;
-    for(const ActionManager::ToolBarInfo &info : qAsConst(m_toolBarInfoList))
+    for(const QSUiActionManager::ToolBarInfo &info : std::as_const(m_toolBarInfoList))
     {
         actionNames << info.actionNames;
         m_ui->toolbarNameComboBox->addItem(info.title);
     }
 
-    for(int id = ActionManager::PLAY; id <= ActionManager::UI_QUICK_SEARCH; ++id)
+    for(int id = QSUiActionManager::PLAY; id <= QSUiActionManager::UI_QUICK_SEARCH; ++id)
     {
         QAction *action = ACTION(id);
         if(!action || actionNames.contains(action->objectName()))
@@ -92,12 +92,12 @@ void ToolBarEditor::populateActionList(bool reset)
 
         QListWidgetItem *item = new QListWidgetItem();
         item->setIcon(action->icon());
-        item->setText(action->text().replace("&", ""));
+        item->setText(action->text().remove(QLatin1Char('&')));
         item->setData(Qt::UserRole, action->objectName());
         m_ui->actionsListWidget->addItem(item);
     }
 
-    m_ui->actionsListWidget->addItem(createExtraItem("-- " + tr("Separator") + " --", "separator"));
+    m_ui->actionsListWidget->addItem(createExtraItem(u"-- "_s + tr("Separator") + u" --"_s, u"separator"_s));
     on_toolbarNameComboBox_activated(m_ui->toolbarNameComboBox->currentIndex());
 }
 
@@ -189,22 +189,22 @@ void ToolBarEditor::on_toolbarNameComboBox_activated(int index)
 
     if(index < 0)
         return;
-    ActionManager::ToolBarInfo info = m_toolBarInfoList.at(index);
+    QSUiActionManager::ToolBarInfo info = m_toolBarInfoList.at(index);
 
-    for(const QString &name : qAsConst(info.actionNames))
+    for(const QString &name : std::as_const(info.actionNames))
     {
-        if(name == "separator")
+        if(name == "separator"_L1)
         {
-            m_ui->activeActionsListWidget->addItem(createExtraItem("-- " + tr("Separator") + " --", name));
+            m_ui->activeActionsListWidget->addItem(createExtraItem(u"-- "_s + tr("Separator") + u" --"_s, name));
             continue;
         }
 
-        QAction *action = ActionManager::instance()->findChild<QAction *>(name);
+        QAction *action = QSUiActionManager::instance()->findChild<QAction *>(name);
         if(action)
         {
             QListWidgetItem *item = new QListWidgetItem();
             item->setIcon(action->icon());
-            item->setText(action->text().replace("&", ""));
+            item->setText(action->text().remove(QLatin1Char('&')));
             item->setData(Qt::UserRole, action->objectName());
             m_ui->activeActionsListWidget->addItem(item);
         }
@@ -217,18 +217,18 @@ void ToolBarEditor::onRowsAboutToBeRemoved(const QModelIndex &, int start, int)
     {
         //recreate separator
         QListWidgetItem *item = m_ui->actionsListWidget->item(start);
-        if(item && item->data(Qt::UserRole).toString() == "separator")
+        if(item && item->data(Qt::UserRole).toString() == "separator"_L1)
             m_ui->actionsListWidget->addItem(item->clone());
     }
     else if(sender() == m_ui->activeActionsListWidget->model())
     {
         //remove separator
         QListWidgetItem *item = m_ui->activeActionsListWidget->item(start);
-        if(item && item->data(Qt::UserRole).toString() == "separator")
+        if(item && item->data(Qt::UserRole).toString() == "separator"_L1)
         {
             for(int i = 0; i < m_ui->actionsListWidget->count(); ++i)
             {
-                if(m_ui->actionsListWidget->item(i)->data(Qt::UserRole).toString() == "separator")
+                if(m_ui->actionsListWidget->item(i)->data(Qt::UserRole).toString() == "separator"_L1)
                 {
                     m_ui->actionsListWidget->model()->blockSignals(true);
                     delete m_ui->actionsListWidget->takeItem(i);
@@ -242,7 +242,7 @@ void ToolBarEditor::onRowsAboutToBeRemoved(const QModelIndex &, int start, int)
 
 void ToolBarEditor::on_createButton_clicked()
 {
-    ActionManager::ToolBarInfo info;
+    QSUiActionManager::ToolBarInfo info;
     int i = 0;
     //generate unique toolbar name
     QString title = tr("Toolbar");
