@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2011-2016 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,53 +28,67 @@
 
 VolumeSlider::VolumeSlider(QWidget *parent) : QSlider(Qt::Horizontal, parent)
 {
-    connect(this, SIGNAL(sliderMoved(int)), SLOT(onSliderMoved(int)));
+    connect(this, &VolumeSlider::sliderMoved, this, &VolumeSlider::onSliderMoved);
 }
 
-void VolumeSlider::mousePressEvent (QMouseEvent *event)
+void VolumeSlider::setValue(int value)
+{
+    if(!isSliderDown())
+        QSlider::setValue(value);
+}
+
+void VolumeSlider::mousePressEvent(QMouseEvent *event)
 {
     QStyleOptionSlider opt;
     initStyleOption(&opt);
     QRect sr = style()->subControlRect(QStyle::CC_Slider, &opt, QStyle::SC_SliderHandle, this);
 
-    if (event->button() == Qt::LeftButton &&
-            sr.contains(event->pos()) == false)
+    if(event->button() == Qt::LeftButton && !sr.contains(event->pos()))
     {
         int val;
-        if (orientation() == Qt::Vertical)
-            val = minimum() + ((maximum() - minimum()) * (height() - event->y())) / height();
+        if(orientation() == Qt::Vertical)
+            val = minimum() + ((maximum() - minimum()) * (height() - event->pos().y())) / height();
         else if(layoutDirection() == Qt::RightToLeft)
-            val = maximum() - ((maximum() - minimum()) * event->x()) / width();
+            val = maximum() - ((maximum() - minimum()) * event->pos().x()) / width();
         else
-            val = minimum() + ((maximum() - minimum()) * event->x()) / width();
+            val = minimum() + ((maximum() - minimum()) * event->pos().x()) / width();
 
-        setSliderDown (true);
+        setSliderDown(true);
 
-        if (invertedAppearance() == true)
+        if(invertedAppearance())
         {
             setValue(maximum() - val);
             onSliderMoved(maximum() - val);
         }
         else
         {
-            setValue(val);
+            QSlider::setValue(val);
             onSliderMoved(val);
         }
         event->accept();
     }
+    else if(event->button() == Qt::MiddleButton)
+    {
+        int val = (maximum() + minimum()) / 2;
+        QSlider::setValue(val);
+        onSliderMoved(val);
+        emit sliderMoved(val);
+        return;
+    }
+
     QSlider::mousePressEvent(event);
 }
 
-void VolumeSlider::mouseReleaseEvent (QMouseEvent *event)
+void VolumeSlider::mouseReleaseEvent(QMouseEvent *event)
 {
-    setSliderDown (false);
+    setSliderDown(false);
     QSlider::mouseReleaseEvent(event);
 }
 
 void VolumeSlider::wheelEvent(QWheelEvent *event)
 {
     setSliderDown(true);
-    setValue(value() + event->delta() / 20);
+    QSlider::setValue(value() + event->angleDelta().y() / 20);
     setSliderDown(false);
 }
 
@@ -87,7 +101,12 @@ void VolumeSlider::onSliderMoved(int pos)
         QRect rect = style()->subControlRect(QStyle::CC_Slider, &opt, QStyle::SC_SliderHandle, this);
         rect.moveTo(rect.x() - 10 , rect.y() - 45);
 
-        int level = (pos - minimum()) * 100 / (maximum() - minimum());
-        QToolTip::showText(mapToGlobal(rect.topLeft()), tr("%1%").arg(level), this, QRect());
+        int level = 0;
+        if(minimum() >= 0)
+            level = (pos - minimum()) * 100 / (maximum() - minimum());
+        else
+            level = pos * 100 * 2 / (maximum() - minimum());
+
+        QToolTip::showText(mapToGlobal(rect.topLeft()), tr("%1: %2%").arg(windowTitle()).arg(level), this, QRect());
     }
 }
