@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2011-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,11 +23,16 @@
 
 #include <QWidget>
 #include <QFileInfo>
-#include "ui_skinnedsettings.h"
 
+class QListWidgetItem;
+class QLabel;
 class SkinReader;
 class Skin;
 
+namespace Ui {
+class SkinnedSettings;
+}
+
 class SkinnedSettings : public QWidget
 {
     Q_OBJECT
@@ -37,10 +42,7 @@ public:
     void writeSettings();
 
 private slots:
-    void on_listWidget_itemClicked(QListWidgetItem *);
-    void on_plFontButton_clicked();
-    void on_headerFontButton_clicked();
-    void on_mainFontButton_clicked();
+    void on_listWidget_itemClicked(QListWidgetItem *item);
     void on_resetFontsButton_clicked();
     void on_skinInstallButton_clicked();
     void loadSkins();
@@ -50,14 +52,14 @@ private slots:
 
 private:
     void showEvent(QShowEvent *) override;
+    void selectFont(QLabel *label);
+    void setFont(QLabel *label, const QString &fontName);
     void loadFonts();
-    void findSkins(const QString &path);
     void createActions();
     void readSettings();
 
-    Ui::SkinnedSettings m_ui;
-    QList <QFileInfo> m_skinList;
-    QString m_currentSkinName;
+    Ui::SkinnedSettings *m_ui;
+    QString m_currentSkinPath;
     Skin *m_skin;
     SkinReader *m_reader;
 
