@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -31,12 +31,12 @@
 #include "inlines.h"
 #include "analyzer.h"
 
-Analyzer::Analyzer (QWidget *parent) : Visual (parent)
+Analyzer::Analyzer(QWidget *parent) : Visual (parent)
 {
     setWindowTitle (tr("Qmmp Analyzer"));
     setMinimumSize(2*300-30,105);
     m_timer = new QTimer (this);
-    connect(m_timer, SIGNAL (timeout()), this, SLOT (timeout()));
+    connect(m_timer, &QTimer::timeout, this, &Analyzer::timeout);
 
     clear();
     createMenu();
@@ -45,12 +45,9 @@ Analyzer::Analyzer (QWidget *parent) : Visual (parent)
 
 Analyzer::~Analyzer()
 {
-    if(m_peaks)
-        delete [] m_peaks;
-    if(m_intern_vis_data)
-        delete [] m_intern_vis_data;
-    if(m_x_scale)
-        delete [] m_x_scale;
+    delete [] m_peaks;
+    delete [] m_intern_vis_data;
+    delete [] m_x_scale;
 }
 
 void Analyzer::start()
@@ -91,17 +88,17 @@ void Analyzer::toggleFullScreen()
 void Analyzer::readSettings()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("Analyzer");
-    m_peaks_falloff = settings.value("peak_falloff", 0.2).toDouble();
-    m_analyzer_falloff = settings.value("analyzer_falloff", 2.2).toDouble();
-    m_show_peaks = settings.value("show_peaks", true).toBool();
-    m_timer->setInterval(1000 / settings.value("refresh_rate", 25).toInt());
-    m_color1.setNamedColor(settings.value("color1", "Green").toString());
-    m_color2.setNamedColor(settings.value("color2", "Yellow").toString());
-    m_color3.setNamedColor(settings.value("color3", "Red").toString());
-    m_bgColor.setNamedColor(settings.value("bg_color", "Black").toString());
-    m_peakColor.setNamedColor(settings.value("peak_color", "Cyan").toString());
-    m_cell_size = settings.value("cells_size", QSize(15, 6)).toSize();
+    settings.beginGroup("Analyzer"_L1);
+    m_peaks_falloff = settings.value("peak_falloff"_L1, 0.2).toDouble();
+    m_analyzer_falloff = settings.value("analyzer_falloff"_L1, 2.2).toDouble();
+    m_show_peaks = settings.value("show_peaks"_L1, true).toBool();
+    m_timer->setInterval(1000 / settings.value("refresh_rate"_L1, 25).toInt());
+    m_color1.setNamedColor(settings.value("color1"_L1, u"Green"_s).toString());
+    m_color2.setNamedColor(settings.value("color2"_L1, u"Yellow"_s).toString());
+    m_color3.setNamedColor(settings.value("color3"_L1, u"Red"_s).toString());
+    m_bgColor.setNamedColor(settings.value("bg_color"_L1, u"Black"_s).toString());
+    m_peakColor.setNamedColor(settings.value("peak_color"_L1, u"Cyan"_s).toString());
+    m_cell_size = settings.value("cells_size"_L1, QSize(15, 6)).toSize();
 
 
     if(!m_update)
@@ -142,21 +139,21 @@ void Analyzer::readSettings()
             m_analyzer_falloff = 2.2;
         }
 
-        restoreGeometry(settings.value("geometry").toByteArray());
+        restoreGeometry(settings.value("geometry"_L1).toByteArray());
     }
 }
 
 void Analyzer::writeSettings()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("Analyzer");
-    QAction *act = m_fpsGroup->checkedAction ();
-    settings.setValue("refresh_rate", act ? act->data().toInt() : 25);
-    act = m_peaksFalloffGroup->checkedAction ();
-    settings.setValue("peak_falloff", act ? act->data().toDouble() : 0.2);
-    act = m_analyzerFalloffGroup->checkedAction ();
-    settings.setValue("analyzer_falloff", act ? act->data().toDouble() : 2.2);
-    settings.setValue("show_peaks", m_peaksAction->isChecked());
+    settings.beginGroup("Analyzer"_L1);
+    QAction *act = m_fpsGroup->checkedAction();
+    settings.setValue("refresh_rate"_L1, act ? act->data().toInt() : 25);
+    act = m_peaksFalloffGroup->checkedAction();
+    settings.setValue("peak_falloff"_L1, act ? act->data().toDouble() : 0.2);
+    act = m_analyzerFalloffGroup->checkedAction();
+    settings.setValue("analyzer_falloff"_L1, act ? act->data().toDouble() : 2.2);
+    settings.setValue("show_peaks"_L1, m_peaksAction->isChecked());
     settings.endGroup();
 }
 
@@ -175,7 +172,7 @@ void Analyzer::closeEvent (QCloseEvent *event)
 {
     //save geometry
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.setValue("Analyzer/geometry", saveGeometry());
+    settings.setValue("Analyzer/geometry"_L1, saveGeometry());
     Visual::closeEvent(event); //removes visualization object
 }
 
@@ -205,21 +202,13 @@ void Analyzer::process()
     {
         m_rows = rows;
         m_cols = cols;
-        if(m_peaks)
-            delete [] m_peaks;
-        if(m_intern_vis_data)
-            delete [] m_intern_vis_data;
-        if(m_x_scale)
-            delete [] m_x_scale;
-        m_peaks = new double[m_cols * 2];
-        m_intern_vis_data = new double[m_cols * 2];
-        m_x_scale = new int[m_cols + 1];
+        delete [] m_peaks;
+        delete [] m_intern_vis_data;
+        delete [] m_x_scale;
+        m_peaks = new double[m_cols * 2] { 0 };
+        m_intern_vis_data = new double[m_cols * 2] { 0 };
+        m_x_scale = new int[m_cols + 1] { 0 };
 
-        for(int i = 0; i < m_cols * 2; ++i)
-        {
-            m_peaks[i] = 0;
-            m_intern_vis_data[i] = 0;
-        }
         for(int i = 0; i < m_cols + 1; ++i)
             m_x_scale[i] = pow(pow(255.0, 1.0 / m_cols), i);
     }
@@ -317,8 +306,8 @@ void Analyzer::draw(QPainter *p)
 void Analyzer::createMenu()
 {
     m_menu = new QMenu (this);
-    connect(m_menu, SIGNAL(triggered (QAction *)),SLOT(writeSettings()));
-    connect(m_menu, SIGNAL(triggered (QAction *)),SLOT(readSettings()));
+    connect(m_menu, &QMenu::triggered, this, &Analyzer::writeSettings);
+    connect(m_menu, &QMenu::triggered, this, &Analyzer::readSettings);
 
     m_peaksAction = m_menu->addAction(tr("Peaks"));
     m_peaksAction->setCheckable(true);
@@ -364,7 +353,7 @@ void Analyzer::createMenu()
         peaksFalloff->addAction(act);
     }
     m_menu->addSeparator();
-    QAction *fullScreenAction = m_menu->addAction(tr("&Full Screen"), this, SLOT(toggleFullScreen()), tr("F"));
+    QAction *fullScreenAction = m_menu->addAction(tr("&Full Screen"), this, &Analyzer::toggleFullScreen, tr("F"));
     addAction(fullScreenAction);
     update();
 }
