@@ -9,140 +9,140 @@
         <translation>מאבחן Qmmp</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="323"/>
+        <location filename="../analyzer.cpp" line="312"/>
         <source>Peaks</source>
         <translation>שיאים</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="326"/>
+        <location filename="../analyzer.cpp" line="315"/>
         <source>Refresh Rate</source>
         <translation>שיעור רענון</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="329"/>
+        <location filename="../analyzer.cpp" line="318"/>
         <source>50 fps</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="330"/>
+        <location filename="../analyzer.cpp" line="319"/>
         <source>25 fps</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="331"/>
+        <location filename="../analyzer.cpp" line="320"/>
         <source>10 fps</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="332"/>
+        <location filename="../analyzer.cpp" line="321"/>
         <source>5 fps</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="339"/>
+        <location filename="../analyzer.cpp" line="328"/>
         <source>Analyzer Falloff</source>
         <translation>נפילת מאבחן</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="342"/>
-        <location filename="../analyzer.cpp" line="356"/>
+        <location filename="../analyzer.cpp" line="331"/>
+        <location filename="../analyzer.cpp" line="345"/>
         <source>Slowest</source>
         <translation>הכי איטית</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="343"/>
-        <location filename="../analyzer.cpp" line="357"/>
+        <location filename="../analyzer.cpp" line="332"/>
+        <location filename="../analyzer.cpp" line="346"/>
         <source>Slow</source>
         <translation>איטית</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="344"/>
-        <location filename="../analyzer.cpp" line="358"/>
+        <location filename="../analyzer.cpp" line="333"/>
+        <location filename="../analyzer.cpp" line="347"/>
         <source>Medium</source>
         <translation>בינונית</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="345"/>
-        <location filename="../analyzer.cpp" line="359"/>
+        <location filename="../analyzer.cpp" line="334"/>
+        <location filename="../analyzer.cpp" line="348"/>
         <source>Fast</source>
         <translation>מהירה</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="346"/>
-        <location filename="../analyzer.cpp" line="360"/>
+        <location filename="../analyzer.cpp" line="335"/>
+        <location filename="../analyzer.cpp" line="349"/>
         <source>Fastest</source>
         <translation>הכי מהירה</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="353"/>
+        <location filename="../analyzer.cpp" line="342"/>
         <source>Peaks Falloff</source>
         <translation>נפילת שיאים</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="367"/>
+        <location filename="../analyzer.cpp" line="356"/>
         <source>&amp;Full Screen</source>
         <translation>&amp;מסך מלא</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="367"/>
+        <location filename="../analyzer.cpp" line="356"/>
         <source>F</source>
         <translation>F</translation>
     </message>
 </context>
 <context>
-    <name>ColorWidget</name>
+    <name>AnalyzerColorWidget</name>
     <message>
-        <location filename="../colorwidget.cpp" line="37"/>
+        <location filename="../analyzercolorwidget.cpp" line="37"/>
         <source>Select Color</source>
-        <translation>בחר צבע</translation>
+        <translation type="unfinished">בחר צבע</translation>
     </message>
 </context>
 <context>
-    <name>SettingsDialog</name>
+    <name>AnalyzerSettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.ui" line="14"/>
+        <location filename="../analyzersettingsdialog.ui" line="14"/>
         <source>Analyzer Plugin Settings</source>
-        <translation>הגדרות תוסף אבחון</translation>
+        <translation type="unfinished">הגדרות תוסף אבחון</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="35"/>
+        <location filename="../analyzersettingsdialog.ui" line="35"/>
         <source>General</source>
-        <translation>כללי</translation>
+        <translation type="unfinished">כללי</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="41"/>
+        <location filename="../analyzersettingsdialog.ui" line="41"/>
         <source>Cells size:</source>
-        <translation>מימד תאים:</translation>
+        <translation type="unfinished">מימד תאים:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="101"/>
+        <location filename="../analyzersettingsdialog.ui" line="101"/>
         <source>Colors</source>
-        <translation>צבעים</translation>
+        <translation type="unfinished">צבעים</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="107"/>
+        <location filename="../analyzersettingsdialog.ui" line="107"/>
         <source>Peaks:</source>
-        <translation>שיאים:</translation>
+        <translation type="unfinished">שיאים:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="139"/>
+        <location filename="../analyzersettingsdialog.ui" line="139"/>
         <source>Analyzer #1:</source>
-        <translation>מאבחן 1:</translation>
+        <translation type="unfinished">מאבחן 1:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="171"/>
+        <location filename="../analyzersettingsdialog.ui" line="171"/>
         <source>Background:</source>
-        <translation>רקע אחורי:</translation>
+        <translation type="unfinished">רקע אחורי:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="203"/>
+        <location filename="../analyzersettingsdialog.ui" line="203"/>
         <source>Analyzer #2:</source>
-        <translation>מאבחן 2:</translation>
+        <translation type="unfinished">מאבחן 2:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="248"/>
+        <location filename="../analyzersettingsdialog.ui" line="248"/>
         <source>Analyzer #3:</source>
-        <translation>מאבחן 3:</translation>
+        <translation type="unfinished">מאבחן 3:</translation>
     </message>
 </context>
 <context>
