@@ -9,138 +9,138 @@
         <translation>Qmmp 可視化解析器</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="323"/>
+        <location filename="../analyzer.cpp" line="312"/>
         <source>Peaks</source>
         <translation>峰值</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="326"/>
+        <location filename="../analyzer.cpp" line="315"/>
         <source>Refresh Rate</source>
         <translation>刷新率</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="329"/>
+        <location filename="../analyzer.cpp" line="318"/>
         <source>50 fps</source>
         <translation>50 fps</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="330"/>
+        <location filename="../analyzer.cpp" line="319"/>
         <source>25 fps</source>
         <translation>25 fps</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="331"/>
+        <location filename="../analyzer.cpp" line="320"/>
         <source>10 fps</source>
         <translation>10 fps</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="332"/>
+        <location filename="../analyzer.cpp" line="321"/>
         <source>5 fps</source>
         <translation>5 fps</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="339"/>
+        <location filename="../analyzer.cpp" line="328"/>
         <source>Analyzer Falloff</source>
         <translation>解析器下降速度</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="342"/>
-        <location filename="../analyzer.cpp" line="356"/>
+        <location filename="../analyzer.cpp" line="331"/>
+        <location filename="../analyzer.cpp" line="345"/>
         <source>Slowest</source>
         <translation>最慢</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="343"/>
-        <location filename="../analyzer.cpp" line="357"/>
+        <location filename="../analyzer.cpp" line="332"/>
+        <location filename="../analyzer.cpp" line="346"/>
         <source>Slow</source>
         <translation>慢</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="344"/>
-        <location filename="../analyzer.cpp" line="358"/>
+        <location filename="../analyzer.cpp" line="333"/>
+        <location filename="../analyzer.cpp" line="347"/>
         <source>Medium</source>
         <translation>中</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="345"/>
-        <location filename="../analyzer.cpp" line="359"/>
+        <location filename="../analyzer.cpp" line="334"/>
+        <location filename="../analyzer.cpp" line="348"/>
         <source>Fast</source>
         <translation>快</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="346"/>
-        <location filename="../analyzer.cpp" line="360"/>
+        <location filename="../analyzer.cpp" line="335"/>
+        <location filename="../analyzer.cpp" line="349"/>
         <source>Fastest</source>
         <translation>最快</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="353"/>
+        <location filename="../analyzer.cpp" line="342"/>
         <source>Peaks Falloff</source>
         <translation>峰值下降速度</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="367"/>
+        <location filename="../analyzer.cpp" line="356"/>
         <source>&amp;Full Screen</source>
         <translation>(&amp;F)全螢幕</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="367"/>
+        <location filename="../analyzer.cpp" line="356"/>
         <source>F</source>
         <translation>F</translation>
     </message>
 </context>
 <context>
-    <name>ColorWidget</name>
+    <name>AnalyzerColorWidget</name>
     <message>
-        <location filename="../colorwidget.cpp" line="37"/>
+        <location filename="../analyzercolorwidget.cpp" line="37"/>
         <source>Select Color</source>
         <translation>選擇色彩</translation>
     </message>
 </context>
 <context>
-    <name>SettingsDialog</name>
+    <name>AnalyzerSettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.ui" line="14"/>
+        <location filename="../analyzersettingsdialog.ui" line="14"/>
         <source>Analyzer Plugin Settings</source>
         <translation>可視化解析器插件設定</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="35"/>
+        <location filename="../analyzersettingsdialog.ui" line="35"/>
         <source>General</source>
         <translation>常規</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="41"/>
+        <location filename="../analyzersettingsdialog.ui" line="41"/>
         <source>Cells size:</source>
         <translation>框柵大小:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="101"/>
+        <location filename="../analyzersettingsdialog.ui" line="101"/>
         <source>Colors</source>
         <translation>色彩</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="107"/>
+        <location filename="../analyzersettingsdialog.ui" line="107"/>
         <source>Peaks:</source>
         <translation>峰值：</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="139"/>
+        <location filename="../analyzersettingsdialog.ui" line="139"/>
         <source>Analyzer #1:</source>
         <translation>解析 #1：</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="171"/>
+        <location filename="../analyzersettingsdialog.ui" line="171"/>
         <source>Background:</source>
         <translation>背景：</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="203"/>
+        <location filename="../analyzersettingsdialog.ui" line="203"/>
         <source>Analyzer #2:</source>
         <translation>解析 #2：</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="248"/>
+        <location filename="../analyzersettingsdialog.ui" line="248"/>
         <source>Analyzer #3:</source>
         <translation>解析 #3：</translation>
     </message>
