@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2023 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   Copyright (C) 2007 by  projectM team                                  *
@@ -43,7 +43,7 @@ ProjectMWidget::ProjectMWidget(QListWidget *listWidget, QWidget *parent)
     setMouseTracking(true);
     m_listWidget = listWidget;
     m_menu = new QMenu(this);
-    connect(SoundCore::instance(), SIGNAL(trackInfoChanged()), SLOT(updateTitle()));
+    connect(SoundCore::instance(), &SoundCore::trackInfoChanged, this, &ProjectMWidget::updateTitle);
     createActions();
 }
 
@@ -95,9 +95,9 @@ void ProjectMWidget::initializeGL()
         settings.textureSize = 1024;
         settings.windowWidth = 512;
         settings.windowHeight = 512;
-        settings.presetURL = QString(qApp->applicationDirPath() + "/projectM/presets").toLocal8Bit().constData();
-        settings.titleFontURL = QString(qApp->applicationDirPath() + "/projectM/fonts/Vera.ttf").toLocal8Bit().constData();
-        settings.menuFontURL = QString(qApp->applicationDirPath() + "/projectM/fonts/VeraMono.ttf").toLocal8Bit().constData();
+        settings.presetURL = QString(qApp->applicationDirPath() + u"/projectM/presets"_s).toLocal8Bit().constData();
+        settings.titleFontURL = QString(qApp->applicationDirPath() + u"/projectM/fonts/Vera.ttf"_s).toLocal8Bit().constData();
+        settings.menuFontURL = QString(qApp->applicationDirPath() + u"/projectM/fonts/VeraMono.ttf"_s).toLocal8Bit().constData();
         settings.smoothPresetDuration = 5;
         settings.presetDuration = 30;
         settings.beatSensitivity = 1.0;
@@ -111,15 +111,15 @@ void ProjectMWidget::initializeGL()
 #endif
         findPresets(QString::fromLocal8Bit(m_projectM->settings().presetURL.c_str()));
 
-        connect(m_listWidget, SIGNAL(currentRowChanged(int)), m_projectM, SLOT(selectPreset(int)));
-        connect(m_projectM, SIGNAL(currentPresetChanged(int)), SLOT(setCurrentRow(int)));
+        connect(m_listWidget, &QListWidget::currentRowChanged, m_projectM, &ProjectMWrapper::selectPreset);
+        connect(m_projectM, &ProjectMWrapper::currentPresetChanged, this, &ProjectMWidget::setCurrentRow);
         updateTitle();
     }
 }
 
-void ProjectMWidget::resizeGL (int w, int h)
+void ProjectMWidget::resizeGL(int w, int h)
 {
-    if (m_projectM)
+    if(m_projectM)
     {
         m_projectM->projectM_resetGL(w, h);
         initializeGL();
@@ -128,29 +128,29 @@ void ProjectMWidget::resizeGL (int w, int h)
 
 void ProjectMWidget::paintGL()
 {
-    if (m_projectM)
+    if(m_projectM)
         m_projectM->renderFrame();
 }
 
 void ProjectMWidget::mousePressEvent (QMouseEvent *event)
 {
-    if (event->button () == Qt::RightButton)
+    if(event->button () == Qt::RightButton)
         m_menu->exec(event->globalPos());
 }
 
 void ProjectMWidget::createActions()
 {
-    m_menu->addAction(tr("&Help"), this, SLOT(showHelp()), tr("F1"))->setCheckable(true);
-    m_menu->addAction(tr("&Show Song Title"), this, SLOT(showTitle()), tr("F2"))->setCheckable(true);
-    m_menu->addAction(tr("&Show Preset Name"), this, SLOT(showPresetName()), tr("F3"))->setCheckable(true);
-    m_menu->addAction(tr("&Show Menu"), this, SIGNAL(showMenuToggled(bool)), tr("M"))->setCheckable(true);
+    m_menu->addAction(tr("&Help"), this, &ProjectMWidget::showHelp, tr("F1"))->setCheckable(true);
+    m_menu->addAction(tr("&Show Song Title"), this, &ProjectMWidget::showTitle, tr("F2"))->setCheckable(true);
+    m_menu->addAction(tr("&Show Preset Name"), this, &ProjectMWidget::showPresetName, tr("F3"))->setCheckable(true);
+    m_menu->addAction(tr("&Show Menu"), this, &ProjectMWidget::showMenuToggled, tr("M"))->setCheckable(true);
     m_menu->addSeparator();
-    m_menu->addAction(tr("&Next Preset"), this, SLOT(nextPreset()), tr("N"));
-    m_menu->addAction(tr("&Previous Preset"), this, SLOT(previousPreset()), tr("P"));
-    m_menu->addAction(tr("&Random Preset"), this, SLOT(randomPreset()), tr("R"));
-    m_menu->addAction(tr("&Lock Preset"), this, SLOT(lockPreset(bool)), tr("L"))->setCheckable(true);
+    m_menu->addAction(tr("&Next Preset"), this, &ProjectMWidget::nextPreset, tr("N"));
+    m_menu->addAction(tr("&Previous Preset"),  this, &ProjectMWidget::previousPreset, tr("P"));
+    m_menu->addAction(tr("&Random Preset"), this, &ProjectMWidget::randomPreset, tr("R"));
+    m_menu->addAction(tr("&Lock Preset"), this, &ProjectMWidget::lockPreset, tr("L"))->setCheckable(true);
     m_menu->addSeparator();
-    m_menu->addAction(tr("&Fullscreen"), this, SIGNAL(fullscreenToggled(bool)), tr("F"))->setCheckable(true);
+    m_menu->addAction(tr("&Fullscreen"), this, &ProjectMWidget::fullscreenToggled, tr("F"))->setCheckable(true);
     m_menu->addSeparator();
     addActions(m_menu->actions());
 }
@@ -159,10 +159,10 @@ void ProjectMWidget::findPresets(const QString &path)
 {
     QDir presetDir(path);
     presetDir.setFilter(QDir::Files);
-    const QFileInfoList files = presetDir.entryInfoList({ "*.prjm", "*.milk" }, QDir::Files);
+    const QFileInfoList files = presetDir.entryInfoList({ u"*.prjm"_s, u"*.milk"_s }, QDir::Files);
 
     const RatingList list = { 3, 3 };
-    for(const QFileInfo &info : qAsConst(files))
+    for(const QFileInfo &info : std::as_const(files))
     {
         m_projectM->addPresetURL(info.absoluteFilePath().toStdString(), info.fileName().toStdString(), list);
         m_listWidget->addItem(info.fileName());
@@ -170,7 +170,7 @@ void ProjectMWidget::findPresets(const QString &path)
     }
 
     const QFileInfoList dirs = presetDir.entryInfoList(QDir::Dirs | QDir::NoDotAndDotDot);
-    for(const QFileInfo &info : qAsConst(dirs))
+    for(const QFileInfo &info : std::as_const(dirs))
         findPresets(info.canonicalFilePath());
 }
 
