@@ -1,10 +1,73 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="bg">
+<context>
+    <name>ProjectM4Widget</name>
+    <message>
+        <location filename="../projectm4widget.cpp" line="163"/>
+        <source>&amp;Show Menu</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="163"/>
+        <source>M</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="165"/>
+        <source>&amp;Next Preset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="165"/>
+        <source>N</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="166"/>
+        <source>&amp;Previous Preset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="166"/>
+        <source>P</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="167"/>
+        <source>&amp;Shuffle</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="167"/>
+        <source>R</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="168"/>
+        <source>&amp;Lock Preset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="168"/>
+        <source>L</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="170"/>
+        <source>&amp;Fullscreen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="170"/>
+        <source>F</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ProjectMPlugin</name>
     <message>
-        <location filename="../projectmplugin.cpp" line="41"/>
+        <location filename="../projectmplugin.cpp" line="42"/>
         <source>ProjectM</source>
         <translation type="unfinished"></translation>
     </message>
@@ -12,92 +75,92 @@
 <context>
     <name>ProjectMWidget</name>
     <message>
-        <location filename="../projectmwidget.cpp" line="136"/>
+        <location filename="../projectmwidget.cpp" line="143"/>
         <source>&amp;Help</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="136"/>
+        <location filename="../projectmwidget.cpp" line="143"/>
         <source>F1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="137"/>
+        <location filename="../projectmwidget.cpp" line="144"/>
         <source>&amp;Show Song Title</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="137"/>
+        <location filename="../projectmwidget.cpp" line="144"/>
         <source>F2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="138"/>
+        <location filename="../projectmwidget.cpp" line="145"/>
         <source>&amp;Show Preset Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="138"/>
+        <location filename="../projectmwidget.cpp" line="145"/>
         <source>F3</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="139"/>
+        <location filename="../projectmwidget.cpp" line="146"/>
         <source>&amp;Show Menu</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="139"/>
+        <location filename="../projectmwidget.cpp" line="146"/>
         <source>M</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="141"/>
+        <location filename="../projectmwidget.cpp" line="148"/>
         <source>&amp;Next Preset</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="141"/>
+        <location filename="../projectmwidget.cpp" line="148"/>
         <source>N</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="142"/>
+        <location filename="../projectmwidget.cpp" line="149"/>
         <source>&amp;Previous Preset</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="142"/>
+        <location filename="../projectmwidget.cpp" line="149"/>
         <source>P</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="143"/>
+        <location filename="../projectmwidget.cpp" line="150"/>
         <source>&amp;Random Preset</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="143"/>
+        <location filename="../projectmwidget.cpp" line="150"/>
         <source>R</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="144"/>
+        <location filename="../projectmwidget.cpp" line="151"/>
         <source>&amp;Lock Preset</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="144"/>
+        <location filename="../projectmwidget.cpp" line="151"/>
         <source>L</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="146"/>
+        <location filename="../projectmwidget.cpp" line="153"/>
         <source>&amp;Fullscreen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="146"/>
+        <location filename="../projectmwidget.cpp" line="153"/>
         <source>F</source>
         <translation type="unfinished"></translation>
     </message>
@@ -105,32 +168,32 @@
 <context>
     <name>VisualProjectMFactory</name>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="29"/>
+        <location filename="../visualprojectmfactory.cpp" line="30"/>
         <source>ProjectM</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="49"/>
+        <location filename="../visualprojectmfactory.cpp" line="50"/>
         <source>About ProjectM Visual Plugin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="50"/>
+        <location filename="../visualprojectmfactory.cpp" line="51"/>
         <source>Qmmp ProjectM Visual Plugin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="51"/>
+        <location filename="../visualprojectmfactory.cpp" line="52"/>
         <source>This plugin adds projectM visualization</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="52"/>
+        <location filename="../visualprojectmfactory.cpp" line="53"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="53"/>
+        <location filename="../visualprojectmfactory.cpp" line="54"/>
         <source>Based on libprojectM-qt library</source>
         <translation type="unfinished"></translation>
     </message>
