@@ -67,7 +67,7 @@
 <context>
     <name>ProjectMPlugin</name>
     <message>
-        <location filename="../projectmplugin.cpp" line="41"/>
+        <location filename="../projectmplugin.cpp" line="42"/>
         <source>ProjectM</source>
         <translation>ProjectM</translation>
     </message>
@@ -97,7 +97,7 @@
     <message>
         <location filename="../projectmwidget.cpp" line="145"/>
         <source>&amp;Show Preset Name</source>
-        <translation>&amp;Önayar Adını Göster</translation>
+        <translation>&amp;Preset Adını Göster</translation>
     </message>
     <message>
         <location filename="../projectmwidget.cpp" line="145"/>
@@ -117,7 +117,7 @@
     <message>
         <location filename="../projectmwidget.cpp" line="148"/>
         <source>&amp;Next Preset</source>
-        <translation>&amp;Sonraki Önayar</translation>
+        <translation>&amp;Sonraki Preset</translation>
     </message>
     <message>
         <location filename="../projectmwidget.cpp" line="148"/>
@@ -127,7 +127,7 @@
     <message>
         <location filename="../projectmwidget.cpp" line="149"/>
         <source>&amp;Previous Preset</source>
-        <translation>&amp;Önceki Önayar</translation>
+        <translation>&amp;Önceki Preset</translation>
     </message>
     <message>
         <location filename="../projectmwidget.cpp" line="149"/>
@@ -137,7 +137,7 @@
     <message>
         <location filename="../projectmwidget.cpp" line="150"/>
         <source>&amp;Random Preset</source>
-        <translation>&amp;Rastgele Önayar</translation>
+        <translation>&amp;Rastgele Preset</translation>
     </message>
     <message>
         <location filename="../projectmwidget.cpp" line="150"/>
@@ -147,7 +147,7 @@
     <message>
         <location filename="../projectmwidget.cpp" line="151"/>
         <source>&amp;Lock Preset</source>
-        <translation>&amp;Önayarı Kilitle</translation>
+        <translation>Preset &amp;Kilitle</translation>
     </message>
     <message>
         <location filename="../projectmwidget.cpp" line="151"/>
@@ -168,32 +168,32 @@
 <context>
     <name>VisualProjectMFactory</name>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="29"/>
+        <location filename="../visualprojectmfactory.cpp" line="30"/>
         <source>ProjectM</source>
         <translation>ProjectM</translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="49"/>
+        <location filename="../visualprojectmfactory.cpp" line="50"/>
         <source>About ProjectM Visual Plugin</source>
         <translation>ProjectM Görsel Eklenti Hakkında</translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="50"/>
+        <location filename="../visualprojectmfactory.cpp" line="51"/>
         <source>Qmmp ProjectM Visual Plugin</source>
         <translation>Qmmp ProjectM Görsel Eklentisi</translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="51"/>
+        <location filename="../visualprojectmfactory.cpp" line="52"/>
         <source>This plugin adds projectM visualization</source>
         <translation>Bu eklenti projectM görselliğini ekler</translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="52"/>
+        <location filename="../visualprojectmfactory.cpp" line="53"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Yazan: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="53"/>
+        <location filename="../visualprojectmfactory.cpp" line="54"/>
         <source>Based on libprojectM-qt library</source>
         <translation>librojectM qt kitaplığı temellidir</translation>
     </message>
