@@ -1,10 +1,73 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="zh_TW">
+<context>
+    <name>ProjectM4Widget</name>
+    <message>
+        <location filename="../projectm4widget.cpp" line="163"/>
+        <source>&amp;Show Menu</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="163"/>
+        <source>M</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="165"/>
+        <source>&amp;Next Preset</source>
+        <translation>下一邊框形式(&amp;N)</translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="165"/>
+        <source>N</source>
+        <translation>N</translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="166"/>
+        <source>&amp;Previous Preset</source>
+        <translation>上一邊框形式(&amp;P)</translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="166"/>
+        <source>P</source>
+        <translation>P</translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="167"/>
+        <source>&amp;Shuffle</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="167"/>
+        <source>R</source>
+        <translation>R</translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="168"/>
+        <source>&amp;Lock Preset</source>
+        <translation>鎖定邊框形式(&amp;L)</translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="168"/>
+        <source>L</source>
+        <translation>L</translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="170"/>
+        <source>&amp;Fullscreen</source>
+        <translation>全屏(&amp;F)</translation>
+    </message>
+    <message>
+        <location filename="../projectm4widget.cpp" line="170"/>
+        <source>F</source>
+        <translation>F</translation>
+    </message>
+</context>
 <context>
     <name>ProjectMPlugin</name>
     <message>
-        <location filename="../projectmplugin.cpp" line="41"/>
+        <location filename="../projectmplugin.cpp" line="42"/>
         <source>ProjectM</source>
         <translation>ProjectM</translation>
     </message>
@@ -12,92 +75,92 @@
 <context>
     <name>ProjectMWidget</name>
     <message>
-        <location filename="../projectmwidget.cpp" line="136"/>
+        <location filename="../projectmwidget.cpp" line="143"/>
         <source>&amp;Help</source>
         <translation>幫助(&amp;H)</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="136"/>
+        <location filename="../projectmwidget.cpp" line="143"/>
         <source>F1</source>
         <translation>F1</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="137"/>
+        <location filename="../projectmwidget.cpp" line="144"/>
         <source>&amp;Show Song Title</source>
         <translation>顯示曲目標題(&amp;S)</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="137"/>
+        <location filename="../projectmwidget.cpp" line="144"/>
         <source>F2</source>
         <translation>F2</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="138"/>
+        <location filename="../projectmwidget.cpp" line="145"/>
         <source>&amp;Show Preset Name</source>
         <translation>顯示邊框形式名稱(&amp;S)</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="138"/>
+        <location filename="../projectmwidget.cpp" line="145"/>
         <source>F3</source>
         <translation>F3</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="139"/>
+        <location filename="../projectmwidget.cpp" line="146"/>
         <source>&amp;Show Menu</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="139"/>
+        <location filename="../projectmwidget.cpp" line="146"/>
         <source>M</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="141"/>
+        <location filename="../projectmwidget.cpp" line="148"/>
         <source>&amp;Next Preset</source>
         <translation>下一邊框形式(&amp;N)</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="141"/>
+        <location filename="../projectmwidget.cpp" line="148"/>
         <source>N</source>
         <translation>N</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="142"/>
+        <location filename="../projectmwidget.cpp" line="149"/>
         <source>&amp;Previous Preset</source>
         <translation>上一邊框形式(&amp;P)</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="142"/>
+        <location filename="../projectmwidget.cpp" line="149"/>
         <source>P</source>
         <translation>P</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="143"/>
+        <location filename="../projectmwidget.cpp" line="150"/>
         <source>&amp;Random Preset</source>
         <translation>隨意邊框形式(&amp;R)</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="143"/>
+        <location filename="../projectmwidget.cpp" line="150"/>
         <source>R</source>
         <translation>R</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="144"/>
+        <location filename="../projectmwidget.cpp" line="151"/>
         <source>&amp;Lock Preset</source>
         <translation>鎖定邊框形式(&amp;L)</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="144"/>
+        <location filename="../projectmwidget.cpp" line="151"/>
         <source>L</source>
         <translation>L</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="146"/>
+        <location filename="../projectmwidget.cpp" line="153"/>
         <source>&amp;Fullscreen</source>
         <translation>全屏(&amp;F)</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="146"/>
+        <location filename="../projectmwidget.cpp" line="153"/>
         <source>F</source>
         <translation>F</translation>
     </message>
@@ -105,32 +168,32 @@
 <context>
     <name>VisualProjectMFactory</name>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="29"/>
+        <location filename="../visualprojectmfactory.cpp" line="30"/>
         <source>ProjectM</source>
         <translation>ProjectM</translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="49"/>
+        <location filename="../visualprojectmfactory.cpp" line="50"/>
         <source>About ProjectM Visual Plugin</source>
         <translation>關於 ProjectM 可視化插件</translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="50"/>
+        <location filename="../visualprojectmfactory.cpp" line="51"/>
         <source>Qmmp ProjectM Visual Plugin</source>
         <translation>Qmmp ProjectM 可視化插件</translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="51"/>
+        <location filename="../visualprojectmfactory.cpp" line="52"/>
         <source>This plugin adds projectM visualization</source>
         <translation>此插件添加 ProjectM 可視化</translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="52"/>
+        <location filename="../visualprojectmfactory.cpp" line="53"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>撰寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="53"/>
+        <location filename="../visualprojectmfactory.cpp" line="54"/>
         <source>Based on libprojectM-qt library</source>
         <translation>基於 libprojectM-qt 程式庫</translation>
     </message>
