@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -33,10 +33,6 @@ AbstractEngine::AbstractEngine(QObject *parent) : QThread(parent)
 {
 }
 
-AbstractEngine::~AbstractEngine()
-{
-}
-
 QMutex *AbstractEngine::mutex()
 {
     return &m_mutex;
@@ -52,8 +48,8 @@ void AbstractEngine::loadPlugins()
         return;
 
     m_cache = new QList<QmmpPluginCache*>;
-    QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
-    for(const QString &filePath : Qmmp::findPlugins("Engines"))
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    for(const QString &filePath : Qmmp::findPlugins(u"Engines"_s))
     {
         QmmpPluginCache *item = new QmmpPluginCache(filePath, &settings);
         if(item->hasError())
@@ -63,7 +59,7 @@ void AbstractEngine::loadPlugins()
         }
         m_cache->append(item);
     }
-    m_disabledNames = settings.value("Engine/disabled_plugins").toStringList();
+    m_disabledNames = settings.value(u"Engine/disabled_plugins"_s).toStringList();
     QmmpPluginCache::cleanup(&settings);
 }
 
@@ -80,7 +76,7 @@ AbstractEngine *AbstractEngine::create(InputSource *s, QObject *parent)
 
 
     loadPlugins();
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(m_disabledNames.contains(item->shortName()))
             continue;
@@ -104,7 +100,7 @@ QList<EngineFactory *> AbstractEngine::factories()
 {
     loadPlugins();
     QList<EngineFactory *> list;
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(item->engineFactory())
             list.append(item->engineFactory());
@@ -116,7 +112,7 @@ QList<EngineFactory *> AbstractEngine::enabledFactories()
 {
     loadPlugins();
     QList<EngineFactory *> list;
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(m_disabledNames.contains(item->shortName()))
             continue;
@@ -130,7 +126,7 @@ QStringList AbstractEngine::nameFilters()
 {
     loadPlugins();
     QStringList filters;
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(m_disabledNames.contains(item->shortName()))
             continue;
@@ -144,7 +140,7 @@ QStringList AbstractEngine::contentTypes()
 {
     loadPlugins();
     QStringList types;
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(m_disabledNames.contains(item->shortName()))
             continue;
@@ -157,7 +153,7 @@ QStringList AbstractEngine::contentTypes()
 EngineFactory *AbstractEngine::findByFilePath(const QString& source)
 {
     loadPlugins();
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(m_disabledNames.contains(item->shortName()))
             continue;
@@ -183,8 +179,8 @@ void AbstractEngine::setEnabled(EngineFactory *factory, bool enable)
         m_disabledNames.append(factory->properties().shortName);
 
     m_disabledNames.removeDuplicates();
-    QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
-    settings.setValue("Engine/disabled_plugins", m_disabledNames);
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    settings.setValue(u"Engine/disabled_plugins"_s, m_disabledNames);
 }
 
 bool AbstractEngine::isEnabled(const EngineFactory *factory)
@@ -205,7 +201,7 @@ bool AbstractEngine::isEnabled(const AbstractEngine *engine)
 QString AbstractEngine::file(const EngineFactory *factory)
 {
     loadPlugins();
-    for(const QmmpPluginCache *item : qAsConst(*m_cache))
+    for(const QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(item->shortName() == factory->properties().shortName)
             return item->file();
@@ -218,7 +214,7 @@ QStringList AbstractEngine::protocols()
     loadPlugins();
     QStringList protocolList;
 
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(m_disabledNames.contains(item->shortName()))
             continue;
