@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,7 +18,6 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 #include <QTextStream>
-#include <QTextCodec>
 #include "cueparser.h"
 
 CueParser::CueParser()
@@ -45,7 +44,7 @@ void CueParser::loadData(const QByteArray &data, QTextCodec *codec)
 
     QString artist, album, genre, date, comment, file;
     double album_peak = 0.0, album_gain = 0.0;
-    QTextStream textStream(data);
+    QTextStream textStream(data, QIODevice::ReadOnly);
 
     textStream.setCodec(codec ? codec : QTextCodec::codecForName("UTF-8"));
 
@@ -56,26 +55,26 @@ void CueParser::loadData(const QByteArray &data, QTextCodec *codec)
         if(words.size() < 2)
             continue;
 
-        if(words[0] == "FILE")
+        if(words[0] == "FILE"_L1)
         {
             file = words[1];
             m_files << file;
         }
-        else if(words[0] == "PERFORMER")
+        else if(words[0] == "PERFORMER"_L1)
         {
             if(m_tracks.isEmpty())
                 artist = words[1];
             else
                 m_tracks.last()->info.setValue(Qmmp::ARTIST, words[1]);
         }
-        else if(words[0] == "TITLE")
+        else if(words[0] == "TITLE"_L1)
         {
             if(m_tracks.isEmpty())
                 album = words[1];
             else
                 m_tracks.last()->info.setValue(Qmmp::TITLE, words[1]);
         }
-        else if(words[0] == "TRACK")
+        else if(words[0] == "TRACK"_L1)
         {
             TrackInfo info;
             info.setValue(Qmmp::TRACK, words[1].toInt());
@@ -92,50 +91,50 @@ void CueParser::loadData(const QByteArray &data, QTextCodec *codec)
             m_tracks.last()->info = info;
             m_tracks.last()->offset = 0;
         }
-        else if(words[0] == "INDEX" && words[1] == "01")
+        else if(words[0] == "INDEX"_L1 && words[1] == "01"_L1)
         {
             if(m_tracks.isEmpty())
                 continue;
             m_tracks.last()->offset = getLength(words[2]);
             m_tracks.last()->file = file;
         }
-        else if(words[0] == "REM")
+        else if(words[0] == "REM"_L1)
         {
             if(words.size() < 3)
                 continue;
-            if(words[1] == "GENRE")
+            if(words[1] == "GENRE"_L1)
             {
                 if(m_tracks.isEmpty())
                     genre = words[2];
                 else
                     m_tracks.last()->info.setValue(Qmmp::GENRE, words[2]);
             }
-            else if(words[1] == "DATE")
+            else if(words[1] == "DATE"_L1)
             {
                  if(m_tracks.isEmpty())
                      date = words[2];
                  else
                      m_tracks.last()->info.setValue(Qmmp::YEAR, words[2]);
             }
-            else if(words[1] == "COMMENT")
+            else if(words[1] == "COMMENT"_L1)
             {
                  if(m_tracks.isEmpty())
                      comment = words[2];
                  else
                      m_tracks.last()->info.setValue(Qmmp::COMMENT, words[2]);
             }
-            else if(words[1] == "REPLAYGAIN_ALBUM_GAIN")
+            else if(words[1] == "REPLAYGAIN_ALBUM_GAIN"_L1)
                 album_gain = words[2].toDouble();
-            else if(words[1] == "REPLAYGAIN_ALBUM_PEAK")
+            else if(words[1] == "REPLAYGAIN_ALBUM_PEAK"_L1)
                 album_peak = words[2].toDouble();
-            else if(words[1] == "REPLAYGAIN_TRACK_GAIN" && !m_tracks.isEmpty())
+            else if(words[1] == "REPLAYGAIN_TRACK_GAIN"_L1 && !m_tracks.isEmpty())
                 m_tracks.last()->info.setValue(Qmmp::REPLAYGAIN_TRACK_GAIN, words[2].toDouble());
-            else if(words[1] == "REPLAYGAIN_TRACK_PEAK" && !m_tracks.isEmpty())
+            else if(words[1] == "REPLAYGAIN_TRACK_PEAK"_L1 && !m_tracks.isEmpty())
                 m_tracks.last()->info.setValue(Qmmp::REPLAYGAIN_TRACK_PEAK, words[2].toDouble());
         }
     }
     if(m_tracks.isEmpty())
-        qWarning("CueParser: invalid cue data");
+        qCWarning(core, "invalid cue data");
 }
 
 QList<TrackInfo *> CueParser::createPlayList(int track) const
@@ -149,7 +148,7 @@ QList<TrackInfo *> CueParser::createPlayList(int track) const
     }
     else if(track > m_tracks.count())
     {
-        qWarning("CueParser: invalid track number: %d", track);
+        qCWarning(core, "invalid track number: %d", track);
         return out;
     }
     else
@@ -169,7 +168,7 @@ qint64 CueParser::offset(int track) const
 {
     if(track < 1 || track > m_tracks.count())
     {
-        qWarning("CueParser: invalid track number: %d", track);
+        qCWarning(core, "invalid track number: %d", track);
         return 0;
     }
     return m_tracks.at(track - 1)->offset;
@@ -179,7 +178,7 @@ qint64 CueParser::duration(int track) const
 {
     if(track < 1 || track > m_tracks.count())
     {
-        qWarning("CueParser: invalid track number: %d", track);
+        qCWarning(core, "invalid track number: %d", track);
         return 0;
     }
     return m_tracks.at(track - 1)->info.duration();
@@ -189,8 +188,8 @@ QString CueParser::file(int track) const
 {
     if(track < 1 || track > m_tracks.count())
     {
-        qWarning("CueParser: invalid track number: %d", track);
-        return nullptr;
+        qCWarning(core, "invalid track number: %d", track);
+        return QString();
     }
     return m_tracks.at(track - 1)->file;
 }
@@ -199,7 +198,7 @@ QString CueParser::url(int track) const
 {
     if(track < 1 || track > m_tracks.count())
     {
-        qWarning("CueParser: invalid track number: %d", track);
+        qCWarning(core, "invalid track number: %d", track);
         return QString();
     }
     return m_tracks.at(track - 1)->info.path();
@@ -219,7 +218,7 @@ const TrackInfo *CueParser::info(int track) const
 {
     if(track < 1 || track > m_tracks.count())
     {
-        qWarning("CueParser: invalid track number: %d", track);
+        qCWarning(core, "invalid track number: %d", track);
         return nullptr;
     }
     return &m_tracks.at(track - 1)->info;
@@ -277,7 +276,7 @@ void CueParser::setProperties(const QMap<Qmmp::TrackProperty, QString> &properti
 void CueParser::setMetaData(int track, Qmmp::MetaData key, const QVariant &value)
 {
     if(track < 1 || track > m_tracks.count())
-        qWarning("CueParser: invalid track number: %d", track);
+        qCWarning(core, "invalid track number: %d", track);
 
     m_tracks.at(track - 1)->info.setValue(key, value);
 }
@@ -285,7 +284,7 @@ void CueParser::setMetaData(int track, Qmmp::MetaData key, const QVariant &value
 void CueParser::setUrl(const QString &scheme, const QString &path)
 {
     for(int i = 0; i < m_tracks.count(); ++i)
-        m_tracks.at(i)->info.setPath(QString("%1://%2#%3").arg(scheme).arg(path).arg(m_tracks.at(i)->info.value(Qmmp::TRACK)));
+        m_tracks.at(i)->info.setPath(QStringLiteral("%1://%2#%3").arg(scheme, path, m_tracks.at(i)->info.value(Qmmp::TRACK)));
 }
 
 void CueParser::clear()
@@ -297,29 +296,27 @@ void CueParser::clear()
 
 QStringList CueParser::splitLine(const QString &line)
 {
-    //qDebug("raw string = %s",qPrintable(line));
     QStringList list;
     QString buf = line.trimmed();
     if(buf.isEmpty())
         return list;
     while (!buf.isEmpty())
     {
-        //qDebug(qPrintable(buf));
-        if(buf.startsWith('"'))
+        if(buf.startsWith(QLatin1Char('"')))
         {
-            int end = buf.indexOf('"',1);
+            int end = buf.indexOf(QLatin1Char('"'), 1);
             if(end == -1) //ignore invalid line
             {
                 list.clear();
-                qWarning("CueParser: unable to parse line: %s",qPrintable(line));
+                qCWarning(core, "unable to parse line: %s",qPrintable(line));
                 return list;
             }
             list << buf.mid (1, end - 1);
-            buf.remove (0, end+1);
+            buf.remove (0, end + 1);
         }
         else
         {
-            int end = buf.indexOf(' ', 0);
+            int end = buf.indexOf(QChar::Space, 0);
             if(end < 0)
                 end = buf.size();
             list << buf.mid (0, end);
@@ -332,10 +329,10 @@ QStringList CueParser::splitLine(const QString &line)
 
 qint64 CueParser::getLength(const QString &str)
 {
-    QStringList list = str.split(":");
+    QStringList list = str.split(QLatin1Char(':'));
     if(list.size() == 2)
-        return (qint64)list.at(0).toInt()*60000 + list.at(1).toInt()*1000;
-    else if(list.size() == 3)
-        return (qint64)list.at(0).toInt()*60000 + list.at(1).toInt()*1000 + list.at(2).toInt()*1000/75;
+        return (qint64)list.at(0).toInt() * 60000 + list.at(1).toInt() * 1000;
+    if(list.size() == 3)
+        return (qint64)list.at(0).toInt() * 60000 + list.at(1).toInt() * 1000 + list.at(2).toInt() * 1000 / 75;
     return 0;
 }
