@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -53,7 +53,7 @@ public:
      * \param data Content of CUE file.
      * \param codecName Codec name ("UTF-8" by default).
      */
-    void loadData(const QByteArray &data, const QByteArray &codecName = QByteArray());
+    void loadData(const QByteArray &data, const QByteArray &codecName = "UTF-8");
     /*!
      * Parses CUE file content.
      * \param data Content of CUE file.
