@@ -20,9 +20,7 @@ extern "C"
 #include "decoder.h"
 
 Decoder::Decoder(QIODevice *input) : m_input(input)
-{
-    m_hasMetaData = false;
-}
+{}
 
 Decoder::~Decoder()
 {}
@@ -39,7 +37,7 @@ void Decoder::configure(quint32 srate, const ChannelMap &map, Qmmp::AudioFormat
 
 void Decoder::configure(quint32 srate, int channels, Qmmp::AudioFormat f)
 {
-    qDebug("Decoder: using internal channel order");
+    qCDebug(core) << "using internal channel order";
     configure(AudioParameters(srate, ChannelMap(channels), f));
 }
 
@@ -59,12 +57,12 @@ const QString Decoder::nextURL() const
     return QString();
 }
 
-AudioParameters Decoder::audioParameters() const
+const AudioParameters &Decoder::audioParameters() const
 {
     return m_parameters;
 }
 
-QMap<Qmmp::ReplayGainKey, double> Decoder::replayGainInfo() const
+const QMap<Qmmp::ReplayGainKey, double> &Decoder::replayGainInfo() const
 {
     return m_rg;
 }
@@ -94,7 +92,7 @@ QMap<Qmmp::MetaData, QString> Decoder::takeMetaData()
 void Decoder::setProperty(Qmmp::TrackProperty key, const QVariant &value)
 {
     QString strValue = value.toString();
-    if(strValue.isEmpty() || strValue == "0")
+    if(strValue.isEmpty() || strValue == "0"_L1)
         m_properties.remove(key);
     else
         m_properties[key] = strValue;
@@ -102,13 +100,11 @@ void Decoder::setProperty(Qmmp::TrackProperty key, const QVariant &value)
 
 void Decoder::setProperties(const QMap<Qmmp::TrackProperty, QString> &properties)
 {
-    for(const Qmmp::TrackProperty &key : properties.keys())
-    {
-        setProperty(key, properties.value(key));
-    }
+    for(auto it = properties.cbegin(); it != properties.cend(); ++it)
+        setProperty(it.key(), it.value());
 }
 
-const QMap<Qmmp::TrackProperty, QString> &Decoder::properties() const
+QMap<Qmmp::TrackProperty, QString> Decoder::properties() const
 {
     return m_properties;
 }
@@ -118,7 +114,7 @@ QStringList Decoder::m_disabledNames;
 QList<QmmpPluginCache*> *Decoder::m_cache = nullptr;
 
 //sort cache items by priority
-static bool _pluginCacheLessComparator(QmmpPluginCache* f1, QmmpPluginCache* f2)
+static bool _pluginCacheLessComparator(const QmmpPluginCache* f1, const QmmpPluginCache* f2)
 {
     return f1->priority() < f2->priority();
 }
@@ -129,8 +125,8 @@ void Decoder::loadPlugins()
         return;
 
     m_cache = new QList<QmmpPluginCache*>;
-    QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
-    for(const QString &filePath : Qmmp::findPlugins("Input"))
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    for(const QString &filePath : Qmmp::findPlugins(u"Input"_s))
     {
         QmmpPluginCache *item = new QmmpPluginCache(filePath, &settings);
         if(item->hasError())
@@ -140,7 +136,7 @@ void Decoder::loadPlugins()
         }
         m_cache->append(item);
     }
-    m_disabledNames = settings.value("Decoder/disabled_plugins").toStringList();
+    m_disabledNames = settings.value(u"Decoder/disabled_plugins"_s).toStringList();
     std::stable_sort(m_cache->begin(), m_cache->end(), _pluginCacheLessComparator);
     QmmpPluginCache::cleanup(&settings);
 }
@@ -148,7 +144,7 @@ void Decoder::loadPlugins()
 QString Decoder::file(const DecoderFactory *factory)
 {
     loadPlugins();
-    for(const QmmpPluginCache *item : qAsConst(*m_cache))
+    for(const QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(item->shortName() == factory->properties().shortName)
             return item->file();
@@ -159,75 +155,60 @@ QString Decoder::file(const DecoderFactory *factory)
 QStringList Decoder::protocols()
 {
     loadPlugins();
-    QStringList protocolsList;
+    QStringList protocolList;
 
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(m_disabledNames.contains(item->shortName()))
             continue;
-        if(item->decoderFactory())
-            protocolsList << item->decoderFactory()->properties().protocols;
+
+        protocolList << item->protocols();
     }
-    protocolsList.removeDuplicates();
-    return protocolsList;
+    protocolList.removeDuplicates();
+    return protocolList;
 }
 
 DecoderFactory *Decoder::findByFilePath(const QString &path, bool useContent)
 {
     loadPlugins();
-    DecoderFactory *fact = nullptr;
-    //detect by content if enabled
-    if(useContent)
-    {
-        QFile file(path);
-        if(!file.open(QIODevice::ReadOnly))
-        {
-            qWarning("Decoder: file open error: %s", qPrintable(file.errorString()));
-            return nullptr;
-        }
 
-        for(QmmpPluginCache *item : qAsConst(*m_cache))
-        {
-            if(m_disabledNames.contains(item->shortName()))
-                continue;
-
-            if(!(fact = item->decoderFactory()))
-                continue;
-
-            if(fact->properties().noInput && !fact->properties().protocols.contains("file"))
-                continue;
-
-            if (fact->canDecode(&file))
-                return fact;
-        }
-        fact = nullptr;
-    }
-
-    const QList<DecoderFactory*> filtered = findByFileExtension(path);
+    //get list of available/supported factories
+    QList<DecoderFactory*> filtered = useContent ? enabledFactories() : findByFileExtension(path);
 
     if(filtered.isEmpty())
         return nullptr;
 
-    if(filtered.size() == 1)
-        return filtered.at(0);
-
-    //more than one factories with same filters
-    //try to determine by content
+    //try to find by content
     QFile file(path);
     if(!file.open(QIODevice::ReadOnly))
     {
-        qWarning("Decoder: file open error: %s", qPrintable(file.errorString()));
+        qCWarning(core, "file open error: %s", qPrintable(file.errorString()));
         return nullptr;
     }
 
-    for(DecoderFactory *fact : qAsConst(filtered))
+    for(DecoderFactory *fact : std::as_const(filtered))
     {
         if(fact->canDecode(&file))
             return fact;
     }
 
-    if(!filtered.isEmpty() && !useContent) //fallback
-        return filtered.first();
+    //fallback: try to find by extension
+    if(useContent)
+        filtered = findByFileExtension(path);
+
+    for(DecoderFactory *fact : std::as_const(filtered))
+    {
+        if(fact->properties().noInput || fact->properties().protocols.contains(u"file"_s))
+            return fact;
+    }
+
+    //fallback: try to find by content
+    if(!useContent)
+        return findByContent(&file);
+
+    //fallback: use first available factory
+    if(!filtered.isEmpty() && !useContent)
+        return filtered.constFirst();
 
     return nullptr;
 }
@@ -237,7 +218,7 @@ DecoderFactory *Decoder::findByMime(const QString& type)
     if(type.isEmpty())
         return nullptr;
     loadPlugins();
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(m_disabledNames.contains(item->shortName()))
             continue;
@@ -251,7 +232,7 @@ DecoderFactory *Decoder::findByMime(const QString& type)
 DecoderFactory *Decoder::findByContent(QIODevice *input)
 {
     loadPlugins();
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(m_disabledNames.contains(item->shortName()))
             continue;
@@ -265,7 +246,7 @@ DecoderFactory *Decoder::findByContent(QIODevice *input)
 DecoderFactory *Decoder::findByProtocol(const QString &p)
 {
     loadPlugins();
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(m_disabledNames.contains(item->shortName()))
             continue;
@@ -280,7 +261,7 @@ QList<DecoderFactory *> Decoder::findByFileExtension(const QString &path)
 {
     QList<DecoderFactory*> filtered;
     DecoderFactory *fact = nullptr;
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(m_disabledNames.contains(item->shortName()))
             continue;
@@ -288,15 +269,8 @@ QList<DecoderFactory *> Decoder::findByFileExtension(const QString &path)
         if(!(fact = item->decoderFactory()))
             continue;
 
-        for(const QString &filter : fact->properties().filters)
-        {
-            QRegExp regexp(filter, Qt::CaseInsensitive, QRegExp::Wildcard);
-            if (regexp.exactMatch(path))
-            {
-                filtered.append(fact);
-                break;
-            }
-        }
+        if(QDir::match(fact->properties().filters, path.section(QLatin1Char('/'), -1)))
+            filtered.append(fact);
     }
 
     return filtered;
@@ -317,8 +291,8 @@ void Decoder::setEnabled(DecoderFactory *factory, bool enable)
         m_disabledNames.append(factory->properties().shortName);
 
     m_disabledNames.removeDuplicates();
-    QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
-    settings.setValue("Decoder/disabled_plugins", m_disabledNames);
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    settings.setValue(u"Decoder/disabled_plugins"_s, m_disabledNames);
 }
 
 bool Decoder::isEnabled(const DecoderFactory *factory)
@@ -331,7 +305,7 @@ QList<DecoderFactory *> Decoder::factories()
 {
     loadPlugins();
     QList<DecoderFactory *> list;
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(item->decoderFactory())
             list.append(item->decoderFactory());
@@ -343,7 +317,7 @@ QList<DecoderFactory *> Decoder::enabledFactories()
 {
     loadPlugins();
     QList<DecoderFactory *> list;
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(m_disabledNames.contains(item->shortName()))
             continue;
@@ -352,3 +326,31 @@ QList<DecoderFactory *> Decoder::enabledFactories()
     }
     return list;
 }
+
+QStringList Decoder::nameFilters()
+{
+    loadPlugins();
+    QStringList filters;
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
+    {
+        if(m_disabledNames.contains(item->shortName()))
+            continue;
+
+        filters << item->filters();
+    }
+    return filters;
+}
+
+QStringList Decoder::contentTypes()
+{
+    loadPlugins();
+    QStringList types;
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
+    {
+        if(m_disabledNames.contains(item->shortName()))
+            continue;
+
+        types << item->contentTypes();
+    }
+    return types;
+}
