@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -50,7 +50,7 @@ int Effect::channels() const
     return m_channels;
 }
 
-const ChannelMap Effect::channelMap() const
+const ChannelMap &Effect::channelMap() const
 {
     return m_chan_map;
 }
@@ -80,8 +80,8 @@ void Effect::loadPlugins()
         return;
 
     m_cache = new QList<QmmpPluginCache *>;
-    QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
-    for(const QString &filePath : Qmmp::findPlugins("Effect"))
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    for(const QString &filePath : Qmmp::findPlugins(u"Effect"_s))
     {
         QmmpPluginCache *item = new QmmpPluginCache(filePath, &settings);
         if(item->hasError())
@@ -93,7 +93,7 @@ void Effect::loadPlugins()
     }
 
     std::stable_sort(m_cache->begin(), m_cache->end(), _effectCacheCompareFunc);
-    m_enabledNames = settings.value("Effect/enabled_plugins").toStringList();
+    m_enabledNames = settings.value(u"Effect/enabled_plugins"_s).toStringList();
 }
 
 Effect* Effect::create(EffectFactory *factory)
@@ -108,7 +108,7 @@ QList<EffectFactory *> Effect::factories()
 {
     loadPlugins();
     QList<EffectFactory *> list;
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(item->effectFactory())
             list.append(item->effectFactory());
@@ -120,7 +120,7 @@ QList<EffectFactory *> Effect::enabledFactories()
 {
     loadPlugins();
     QList<EffectFactory *> list;
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(m_enabledNames.contains(item->shortName()) && item->effectFactory())
             list.append(item->effectFactory());
@@ -131,7 +131,7 @@ QList<EffectFactory *> Effect::enabledFactories()
 QString Effect::file(const EffectFactory *factory)
 {
     loadPlugins();
-    for(const QmmpPluginCache *item : qAsConst(*m_cache))
+    for(const QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(item->shortName() == factory->properties().shortName)
             return item->file();
@@ -163,8 +163,8 @@ void Effect::setEnabled(EffectFactory *factory, bool enable)
 
     m_enabledNames.removeDuplicates();
 
-    QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
-    settings.setValue("Effect/enabled_plugins", m_enabledNames);
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    settings.setValue(u"Effect/enabled_plugins"_s, m_enabledNames);
     QmmpPluginCache::cleanup(&settings);
 }
 
@@ -177,7 +177,7 @@ bool Effect::isEnabled(const EffectFactory *factory)
 EffectFactory *Effect::findFactory(const QString &shortName)
 {
     loadPlugins();
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(item->shortName() == shortName)
             return item->effectFactory();
