@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -66,7 +66,7 @@ public:
     /*!
      * Returns map of channels
      */
-    const ChannelMap channelMap() const;
+    const ChannelMap &channelMap() const;
     /*!
      * Returns audio parameters for output data.
      */
