@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -72,7 +72,7 @@ QMap<Qmmp::MetaData, QString> InputSource::takeMetaData()
 void InputSource::setProperty(Qmmp::TrackProperty key, const QVariant &value)
 {
     QString strValue = value.toString();
-    if(strValue.isEmpty() || strValue == "0")
+    if(strValue.isEmpty() || strValue == "0"_L1)
         m_properties.remove(key);
     else
         m_properties[key] = strValue;
@@ -80,10 +80,8 @@ void InputSource::setProperty(Qmmp::TrackProperty key, const QVariant &value)
 
 void InputSource::setProperties(const QMap<Qmmp::TrackProperty, QString> &properties)
 {
-    for(const Qmmp::TrackProperty &key : properties.keys())
-    {
-        setProperty(key, properties.value(key));
-    }
+    for(auto it = properties.cbegin(); it != properties.cend(); ++it)
+        setProperty(it.key(), it.value());
 }
 
 const QMap<Qmmp::TrackProperty, QString> &InputSource::properties() const
@@ -121,9 +119,9 @@ QList<QmmpPluginCache*> *InputSource::m_cache = nullptr;
 InputSource *InputSource::create(const QString &url, QObject *parent)
 {
     loadPlugins();
-    if(!url.contains("://")) //local file path doesn't contain "://"
+    if(!url.contains(u"://"_s)) //local file path doesn't contain "://"
     {
-        qDebug("InputSource: using file transport");
+        qCDebug(core) << "using file transport";
         return new FileInputSource(url, parent);
     }
 
@@ -131,21 +129,19 @@ InputSource *InputSource::create(const QString &url, QObject *parent)
 
     if(factory)
     {
-        qDebug("InputSource: using %s transport", qPrintable(url.section("://", 0, 0)));
+        qCDebug(core, "using %s transport", qPrintable(url.section(u"://"_s, 0, 0)));
         return factory->create(url, parent);
     }
-    else
-    {
-        qDebug("InputSource: using fake transport");
-        return new EmptyInputSource(url, parent);
-    }
+
+    qCDebug(core) << "using fake transport";
+    return new EmptyInputSource(url, parent);
 }
 
 QList<InputSourceFactory *> InputSource::factories()
 {
     loadPlugins();
     QList<InputSourceFactory *> list;
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(item->inputSourceFactory())
             list.append(item->inputSourceFactory());
@@ -157,7 +153,7 @@ QList<InputSourceFactory *> InputSource::enabledFactories()
 {
     loadPlugins();
     QList<InputSourceFactory *> list;
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(m_disabledNames.contains(item->shortName()))
             continue;
@@ -180,7 +176,7 @@ QStringList InputSource::protocols()
     loadPlugins();
     QStringList protocolList;
 
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(m_disabledNames.contains(item->shortName()))
             continue;
@@ -196,7 +192,7 @@ QList<QRegularExpression> InputSource::regExps()
     loadPlugins();
     QList<QRegularExpression> regExpList;
 
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(m_disabledNames.contains(item->shortName()))
             continue;
@@ -209,7 +205,7 @@ QList<QRegularExpression> InputSource::regExps()
 InputSourceFactory *InputSource::findByUrl(const QString &url)
 {
     loadPlugins();
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(m_disabledNames.contains(item->shortName()))
             continue;
@@ -225,14 +221,14 @@ InputSourceFactory *InputSource::findByUrl(const QString &url)
         }
     }
 
-    for(QmmpPluginCache *item : qAsConst(*m_cache))
+    for(QmmpPluginCache *item : std::as_const(*m_cache))
     {
         if(m_disabledNames.contains(item->shortName()))
             continue;
 
         InputSourceFactory *factory = item->inputSourceFactory();
 
-        if(factory && factory->properties().protocols.contains(url.section("://", 0, 0)))
+        if(factory && factory->properties().protocols.contains(url.section(u"://"_s, 0, 0)))
             return factory;
     }
 
@@ -242,7 +238,7 @@ InputSourceFactory *InputSource::findByUrl(const QString &url)
 void InputSource::setEnabled(InputSourceFactory *factory, bool enable)
 {
     loadPlugins();
-    if (!factories().contains(factory))
+    if(!factories().contains(factory))
         return;
 
     if(enable == isEnabled(factory))
@@ -254,8 +250,8 @@ void InputSource::setEnabled(InputSourceFactory *factory, bool enable)
         m_disabledNames.append(factory->properties().shortName);
 
     m_disabledNames.removeDuplicates();
-    QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
-    settings.setValue("Transports/disabled_plugins", m_disabledNames);
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    settings.setValue("Transports/disabled_plugins"_L1, m_disabledNames);
 }
 
 bool InputSource::isEnabled(const InputSourceFactory *factory)
@@ -270,8 +266,8 @@ void InputSource::loadPlugins()
         return;
 
     m_cache = new QList<QmmpPluginCache*>;
-    QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
-    for(const QString &filePath : Qmmp::findPlugins("Transports"))
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    for(const QString &filePath : Qmmp::findPlugins(u"Transports"_s))
     {
         QmmpPluginCache *item = new QmmpPluginCache(filePath, &settings);
         if(item->hasError())
@@ -281,6 +277,6 @@ void InputSource::loadPlugins()
         }
         m_cache->append(item);
     }
-    m_disabledNames = settings.value("Transports/disabled_plugins").toStringList();
+    m_disabledNames = settings.value(u"Transports/disabled_plugins"_s).toStringList();
     QmmpPluginCache::cleanup(&settings);
 }
