@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,6 +23,7 @@
 
 #include <QObject>
 #include <QRegularExpression>
+#include <QDialog>
 #include <QList>
 #include <QStringList>
 #include "qmmp_export.h"
@@ -60,10 +61,11 @@ public:
      */
     virtual InputSource *create(const QString &url, QObject *parent = nullptr) = 0;
     /*!
-     * Shows settings dialog.
+     * Creates settings dialog.
      * @param parent Parent widget.
+     * @return Settings dialog pointer.
      */
-    virtual void showSettings(QWidget *parent) = 0;
+    virtual QDialog *createSettings(QWidget *parent) = 0;
     /*!
      * Shows about dialog.
      * @param parent Parent widget.
