@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -35,10 +35,8 @@
 
 MetaDataManager* MetaDataManager::m_instance = nullptr;
 
-MetaDataManager::MetaDataManager() : m_mutex(QMutex::Recursive)
-{
-    m_settings = QmmpSettings::instance();
-}
+MetaDataManager::MetaDataManager() : m_settings(QmmpSettings::instance())
+{}
 
 MetaDataManager::~MetaDataManager()
 {
@@ -47,14 +45,14 @@ MetaDataManager::~MetaDataManager()
 
 QList<TrackInfo *> MetaDataManager::createPlayList(const QString &path, TrackInfo::Parts parts, QStringList *ignoredPaths) const
 {
-    QList <TrackInfo *> list;
+    QList<TrackInfo *> list;
     DecoderFactory *fact = nullptr;
     EngineFactory *efact = nullptr;
     QStringList dummyList;
     if(!ignoredPaths)
         ignoredPaths = &dummyList;
 
-    if (!path.contains("://")) //local file
+    if(!path.contains(u"://"_s)) //local file
     {
         if(!QFile::exists(path))
             return list;
@@ -64,7 +62,7 @@ QList<TrackInfo *> MetaDataManager::createPlayList(const QString &path, TrackInf
     }
     else
     {
-        QString scheme = path.section("://",0,0);
+        QString scheme = path.section(u"://"_s, 0, 0);
         if(InputSource::findByUrl(path))
         {
             list << new TrackInfo(path);
@@ -87,11 +85,11 @@ QList<TrackInfo *> MetaDataManager::createPlayList(const QString &path, TrackInf
     else if(efact)
         list = efact->createPlayList(path, parts, ignoredPaths);
 
-    for(TrackInfo *info : qAsConst(list))
+    for(TrackInfo *info : std::as_const(list))
     {
         if(info->value(Qmmp::DECODER).isEmpty() && (fact || efact))
             info->setValue(Qmmp::DECODER, fact ? fact->properties().shortName : efact->properties().shortName);
-        if(info->value(Qmmp::FILE_SIZE).isEmpty() && !path.contains("://"))
+        if(info->value(Qmmp::FILE_SIZE).isEmpty() && !path.contains(u"://"_s))
             info->setValue(Qmmp::FILE_SIZE, QFileInfo(path).size());
     }
     return list;
@@ -102,31 +100,29 @@ MetaDataModel* MetaDataManager::createMetaDataModel(const QString &path, bool re
     DecoderFactory *fact = nullptr;
     EngineFactory *efact = nullptr;
 
-    if (!path.contains("://")) //local file
+    if (!path.contains(u"://"_s)) //local file
     {
         if(!QFile::exists(path))
             return nullptr;
-        else if((fact = Decoder::findByFilePath(path, m_settings->determineFileTypeByContent())))
+        if((fact = Decoder::findByFilePath(path, m_settings->determineFileTypeByContent())))
             return fact->createMetaDataModel(path, readOnly);
-        else if((efact = AbstractEngine::findByFilePath(path)))
+        if((efact = AbstractEngine::findByFilePath(path)))
             return efact->createMetaDataModel(path, readOnly);
         return nullptr;
     }
-    else
+
+    QString scheme = path.section(u"://"_s, 0, 0);
+    MetaDataModel *model = nullptr;
+    if((fact = Decoder::findByProtocol(scheme)))
     {
-        QString scheme = path.section("://",0,0);
-        MetaDataModel *model = nullptr;
-        if((fact = Decoder::findByProtocol(scheme)))
-        {
-            return fact->createMetaDataModel(path, readOnly);
-        }
-        for(EngineFactory *efact : AbstractEngine::enabledFactories())
-        {
-            if(efact->properties().protocols.contains(scheme))
-                model = efact->createMetaDataModel(path, readOnly);
-            if(model)
-                return model;
-        }
+        return fact->createMetaDataModel(path, readOnly);
+    }
+    for(EngineFactory *efact : AbstractEngine::enabledFactories())
+    {
+        if(efact->properties().protocols.contains(scheme))
+            model = efact->createMetaDataModel(path, readOnly);
+        if(model)
+            return model;
     }
     return nullptr;
 }
@@ -137,12 +133,12 @@ QStringList MetaDataManager::filters() const
     for(const DecoderFactory *fact : Decoder::enabledFactories())
     {
         if (!fact->properties().filters.isEmpty())
-            filters << fact->properties().description + " (" + fact->properties().filters.join(" ") + ")";
+            filters << QStringLiteral("%1 (%2)").arg(fact->properties().description, fact->properties().filters.join(QChar::Space));
     }
     for(const EngineFactory *fact : AbstractEngine::enabledFactories())
     {
         if (!fact->properties().filters.isEmpty())
-            filters << fact->properties().description + " (" + fact->properties().filters.join(" ") + ")";
+            filters << QStringLiteral("%1 (%2)").arg(fact->properties().description, fact->properties().filters.join(QChar::Space));
     }
     return filters;
 }
@@ -152,7 +148,7 @@ QStringList MetaDataManager::nameFilters() const
     QStringList filters = Decoder::nameFilters();
     filters << AbstractEngine::nameFilters();
     if(m_settings->determineFileTypeByContent())
-        filters << "*";
+        filters << u"*"_s;
     filters.removeDuplicates();
     return filters;
 }
@@ -174,26 +170,26 @@ QList<QRegularExpression> MetaDataManager::regExps() const
 
 bool MetaDataManager::supports(const QString &fileName) const
 {
-    if (!fileName.contains("://")) //local file
+    if (!fileName.contains(u"://"_s)) //local file
     {
-        if (!QFile::exists(fileName))
+        if(!QFile::exists(fileName))
             return false;
         if(Decoder::findByFilePath(fileName))
             return true;
-        else if(AbstractEngine::findByFilePath(fileName))
+        if(AbstractEngine::findByFilePath(fileName))
             return true;
         return false;
     }
     return false;
 }
 
-QPixmap MetaDataManager::getCover(const QString &url) const
+QImage MetaDataManager::getCover(const QString &url) const
 {
     QMutexLocker locker(&m_mutex);
     for(int i = 0; i < m_cover_cache.size(); ++i)
     {
         if(m_cover_cache[i]->url == url)
-            return m_cover_cache[i]->coverPixmap;
+            return m_cover_cache[i]->coverImage;
     }
 
     m_cover_cache << createCoverCacheItem(url);
@@ -201,7 +197,7 @@ QPixmap MetaDataManager::getCover(const QString &url) const
     while(m_cover_cache.size() > COVER_CACHE_SIZE)
         delete m_cover_cache.takeFirst();
 
-    return m_cover_cache.last()->coverPixmap;
+    return m_cover_cache.last()->coverImage;
 }
 
 QString MetaDataManager::getCoverPath(const QString &url) const
@@ -242,21 +238,22 @@ QFileInfoList MetaDataManager::findCoverFiles(QDir dir, int depth) const
     QFileInfoList file_list = dir.entryInfoList(m_settings->coverNameFilters());
 
     const auto fileListCopy = file_list; //avoid container modification
-    for(const QFileInfo &i : qAsConst(fileListCopy))
+    for(const QFileInfo &i : std::as_const(fileListCopy))
     {
         if(QDir::match(m_settings->coverNameFilters(false), i.fileName()))
             file_list.removeAll(i);
 
         if(QImageReader::imageFormat(i.filePath()).isEmpty()) //remove unsupported image formats
-            file_list.removeAll(i.fileName());
+            file_list.removeAll(i);
     }
     if(!depth || !file_list.isEmpty())
         return file_list;
+
     depth--;
     dir.setFilter(QDir::Dirs | QDir::NoDotAndDotDot);
     dir.setSorting(QDir::Name);
     const QFileInfoList dir_info_list = dir.entryInfoList();
-    for(const QFileInfo &i : qAsConst(dir_info_list))
+    for(const QFileInfo &i : std::as_const(dir_info_list))
     {
         file_list << findCoverFiles(QDir(i.absoluteFilePath()), depth);
     }
@@ -267,7 +264,7 @@ MetaDataManager::CoverCacheItem *MetaDataManager::createCoverCacheItem(const QSt
 {
     CoverCacheItem *item = new CoverCacheItem;
     item->url = url;
-    if(!url.contains("://") && m_settings->useCoverFiles())
+    if(!url.contains(u"://"_s) && m_settings->useCoverFiles())
         item->coverPath = findCoverFile(url);
 
     if(item->coverPath.isEmpty())
@@ -276,22 +273,23 @@ MetaDataManager::CoverCacheItem *MetaDataManager::createCoverCacheItem(const QSt
         if(model)
         {
             item->coverPath = model->coverPath();
-            item->coverPixmap = model->cover();
+            item->coverImage = model->cover();
             delete model;
         }
     }
 
-    if(!item->coverPath.isEmpty() && item->coverPixmap.isNull())
-        item->coverPixmap = QPixmap(item->coverPath);
+    if(!item->coverPath.isEmpty() && item->coverImage.isNull())
+        item->coverImage = QImage(item->coverPath);
 
-    if(item->coverPixmap.width() > 1024 || item->coverPixmap.height() > 1024)
-        item->coverPixmap = item->coverPixmap.scaled(1024, 1024, Qt::KeepAspectRatio, Qt::SmoothTransformation);
+    if(item->coverImage.width() > 1024 || item->coverImage.height() > 1024)
+        item->coverImage = item->coverImage.scaled(1024, 1024, Qt::KeepAspectRatio, Qt::SmoothTransformation);
 
     return item;
 }
 
 void MetaDataManager::clearCoverCache()
 {
+    QMutexLocker locker(&m_mutex);
     qDeleteAll(m_cover_cache);
     m_cover_cache.clear();
 }
@@ -306,7 +304,7 @@ void MetaDataManager::prepareForAnotherThread()
 
 bool MetaDataManager::hasMatch(const QList<QRegularExpression> &regExps, const QString &path)
 {
-    for(const QRegularExpression &re : qAsConst(regExps))
+    for(const QRegularExpression &re : std::as_const(regExps))
     {
         if(re.match(path).hasMatch())
             return true;
@@ -326,7 +324,6 @@ MetaDataManager *MetaDataManager::instance()
 
 void MetaDataManager::destroy()
 {
-    if(m_instance)
-        delete m_instance;
+    delete m_instance;
     m_instance = nullptr;
 }
