@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2012-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2012-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,7 +18,6 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#include <QtDebug>
 #include <string.h>
 #include "statehandler.h"
 #include "visual.h"
@@ -40,14 +39,10 @@ OutputWriter::OutputWriter (QObject* parent) : QThread (parent)
 
 OutputWriter::~OutputWriter()
 {
-    if(m_output)
-        delete m_output;
-    if(m_format_converter)
-        delete m_format_converter;
-    if(m_channel_converter)
-        delete m_channel_converter;
-    if(m_output_buf)
-        delete[] m_output_buf;
+    delete m_output;
+    delete m_format_converter;
+    delete m_channel_converter;
+    delete[] m_output_buf;
 }
 
 bool OutputWriter::initialize(quint32 freq, ChannelMap map)
@@ -56,13 +51,13 @@ bool OutputWriter::initialize(quint32 freq, ChannelMap map)
     m_output = Output::create();
     if(!m_output)
     {
-        qWarning("OutputWriter: unable to create output");
+        qCWarning(core, "unable to create output");
         return false;
     }
 
     if (!m_output->initialize(freq, map, m_settings->outputFormat()))
     {
-        qWarning("OutputWriter: unable to initialize output");
+        qCWarning(core, "unable to initialize output");
         delete m_output;
         m_output = nullptr;
         return false;
@@ -73,20 +68,18 @@ bool OutputWriter::initialize(quint32 freq, ChannelMap map)
     m_format = m_output->format();
     m_abr = m_settings->averageBitrate();
 
-    qDebug("OutputWriter: [%s] %s ==> %s",
-           qPrintable(Output::currentFactory()->properties().shortName),
-           qPrintable(m_in_params.toString()), qPrintable(m_output->audioParameters().toString()));
+    qCDebug(core, "[%s] %s ==> %s", qPrintable(Output::currentFactory()->properties().shortName),
+            qPrintable(m_in_params.toString()), qPrintable(m_output->audioParameters().toString()));
 
     if(!prepareConverters())
     {
-        qWarning("OutputWriter: unable to convert audio");
+        qCWarning(core, "unable to convert audio");
         delete m_output;
         m_output = nullptr;
         return false;
     }
 
-    if(m_output_buf)
-        delete[] m_output_buf;
+    delete[] m_output_buf;
     m_output_size = QMMP_BLOCK_FRAMES * m_channels * 4;
     m_output_buf = new unsigned char[m_output_size * m_output->sampleSize()];
 
@@ -167,7 +160,7 @@ bool OutputWriter::prepareConverters()
 
     if(m_channels != m_output->channels())
     {
-        qWarning("OutputWriter: unsupported channel number");
+        qCWarning(core, "unsupported channel number");
         return false;
     }
 
@@ -225,7 +218,7 @@ void OutputWriter::run()
     m_mutex.lock ();
     if (!m_bytesPerMillisecond)
     {
-        qWarning("OutputWriter: invalid audio parameters");
+        qCWarning(core, "invalid audio parameters");
         m_mutex.unlock ();
         return;
     }
@@ -242,7 +235,7 @@ void OutputWriter::run()
     dispatch(m_output->audioParameters());
     startVisualization();
 
-    while (!done)
+    while(!done)
     {
         m_mutex.lock ();
         if(m_pause != m_paused)
@@ -255,13 +248,12 @@ void OutputWriter::run()
                 m_mutex.unlock();
                 continue;
             }
-            else
-                m_output->resume();
+            m_output->resume();
         }
         recycler()->mutex()->lock ();
         done = m_user_stop || (m_finish && recycler()->empty());
 
-        while (!done && (recycler()->empty() || m_pause))
+        while(!done && (recycler()->empty() || m_pause))
         {
             recycler()->cond()->wakeOne();
             m_mutex.unlock();
@@ -359,7 +351,7 @@ void OutputWriter::run()
     if(m_finish)
     {
         m_output->drain();
-        qDebug() << "OutputWriter: total written" << m_totalWritten;
+        qCDebug(core) << "total written" << m_totalWritten;
     }
     dispatch(Qmmp::Stopped);
     stopVisualization();
