@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -38,9 +38,18 @@ QString Qmmp::m_langID;
 QString Qmmp::m_appDir;
 #endif
 
+#ifdef QT_DEBUG
+Q_LOGGING_CATEGORY(core, "qmmp.core", QtDebugMsg)
+Q_LOGGING_CATEGORY(plugin, "qmmp.plugin", QtDebugMsg)
+#else
+Q_LOGGING_CATEGORY(core, "qmmp.core", QtWarningMsg)
+Q_LOGGING_CATEGORY(plugin, "qmmp.plugin", QtWarningMsg)
+#endif
+
+
 QString Qmmp::configFile()
 {
-    return configDir() + "/qmmprc";
+    return configDir() + QStringLiteral("/qmmprc");
 }
 
 QString Qmmp::configDir()
@@ -49,14 +58,14 @@ QString Qmmp::configDir()
     if(m_configDir.isEmpty())
     {
         if(isPortable())
-            return m_appDir + "/.qmmp";
+            return m_appDir + QStringLiteral("/.qmmp");
         else
-            return  QDir::homePath() +"/.qmmp";
+            return  QDir::homePath() + QStringLiteral("/.qmmp");
     }
     else
         return m_configDir;
 #else
-    return m_configDir.isEmpty() ? QDir::homePath() +"/.qmmp" : m_configDir;
+    return m_configDir.isEmpty() ? QDir::homePath() + u"/.qmmp"_s : m_configDir;
 #endif
 }
 
@@ -65,17 +74,29 @@ void Qmmp::setConfigDir(const QString &path)
     m_configDir = path;
 }
 
+QString Qmmp::cacheDir()
+{
+#ifdef Q_OS_WIN
+    return configDir();
+#else
+    if(m_configDir.isEmpty())
+        return QStringLiteral("%1/%2").arg(QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation),
+                                           QCoreApplication::organizationName());
+    return m_configDir;
+#endif
+}
+
 QString Qmmp::strVersion()
 {
-    QString ver = QString("%1.%2.%3")
+    QString ver = QStringLiteral("%1.%2.%3")
             .arg(QMMP_VERSION_MAJOR)
             .arg(QMMP_VERSION_MINOR)
             .arg(QMMP_VERSION_PATCH);
 #if !QMMP_VERSION_STABLE
 #ifdef SVN_REVISION
-    ver += "-svn-" SVN_REVISION;
+    ver += QStringLiteral("-svn-" SVN_REVISION);
 #else
-    ver += "-" DEV_SUFFIX;
+    ver += QStringLiteral("-" DEV_SUFFIX);
 #endif
 #endif
     return ver;
@@ -85,12 +106,12 @@ QString Qmmp::pluginPath()
 {
     QByteArray path = qgetenv("QMMP_PLUGINS");
     if(!path.isEmpty())
-        return path;
-    QString fallbackPath = qApp->applicationDirPath() + "/../lib/qmmp-" STR(QMMP_VERSION_MAJOR) "." STR(QMMP_VERSION_MINOR);
+        return QString::fromLocal8Bit(path);
+    QString fallbackPath = QStringLiteral("%1/../lib/qmmp-" STR(QMMP_VERSION_MAJOR) "." STR(QMMP_VERSION_MINOR)).arg(qApp->applicationDirPath());
 #ifdef QMMP_PLUGIN_DIR
-    QDir dir(QMMP_PLUGIN_DIR);
+    QDir dir(QStringLiteral(QMMP_PLUGIN_DIR));
 #elif defined(Q_OS_WIN) && !defined(Q_OS_CYGWIN)
-    QDir dir(qApp->applicationDirPath() + "/plugins");
+    QDir dir(qApp->applicationDirPath() + u"/plugins"_s);
 #else
     QDir dir(fallbackPath);
 #endif
@@ -101,9 +122,9 @@ QString Qmmp::pluginPath()
 
 QStringList Qmmp::findPlugins(const QString &prefix)
 {
-    QDir pluginDir(pluginPath() + "/" + prefix);
+    QDir pluginDir(pluginPath() + u"/"_s + prefix);
     QStringList paths;
-    for(const QFileInfo &info : pluginDir.entryInfoList(QStringList() << "*.dll" << "*.so", QDir::Files))
+    for(const QFileInfo &info : pluginDir.entryInfoList({ u"*.dll"_s, u"*.so"_s }, QDir::Files))
         paths << info.canonicalFilePath();
     return paths;
 }
@@ -113,10 +134,9 @@ QString Qmmp::systemLanguageID()
     if(m_langID.isEmpty())
     {
         m_langID = uiLanguageID();
-        //qDebug("Qmmp: setting ui language to '%s'", qPrintable(m_langID));
     }
 
-    if(m_langID != "auto")
+    if(m_langID != "auto"_L1)
         return m_langID;
 
 #ifdef Q_OS_UNIX
@@ -126,7 +146,7 @@ QString Qmmp::systemLanguageID()
     if (v.isEmpty())
         v = qgetenv ("LANG");
     if (!v.isEmpty())
-        return QLocale (v).name();
+        return QLocale(QString::fromLatin1(v)).name();
 #endif
     return  QLocale::system().name();
 }
@@ -134,15 +154,15 @@ QString Qmmp::systemLanguageID()
 QString Qmmp::uiLanguageID()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    QString langID = settings.value("General/locale", "auto").toString();
-    langID = langID.isEmpty() ? "auto" : langID;
+    QString langID = settings.value(u"General/locale"_s, u"auto"_s).toString();
+    langID = langID.isEmpty() ? u"auto"_s : langID;
     return langID;
 }
 
 void Qmmp::setUiLanguageID(const QString &code)
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.setValue("General/locale", code);
+    settings.setValue(u"General/locale"_s, code);
     m_langID.clear();
 }
 
@@ -151,7 +171,7 @@ QString Qmmp::dataPath()
 #if defined(Q_OS_WIN) && !defined(Q_OS_CYGWIN)
     return qApp->applicationDirPath();
 #else
-    return QDir(qApp->applicationDirPath() + "/../share/qmmp" APP_NAME_SUFFIX).absolutePath();
+    return QDir(QStringLiteral("%1/../share/qmmp" APP_NAME_SUFFIX).arg(qApp->applicationDirPath())).absolutePath();
 #endif
 }
 
@@ -161,10 +181,11 @@ QString Qmmp::userDataPath()
     return configDir();
 #else
     if(m_configDir.isEmpty())
-        return QStringLiteral("%1/%2").arg(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation))
-                .arg(QStringLiteral("qmmp"));
-    else
-        return m_configDir;
+    {
+        return QStringLiteral("%1/%2").arg(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation),
+                                           QCoreApplication::organizationName());
+    }
+    return m_configDir;
 #endif
 }
 
@@ -173,97 +194,6 @@ bool Qmmp::isPortable()
 {
     if(m_appDir.isEmpty())
         m_appDir = QCoreApplication::applicationDirPath();
-    return QFile::exists(m_appDir + "/qmmp_portable.txt");
-}
-#endif
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 12, 0)
-QString Qmmp::wildcardToRegularExpression(const QString &pattern)
-{
-    const int wclen = pattern.length();
-    QString rx;
-    rx.reserve(wclen + wclen / 16);
-    int i = 0;
-    const QChar *wc = pattern.data();
-
-#ifdef Q_OS_WIN
-    const QLatin1Char nativePathSeparator('\\');
-    const QLatin1String starEscape("[^/\\\\]*");
-    const QLatin1String questionMarkEscape("[^/\\\\]");
-#else
-    const QLatin1Char nativePathSeparator('/');
-    const QLatin1String starEscape("[^/]*");
-    const QLatin1String questionMarkEscape("[^/]");
-#endif
-
-    while (i < wclen) {
-        const QChar c = wc[i++];
-        switch (c.unicode())
-        {
-        case '*':
-            rx += starEscape;
-            break;
-        case '?':
-            rx += questionMarkEscape;
-            break;
-        case '\\':
-#ifdef Q_OS_WIN
-        case '/':
-            rx += QLatin1String("[/\\\\]");
-            break;
-#endif
-        case '$':
-        case '(':
-        case ')':
-        case '+':
-        case '.':
-        case '^':
-        case '{':
-        case '|':
-        case '}':
-            rx += QLatin1Char('\\');
-            rx += c;
-            break;
-        case '[':
-            rx += c;
-            // Support for the [!abc] or [!a-c] syntax
-            if (i < wclen) {
-                if (wc[i] == QLatin1Char('!'))
-                {
-                    rx += QLatin1Char('^');
-                    ++i;
-                }
-
-                if (i < wclen && wc[i] == QLatin1Char(']'))
-                    rx += wc[i++];
-
-                while (i < wclen && wc[i] != QLatin1Char(']'))
-                {
-                    // The '/' appearing in a character class invalidates the
-                    // regular expression parsing. It also concerns '\\' on
-                    // Windows OS types.
-                    if (wc[i] == QLatin1Char('/') || wc[i] == nativePathSeparator)
-                        return rx;
-                    if (wc[i] == QLatin1Char('\\'))
-                        rx += QLatin1Char('\\');
-                    rx += wc[i++];
-                }
-            }
-            break;
-        default:
-            rx += c;
-            break;
-        }
-    }
-
-    return anchoredPattern(rx);
-}
-
-QString Qmmp::anchoredPattern(const QString &expression)
-{
-    return QString()
-            + QLatin1String("\\A(?:")
-            + expression
-            + QLatin1String(")\\z");
+    return QFile::exists(m_appDir + QStringLiteral("/qmmp_portable.txt"));
 }
 #endif
