@@ -21,11 +21,12 @@
 #define QMMP_H
 
 #include <QString>
+#include <QLoggingCategory>
 #include "qmmp_export.h"
 
 #define QMMP_VERSION_MAJOR 1
-#define QMMP_VERSION_MINOR 6
-#define QMMP_VERSION_PATCH 9
+#define QMMP_VERSION_MINOR 7
+#define QMMP_VERSION_PATCH 0
 #define QMMP_VERSION_STABLE 1
 
 #define QMMP_VERSION_INT (QMMP_VERSION_MAJOR<<16 | QMMP_VERSION_MINOR<<8 | QMMP_VERSION_PATCH)
@@ -39,14 +40,39 @@
 #define QStringToFileName(s) s.toLocal8Bit().constData()
 #endif
 
-#if (QT_VERSION < QT_VERSION_CHECK(5, 7, 0))
-// this adds const to non-const objects (like std::as_const)
-template <typename T>
-Q_DECL_CONSTEXPR typename std::add_const<T>::type &qAsConst(T &t) noexcept { return t; }
-// prevent rvalue arguments:
-template <typename T>
-void qAsConst(const T &&) = delete;
-#endif
+#include <QLatin1String>
+
+namespace Qt {
+inline namespace Literals {
+inline namespace StringLiterals {
+
+inline QString operator""_s(const char16_t *str, size_t size) noexcept
+{
+    return QString::fromUtf16(str, size);
+}
+
+constexpr inline QLatin1String operator""_L1(const char *str, size_t size) noexcept
+{
+    return QLatin1String(str, int(size));
+}
+
+inline QByteArray operator""_ba(const char *str, size_t size) noexcept
+{
+    return QByteArray(str, qsizetype(size));
+}
+
+} // StringLiterals
+} // Literals
+} // Qt
+
+using QLatin1StringView = QLatin1String;
+
+using namespace Qt::Literals::StringLiterals;
+
+QMMP_EXPORT Q_DECLARE_LOGGING_CATEGORY(core)
+QMMP_EXPORT Q_DECLARE_LOGGING_CATEGORY(plugin)
+
+#define qCFatal qCCritical
 
 
 /*! @brief The Qmmp class stores global settings and enums.
@@ -147,10 +173,9 @@ public:
         CHAN_SIDE_RIGHT   = 0x80,   /*!< Side right channel */
         CHAN_LFE          = 0x100,  /*!< Low-frequency effects channel */
     };
-
     /*!
-     * Returns the configuration file name, including the path.
-     */
+         * Returns the configuration file name, including the path.
+         */
     static QString configFile();
     /*!
      * Returns the configuration directory path.
@@ -160,6 +185,10 @@ public:
      * Overrides default configuration directory path.
      */
     static void setConfigDir(const QString &path);
+    /*!
+     * Returns the cache directory path.
+     */
+    static QString cacheDir();
     /*!
      * Returns %Qmmp library version.
      */
@@ -202,11 +231,6 @@ public:
     static bool isPortable();
 #endif
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 12, 0)
-    static QString wildcardToRegularExpression(const QString &pattern);
-    static QString anchoredPattern(const QString &expression);
-#endif
-
 private:
     static QString m_configDir;
     static QString m_langID;
