@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -34,15 +34,15 @@ void ReplayGain::setReplayGainInfo(const QMap<Qmmp::ReplayGainKey, double> &info
     updateScale();
     if(m_mode != QmmpSettings::REPLAYGAIN_DISABLED && !m_disabled)
     {
-        qDebug("ReplayGain: track: gain=%f dB, peak=%f; album: gain=%f dB, peak=%f",
+        qCDebug(core, "ReplayGain: track: gain=%f dB, peak=%f; album: gain=%f dB, peak=%f",
                m_info[Qmmp::REPLAYGAIN_TRACK_GAIN],
                m_info[Qmmp::REPLAYGAIN_TRACK_PEAK],
                m_info[Qmmp::REPLAYGAIN_ALBUM_GAIN],
                m_info[Qmmp::REPLAYGAIN_ALBUM_PEAK]);
-        qDebug("ReplayGain: scale=%f", m_scale);
+        qCDebug(core, "ReplayGain: scale=%f", m_scale);
     }
     else
-        qDebug("ReplayGain: disabled");
+        qCDebug(core, "ReplayGain: disabled");
 }
 
 void ReplayGain::applyEffect(Buffer *b)
@@ -82,11 +82,11 @@ void ReplayGain::updateScale()
     switch(m_mode)
     {
     case QmmpSettings::REPLAYGAIN_TRACK:
-        m_scale = pow(10.0, m_info[Qmmp::REPLAYGAIN_TRACK_GAIN]/20);
+        m_scale = pow(10.0, m_info[Qmmp::REPLAYGAIN_TRACK_GAIN] / 20);
         peak = m_info[Qmmp::REPLAYGAIN_TRACK_PEAK];
         break;
     case QmmpSettings::REPLAYGAIN_ALBUM:
-        m_scale = pow(10.0, m_info[Qmmp::REPLAYGAIN_ALBUM_GAIN]/20);
+        m_scale = pow(10.0, m_info[Qmmp::REPLAYGAIN_ALBUM_GAIN] / 20);
         peak = m_info[Qmmp::REPLAYGAIN_ALBUM_PEAK];
         break;
     case QmmpSettings::REPLAYGAIN_DISABLED:
@@ -94,7 +94,7 @@ void ReplayGain::updateScale()
         return;
     }
     if(m_scale == 1.0)
-        m_scale = pow(10.0, m_default_gain/20);
+        m_scale = pow(10.0, m_default_gain / 20);
     m_scale *= pow(10.0, m_preamp/20);
     if(peak > 0.0 && m_prevent_clipping)
         m_scale = m_scale*peak > 1.0 ? 1.0 / peak : m_scale;
