@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -41,21 +41,20 @@ SoundCore::SoundCore(QObject *parent)
         : QObject(parent)
 {
     if(m_instance)
-        qFatal("SoundCore: only one instance is allowed");
+        qCFatal(core) << "only one instance is allowed";
     qRegisterMetaType<Qmmp::State>("Qmmp::State");
     m_instance = this;
     m_handler = new StateHandler(this);
     m_volumeControl = new VolumeHandler(this);
-    connect(m_handler, SIGNAL(elapsedChanged(qint64)), SIGNAL(elapsedChanged(qint64)));
-    connect(m_handler, SIGNAL(bitrateChanged(int)), SIGNAL(bitrateChanged(int)));
-    connect(m_handler, SIGNAL(audioParametersChanged(AudioParameters)), SIGNAL(audioParametersChanged(AudioParameters)));
-    connect(m_handler, SIGNAL(bufferingProgress(int)), SIGNAL(bufferingProgress(int)));
-    connect(QmmpSettings::instance(), SIGNAL(eqSettingsChanged()), SIGNAL(eqSettingsChanged()));
-    connect(QmmpSettings::instance(), SIGNAL(audioSettingsChanged()), m_volumeControl, SLOT(reload()));
-    connect(m_volumeControl, SIGNAL(volumeChanged(int, int)), SIGNAL(volumeChanged(int, int)));
-    connect(m_volumeControl, SIGNAL(volumeChanged(int)), SIGNAL(volumeChanged(int)));
-    connect(m_volumeControl, SIGNAL(balanceChanged(int)), SIGNAL(balanceChanged(int)));
-    connect(m_volumeControl, SIGNAL(mutedChanged(bool)), SIGNAL(mutedChanged(bool)));
+    connect(m_handler, &StateHandler::elapsedChanged, this, &SoundCore::elapsedChanged);
+    connect(m_handler, &StateHandler::bitrateChanged, this, &SoundCore::bitrateChanged);
+    connect(m_handler, &StateHandler::audioParametersChanged, this, &SoundCore::audioParametersChanged);
+    connect(m_handler, &StateHandler::bufferingProgress, this, &SoundCore::bufferingProgress);
+    connect(QmmpSettings::instance(), &QmmpSettings::eqSettingsChanged, this, &SoundCore::eqSettingsChanged);
+    connect(QmmpSettings::instance(), &QmmpSettings::audioSettingsChanged, m_volumeControl, &VolumeHandler::reload);
+    connect(m_volumeControl, &VolumeHandler::volumeChanged, this, &SoundCore::volumeChanged);
+    connect(m_volumeControl, &VolumeHandler::balanceChanged, this, &SoundCore::balanceChanged);
+    connect(m_volumeControl, &VolumeHandler::mutedChanged, this, &SoundCore::mutedChanged);
 }
 
 SoundCore::~SoundCore()
@@ -75,8 +74,8 @@ bool SoundCore::play(const QString &source, bool queue, qint64 offset)
     s->setOffset(offset);
     m_sources.enqueue(s);
 
-    connect(s, SIGNAL(ready()), SLOT(startNextSource()));
-    connect(s, SIGNAL(error()), SLOT(startNextSource()));
+    connect(s, &InputSource::ready, this, &SoundCore::startNextSource);
+    connect(s, &InputSource::error, this, &SoundCore::startNextSource);
 
     if(!s->initialize())
     {
@@ -122,16 +121,16 @@ void SoundCore::seek(qint64 pos)
         m_engine->seek(pos);
 }
 
-const QString SoundCore::path() const
-{
-    return m_path;
-}
-
 bool SoundCore::nextTrackAccepted() const
 {
     return m_nextState == SAME_ENGINE;
 }
 
+const QString SoundCore::path() const
+{
+    return m_path;
+}
+
 qint64 SoundCore::duration() const
 {
     return m_handler->duration();
@@ -147,7 +146,7 @@ void SoundCore::setEqSettings(const EqSettings &settings)
     QmmpSettings::instance()->setEqSettings(settings);
 }
 
-void SoundCore::setVolume(int L, int R)
+void SoundCore::setVolumePerChannel(int L, int R)
 {
     setMuted(false);
     m_volumeControl->setVolume(L, R);
@@ -241,7 +240,7 @@ QString SoundCore::metaData(Qmmp::MetaData key) const
     return m_info.value(key);
 }
 
-QHash<QString, QString> SoundCore::streamInfo() const
+const QHash<QString, QString> &SoundCore::streamInfo() const
 {
     return m_streamInfo;
 }
@@ -261,7 +260,7 @@ void SoundCore::startNextSource()
 
     if(s->ioDevice() && !s->ioDevice()->isOpen() && !s->ioDevice()->open(QIODevice::ReadOnly))
     {
-        qWarning("SoundCore: input error: %s", qPrintable(s->ioDevice()->errorString()));
+        qCWarning(core, "input error: %s", qPrintable(s->ioDevice()->errorString()));
         m_path.clear();
         s->deleteLater();
         m_nextState = INVALID_SOURCE;
@@ -278,14 +277,13 @@ void SoundCore::startNextSource()
             m_nextState = NO_ENGINE;
             return;
         }
-        else
-        {
-            s->deleteLater();
-            m_handler->dispatch(Qmmp::NormalError);
-            return;
-        }
+
+        s->deleteLater();
+        m_handler->dispatch(Qmmp::NormalError);
+        return;
     }
-    else if(AbstractEngine::isEnabled(m_engine) && m_engine->enqueue(s))
+
+    if(AbstractEngine::isEnabled(m_engine) && m_engine->enqueue(s))
     {
         if(state() == Qmmp::Stopped || state() == Qmmp::Buffering)
         {
@@ -317,7 +315,7 @@ void SoundCore::startNextEngine()
     {
         if(m_sources.isEmpty())
             m_nextState = NO_ENGINE;
-        else if(!m_sources.first()->isReady() && state() == Qmmp::Stopped)
+        else if(!m_sources.constFirst()->isReady() && state() == Qmmp::Stopped)
             m_handler->dispatch(Qmmp::Buffering);
         break;
     }
@@ -373,5 +371,5 @@ bool SoundCore::event(QEvent *e)
     else if(e->type() == EVENT_FINISHED)
         emit finished();
 
-    return QObject::event(e);;
+    return QObject::event(e);
 }
