@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -32,10 +32,10 @@
 StateHandler* StateHandler::m_instance = nullptr;
 
 StateHandler::StateHandler(QObject *parent)
-        : QObject(parent), m_mutex(QMutex::Recursive)
+        : QObject(parent)
 {
     if(m_instance)
-        qFatal("StateHandler: only one instance is allowed");
+        qCFatal(core) << "only one instance is allowed";
     qRegisterMetaType<AudioParameters>("AudioParameters");
     m_instance = this;
 }
@@ -51,18 +51,18 @@ void StateHandler::dispatch(qint64 elapsed, int bitrate)
     if (qAbs(m_elapsed - elapsed) > TICK_INTERVAL)
     {
         m_elapsed = elapsed;
-        emit (elapsedChanged(elapsed));
+        emit elapsedChanged(elapsed);
         if (m_bitrate != bitrate)
         {
             m_bitrate = bitrate;
-            emit (bitrateChanged(bitrate));
+            emit bitrateChanged(bitrate);
         }
         if((SoundCore::instance()->duration() > PREFINISH_TIME)
                  && (m_duration - m_elapsed < PREFINISH_TIME)
                  && m_sendAboutToFinish)
         {
             m_sendAboutToFinish = false;
-            if(m_duration - m_elapsed > PREFINISH_TIME/2)
+            if(m_duration - m_elapsed > PREFINISH_TIME / 2)
                 qApp->postEvent(parent(), new QEvent(EVENT_NEXT_TRACK_REQUEST));
         }
     }
@@ -92,12 +92,12 @@ bool StateHandler::dispatch(const TrackInfo &info)
     QMutexLocker locker(&m_mutex);
     if(info.isEmpty())
     {
-        qWarning("StateHandler: empty metadata");
+        qCWarning(core, "empty metadata");
         return false;
     }
     if(m_state != Qmmp::Playing && m_state != Qmmp::Paused)
     {
-        qWarning("StateHandler: metadata is ignored");
+        qCWarning(core, "metadata is ignored");
         return false;
     }
 
@@ -146,8 +146,7 @@ void StateHandler::dispatch(Qmmp::State state)
 {
     m_mutex.lock();
     //clear
-    QList <Qmmp::State> clearStates;
-    clearStates << Qmmp::Stopped << Qmmp::NormalError << Qmmp::FatalError;
+    static const QList<Qmmp::State> clearStates = { Qmmp::Stopped, Qmmp::NormalError, Qmmp::FatalError };
     if (clearStates.contains(state))
     {
         m_elapsed = -1;
@@ -159,10 +158,10 @@ void StateHandler::dispatch(Qmmp::State state)
     }
     if (m_state != state)
     {
-        QStringList states;
-        states << "Playing" << "Paused" << "Stopped" << "Buffering" << "NormalError" << "FatalError";
-        qDebug("StateHandler: Current state: %s; previous state: %s",
-               qPrintable(states.at(state)), qPrintable(states.at(m_state)));
+        static const QStringList states = {
+            u"Playing"_s, u"Paused"_s, u"Stopped"_s, u"Buffering"_s, u"NormalError"_s, u"FatalError"_s
+        };
+        qCDebug(core) << "Current state:" << states.at(state) <<  "; previous state:" << states.at(m_state);
         Qmmp::State prevState = state;
         m_state = state;
         qApp->postEvent(parent(), new StateChangedEvent(m_state, prevState));
