@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,6 +28,7 @@
 #include <QDialog>
 #include <QPluginLoader>
 #include <QTranslator>
+#include <QTimer>
 #include "statehandler.h"
 #include "visualfactory.h"
 #include "visualbuffer_p.h"
@@ -41,7 +42,7 @@ Visual::Visual(QWidget *parent, Qt::WindowFlags f) : QWidget(parent, f)
 
 Visual::~Visual()
 {
-    qDebug("Visual::~Visual()");
+    qCDebug(core) << Q_FUNC_INFO;
 }
 
 void Visual::closeEvent (QCloseEvent *event)
@@ -115,8 +116,8 @@ void Visual::setEnabled(VisualFactory *factory, bool enable)
         return;
 
     QString name = factory->properties().shortName;
-    QSettings settings ( Qmmp::configFile(), QSettings::IniFormat );
-    QStringList visList = settings.value("Visualization/enabled_plugins").toStringList();
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QStringList visList = settings.value(u"Visualization/enabled_plugins"_s).toStringList();
 
     if (enable)
     {
@@ -124,16 +125,7 @@ void Visual::setEnabled(VisualFactory *factory, bool enable)
             visList << name;
         if (!m_vis_map.value(factory) && m_parentWidget)
         {
-            Visual* visual = factory->create(m_parentWidget);
-            if (m_receiver && m_member)
-                connect(visual, SIGNAL(closedByUser()), m_receiver, m_member);
-            visual->setWindowFlags(Qt::Window);
-            m_vis_map.insert (factory, visual);
-            Qmmp::State st = StateHandler::instance()->state();
-            if(st == Qmmp::Playing || st == Qmmp::Buffering || st == Qmmp::Paused)
-                visual->start();
-            m_visuals.append(visual);
-            visual->show();
+            createVisualization(factory, m_parentWidget);
         }
     }
     else
@@ -146,15 +138,15 @@ void Visual::setEnabled(VisualFactory *factory, bool enable)
             m_vis_map.remove (factory);
         }
     }
-    settings.setValue("Visualization/enabled_plugins", visList);
+    settings.setValue(u"Visualization/enabled_plugins"_s, visList);
 }
 
 bool Visual::isEnabled(const VisualFactory *factory)
 {
     checkFactories();
     QString name = factory->properties().shortName;
-    QSettings settings ( Qmmp::configFile(), QSettings::IniFormat );
-    QStringList visList = settings.value("Visualization/enabled_plugins").toStringList();
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QStringList visList = settings.value(u"Visualization/enabled_plugins"_s).toStringList();
     return visList.contains(name);
 }
 
@@ -162,7 +154,7 @@ void Visual::add(Visual *visual)
 {
     if (!m_visuals.contains(visual))
     {
-        Qmmp::State st = StateHandler::instance()->state();
+        Qmmp::State st = StateHandler::instance() ? StateHandler::instance()->state() : Qmmp::Stopped;
         if(st == Qmmp::Playing || st == Qmmp::Buffering || st == Qmmp::Paused)
             visual->start();
         m_visuals.append(visual);
@@ -181,16 +173,9 @@ void Visual::initialize(QWidget *parent , QObject *receiver, const char *member)
     m_parentWidget = parent;
     for(VisualFactory *factory : factories())
     {
-        if (isEnabled(factory))
+        if(isEnabled(factory))
         {
-            Visual* visual = factory->create(parent);
-            if (m_receiver && m_member)
-                connect(visual, SIGNAL(closedByUser()), m_receiver, m_member);
-            visual->setWindowFlags(visual->windowFlags() | Qt::Window);
-            qDebug("Visual: added visualization: %s", qPrintable(factory->properties().name));
-            m_vis_map.insert (factory, visual);
-            m_visuals.append(visual);
-            visual->show();
+            QTimer::singleShot(0, parent, [factory, parent] { createVisualization(factory, parent); });
         }
     }
 }
@@ -202,7 +187,7 @@ QList<Visual*>* Visual::visuals()
 
 void Visual::showSettings(VisualFactory *factory, QWidget *parent)
 {
-    QDialog *dialog = factory->createConfigDialog(parent);
+    QDialog *dialog = factory->createSettings(parent);
     if (!dialog)
         return;
 
@@ -211,13 +196,7 @@ void Visual::showSettings(VisualFactory *factory, QWidget *parent)
         Visual *visual = m_vis_map.value(factory);
         remove(visual);
         visual->close();
-        visual = factory->create(m_parentWidget);
-        if (m_receiver && m_member)
-            connect(visual, SIGNAL(closedByUser()), m_receiver, m_member);
-        visual->setWindowFlags(Qt::Window);
-        m_vis_map[factory] = visual;
-        visual->show();
-        add(visual);
+        createVisualization(factory, m_parentWidget);
     }
     dialog->deleteLater();
 }
@@ -249,14 +228,14 @@ void Visual::checkFactories()
         m_factories = new QList<VisualFactory *>;
         m_files = new QHash <const VisualFactory*, QString>;
 
-        for(const QString &filePath : Qmmp::findPlugins("Visual"))
+        for(const QString &filePath : Qmmp::findPlugins(u"Visual"_s))
         {
             QPluginLoader loader(filePath);
             QObject *plugin = loader.instance();
             if (loader.isLoaded())
-                qDebug("Visual: loaded plugin %s", qPrintable(QFileInfo(filePath).fileName()));
+                qCDebug(core) << "loaded plugin" << QFileInfo(filePath).fileName();
             else
-                qWarning("Visual: %s", qPrintable(loader.errorString ()));
+                qCWarning(core) << loader.errorString();
 
             VisualFactory *factory = nullptr;
             if (plugin)
@@ -278,3 +257,15 @@ void Visual::checkFactories()
         }
     }
 }
+
+void Visual::createVisualization(VisualFactory *factory, QWidget *parent)
+{
+    Visual *visual = factory->create(parent);
+    if (m_receiver && m_member)
+        connect(visual, SIGNAL(closedByUser()), m_receiver, m_member);
+    visual->setWindowFlags(visual->windowFlags() | Qt::Window);
+    qCDebug(core) << "added visualization:" << factory->properties().shortName;
+    m_vis_map.insert(factory, visual);
+    add(visual);
+    visual->show();
+}
