@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -30,13 +30,13 @@ VolumeHandler *VolumeHandler::m_instance = nullptr;
 VolumeHandler::VolumeHandler(QObject *parent) : QObject(parent)
 {
     if(m_instance)
-        qFatal("VolumeHandler: only one instance is allowed!");
+        qCFatal(core) << "only one instance is allowed!";
 
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    m_settings.left = settings.value("Volume/left", 80).toInt();
-    m_settings.right = settings.value("Volume/right", 80).toInt();
+    m_settings.left = settings.value(u"Volume/left"_s, 80).toInt();
+    m_settings.right = settings.value(u"Volume/right"_s, 80).toInt();
     m_timer = new QTimer(this);
-    connect(m_timer, SIGNAL(timeout()), SLOT(checkVolume()));
+    connect(m_timer, &QTimer::timeout, this, &VolumeHandler::checkVolume);
     reload();
     m_instance = this;
 }
@@ -44,19 +44,18 @@ VolumeHandler::VolumeHandler(QObject *parent) : QObject(parent)
 VolumeHandler::~VolumeHandler()
 {
     m_instance = nullptr;
-    if(m_volume)
-        delete m_volume;
+    delete m_volume;
 
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.setValue("Volume/left", m_settings.left);
-    settings.setValue("Volume/right", m_settings.right);
+    settings.setValue(u"Volume/left"_s, m_settings.left);
+    settings.setValue(u"Volume/right"_s, m_settings.right);
 }
 
 void VolumeHandler::setVolume(int left, int right)
 {
     VolumeSettings v;
-    v.left = qBound(0,left,100);
-    v.right = qBound(0,right,100);
+    v.left = qBound(0, left, 100);
+    v.right = qBound(0, right, 100);
     if(m_volume)
     {
         m_volume->setVolume(v);
@@ -81,15 +80,15 @@ void VolumeHandler::changeVolume(int delta)
 void VolumeHandler::setVolume(int volume)
 {
     volume = qBound(0, volume, 100);
-    setVolume(volume-qMax(balance(),0)*volume/100,
-              volume+qMin(balance(),0)*volume/100);
+    setVolume(volume - qMax(balance(),0)*volume/100,
+              volume + qMin(balance(),0)*volume/100);
 }
 
 void VolumeHandler::setBalance(int balance)
 {
     balance = qBound(-100, balance, 100);
-    setVolume(volume()-qMax(balance,0)*volume()/100,
-              volume()+qMin(balance,0)*volume()/100);
+    setVolume(volume() - qMax(balance,0)*volume()/100,
+              volume() + qMin(balance,0)*volume()/100);
 }
 
 void VolumeHandler::setMuted(bool muted)
@@ -180,7 +179,6 @@ void VolumeHandler::checkVolume()
 {
     if(!m_volume) //soft volume
     {
-        emit volumeChanged(m_settings.left, m_settings.right);
         emit volumeChanged(volume());
         emit balanceChanged(balance());
         return;
@@ -200,13 +198,11 @@ void VolumeHandler::checkVolume()
     if (m_settings != v) //volume has been changed
     {
         m_settings = v;
-        emit volumeChanged(v.left, v.right);
         emit volumeChanged(volume());
         emit balanceChanged(balance());
     }
     else if(m_prev_block && !signalsBlocked ()) //signals have been unblocked
     {
-        emit volumeChanged(v.left, v.right);
         emit volumeChanged(volume());
         emit balanceChanged(balance());
     }
@@ -239,7 +235,7 @@ void VolumeHandler::reload()
         if(m_volume->flags() & Volume::HasNotifySignal)
         {
             checkVolume();
-            connect(m_volume, SIGNAL(changed()), SLOT(checkVolume()));
+            connect(m_volume, &Volume::changed, this, &VolumeHandler::checkVolume);
         }
         else
         {
@@ -256,6 +252,6 @@ void VolumeHandler::reload()
         blockSignals(true);
         checkVolume();
         blockSignals(false);
-        QTimer::singleShot(125, this, SLOT(checkVolume()));
+        QTimer::singleShot(125, this, &VolumeHandler::checkVolume);
     }
 }
