@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -30,20 +30,21 @@
 #include "playlistmodel.h"
 #include "playlistdownloader.h"
 #include "qmmpuisettings.h"
+#include "ui_addurldialog.h"
 #include "addurldialog_p.h"
 
 #define HISTORY_SIZE 10
 
-AddUrlDialog::AddUrlDialog(QWidget *parent) : QDialog(parent)
+AddUrlDialog::AddUrlDialog(QWidget *parent) : QDialog(parent), m_ui(new Ui::AddUrlDialog)
 {
-    setupUi(this);
+    m_ui->setupUi(this);
     setAttribute(Qt::WA_DeleteOnClose);
     setAttribute(Qt::WA_QuitOnClose, false);
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    m_history = settings.value("URLDialog/history").toStringList();
-    urlComboBox->addItems(m_history);
+    m_history = settings.value(u"URLDialog/history"_s).toStringList();
+    m_ui->urlComboBox->addItems(m_history);
     m_downloader = new PlayListDownloader(this);
-    connect(m_downloader, SIGNAL(finished(bool,QString)), SLOT(onFinished(bool,QString)));
+    connect(m_downloader, &PlayListDownloader::finished, this, &AddUrlDialog::onFinished);
 
     if(QmmpUiSettings::instance()->useClipboard())
     {
@@ -51,7 +52,7 @@ AddUrlDialog::AddUrlDialog(QWidget *parent) : QDialog(parent)
         if(url.isValid() && (MetaDataManager::instance()->protocols().contains(url.scheme()) ||
                              MetaDataManager::hasMatch(MetaDataManager::instance()->regExps(), url.toString())))
         {
-            urlComboBox->setEditText(QApplication::clipboard()->text().trimmed());
+            m_ui->urlComboBox->setEditText(QApplication::clipboard()->text().trimmed());
         }
     }
 }
@@ -61,7 +62,8 @@ AddUrlDialog::~AddUrlDialog()
     while (m_history.size() > HISTORY_SIZE)
         m_history.removeLast();
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.setValue("URLDialog/history", m_history);
+    settings.setValue(u"URLDialog/history"_s, m_history);
+    delete m_ui;
 }
 
 QPointer<AddUrlDialog> AddUrlDialog::m_instance = nullptr;
@@ -86,41 +88,41 @@ void AddUrlDialog::onFinished(bool ok, const QString &message)
     else
     {
         QMessageBox::warning(this, tr("Error"), message);
-        addButton->setEnabled(true);
+        m_ui->addButton->setEnabled(true);
     }
 }
 
 void AddUrlDialog::accept()
 {
-    addButton->setEnabled(false);
-    if(urlComboBox->currentText().isEmpty())
+    m_ui->addButton->setEnabled(false);
+    if(m_ui->urlComboBox->currentText().isEmpty())
     {
          QDialog::accept();
          return;
     }
 
-    QString path = urlComboBox->currentText().trimmed();
+    QString path = m_ui->urlComboBox->currentText().trimmed();
 
     if(QFile::exists(path)) //is local file
     {
-        m_model->add(path);
+        m_model->addPath(path);
         addToHistory(path);
         QDialog::accept();
         return;
     }
 
-    if(!path.startsWith("http://") && !path.contains("://"))
-        path.prepend("http://");
+    if(!path.startsWith(u"http://"_s) && !path.contains(u"://"_s))
+        path.prepend(u"http://"_s);
 
     if(MetaDataManager::hasMatch(MetaDataManager::instance()->regExps(), path))
     {
         addToHistory(path);
-        m_model->add(path);
+        m_model->addPath(path);
         QDialog::accept();
         return;
     }
 
-    if (path.startsWith("http://") || path.startsWith("https://")) //try to download playlist
+    if (path.startsWith(u"http://"_s) || path.startsWith(u"https://"_s)) //try to download playlist
     {
         m_downloader->start(QUrl(path), m_model);
         addToHistory(path);
@@ -129,13 +131,13 @@ void AddUrlDialog::accept()
 
     if(!MetaDataManager::instance()->protocols().contains(QUrl(path).scheme()))
     {
-        qWarning("AddUrlDialog: unsupported protocol");
+        qCWarning(core, "unsupported protocol");
         QDialog::reject();
         return;
     }
 
     addToHistory(path);
-    m_model->add(path);
+    m_model->addPath(path);
     QDialog::accept();
 }
 
