@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -62,12 +62,11 @@ private slots:
     void on_contentsWidget_currentItemChanged (QListWidgetItem *current, QListWidgetItem *previous);
     void on_preferencesButton_clicked();
     void on_informationButton_clicked();
-    void addGroupString(const QString &str);
-    void saveSettings();
     void on_treeWidget_itemChanged (QTreeWidgetItem *item, int column);
     void on_treeWidget_currentItemChanged (QTreeWidgetItem *current, QTreeWidgetItem *);
     void on_cueFontButton_clicked();
-
+    void saveSettings();
+    void updateGroupSettings();
 
 private:
     void readSettings();
