@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2018-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2018-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,20 +24,23 @@
 #include <QWidget>
 #include <QString>
 #include <qmmp/metadatamodel.h>
-#include "ui_covereditor.h"
 
 class CoverViewer;
 
+namespace Ui {
+class CoverEditor;
+}
+
 /**
    @internal
    @author Ilya Kotov <forkotov02@ya.ru>
 */
-
 class CoverEditor : public QWidget
 {
     Q_OBJECT
 public:
     explicit CoverEditor(MetaDataModel *model, const QString &coverPath, QWidget *parent = nullptr);
+    ~CoverEditor();
 
     bool isEditable() const;
     void save();
@@ -49,7 +52,7 @@ private slots:
     void on_saveAsButton_clicked();
 
 private:
-    Ui::CoverEditor m_ui;
+    Ui::CoverEditor *m_ui;
     MetaDataModel *m_model;
     CoverViewer *m_viewer;
     QString m_coverPath;
