@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,116 +18,103 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#include "playlistmodel.h"
+#include <QRandomGenerator>
 #include "groupedcontainer_p.h"
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-#define swapItemsAt swap
-#endif
-
 GroupedContainer::GroupedContainer()
-{}
-
-GroupedContainer::~GroupedContainer()
 {
-    clear();
+
 }
 
 void GroupedContainer::addTrack(PlayListTrack *track)
 {
     int firstIndex = 0, lastIndex = 0;
-    track->m_queued_index = -1;
     //insert if possible
     for(int i = 0; i < m_groups.count(); ++i)
     {
         if(i == 0)
         {
            firstIndex = 0;
-           lastIndex = m_groups[i]->count();
+           lastIndex = m_groups[i]->count() - 1;
         }
         else
         {
             firstIndex = lastIndex + 1;
-            lastIndex = firstIndex + m_groups[i]->count();
+            lastIndex = firstIndex + m_groups[i]->count() - 1;
         }
 
         if(track->groupName() == m_groups[i]->formattedTitle())
         {
-            m_groups[i]->trackList.append(track);
-            m_items.insert(lastIndex + 1, track);
+            m_groups[i]->m_trackList.append(track);
+            m_groups[i]->m_title2.clear();
+            m_tracks.insert(lastIndex + 1, track);
             m_update = true;
             return;
         }
     }
     PlayListGroup *group = new PlayListGroup(track->groupName());
-    group->trackList.append(track);
+    group->m_trackList.append(track);
+    group->m_title2.clear();
+    m_tracks.append(track);
     m_groups.append(group);
-    m_items.append(group);
-    m_items.append(track);
-    track->m_track_index = trackCount() - 1;
+
+    if(!m_update)
+    {
+        for(int j = 0; j < linesPerGroup(); ++j)
+        {
+            PlayListLine line = { .isGroup = true, .index = int(m_groups.count() - 1), .subindex = j };
+            m_lines << line;
+        }
+
+        m_lines << PlayListLine { .isGroup = false, .index = int(m_tracks.count() - 1), .subindex = 0 };
+    }
 }
 
 void GroupedContainer::addTracks(const QList<PlayListTrack *> &tracks)
 {
-    for(int i = 0; i < tracks.count(); ++i)
-    {
-        bool found = false;
-        tracks[i]->m_queued_index = -1;
-        for(int j = m_groups.count() - 1; j >= 0; --j)
-        {
-            if(m_groups.at(j)->formattedTitle() == tracks.at(i)->groupName())
-            {
-                found = true;
-                m_groups.at(j)->trackList.append(tracks[i]);
-                break;
-            }
-        }
-
-        if(found)
-            continue;
-
-        m_groups << new PlayListGroup(tracks.at(i)->groupName());
-        m_groups.last()->trackList.append(tracks.at(i));
-    }
-    m_update = true;
+    m_tracks.reserve(m_tracks.count() + tracks.count());
+    for(PlayListTrack *track : std::as_const(tracks))
+        addTrack(track);
 }
 
 int GroupedContainer::insertTrack(int index, PlayListTrack *track)
 {
     int firstIndex = 0, lastIndex = 0;
-    track->m_queued_index = -1;
     //insert if possible
     for(int i = 0; i < m_groups.count(); ++i)
     {
         if(i == 0)
         {
            firstIndex = 0;
-           lastIndex = m_groups[i]->count();
+           lastIndex = m_groups[i]->count() - 1;
         }
         else
         {
             firstIndex = lastIndex + 1;
-            lastIndex = firstIndex + m_groups[i]->count();
+            lastIndex = firstIndex + m_groups[i]->count() - 1;
         }
 
         if(track->groupName() == m_groups[i]->formattedTitle() &&
-                index > firstIndex && index <= lastIndex + 1)
+                index >= firstIndex && index <= lastIndex + 1)
         {
-            m_groups[i]->trackList.insert(index - firstIndex - 1, track);
+            m_groups[i]->m_trackList.insert(index - firstIndex, track);
+            m_groups[i]->m_title2.clear();
+            m_tracks.insert(index, track);
             m_update = true;
             return index;
         }
     }
     //just add otherwise
     addTrack(track);
-    return m_items.count() - 1;
+    return m_tracks.count() - 1;
 }
 
 void GroupedContainer::replaceTracks(const QList<PlayListTrack *> &tracks)
 {
-    for(PlayListGroup *g : qAsConst(m_groups))
+    for(PlayListGroup *g : std::as_const(m_groups))
     {
-        g->trackList.clear();
+        g->m_trackList.clear();
+        g->m_title2.clear();
     }
     clear();
     addTracks(tracks);
@@ -140,130 +127,63 @@ QList<PlayListGroup *> GroupedContainer::groups() const
 
 QList<PlayListTrack *> GroupedContainer::tracks() const
 {
-    QList<PlayListTrack *> trackList;
-    for(int i = 0; i < m_groups.count(); ++i)
-    {
-        trackList.append(m_groups[i]->trackList);
-    }
-    return trackList;
+    return m_tracks;
 }
 
-const QList<PlayListItem *> &GroupedContainer::items() const
+int GroupedContainer::groupCount() const
 {
-    updateCache();
-    return m_items;
-}
-
-int GroupedContainer::count() const
-{
-    updateCache();
-    return m_items.count();
+    return m_groups.count();
 }
 
 int GroupedContainer::trackCount() const
 {
-    updateCache();
-    return m_items.count() - m_groups.count();
+    return m_tracks.count();
 }
 
-QList<PlayListItem *> GroupedContainer::mid(int pos, int count) const
+QList<PlayListTrack *> GroupedContainer::mid(int pos, int count) const
 {
     updateCache();
-    return m_items.mid(pos, count);
+    return m_tracks.mid(pos, count);
 }
 
 bool GroupedContainer::isEmpty() const
 {
-    return m_groups.isEmpty();
-}
-
-bool GroupedContainer::isSelected(int index) const
-{
-    updateCache();
-    if (0 <= index && index < m_items.count())
-        return m_items.at(index)->isSelected();
-    return false;
-}
-
-void GroupedContainer::setSelected(int index, bool selected)
-{
-    updateCache();
-    if (0 <= index && index < m_items.count())// && !m_items.at(index)->isGroup())
-        m_items.at(index)->setSelected(selected);
+    return m_tracks.isEmpty();
 }
 
 void GroupedContainer::clearSelection()
 {
-    updateCache();
-    for(PlayListItem *item : qAsConst(m_items))
-    {
-        item->setSelected(false);
-    }
+    for(PlayListTrack *track : std::as_const(m_tracks))
+        track->setSelected(false);
+
+    for(PlayListGroup *group : std::as_const(m_groups))
+        group->setSelected(false);
 }
 
 int GroupedContainer::indexOf(PlayListItem *item) const
 {
-    updateCache();
-    return m_items.indexOf(item);
-}
-
-PlayListItem *GroupedContainer::item(int index) const
-{
-    updateCache();
-    if(index >= count() || index < 0)
-    {
-        qWarning("GroupedContainer: index is out of range");
-        return nullptr;
-    }
-    return m_items.at(index);
+    return item->isGroup() ? m_groups.indexOf(static_cast<PlayListGroup *>(item)) : m_tracks.indexOf(static_cast<PlayListTrack *>(item));
 }
 
 PlayListTrack *GroupedContainer::track(int index) const
 {
-    updateCache();
-    PlayListItem *i = item(index);
-    if(!i || i->isGroup())
-        return nullptr;
-    return static_cast<PlayListTrack *> (i);
+    if (0 <= index && index < m_tracks.count())
+        return m_tracks.at(index);
+
+    return nullptr;
 }
 
 PlayListGroup *GroupedContainer::group(int index) const
 {
-    PlayListItem *i = item(index);
-    if(i && i->isGroup())
-        return static_cast<PlayListGroup *> (i);
+    if (0 <= index && index < m_groups.count())
+        return m_groups.at(index);
+
     return nullptr;
 }
 
-bool GroupedContainer::contains(PlayListItem *item) const
+bool GroupedContainer::contains(PlayListTrack *track) const
 {
-    updateCache();
-    return m_items.contains(item);
-}
-
-int GroupedContainer::indexOfTrack(int index) const
-{
-    updateCache();
-    if(index >= count() || index < 0)
-    {
-        qWarning("GroupedContainer: index is out of range");
-        return -1;
-    }
-    return m_items.at(index)->trackIndex();
-}
-
-PlayListTrack *GroupedContainer::findTrack(int number) const
-{
-    int firstNumber = 0;
-    for(const PlayListGroup *group : qAsConst(m_groups))
-    {
-        if(number >= firstNumber && number < firstNumber + group->count())
-        {
-            return group->trackList.at(number - firstNumber);
-        }
-        firstNumber += group->count();
-    }
-    return nullptr;
+    return m_tracks.contains(track);
 }
 
 void GroupedContainer::removeTrack(PlayListTrack *track)
@@ -273,33 +193,32 @@ void GroupedContainer::removeTrack(PlayListTrack *track)
     {
         if((*it)->contains(track))
         {
-            (*it)->trackList.removeAll(track);
-            m_items.removeAll(track);
+            (*it)->m_trackList.removeAll(track);
+            (*it)->m_title2.clear();
+            m_tracks.removeAll(track);
             removeFromQueue(track);
             if((*it)->isEmpty())
             {
                 PlayListGroup *group = *it;
                 m_groups.removeAll(group);
-                m_items.removeAll(group);
                 delete group;
             }
-            return;
+            break;
         }
         ++it;
     }
 
-    removeFromQueue(track);
+    m_update = true;
 }
 
 void GroupedContainer::removeTracks(QList<PlayListTrack *> tracks)
 {
-    for(PlayListTrack *t : qAsConst(tracks))
+    for(PlayListTrack *t : std::as_const(tracks))
         removeTrack(t);
 }
 
 bool GroupedContainer::move(const QList<int> &indexes, int from, int to)
 {
-    updateCache();
     PlayListGroup *group = nullptr;
     int firstIndex = 0, lastIndex = 0;
 
@@ -308,15 +227,15 @@ bool GroupedContainer::move(const QList<int> &indexes, int from, int to)
         if(i == 0)
         {
            firstIndex = 0;
-           lastIndex = m_groups[i]->count();
+           lastIndex = m_groups[i]->count() - 1;
         }
         else
         {
             firstIndex = lastIndex + 1;
-            lastIndex = firstIndex + m_groups[i]->count();
+            lastIndex = firstIndex + m_groups[i]->count() - 1;
         }
 
-        if(from > firstIndex && from <= lastIndex && to > firstIndex && to <= lastIndex)
+        if(from >= firstIndex && from <= lastIndex && to >= firstIndex && to <= lastIndex)
         {
             group = m_groups.at(i);
             break;
@@ -326,46 +245,39 @@ bool GroupedContainer::move(const QList<int> &indexes, int from, int to)
     if(!group)
         return false;
 
-    for(int i : qAsConst(indexes))
+    for(int i : std::as_const(indexes))
     {
-        if(i <= firstIndex || i > lastIndex)
+        if(i < firstIndex || i > lastIndex)
             return false;
-        if(i + to - from - firstIndex - 1 >= group->count())
+        if(i + to - from > lastIndex)
             return false;
-        if(i + to - from - firstIndex - 1 < 0)
-            return false;
-        if(i + to - from < 0)
+        if(i + to - from < firstIndex)
             return false;
     }
 
     if (from > to)
     {
-        for(const int &i : qAsConst(indexes))
+        for(int i : std::as_const(indexes))
         {
             if (i + to - from < 0)
                 break;
-            else
-            {
-                m_items.move(i,i + to - from);
-                swapTrackNumbers(&m_items,i,i + to - from);
-                group->trackList.move(i - firstIndex - 1,
-                                      i + to - from  - firstIndex - 1);
-            }
+
+
+            m_tracks.move(i, i + to - from);
+            swapTrackNumbers(&m_tracks, i, i + to - from);
+            group->m_trackList.move(i - firstIndex, i + to - from - firstIndex);
         }
     }
     else
     {
         for (int i = indexes.count() - 1; i >= 0; i--)
         {
-            if (indexes[i] + to - from >= m_items.count())
+            if (indexes[i] + to - from >= m_tracks.count())
                 break;
-            else
-            {
-                m_items.move(indexes[i], indexes[i] + to - from);
-                swapTrackNumbers(&m_items,indexes[i], indexes[i] + to - from);
-                group->trackList.move(indexes[i] - firstIndex - 1,
-                                      indexes[i] + to - from - firstIndex - 1);
-            }
+
+            m_tracks.move(indexes[i], indexes[i] + to - from);
+            swapTrackNumbers(&m_tracks,indexes[i], indexes[i] + to - from);
+            group->m_trackList.move(indexes[i] - firstIndex, indexes[i] + to - from - firstIndex);
         }
     }
     return true;
@@ -373,11 +285,11 @@ bool GroupedContainer::move(const QList<int> &indexes, int from, int to)
 
 QList<PlayListTrack *> GroupedContainer::takeAllTracks()
 {
-    QList<PlayListTrack *> tracks;
-    for(PlayListGroup *g : qAsConst(m_groups))
+    QList<PlayListTrack *> tracks = m_tracks;
+    for(PlayListGroup *g : std::as_const(m_groups))
     {
-        tracks.append(g->trackList);
-        g->trackList.clear();
+        g->m_trackList.clear();
+        g->m_title2.clear();
     }
     clear();
     return tracks;
@@ -390,14 +302,15 @@ void GroupedContainer::clear()
     {
         delete m_groups.takeFirst();
     }
-    m_items.clear();
+    m_tracks.clear();
+    m_lines.clear();
 }
 
 void GroupedContainer::reverseList()
 {
     QList<PlayListTrack *> tracks = takeAllTracks();
 
-    for (int i = 0; i < tracks.size()/2 ;i++)
+    for (int i = 0; i < tracks.size() / 2 ;i++)
         tracks.swapItemsAt(i, tracks.size() - i - 1);
 
     addTracks(tracks);
@@ -405,21 +318,71 @@ void GroupedContainer::reverseList()
 
 void GroupedContainer::randomizeList()
 {
-    for(int i = 0; i < m_groups.count(); ++i)
+    QRandomGenerator *rg = QRandomGenerator::global();
+    QList<PlayListTrack *> tracks = takeAllTracks();
+
+    for (int i = 0; i < tracks.size(); i++)
+        tracks.swapItemsAt(rg->generate() % tracks.size(), rg->generate() % tracks.size());
+    addTracks(tracks);
+}
+
+int GroupedContainer::lineCount() const
+{
+    updateCache();
+    return m_lines.count();
+}
+
+PlayListItem *GroupedContainer::itemAtLine(int lineIndex) const
+{
+    updateCache();
+    if (lineIndex < 0 || lineIndex >= m_lines.count())
+        return nullptr;
+
+    PlayListLine line = m_lines.at(lineIndex);
+    if(line.isGroup)
+        return m_groups.at(line.index);
+
+    return m_tracks.at(line.index);
+}
+
+QList<PlayListItem *> GroupedContainer::itemsAtLines(int pos, int length) const
+{
+    updateCache();
+    QList<PlayListLine> lines = m_lines.mid(pos, length);
+    QList<PlayListItem *> out;
+    for(const PlayListLine &line : std::as_const(lines))
     {
-        for (int j = 0; j < m_groups[i]->trackList.size(); j++)
-        {
-            m_groups[i]->trackList.swapItemsAt(qrand() % m_groups[i]->trackList.size(),
-                                               qrand() % m_groups[i]->trackList.size());
-        }
+        if(line.isGroup)
+            out << m_groups.at(line.index);
+        else
+            out << m_tracks.at(line.index);
     }
 
-    for(int i = 0; i < m_groups.count(); ++i)
-    {
-        m_groups.swapItemsAt(qrand() % m_groups.size(), qrand() % m_groups.size());
-    }
+    return out;
+}
 
-    m_update = true;
+int GroupedContainer::subIndexOfLine(int lineIndex) const
+{
+    updateCache();
+    return m_lines[lineIndex].subindex;
+}
+
+int GroupedContainer::trackIndexAtLine(int lineIndex) const
+{
+    updateCache();
+    if(lineIndex < 0 || lineIndex >= m_lines.count())
+        return -1;
+
+    return m_lines[lineIndex].isGroup ? -1 : m_lines[lineIndex].index;
+}
+
+bool GroupedContainer::alternateColor(int lineIndex) const
+{
+    updateCache();
+    if(lineIndex < 0 || lineIndex >= m_lines.count())
+        return false;
+
+    return m_lines[lineIndex].alternateColor;
 }
 
 void GroupedContainer::updateCache() const
@@ -427,16 +390,40 @@ void GroupedContainer::updateCache() const
     if(!m_update)
         return;
 
-    m_items.clear();
+    int lines = linesPerGroup();
     int t = 0;
+    bool alternateColor = false;
 
-    for(int i = 0; i < m_groups.count(); ++i)
+    m_lines.clear();
+    m_lines.reserve(lines * m_groups.count() + m_tracks.count());
+
+    for(int g = 0; g < m_groups.count(); ++g)
     {
-        m_items.append(m_groups.at(i));
-        for(PlayListTrack *track : m_groups.at(i)->trackList)
+
+        for(int j = 0; j < lines; ++j)
         {
-            track->m_track_index = t++;
-            m_items.append(track);
+            PlayListLine line = {
+                .isGroup = true,
+                .index = g,
+                .subindex = j,
+                .alternateColor = alternateColor
+            };
+            m_lines << line;
+        }
+
+        alternateColor = !alternateColor;
+
+        for(PlayListTrack *track : std::as_const(m_groups.at(g)->m_trackList))
+        {
+            PlayListLine line = {
+                .isGroup = false,
+                .index = t++,
+                .subindex = 0,
+                .alternateColor = alternateColor
+            };
+            track->m_track_index = line.index;
+            m_lines << line;
+            alternateColor = !alternateColor;
         }
     }
     m_update = false;
