@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,16 +18,21 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
+#include "qmmpuisettings.h"
+#include "metadatahelper_p.h"
 #include "playlistgroup.h"
 
-PlayListGroup::PlayListGroup(const QString &name) : m_name(name)
-{}
+PlayListGroup::PlayListGroup(const QString &name) : m_title(name)
+{
+    m_settings = QmmpUiSettings::instance();
+    m_helper = MetaDataHelper::instance();
+}
 
 PlayListGroup::~PlayListGroup()
 {
-    while(!trackList.isEmpty())
+    while(!m_trackList.isEmpty())
     {
-        PlayListTrack* mf = trackList.takeFirst();
+        PlayListTrack* mf = m_trackList.takeFirst();
 
         if (mf->isUsed())
             mf->deleteLater();
@@ -36,38 +41,51 @@ PlayListGroup::~PlayListGroup()
     }
 }
 
-QString PlayListGroup::formattedTitle(int column)
+QString PlayListGroup::formattedTitle(int line) const
 {
-    Q_UNUSED(column);
-    return m_name;
+    if(line == 0)
+        return m_title;
+
+    if(line == 1)
+    {
+        if(m_title2.isEmpty())
+            m_title2 = formatTitle2();
+
+        return m_title2;
+    }
+
+    return QString();
 }
 
-QStringList PlayListGroup::formattedTitles()
+QStringList PlayListGroup::formattedTitles() const
 {
-    return QStringList() << m_name;
+    if(m_title2.isEmpty())
+        m_title2 = formatTitle2();
+
+    return { m_title, m_title2 };
 }
 
 bool PlayListGroup::contains(PlayListTrack *track) const
 {
-    return trackList.contains(track);
+    return m_trackList.contains(track);
 }
 
 bool PlayListGroup::isEmpty() const
 {
-    return trackList.isEmpty();
+    return m_trackList.isEmpty();
 }
 
 QList<PlayListTrack *> PlayListGroup::tracks() const
 {
-    return trackList;
+    return m_trackList;
 }
 
 int PlayListGroup::count() const
 {
-    return trackList.count();
+    return m_trackList.count();
 }
 
-QString PlayListGroup::formattedLength()
+QString PlayListGroup::formattedDuration() const
 {
     return QString();
 }
@@ -76,3 +94,39 @@ bool PlayListGroup::isGroup() const
 {
     return true;
 }
+
+QString PlayListGroup::firstTrackPath() const
+{
+    return m_trackList.isEmpty() ? QString() : m_trackList.constFirst()->path();
+}
+
+bool PlayListGroup::isCoverLoaded() const
+{
+    return m_isCoverLoaded;
+}
+
+QImage PlayListGroup::cover() const
+{
+    return m_cover;
+}
+
+void PlayListGroup::setCover(const QImage &cover)
+{
+    m_isCoverLoaded = true;
+    m_cover = cover;
+}
+
+QString PlayListGroup::formatTitle2() const
+{
+    if(m_trackList.isEmpty() || m_trackList.constFirst()->properties().isEmpty())
+        return QString();
+
+    qint64 duration = 0;
+    for(const PlayListTrack *t : std::as_const(m_trackList))
+        duration += t->duration();
+
+    TrackInfo info = *m_trackList.constFirst();
+    info.setDuration(duration);
+
+    return m_helper->groupFormatter2()->format(info);
+}
