@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,13 +18,10 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
+#include <QRandomGenerator>
 #include "qmmpuisettings.h"
 #include "playstate_p.h"
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-#define swapItemsAt swap
-#endif
-
 PlayState::PlayState(PlayListModel *model) : m_model(model)
 {
     m_ui_settings = QmmpUiSettings::instance();
@@ -32,20 +29,20 @@ PlayState::PlayState(PlayListModel *model) : m_model(model)
 
 ShufflePlayState::ShufflePlayState(PlayListModel * model) : PlayState(model)
 {
-    prepare();
+    ShufflePlayState::prepare();
 }
 
 bool ShufflePlayState::next()
 {
-    if(!m_model->count())
+    if(m_model->isEmpty())
         return false;
 
     if (m_shuffled_current >= m_shuffled_indexes.count() - 1)
     {
         if (!m_ui_settings->isRepeatableList())
             return false;
-        else
-            prepare();
+
+        prepare();
     }
     else
         m_shuffled_current = (m_shuffled_current + 1) % m_shuffled_indexes.count();
@@ -56,36 +53,34 @@ bool ShufflePlayState::next()
 
 int ShufflePlayState::nextIndex()
 {
-    if(!m_model->count())
+    if(m_model->isEmpty())
         return -1;
 
     if (m_shuffled_current >= m_shuffled_indexes.count() - 1)
     {
         if (!m_ui_settings->isRepeatableList())
             return -1;
-        else
-            prepare();
+
+        prepare();
     }
     return m_shuffled_indexes.at((m_shuffled_current + 1) % m_shuffled_indexes.count());
 }
 
 bool ShufflePlayState::previous()
 {
-    if(!m_model->count())
+    if(m_model->isEmpty())
         return false;
 
     if (m_shuffled_current <= 0)
     {
         if (!m_ui_settings->isRepeatableList())
             return false;
-        else
-        {
-            prepare();
-            m_shuffled_current = m_shuffled_indexes.count() - 1;
-        }
+
+        prepare();
+        m_shuffled_current = m_shuffled_indexes.count() - 1;
     }
 
-    if (m_model->count() > 1)
+    if (m_model->trackCount() > 1)
         m_shuffled_current--;
 
     return m_model->setCurrent(m_shuffled_indexes.at(m_shuffled_current));
@@ -93,15 +88,17 @@ bool ShufflePlayState::previous()
 
 void ShufflePlayState::prepare()
 {
+    QRandomGenerator *rg = QRandomGenerator::global();
+
     resetState();
-    for(int i = 0; i < m_model->count(); i++)
+    for(int i = 0; i < m_model->trackCount(); i++)
     {
-        if (i != m_model->currentIndex() && m_model->isTrack(i))
+        if (i != m_model->currentIndex())
             m_shuffled_indexes << i;
     }
 
     for (int i = 0; i < m_shuffled_indexes.count(); i++)
-        m_shuffled_indexes.swapItemsAt(i, qrand()%m_shuffled_indexes.size());
+        m_shuffled_indexes.swapItemsAt(i, rg->generate() % m_shuffled_indexes.size());
 
     m_shuffled_indexes.prepend(m_model->currentIndex());
 }
@@ -117,75 +114,42 @@ NormalPlayState::NormalPlayState(PlayListModel * model) : PlayState(model)
 
 bool NormalPlayState::next()
 {
-    if(!m_model->count())
+    if(m_model->isEmpty())
         return false;
 
-    if (m_ui_settings->isRepeatableList() && m_model->currentIndex() == m_model->count() - 1)
-    {
-        if(m_model->track(0))
-            return m_model->setCurrent(0);
-        else if(m_model->count() >= 2 && m_model->track(1))
-            return m_model->setCurrent(1);
-        else
-            return false;
-    }
+    if(m_ui_settings->isRepeatableList() && m_model->currentIndex() == m_model->trackCount() - 1)
+        return m_model->setCurrent(0);
 
-    if(m_model->currentIndex() + 1 >= m_model->count())
+    if(m_model->currentIndex() + 1 >= m_model->trackCount())
         return false;
-    else if(m_model->track((m_model->currentIndex() + 1)))
-        return m_model->setCurrent(m_model->currentIndex() + 1);
-    else if(m_model->currentIndex() + 2 > m_model->count() - 1)
-        return false;
-    else if(m_model->track(m_model->currentIndex() + 2))
-        return m_model->setCurrent(m_model->currentIndex() + 2);
-    return false;
+
+    return m_model->setCurrent(m_model->currentIndex() + 1);
 }
 
 bool NormalPlayState::previous()
 {
-    if(!m_model->count())
+    if(m_model->isEmpty())
         return false;
 
     if(m_ui_settings->isRepeatableList())
     {
-        if(m_model->currentIndex() == 1 && !m_model->isTrack(0))
-            return (m_model->setCurrent(m_model->count() - 1));
-        else if(m_model->currentIndex() == 0)
-            return m_model->setCurrent(m_model->count() - 1);
+        if(m_model->currentIndex() == 0)
+            return m_model->setCurrent(m_model->trackCount() - 1);
     }
 
-    if(m_model->currentIndex() == 1 && !m_model->isTrack(0))
+    if(m_model->currentIndex() == 0)
         return false;
-    else if(m_model->currentIndex() == 0)
-        return false;
-    else if(m_model->isTrack(m_model->currentIndex() - 1))
-        return m_model->setCurrent(m_model->currentIndex() - 1);
-    else if(m_model->currentIndex() >= 2 && m_model->isTrack(m_model->currentIndex() - 2))
-        return m_model->setCurrent(m_model->currentIndex() - 2);
-    return false;
+
+    return m_model->setCurrent(m_model->currentIndex() - 1);
 }
 
 int NormalPlayState::nextIndex()
 {
-    if(!m_model->count())
+    if(m_model->isEmpty())
         return -1;
 
-    if (m_model->currentIndex() == m_model->count() - 1)
-    {
-        if (m_ui_settings->isRepeatableList())
-        {
-            if(m_model->isTrack(0))
-                return 0;
-            else if(m_model->isTrack(1))
-                return 1;
-        }
-        return -1;
-    }
-    if(m_model->isTrack(m_model->currentIndex() + 1))
-        return m_model->currentIndex() + 1;
-    else if(m_model->currentIndex() + 2 > m_model->count() - 1)
-        return -1;
-    else if(m_model->isTrack(m_model->currentIndex() + 2))
-        return m_model->currentIndex() + 2;
-    return -1;
+    if (m_model->currentIndex() == m_model->trackCount() - 1)
+        return m_ui_settings->isRepeatableList() ? 0 : -1;
+
+    return m_model->currentIndex() + 1;
 }
