@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,12 +20,12 @@
 
 #include <QFileDialog>
 #include <QCoreApplication>
+#include <qmmp/qmmp.h>
 #include "qtfiledialog_p.h"
 
-
 FileDialog* QtFileDialogFactory::create()
 {
-    qDebug("QtFileDialogFactory::create()");
+    qCDebug(core) << Q_FUNC_INFO;
     return new QtFileDialog();
 }
 
@@ -33,7 +33,7 @@ FileDialogProperties QtFileDialogFactory::properties() const
 {
     FileDialogProperties properties;
     properties.name = tr("Qt File Dialog");
-    properties.shortName = "qt_dialog";
+    properties.shortName = u"qt_dialog"_s;
     properties.hasAbout = false;
     properties.modal = true;
     return properties;
@@ -48,7 +48,7 @@ QString QtFileDialogFactory::translation() const
 
 QtFileDialog::~QtFileDialog()
 {
-    qDebug("QtFileDialog::~QtFileDialog()");
+    qCDebug(core) << Q_FUNC_INFO;
 }
 
 QStringList QtFileDialog::exec(QWidget *parent, const QString &dir, FileDialog::Mode mode,
