@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2010-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -52,7 +52,7 @@ void TemplateEditor::createMenu()
 {
     MetaDataFormatterMenu *menu = new MetaDataFormatterMenu(MetaDataFormatterMenu::TITLE_MENU, this);
     m_ui->insertButton->setMenu(menu);
-    connect(menu, SIGNAL(patternSelected(QString)), m_ui->textEdit, SLOT(insertPlainText(QString)));
+    connect(menu, &MetaDataFormatterMenu::patternSelected, m_ui->textEdit, &QPlainTextEdit::insertPlainText);
 }
 
 void TemplateEditor::on_resetButton_clicked()
@@ -60,8 +60,8 @@ void TemplateEditor::on_resetButton_clicked()
     m_ui->textEdit->setPlainText(m_defaultTemplate);
 }
 
-QString TemplateEditor::getTemplate (QWidget *parent, const QString &title, const QString &text,
-                                     const QString &default_template, bool *ok)
+QString TemplateEditor::getTemplate(QWidget *parent, const QString &title, const QString &text,
+                                    const QString &default_template, bool *ok)
 {
     TemplateEditor *editor = new TemplateEditor(parent);
     editor->setWindowTitle(title);
@@ -75,11 +75,9 @@ QString TemplateEditor::getTemplate (QWidget *parent, const QString &title, cons
         editor->deleteLater();
         return t;
     }
-    else
-    {
-        if(ok)
-            *ok = false;
-        editor->deleteLater();
-        return QString();
-    }
+
+    if(ok)
+        *ok = false;
+    editor->deleteLater();
+    return QString();
 }
