@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -49,13 +49,13 @@ UiHelper::UiHelper(QObject *parent)
     m_instance = this;
     General::create(parent);
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    m_lastDir = settings.value("General/last_dir", QDir::homePath()).toString(); //last directory
+    m_lastDir = settings.value(u"General/last_dir"_s, QDir::homePath()).toString(); //last directory
 }
 
 UiHelper::~UiHelper()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.setValue("General/last_dir",m_lastDir);
+    settings.setValue(u"General/last_dir"_s, m_lastDir);
 }
 
 bool UiHelper::visibilityControl()
@@ -67,14 +67,12 @@ bool UiHelper::visibilityControl()
 
 void UiHelper::addAction(QAction *action, MenuType type)
 {
-    connect(action, SIGNAL(destroyed (QObject *)), SLOT(removeAction(QObject*)));
+    connect(action, &QAction::destroyed, this, qOverload<QObject *>(&UiHelper::removeAction));
 
     if(!m_menus[type].actions.contains(action))
     {
         m_menus[type].actions.append(action);
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
         action->setShortcutVisibleInContextMenu(true);
-#endif
     }
     if(m_menus[type].menu && !m_menus[type].menu->actions().contains(action))
     {
@@ -135,32 +133,32 @@ void UiHelper::registerMenu(UiHelper::MenuType type, QMenu *menu, bool autoHide,
 void UiHelper::addFiles(QWidget *parent, PlayListModel *model)
 {
     QStringList filters;
-    filters << tr("All Supported Bitstreams")+" (" +
-            MetaDataManager::instance()->nameFilters().join (" ") +")";
+    filters << tr("All Supported Bitstreams") +
+               QStringLiteral(" (%1)").arg(MetaDataManager::instance()->nameFilters().join(QChar::Space));
     filters << MetaDataManager::instance()->filters();
     m_model = model;
     FileDialog::popup(parent, FileDialog::PlayDirsFiles, &m_lastDir,
                       this, SLOT(addSelectedFiles(QStringList,bool)),
-                      tr("Select one or more files to open"), filters.join(";;"));
+                      tr("Select one or more files to open"), filters.join(u";;"_s));
 }
 
 void UiHelper::playFiles(QWidget *parent, PlayListModel *model)
 {
     QStringList filters;
-    filters << tr("All Supported Bitstreams")+" (" +
-            MetaDataManager::instance()->nameFilters().join (" ") +")";
+    filters << tr("All Supported Bitstreams") +
+               QStringLiteral(" (%1)").arg(MetaDataManager::instance()->nameFilters().join(QChar::Space));
     filters << MetaDataManager::instance()->filters();
     m_model = model;
     FileDialog::popup(parent, FileDialog::AddDirsFiles, &m_lastDir,
                       this, SLOT(playSelectedFiles(QStringList)),
-                      tr("Select one or more files to play"), filters.join(";;"));
+                      tr("Select one or more files to play"), filters.join(u";;"_s));
 
 }
 
 void UiHelper::addDirectory(QWidget *parent, PlayListModel *model)
 {
     FileDialog::popup(parent, FileDialog::AddDirs, &m_lastDir,
-                      model, SLOT(add(QStringList)),
+                      model, SLOT(addPaths(QStringList)),
                       tr("Choose a directory"));
 }
 
@@ -173,11 +171,11 @@ void UiHelper::loadPlayList(QWidget *parent, PlayListModel *model)
 {
     if(PlayListParser::nameFilters().isEmpty())
     {
-        qWarning("UiHelper: There is no registered playlist parsers");
+        qCWarning(core, "There is no registered playlist parsers");
         return;
     }
 
-    QString mask = tr("Playlist Files") + " (" + PlayListParser::nameFilters().join(" ") + ")";
+    QString mask = tr("Playlist Files") + QStringLiteral(" (%1)").arg(PlayListParser::nameFilters().join(QChar::Space));
     //TODO use nonmodal dialog and multiplier playlists
     QString f_path = FileDialog::getOpenFileName(parent, tr("Open Playlist"), m_lastDir, mask);
     if (!f_path.isEmpty())
@@ -194,38 +192,36 @@ void UiHelper::loadPlayList(QWidget *parent, PlayListModel *model)
 
 void UiHelper::savePlayList(QWidget *parent, PlayListModel *model)
 {
-    QStringList nameFilters = PlayListParser::nameFilters();
-
-    if(nameFilters.isEmpty())
+    if(PlayListParser::nameFilters().isEmpty())
     {
-        qWarning("UiHelper: There is no registered playlist parsers");
+        qCWarning(core, "There is no registered playlist parsers");
         return;
     }
 
     QStringList filters;
-    filters << tr("Playlist Files") + " (" + nameFilters.join(" ") + ")";
+    filters << tr("Playlist Files") + QStringLiteral(" (%1)").arg(PlayListParser::nameFilters().join(QChar::Space));
     filters << PlayListParser::filters();
     QString selectedFilter = filters.at(1);
-    QString f_name = FileDialog::getSaveFileName(parent, tr("Save Playlist"), m_lastDir + "/" +
-                                                 model->name(), filters.join(";;"), &selectedFilter);
+    QString f_name = FileDialog::getSaveFileName(parent, tr("Save Playlist"), m_lastDir + QLatin1Char('/') +
+                                                 model->name(), filters.join(u";;"_s), &selectedFilter);
 
     if(f_name.isEmpty())
         return;
 
     if(!PlayListParser::isPlayList(f_name)) //append selected extension
     {
-        QStringList selectedFilters = selectedFilter.section("(", 1).remove(")").split(" ");
+        QStringList selectedFilters = selectedFilter.section(QLatin1Char('('), 1).remove(QLatin1Char(')')).split(QChar::Space);
         if(selectedFilters.isEmpty())
             return;
 
-        QString ext = selectedFilters.first().remove("*"); //use first extension
+        QString ext = selectedFilters.first().remove(QLatin1Char('*')); //use first extension
         f_name.append(ext);
 
         QFileInfo info(f_name);
 
         if(info.exists())
         {
-            if (QMessageBox::question(parent, tr("Save Playlist"),  tr("%1 already exists.\nDo you want to replace it?")
+            if (QMessageBox::question(parent, tr("Save Playlist"), tr("%1 already exists.\nDo you want to replace it?")
                                       .arg(info.fileName()), QMessageBox::Ok | QMessageBox::Cancel) != QMessageBox::Ok)
             {
                 return;
@@ -279,6 +275,22 @@ void UiHelper::exit()
     qApp->quit();
 }
 
+void UiHelper::replaceAndPlay(const QStringList &paths)
+{
+    if(paths.isEmpty())
+        return;
+
+    SoundCore::instance()->stop();
+    PlayListModel *pl = PlayListManager::instance()->selectedPlayList();
+    PlayListManager::instance()->activatePlayList(pl);
+    pl->clear();
+
+    connect(pl, &PlayListModel::tracksAdded, MediaPlayer::instance(), &MediaPlayer::play);
+    connect(pl, &PlayListModel::tracksAdded, this, &UiHelper::disconnectPl);
+    connect(pl, &PlayListModel::loaderFinished, this, &UiHelper::disconnectPl);
+    pl->addPaths(paths);
+}
+
 UiHelper* UiHelper::instance()
 {
     return m_instance;
@@ -305,20 +317,14 @@ void UiHelper::addSelectedFiles(const QStringList &files, bool play)
     if(files.isEmpty() || !PlayListManager::instance()->playLists().contains(m_model))
         return;
     if(play)
-        playSelectedFiles(files);
+    {
+        PlayListManager::instance()->selectPlayList(m_model);
+        replaceAndPlay(files);
+    }
     else
-        m_model->add(files);
-}
-
-void UiHelper::playSelectedFiles(const QStringList &files)
-{
-    if(files.isEmpty() || !PlayListManager::instance()->playLists().contains(m_model))
-        return;
-    m_model->clear();
-    PlayListManager::instance()->activatePlayList(m_model);
-    connect(m_model, SIGNAL(trackAdded(PlayListTrack*)), MediaPlayer::instance(), SLOT(play()));
-    connect(m_model, SIGNAL(trackAdded(PlayListTrack*)), SLOT(disconnectPl()));
-    m_model->add(files);
+    {
+        m_model->addPaths(files);
+    }
 }
 
 void UiHelper::disconnectPl()
@@ -326,7 +332,8 @@ void UiHelper::disconnectPl()
     PlayListModel *model = qobject_cast<PlayListModel*>(sender());
     if(model)
     {
-        disconnect(model, SIGNAL(trackAdded(PlayListTrack*)), MediaPlayer::instance(), SLOT(play()));
-        disconnect(model, SIGNAL(trackAdded(PlayListTrack*)), this, SLOT(disconnectPl()));
+        disconnect(model, &PlayListModel::tracksAdded, MediaPlayer::instance(), &MediaPlayer::play);
+        disconnect(model, &PlayListModel::tracksAdded, this, &UiHelper::disconnectPl);
+        disconnect(model, &PlayListModel::loaderFinished, this, &UiHelper::disconnectPl);
     }
 }
