@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2011-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -37,8 +37,8 @@ void UiLoader::loadPlugins()
         return;
 
     m_cache = new QList<QmmpUiPluginCache*>;
-    QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
-    for(const QString &filePath : Qmmp::findPlugins("Ui"))
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    for(const QString &filePath : Qmmp::findPlugins(u"Ui"_s))
     {
         QmmpUiPluginCache *item = new QmmpUiPluginCache(filePath, &settings);
         if(item->hasError())
@@ -54,7 +54,7 @@ QList<UiFactory *> UiLoader::factories()
 {
     loadPlugins();
     QList<UiFactory *> list;
-    for(QmmpUiPluginCache *item : qAsConst(*m_cache))
+    for(QmmpUiPluginCache *item : std::as_const(*m_cache))
     {
         if(item->uiFactory())
             list.append(item->uiFactory());
@@ -66,7 +66,7 @@ QStringList UiLoader::names()
 {
     QStringList out;
     loadPlugins();
-    for(const QmmpUiPluginCache *item : qAsConst(*m_cache))
+    for(const QmmpUiPluginCache *item : std::as_const(*m_cache))
     {
         out << item->shortName();
     }
@@ -91,29 +91,29 @@ void UiLoader::select(const QString &name)
     loadPlugins();
     if(std::any_of(m_cache->cbegin(), m_cache->cend(), [name](QmmpUiPluginCache *item) { return item->shortName() == name; } ))
     {
-        QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
-        settings.setValue ("Ui/current_plugin", name);
+        QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+        settings.setValue (u"Ui/current_plugin"_s, name);
     }
 }
 
 UiFactory *UiLoader::selected()
 {
     loadPlugins();
-    QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
 #ifdef Q_OS_UNIX
-    QString defaultUi = QMMP_DEFAULT_UI;
+    QString defaultUi = QStringLiteral(QMMP_DEFAULT_UI);
     if(defaultUi == QLatin1String("skinned") && qApp->platformName() == QLatin1String("wayland"))
-        defaultUi = "qsui";
-    QString name = settings.value("Ui/current_plugin", defaultUi).toString();
+        defaultUi = u"qsui"_s;
+    QString name = settings.value(u"Ui/current_plugin"_s, defaultUi).toString();
 #else
-    QString name = settings.value("Ui/current_plugin", QMMP_DEFAULT_UI).toString();
+    QString name = settings.value(u"Ui/current_plugin"_s, QStringLiteral(QMMP_DEFAULT_UI)).toString();
 #endif
-    for(QmmpUiPluginCache *item : qAsConst(*m_cache))
+    for(QmmpUiPluginCache *item : std::as_const(*m_cache))
     {
         if(item->shortName() == name && item->uiFactory())
             return item->uiFactory();
     }
     if (!m_cache->isEmpty())
-        return m_cache->at(0)->uiFactory();
+        return m_cache->constFirst()->uiFactory();
     return nullptr;
 }
